diff --git a/.eslintignore b/.eslintignore
new file mode 100644
index 000000000000..315b45467795
--- /dev/null
+++ b/.eslintignore
@@ -0,0 +1,11 @@
+bower_components/**
+build/**
+docs/bower_components/**
+docs/app/assets/js/angular-bootstrap/**
+docs/config/templates/**
+node_modules/**
+lib/htmlparser/**
+src/angular.bind.js
+src/ngParseExt/ucd.js
+i18n/closure/**
+tmp/**
diff --git a/.eslintrc-base.json b/.eslintrc-base.json
new file mode 100644
index 000000000000..a22993a7761f
--- /dev/null
+++ b/.eslintrc-base.json
@@ -0,0 +1,116 @@
+{
+  "rules": {
+    // Rules are divided into sections from http://eslint.org/docs/rules/
+
+    // Possible errors
+    "comma-dangle": ["error", "never"],
+    "no-cond-assign": ["error", "except-parens"],
+    "no-constant-condition": ["error", {"checkLoops": false}],
+    "no-control-regex": "error",
+    "no-debugger": "error",
+    "no-dupe-args": "error",
+    "no-dupe-keys": "error",
+    "no-duplicate-case": "error",
+    "no-empty-character-class": "error",
+    "no-empty": "error",
+    "no-ex-assign": "error",
+    "no-extra-boolean-cast": "error",
+    "no-extra-semi": "error",
+    "no-func-assign": "error",
+    "no-inner-declarations": "error",
+    "no-invalid-regexp": "error",
+    "no-irregular-whitespace": "error",
+    "no-negated-in-lhs": "error",
+    "no-obj-calls": "error",
+    "no-regex-spaces": "error",
+    "no-sparse-arrays": "error",
+    "no-unreachable": "error",
+    "use-isnan": "error",
+    "no-unsafe-finally": "error",
+    "valid-typeof": "error",
+    "no-unexpected-multiline": "error",
+
+    // Best practices
+    "accessor-pairs": "error",
+    "array-callback-return": "error",
+    "eqeqeq": ["error", "allow-null"],
+    "no-alert": "error",
+    "no-caller": "error",
+    "no-case-declarations": "error",
+    "no-eval": "error",
+    "no-extend-native": "error",
+    "no-extra-bind": "error",
+    "no-extra-label": "error",
+    "no-fallthrough": "error",
+    "no-floating-decimal": "error",
+    "no-implied-eval": "error",
+    "no-invalid-this": "error",
+    "no-iterator": "error",
+    "no-multi-str": "error",
+    "no-new-func": "error",
+    "no-new-wrappers": "error",
+    "no-new": "error",
+    "no-octal-escape": "error",
+    "no-octal": "error",
+    "no-proto": "error",
+    "no-redeclare": "error",
+    "no-return-assign": "error",
+    "no-script-url": "error",
+    "no-self-assign": "error",
+    "no-self-compare": "error",
+    "no-sequences": "error",
+    "no-throw-literal": "error",
+    "no-unmodified-loop-condition": "error",
+    "no-unused-expressions": "error",
+    "no-unused-labels": "error",
+    "no-useless-call": "error",
+    "no-useless-concat": "error",
+    "no-useless-escape": "error",
+    "no-void": "error",
+    "no-with": "error",
+    "radix": "error",
+    "wrap-iife": ["error", "inside"],
+
+    // Strict mode
+    "strict": ["error", "global"],
+
+    // Variables
+    "no-delete-var": "error",
+    "no-label-var": "error",
+    "no-restricted-globals": ["error", "event"],
+    "no-shadow-restricted-names": "error",
+    "no-undef-init": "error",
+    "no-undef": "error",
+    "no-unused-vars": ["error", { "vars": "local", "args": "none" }],
+
+    // Node.js
+    "handle-callback-err": "error",
+
+    // Stylistic issues
+    "array-bracket-spacing": ["error", "never"],
+    "brace-style": ["error", "1tbs", { "allowSingleLine": true }],
+    "comma-style": ["error", "last"],
+    "eol-last": "error",
+    "keyword-spacing": "error",
+    "linebreak-style": ["error", "unix"],
+    "max-len": ["error", { "code": 200, "ignoreComments": true, "ignoreUrls": true }],
+    "new-cap": "error",
+    "new-parens": "error",
+    "no-array-constructor": "error",
+    "no-bitwise": "error",
+    "no-mixed-spaces-and-tabs": "error",
+    "no-multiple-empty-lines": ["error", { "max": 3, "maxEOF": 1 }],
+    "no-whitespace-before-property": "error",
+    "no-spaced-func": "error",
+    "no-trailing-spaces": "error",
+    "no-unneeded-ternary": "error",
+    "semi-spacing": "error",
+    "semi": "error",
+    "space-before-blocks": ["error", "always"],
+    "space-before-function-paren": ["error", "never"],
+    "space-in-parens": ["error", "never"],
+    "space-infix-ops": "error",
+    "space-unary-ops": ["error", { "words": true, "nonwords": false }],
+    "unicode-bom": ["error", "never"]
+  }
+}
diff --git a/.eslintrc-browser.json b/.eslintrc-browser.json
new file mode 100644
index 000000000000..44024664ae8f
--- /dev/null
+++ b/.eslintrc-browser.json
@@ -0,0 +1,17 @@
+{
+  "extends": "./.eslintrc-base.json",
+
+  "env": {
+    // Note: don't set `"browser": true`; code in "src/" should be compatible with
+    // non-browser environments like Node.js with a custom window implementation
+    // like jsdom. All browser globals should be taken from window.
+    "browser": false,
+    "node": false
+  },
+
+  "globals": {
+    "window": false,
+
+    "angular": false
+  }
+}
diff --git a/.eslintrc-node.json b/.eslintrc-node.json
new file mode 100644
index 000000000000..643f345d88e0
--- /dev/null
+++ b/.eslintrc-node.json
@@ -0,0 +1,8 @@
+{
+  "extends": "./.eslintrc-base.json",
+
+  "env": {
+    "browser": false,
+    "node": true
+  }
+}
diff --git a/.eslintrc-todo.json b/.eslintrc-todo.json
new file mode 100644
index 000000000000..a80e6722b527
--- /dev/null
+++ b/.eslintrc-todo.json
@@ -0,0 +1,26 @@
+{
+  // This config contains proposed rules that we'd like to have enabled but haven't
+  // converted the code to adhere yet. If a decision comes to not enable one of these
+  // rules, it should be removed from the file. Every rule that got enabled in the
+  // end should be moved from here to a respective section in .eslintrc.json
+
+  "rules": {
+    // Rules are divided into sections from http://eslint.org/docs/rules/
+
+    // Best practices
+    "complexity": ["error", 10],
+    "dot-notation": "error",
+    "dot-location": ["error", "property"],
+
+    // Stylistic issues
+    "block-spacing": ["error", "always"],
+    "comma-spacing": "error",
+    "id-blacklist": ["error", "event"],
+    "indent": ["error", 2],
+    "key-spacing": ["error", { "beforeColon": false, "afterColon": true, "mode": "minimum" }],
+    "object-curly-spacing": ["error", "never"],
+    "object-property-newline": ["error", { "allowMultiplePropertiesPerLine": true }],
+    "operator-linebreak": ["error", "after", { "overrides": { "?": "before", ":": "before" }}],
+    "quotes": ["error", "single"]
+  }
+}
diff --git a/.eslintrc.json b/.eslintrc.json
new file mode 100644
index 000000000000..d8de7a976909
--- /dev/null
+++ b/.eslintrc.json
@@ -0,0 +1,4 @@
+{
+  "root": true,
+  "extends": "./.eslintrc-node.json"
+}
diff --git a/.jscsrc b/.jscsrc
deleted file mode 100644
index 4d2b16f30bcd..000000000000
--- a/.jscsrc
+++ /dev/null
@@ -1,48 +0,0 @@
-{
-  "excludeFiles": ["src/ngLocale/**"],
-  "disallowKeywords": ["with"],
-  "disallowKeywordsOnNewLine": ["else"],
-  "disallowMixedSpacesAndTabs": true,
-  "disallowMultipleLineStrings": true,
-  "disallowNewlineBeforeBlockStatements": true,
-  "disallowSpaceAfterObjectKeys": true,
-  "disallowSpaceAfterPrefixUnaryOperators": ["++", "--", "+", "-", "~", "!"],
-  "disallowSpaceBeforeBinaryOperators": [","],
-  "disallowSpaceBeforePostfixUnaryOperators": ["++", "--"],
-  "disallowSpacesInAnonymousFunctionExpression": {
-    "beforeOpeningRoundBrace": true
-  },
-  "disallowSpacesInCallExpression": true,
-  "disallowSpacesInFunctionDeclaration": {
-    "beforeOpeningRoundBrace": true
-  },
-  "disallowSpacesInNamedFunctionExpression": {
-    "beforeOpeningRoundBrace": true
-  },
-  "disallowSpacesInsideArrayBrackets": true,
-  "requireSpaceBeforeKeywords": [
-    "else",
-    "while",
-    "catch"
-  ],
-  "disallowSpacesInsideParentheses": true,
-  "disallowTrailingComma": true,
-  "disallowTrailingWhitespace": true,
-  "requireCommaBeforeLineBreak": true,
-  "requireLineFeedAtFileEnd": true,
-  "requireSpaceAfterBinaryOperators": ["?", ":", "+", "-", "/", "*", "%", "==", "===", "!=", "!==", ">", ">=", "<", "<=", "&&", "||"],
-  "requireSpaceBeforeBinaryOperators": ["?", ":", "+", "-", "/", "*", "%", "==", "===", "!=", "!==", ">", ">=", "<", "<=", "&&", "||"],
-  "requireSpaceAfterKeywords": ["if", "else", "for", "while", "do", "switch", "return", "try", "catch"],
-  "requireSpaceBeforeBlockStatements": true,
-  "requireSpacesInConditionalExpression": {
-    "afterTest": true,
-    "beforeConsequent": true,
-    "afterConsequent": true,
-    "beforeAlternate": true
-  },
-  "requireSpacesInForStatement": true,
-  "requireSpacesInFunction": {
-    "beforeOpeningCurlyBrace": true
-  },
-  "validateLineBreaks": "LF"
-}
diff --git a/.jshintignore b/.jshintignore
deleted file mode 100644
index e9cc4f260316..000000000000
--- a/.jshintignore
+++ /dev/null
@@ -1,2 +0,0 @@
-node_modules/**
-lib/htmlparser/**
diff --git a/.jshintrc b/.jshintrc
deleted file mode 100644
index 7fbaafbc0a8c..000000000000
--- a/.jshintrc
+++ /dev/null
@@ -1,5 +0,0 @@
-{
-  "extends": ".jshintrc-base",
-  "node": true,
-  "globals": {}
-}
diff --git a/.jshintrc-base b/.jshintrc-base
deleted file mode 100644
index ace393873d38..000000000000
--- a/.jshintrc-base
+++ /dev/null
@@ -1,24 +0,0 @@
-{
-  "bitwise": true,
-  "esversion": 6,
-  "immed": true,
-  "newcap": true,
-  "noarg": true,
-  "noempty": true,
-  "nonew": true,
-  "maxlen": 200,
-  "boss": true,
-  "eqnull": true,
-  "expr": true,
-  "laxbreak": true,
-  "loopfunc": true,
-  "strict": "global",
-  "sub": true,
-  "undef": true,
-  "indent": 2,
-
-  "globals": {
-    "ArrayBuffer": false,
-    "Uint8Array": false
-  }
-}
diff --git a/Gruntfile.js b/Gruntfile.js
index e94084cb96cd..bf4b1470d621 100644
--- a/Gruntfile.js
+++ b/Gruntfile.js
@@ -18,7 +18,7 @@ module.exports = function(grunt) {
 
   var NG_VERSION = versionInfo.currentVersion;
   NG_VERSION.cdn = versionInfo.cdnVersion;
-  var dist = 'angular-'+ NG_VERSION.full;
+  var dist = 'angular-' + NG_VERSION.full;
 
   if (versionInfo.cdnVersion == null) {
     throw new Error('Unable to read CDN version, are you offline or has the CDN not been properly pushed?');
@@ -41,7 +41,7 @@ module.exports = function(grunt) {
           hostname: '0.0.0.0',
           base: '.',
           keepalive: true,
-          middleware: function(connect, options){
+          middleware: function(connect, options) {
             var base = Array.isArray(options.base) ? options.base[options.base.length - 1] : options.base;
             return [
               util.conditionalCsp(),
@@ -61,7 +61,7 @@ module.exports = function(grunt) {
           // to avoid https://github.com/joyent/libuv/issues/826
           port: 8000,
           hostname: '0.0.0.0',
-          middleware: function(connect, options){
+          middleware: function(connect, options) {
             var base = Array.isArray(options.base) ? options.base[options.base.length - 1] : options.base;
             return [
               function(req, resp, next) {
@@ -115,68 +115,24 @@ module.exports = function(grunt) {
       tmp: ['tmp']
     },
 
-    jshint: {
-      options: {
-        jshintrc: true,
-      },
-      node: {
-        files: { src: ['*.js', 'lib/**/*.js'] },
-      },
-      tests: {
-        files: { src: 'test/**/*.js' },
-      },
-      ng: {
-        files: { src: files['angularSrc'].concat('!src/angular.bind.js') },
-      },
-      ngAnimate: {
-        files: { src: 'src/ngAnimate/**/*.js' },
-      },
-      ngCookies: {
-        files: { src: 'src/ngCookies/**/*.js' },
-      },
-      ngLocale: {
-        files: { src: 'src/ngLocale/**/*.js' },
-      },
-      ngMessageFormat: {
-        files: { src: 'src/ngMessageFormat/**/*.js' },
-      },
-      ngMessages: {
-        files: { src: 'src/ngMessages/**/*.js' },
-      },
-      ngMock: {
-        files: { src: 'src/ngMock/**/*.js' },
-      },
-      ngParseExt: {
-        files: { src: 'src/ngParseExt/**/*.js' },
-      },
-      ngResource: {
-        files: { src: 'src/ngResource/**/*.js' },
-      },
-      ngRoute: {
-        files: { src: 'src/ngRoute/**/*.js' },
-      },
-      ngSanitize: {
-        files: { src: 'src/ngSanitize/**/*.js' },
-      },
-      ngScenario: {
-        files: { src: 'src/ngScenario/**/*.js' },
-      },
-      ngTouch: {
-        files: { src: 'src/ngTouch/**/*.js' },
-      },
-      ngAria: {
-        files: {src: 'src/ngAria/**/*.js'},
-      }
-    },
-
-    jscs: {
-      src: [
-        'src/**/*.js',
-        'test/**/*.js',
-        '!src/angular.bind.js' // we ignore this file since contains an early return statement
-      ],
-      options: {
-        config: '.jscsrc'
+    eslint: {
+      all: {
+        src: [
+          '*.js',
+          'benchmarks/**/*.js',
+          'docs/**/*.js',
+          'lib/**/*.js',
+          'scripts/**/*.js',
+          'src/**/*.js',
+          'test/**/*.js',
+          'i18n/**/*.js',
+          '!docs/app/assets/js/angular-bootstrap/**',
+          '!docs/bower_components/**',
+          '!docs/config/templates/**',
+          '!src/angular.bind.js',
+          '!i18n/closure/**',
+          '!src/ngParseExt/ucd.js'
+        ]
       }
     },
 
@@ -318,7 +274,7 @@ module.exports = function(grunt) {
 
     compress: {
       build: {
-        options: {archive: 'build/' + dist +'.zip', mode: 'zip'},
+        options: {archive: 'build/' + dist + '.zip', mode: 'zip'},
         src: ['**'],
         cwd: 'build',
         expand: true,
@@ -366,7 +322,7 @@ module.exports = function(grunt) {
 
 
   //alias tasks
-  grunt.registerTask('test', 'Run unit, docs and e2e tests with Karma', ['jshint', 'jscs', 'package', 'test:unit', 'test:promises-aplus', 'tests:docs', 'test:protractor']);
+  grunt.registerTask('test', 'Run unit, docs and e2e tests with Karma', ['eslint', 'package', 'test:unit', 'test:promises-aplus', 'tests:docs', 'test:protractor']);
   grunt.registerTask('test:jqlite', 'Run the unit tests with Karma' , ['tests:jqlite']);
   grunt.registerTask('test:jquery', 'Run the jQuery (latest) unit tests with Karma', ['tests:jquery']);
   grunt.registerTask('test:jquery-2.2', 'Run the jQuery 2.2 unit tests with Karma', ['tests:jquery-2.2']);
@@ -383,6 +339,6 @@ module.exports = function(grunt) {
   grunt.registerTask('minify', ['bower', 'clean', 'build', 'minall']);
   grunt.registerTask('webserver', ['connect:devserver']);
   grunt.registerTask('package', ['bower', 'validate-angular-files', 'clean', 'buildall', 'minall', 'collect-errors', 'docs', 'copy', 'write', 'compress']);
-  grunt.registerTask('ci-checks', ['ddescribe-iit', 'merge-conflict', 'jshint', 'jscs']);
+  grunt.registerTask('ci-checks', ['ddescribe-iit', 'merge-conflict', 'eslint']);
   grunt.registerTask('default', ['package']);
 };
diff --git a/angularFiles.js b/angularFiles.js
index 71edff31c567..e32d5da66d7b 100755
--- a/angularFiles.js
+++ b/angularFiles.js
@@ -244,10 +244,10 @@ var angularFiles = {
   ]
 };
 
-['2.1', '2.2'].forEach(function (jQueryVersion) {
+['2.1', '2.2'].forEach(function(jQueryVersion) {
   angularFiles['karmaJquery' + jQueryVersion] = []
     .concat(angularFiles.karmaJquery)
-    .map(function (path) {
+    .map(function(path) {
       if (path.startsWith('bower_components/jquery')) {
         return path.replace(/^bower_components\/jquery/, 'bower_components/jquery-' + jQueryVersion);
       }
@@ -276,7 +276,7 @@ if (exports) {
     Array.prototype.slice.call(arguments, 0).forEach(function(filegroup) {
       angularFiles[filegroup].forEach(function(file) {
         // replace @ref
-        var match = file.match(/^\@(.*)/);
+        var match = file.match(/^@(.*)/);
         if (match) {
           files = files.concat(angularFiles[match[1]]);
         } else {
diff --git a/benchmarks/.eslintrc.json b/benchmarks/.eslintrc.json
new file mode 100644
index 000000000000..aef8fadbe927
--- /dev/null
+++ b/benchmarks/.eslintrc.json
@@ -0,0 +1,11 @@
+{
+  "root": true,
+  "extends": "../.eslintrc-browser.json",
+
+  "globals": {
+    "benchmarkSteps": false,
+
+    // Benchmarks are not run in IE 9 so we're fine.
+    "console": false
+  }
+}
diff --git a/benchmarks/event-delegation-bp/app.js b/benchmarks/event-delegation-bp/app.js
index 237193ad4d6f..45d91a03fd9b 100644
--- a/benchmarks/event-delegation-bp/app.js
+++ b/benchmarks/event-delegation-bp/app.js
@@ -1,3 +1,5 @@
+'use strict';
+
 var app = angular.module('eventDelegationBenchmark', []);
 
 app.directive('noopDir', function() {
@@ -5,7 +7,7 @@ app.directive('noopDir', function() {
     compile: function($element, $attrs) {
       return function($scope, $element) {
         return 1;
-      }
+      };
     }
   };
 });
@@ -13,12 +15,12 @@ app.directive('noopDir', function() {
 app.directive('nativeClick', ['$parse', function($parse) {
   return {
     compile: function($element, $attrs) {
-      var expr = $parse($attrs.tstEvent);
+      $parse($attrs.tstEvent);
       return function($scope, $element) {
         $element[0].addEventListener('click', function() {
           console.log('clicked');
         }, false);
-      }
+      };
     }
   };
 }]);
@@ -26,13 +28,12 @@ app.directive('nativeClick', ['$parse', function($parse) {
 app.directive('dlgtClick', function() {
   return {
     compile: function($element, $attrs) {
-      var evt = $attrs.dlgtClick;
       // We don't setup the global event listeners as the costs are small and one time only...
     }
   };
 });
 
-app.controller('DataController', function($rootScope) {
+app.controller('DataController', function DataController($rootScope) {
   this.ngRepeatCount = 1000;
   this.rows = [];
   var self = this;
@@ -47,8 +48,8 @@ app.controller('DataController', function($rootScope) {
       self.rows = oldRows;
       if (self.rows.length !== self.ngRepeatCount) {
         self.rows = [];
-        for (var i=0; i<self.ngRepeatCount; i++) {
-          self.rows.push('row'+i);
+        for (var i = 0; i < self.ngRepeatCount; i++) {
+          self.rows.push('row' + i);
         }
       }
       $rootScope.$apply();
diff --git a/benchmarks/event-delegation-bp/bp.conf.js b/benchmarks/event-delegation-bp/bp.conf.js
index 066688edb8d9..d7a1837dddc9 100644
--- a/benchmarks/event-delegation-bp/bp.conf.js
+++ b/benchmarks/event-delegation-bp/bp.conf.js
@@ -1,10 +1,14 @@
+/* eslint-env node */
+
+'use strict';
+
 module.exports = function(config) {
   config.set({
     scripts: [{
       id: 'angular',
       src: '/build/angular.js'
-    },{
-      src: 'app.js',
+    }, {
+      src: 'app.js'
     }]
   });
 };
diff --git a/benchmarks/largetable-bp/app.js b/benchmarks/largetable-bp/app.js
index 10ddbe976218..9cf977ebb707 100644
--- a/benchmarks/largetable-bp/app.js
+++ b/benchmarks/largetable-bp/app.js
@@ -1,3 +1,5 @@
+'use strict';
+
 var app = angular.module('largetableBenchmark', []);
 
 app.config(function($compileProvider) {
@@ -12,21 +14,23 @@ app.filter('noop', function() {
   };
 });
 
-app.controller('DataController', function($scope, $rootScope) {
+app.controller('DataController', function DataController($scope, $rootScope) {
   var totalRows = 1000;
   var totalColumns = 20;
 
   var data = $scope.data = [];
   $scope.digestDuration = '?';
-  $scope.numberOfBindings = totalRows*totalColumns*2 + totalRows + 1;
+  $scope.numberOfBindings = totalRows * totalColumns * 2 + totalRows + 1;
   $scope.numberOfWatches = '?';
 
+  /* @this */
   function iGetter() { return this.i; }
+  /* @this */
   function jGetter() { return this.j; }
 
-  for (var i=0; i<totalRows; i++) {
+  for (var i = 0; i < totalRows; i++) {
     data[i] = [];
-    for (var j=0; j<totalColumns; j++) {
+    for (var j = 0; j < totalColumns; j++) {
       data[i][j] = {
         i: i, j: j,
         iFn: iGetter,
@@ -64,14 +68,13 @@ app.controller('DataController', function($scope, $rootScope) {
   });
 });
 
-var fn = function() { return 'x'};
-
 
 app.directive('baselineBindingTable', function() {
   return {
     restrict: 'E',
-    link: function ($scope, $element) {
+    link: function($scope, $element) {
       var i, j, row, cell, comment;
+      var document = window.document;
       var template = document.createElement('span');
       template.setAttribute('ng-repeat', 'foo in foos');
       template.classList.add('ng-scope');
@@ -104,8 +107,9 @@ app.directive('baselineBindingTable', function() {
 app.directive('baselineInterpolationTable', function() {
   return {
     restrict: 'E',
-    link: function ($scope, $element) {
+    link: function($scope, $element) {
       var i, j, row, cell, comment;
+      var document = window.document;
       var template = document.createElement('span');
       template.setAttribute('ng-repeat', 'foo in foos');
       template.classList.add('ng-scope');
@@ -180,4 +184,4 @@ app.directive('baselineTable', function() {
   };
 });
 
- */
\ No newline at end of file
+ */
diff --git a/benchmarks/largetable-bp/bp.conf.js b/benchmarks/largetable-bp/bp.conf.js
index a9e59b844df9..b428443b3c0a 100644
--- a/benchmarks/largetable-bp/bp.conf.js
+++ b/benchmarks/largetable-bp/bp.conf.js
@@ -1,3 +1,7 @@
+/* eslint-env node */
+
+'use strict';
+
 module.exports = function(config) {
   config.set({
     scripts: [{
@@ -9,7 +13,7 @@ module.exports = function(config) {
       src: '/build/angular.js'
     },
     {
-      src: 'app.js',
+      src: 'app.js'
     }]
   });
 };
diff --git a/benchmarks/largetable-bp/jquery-noop.js b/benchmarks/largetable-bp/jquery-noop.js
index 42eb0d42f08e..8cac7fe4a149 100644
--- a/benchmarks/largetable-bp/jquery-noop.js
+++ b/benchmarks/largetable-bp/jquery-noop.js
@@ -1 +1 @@
-//Override me with ?jquery=/bower_components/jquery/dist/jquery.js
+// Override me with ?jquery=/bower_components/jquery/dist/jquery.js
diff --git a/benchmarks/ng-options-bp/bp.conf.js b/benchmarks/ng-options-bp/bp.conf.js
index bf543bb2cef7..f506db816a97 100755
--- a/benchmarks/ng-options-bp/bp.conf.js
+++ b/benchmarks/ng-options-bp/bp.conf.js
@@ -1,11 +1,15 @@
+/* eslint-env node */
+
+'use strict';
+
 module.exports = function(config) {
   config.set({
-    scripts: [    {
+    scripts: [{
       id: 'angular',
       src: '/build/angular.js'
     },
     {
-      src: 'app.js',
+      src: 'app.js'
     }]
   });
 };
diff --git a/benchmarks/orderby-bp/app.js b/benchmarks/orderby-bp/app.js
index 9897a1fb3baf..849042b87980 100644
--- a/benchmarks/orderby-bp/app.js
+++ b/benchmarks/orderby-bp/app.js
@@ -1,6 +1,8 @@
+'use strict';
+
 var app = angular.module('orderByBenchmark', []);
 
-app.controller('DataController', function($rootScope, $scope) {
+app.controller('DataController', function DataController($rootScope, $scope) {
   this.ngRepeatCount = 5000;
   this.rows = [];
   var self = this;
@@ -37,7 +39,7 @@ app.controller('DataController', function($rootScope, $scope) {
         }
       }
     }
-  })
+  });
 
   benchmarkSteps.push({
     name: '$apply',
diff --git a/benchmarks/orderby-bp/bp.conf.js b/benchmarks/orderby-bp/bp.conf.js
index b8defd7909e1..5fe179be8623 100644
--- a/benchmarks/orderby-bp/bp.conf.js
+++ b/benchmarks/orderby-bp/bp.conf.js
@@ -1,14 +1,18 @@
+/* eslint-env node */
+
+'use strict';
+
 module.exports = function(config) {
   config.set({
     scripts: [
     {
       "id": "jquery",
       "src": "jquery-noop.js"
-    },{
+    }, {
       id: 'angular',
       src: '/build/angular.js'
-    },{
-      src: 'app.js',
+    }, {
+      src: 'app.js'
     }]
   });
 };
diff --git a/benchmarks/parsed-expressions-bp/app.js b/benchmarks/parsed-expressions-bp/app.js
index aa89894ae3eb..1323705b607d 100755
--- a/benchmarks/parsed-expressions-bp/app.js
+++ b/benchmarks/parsed-expressions-bp/app.js
@@ -1,3 +1,5 @@
+'use strict';
+
 var app = angular.module('parsedExpressionBenchmark', []);
 
 app.config(function($compileProvider) {
@@ -17,7 +19,7 @@ app.directive('bmPeWatch', function() {
   return {
     restrict: 'A',
     compile: function($element, $attrs) {
-      $element.text( $attrs.bmPeWatch );
+      $element.text($attrs.bmPeWatch);
       return function($scope, $element, $attrs) {
         $scope.$watch($attrs.bmPeWatch, function(val) {
           $element.text(val);
@@ -38,9 +40,9 @@ app.directive('bmPeWatchLiteral', function($parse) {
   return {
     restrict: 'A',
     compile: function($element, $attrs) {
-      $element.text( $attrs.bmPeWatchLiteral );
+      $element.text($attrs.bmPeWatchLiteral);
       return function($scope, $element, $attrs) {
-        $scope.$watch( $parse($attrs.bmPeWatchLiteral, retZero) );
+        $scope.$watch($parse($attrs.bmPeWatchLiteral, retZero));
       };
     }
   };
@@ -55,31 +57,31 @@ app.controller('DataController', function($scope, $rootScope) {
 
   $scope.func = function() { return star;};
 
-  for (var i=0; i<totalRows; i++) {
+  for (var i = 0; i < totalRows; i++) {
     data.push({
       index: i,
-      odd:   i%2 === 0,
-      even:  i%2 === 1,
-      str0: "foo-" + Math.random()*Date.now(),
-      str1: "bar-" + Math.random()*Date.now(),
-      str2: "baz-" + Math.random()*Date.now(),
-      num0:  Math.random()*Date.now(),
-      num1:  Math.random()*Date.now(),
-      num2:  Math.random()*Date.now(),
-      date0: new Date(Math.random()*Date.now()),
-      date1: new Date(Math.random()*Date.now()),
-      date2: new Date(Math.random()*Date.now()),
-      func: function(){ return star; },
-      obj: data[i-1],
-      keys: data[i-1] && (data[i-1].keys || Object.keys(data[i-1])),
-      constructor: data[i-1]
+      odd:   i % 2 === 0,
+      even:  i % 2 === 1,
+      str0: "foo-" + Math.random() * Date.now(),
+      str1: "bar-" + Math.random() * Date.now(),
+      str2: "baz-" + Math.random() * Date.now(),
+      num0:  Math.random() * Date.now(),
+      num1:  Math.random() * Date.now(),
+      num2:  Math.random() * Date.now(),
+      date0: new Date(Math.random() * Date.now()),
+      date1: new Date(Math.random() * Date.now()),
+      date2: new Date(Math.random() * Date.now()),
+      func: function() { return star; },
+      obj: data[i - 1],
+      keys: data[i - 1] && (data[i - 1].keys || Object.keys(data[i - 1])),
+      constructor: data[i - 1]
     });
   }
 
   benchmarkSteps.push({
     name: '$apply',
     fn: function() {
-      for (var i=0; i<50; i++) {
+      for (var i = 0; i < 50; i++) {
         $rootScope.$digest();
       }
     }
diff --git a/benchmarks/parsed-expressions-bp/bp.conf.js b/benchmarks/parsed-expressions-bp/bp.conf.js
index bf543bb2cef7..f506db816a97 100755
--- a/benchmarks/parsed-expressions-bp/bp.conf.js
+++ b/benchmarks/parsed-expressions-bp/bp.conf.js
@@ -1,11 +1,15 @@
+/* eslint-env node */
+
+'use strict';
+
 module.exports = function(config) {
   config.set({
-    scripts: [    {
+    scripts: [{
       id: 'angular',
       src: '/build/angular.js'
     },
     {
-      src: 'app.js',
+      src: 'app.js'
     }]
   });
 };
diff --git a/benchmarks/select-ng-value-bp/app.js b/benchmarks/select-ng-value-bp/app.js
index 033f55c23a27..ef53b3c00c94 100755
--- a/benchmarks/select-ng-value-bp/app.js
+++ b/benchmarks/select-ng-value-bp/app.js
@@ -20,7 +20,7 @@ app.controller('DataController', function($scope, $element) {
     $scope.groups = [];
     var i = 0;
     var group;
-    while(i < $scope.count) {
+    while (i < $scope.count) {
       if (i % 100 === 0) {
         group = {
           name: 'group-' + $scope.groups.length,
diff --git a/benchmarks/select-ng-value-bp/bp.conf.js b/benchmarks/select-ng-value-bp/bp.conf.js
index bf543bb2cef7..f506db816a97 100755
--- a/benchmarks/select-ng-value-bp/bp.conf.js
+++ b/benchmarks/select-ng-value-bp/bp.conf.js
@@ -1,11 +1,15 @@
+/* eslint-env node */
+
+'use strict';
+
 module.exports = function(config) {
   config.set({
-    scripts: [    {
+    scripts: [{
       id: 'angular',
       src: '/build/angular.js'
     },
     {
-      src: 'app.js',
+      src: 'app.js'
     }]
   });
 };
diff --git a/changelog.js b/changelog.js
index 994e0c4b1aeb..e33bb20747ed 100755
--- a/changelog.js
+++ b/changelog.js
@@ -38,7 +38,7 @@ var parseRawCommit = function(raw) {
 
   lines.forEach(function(line) {
     match = line.match(/(?:Closes|Fixes)\s#(\d+)/);
-    if (match) msg.closes.push(parseInt(match[1]));
+    if (match) msg.closes.push(parseInt(match[1], 10));
   });
 
   match = raw.match(/BREAKING CHANGE:([\s\S]*)/);
@@ -48,7 +48,7 @@ var parseRawCommit = function(raw) {
 
 
   msg.body = lines.join('\n');
-  match = msg.subject.match(/^(.*)\((.*)\)\:\s(.*)$/);
+  match = msg.subject.match(/^(.*)\((.*)\):\s(.*)$/);
 
   if (!match || !match[1] || !match[3]) {
     warn('Incorrect message: %s %s', msg.hash, msg.subject);
diff --git a/changelog.spec.js b/changelog.spec.js
index 03a279f067ad..b3b46ef5515c 100644
--- a/changelog.spec.js
+++ b/changelog.spec.js
@@ -67,7 +67,7 @@ describe('changelog.js', function() {
         module2: [{subject: 'breaking change 2'}]
       };
       var expectedOutput =
-          '\n' + '## test\n\n' +
+          '\n## test\n\n' +
           '- **module1:** breaking change 1\n' +
           '- **module2:** breaking change 2\n' +
           '\n';
@@ -92,7 +92,7 @@ describe('changelog.js', function() {
         ]
       };
       var expectedOutput =
-          '\n' + '## test\n\n' +
+          '\n## test\n\n' +
           '- **module1:**\n' +
           '  - breaking change 1.1\n' +
           '  - breaking change 1.2\n' +
diff --git a/compare-master-to-stable.js b/compare-master-to-stable.js
index d6ded7317a43..ab41b255f70d 100755
--- a/compare-master-to-stable.js
+++ b/compare-master-to-stable.js
@@ -9,72 +9,72 @@ var Q = require('q');
 var _ = require('lodash');
 var semver = require('semver');
 
-var exec = function (cmd) {
-  return function () {
+var exec = function(cmd) {
+  return function() {
     var args = Array.prototype.slice.call(arguments, 0);
     args.unshift(cmd);
     var fullCmd = util.format.apply(util, args);
-    return Q.nfcall(cp.exec, fullCmd).then(function (out) {
+    return Q.nfcall(cp.exec, fullCmd).then(function(out) {
       return out[0].split('\n');
     });
   };
 };
 
-var andThen = function (fn, after) {
-  return function () {
+var andThen = function(fn, after) {
+  return /* @this */ function() {
     return fn.apply(this, arguments).then(after);
   };
 };
 
-var oneArg = function (fn) {
-  return function (arg) {
+var oneArg = function(fn) {
+  return function(arg) {
     return fn(arg);
   };
 };
 
-var oneLine = function (lines) {
+var oneLine = function(lines) {
   return lines[0].trim();
 };
 
-var noArgs = function (fn) {
-  return function () {
+var noArgs = function(fn) {
+  return function() {
     return fn();
   };
 };
 
-var identity = function (i) { return i; };
+var identity = function(i) { return i; };
 
 // like Q.all, but runs the commands in series
 // useful for ensuring env state (like which branch is checked out)
-var allInSeries = function (fn) {
-  return function (args) {
+var allInSeries = function(fn) {
+  return function(args) {
     var results = [];
     var def;
     while (args.length > 0) {
-      (function (arg) {
+      (function(arg) {
         if (def) {
-          def = def.then(function () {
+          def = def.then(function() {
             return fn(arg);
           });
         } else {
           def = fn(arg);
         }
-        def = def.then(function (res) {
+        def = def.then(function(res) {
           results.push(res);
         });
-      }(args.pop()));
+      })(args.pop());
     }
-    return def.then(function () {
+    return def.then(function() {
       return results;
     });
   };
 };
 
-var compareBranches = function (left, right) {
+var compareBranches = function(left, right) {
   console.log('# These commits are in ' + left.name + ' but not in ' + right.name + '\n');
   console.log(_(left.log).
     difference(right.log).
-    map(function (line) {
+    map(function(line) {
       return left.full[left.log.indexOf(line)]; // lol O(n^2)
     }).
     value().
@@ -85,44 +85,43 @@ var checkout = oneArg(exec('git checkout %s'));
 
 var getCurrentBranch = andThen(noArgs(exec('git rev-parse --abbrev-ref HEAD')), oneLine);
 var getTags = noArgs(exec('git tag'));
-var getShaOfTag = oneArg(exec('git rev-list %s | head -n 1'));
 var getTheLog = oneArg(exec('git log --pretty=oneline %s..HEAD | cat'));
 
 // remember this so we can restore state
 var currentBranch;
 
 getCurrentBranch().
-then(function (branch) {
+then(function(branch) {
   currentBranch = branch;
 }).
 then(getTags).
-then(function (tags) {
+then(function(tags) {
   return tags.
     filter(semver.valid).
     map(semver.clean).
     sort(semver.rcompare);
 }).
-then(function (tags) {
-  var major = tags[0].split('.')[0];
+then(function(tags) {
+  var major = semver(tags[0]).major;
   return tags.
-    filter(function (ver) {
-      return semver(ver).major == major;
+    filter(function(ver) {
+      return semver(ver).major === major;
     });
 }).
-then(function (tags) {
+then(function(tags) {
   return _(tags).
-    groupBy(function (tag) {
+    groupBy(function(tag) {
       return tag.split('.')[1];
     }).
-    map(function (group) {
+    map(function(group) {
       return _.first(group);
     }).
-    map(function (tag) {
+    map(function(tag) {
       return 'v' + tag;
     }).
     value();
 }).
-then(function (tags) {
+then(function(tags) {
   var master = tags.pop();
   var stable = tags.pop();
 
@@ -131,38 +130,38 @@ then(function (tags) {
     { name: 'master', tag: master}
   ];
 }).
-then(allInSeries(function (branch) {
+then(allInSeries(function(branch) {
   return checkout(branch.name).
-    then(function () {
+    then(function() {
       return getTheLog(branch.tag);
     }).
-    then(function (log) {
+    then(function(log) {
       return log.
         filter(identity);
     }).
-    then(function (log) {
-      branch.full = log.map(function (line) {
+    then(function(log) {
+      branch.full = log.map(function(line) {
         line = line.split(' ');
         var sha = line.shift();
         var msg = line.join(' ');
         return sha + ((/fix\([^\)]+\):/i.test(msg))  ? ' * ' : '   ') + msg;
       });
-      branch.log = log.map(function (line) {
+      branch.log = log.map(function(line) {
         return line.substr(41);
       });
       return branch;
     });
 })).
-then(function (pairs) {
+then(function(pairs) {
   compareBranches(pairs[0], pairs[1]);
   console.log('\n');
   compareBranches(pairs[1], pairs[0]);
   return pairs;
 }).
-then(function () {
+then(function() {
   return checkout(currentBranch);
 }).
-catch(function (e) {
+catch(function(e) {
   console.log(e.stack);
 });
 
diff --git a/docs/app/assets/js/search-worker.js b/docs/app/assets/js/search-worker.js
index 318461ade8ad..22f3b6226a01 100644
--- a/docs/app/assets/js/search-worker.js
+++ b/docs/app/assets/js/search-worker.js
@@ -1,17 +1,18 @@
-"use strict";
-/* jshint browser: true */
-/* global importScripts, onmessage: true, postMessage, lunr */
+'use strict';
+
+/* eslint-env worker */
+/* global importScripts, lunr */
 
 // Load up the lunr library
 importScripts('../components/lunr.js-0.5.12/lunr.min.js');
 
 // Create the lunr index - the docs should be an array of object, each object containing
 // the path and search terms for a page
-var index = lunr(function() {
+var index = lunr(/* @this */function() {
   this.ref('path');
   this.field('titleWords', {boost: 50});
-  this.field('members', { boost: 40});
-  this.field('keywords', { boost : 20 });
+  this.field('members', {boost: 40});
+  this.field('keywords', {boost: 20});
 });
 
 // Retrieve the searchData which contains the information about each page to be indexed
@@ -25,13 +26,13 @@ searchDataRequest.onload = function() {
   searchData.forEach(function(page) {
     index.add(page);
   });
-  postMessage({ e: 'index-ready' });
+  postMessage({e: 'index-ready'});
 };
 searchDataRequest.open('GET', 'search-data.json');
 searchDataRequest.send();
 
 // The worker receives a message everytime the web app wants to query the index
-onmessage = function(oEvent) {
+self.onmessage = function(oEvent) {
   var q = oEvent.data.q;
   var hits = index.search(q);
   var results = [];
@@ -40,5 +41,5 @@ onmessage = function(oEvent) {
     results.push(hit.ref);
   });
   // The results of the query are sent back to the web app via a new message
-  postMessage({ e: 'query-ready', q: q, d: results });
-};
\ No newline at end of file
+  self.postMessage({e: 'query-ready', q: q, d: results});
+};
diff --git a/docs/app/e2e/.eslintrc.json b/docs/app/e2e/.eslintrc.json
new file mode 100644
index 000000000000..6a949b92ffc9
--- /dev/null
+++ b/docs/app/e2e/.eslintrc.json
@@ -0,0 +1,28 @@
+{
+  "root": true,
+  "extends": "../../../.eslintrc-node.json",
+
+
+  "env": {
+    "jasmine": true,
+    "protractor": true
+  },
+
+  "globals": {
+    /* testabilityPatch / matchers */
+    "inject": false,
+    "module": false,
+    "dealoc": false,
+    "_jQuery": false,
+    "_jqLiteMode": false,
+    "sortedHtml": false,
+    "childrenTagsOf": false,
+    "assertHidden": false,
+    "assertVisible": false,
+    "provideLog": false,
+    "spyOnlyCallsWithArgs": false,
+    "createMockStyleSheet": false,
+    "browserTrigger": false,
+    "jqLiteCacheSize": false
+  }
+}
diff --git a/docs/app/e2e/.jshintrc b/docs/app/e2e/.jshintrc
deleted file mode 100644
index 11e0f84740ec..000000000000
--- a/docs/app/e2e/.jshintrc
+++ /dev/null
@@ -1,45 +0,0 @@
-{
-  "extends": "../../../.jshintrc-base",
-
-  "globals": {
-
-    /* jasmine / karma */
-    "it": false,
-    "iit": false,
-    "describe": false,
-    "ddescribe": false,
-    "beforeEach": false,
-    "afterEach": false,
-    "expect": false,
-    "jasmine": false,
-    "spyOn": false,
-    "waits": false,
-    "waitsFor": false,
-    "runs": false,
-    "dump": false,
-
-    /* e2e */
-    "protractor": false,
-    "browser": false,
-    "element": false,
-    "by": false,
-    "$": false,
-    "$$": false,
-
-    /* testabilityPatch / matchers */
-    "inject": false,
-    "module": false,
-    "dealoc": false,
-    "_jQuery": false,
-    "_jqLiteMode": false,
-    "sortedHtml": false,
-    "childrenTagsOf": false,
-    "assertHidden": false,
-    "assertVisible": false,
-    "provideLog": false,
-    "spyOnlyCallsWithArgs": false,
-    "createMockStyleSheet": false,
-    "browserTrigger": false,
-    "jqLiteCacheSize": false
-  }
-}
diff --git a/docs/app/e2e/api-docs/api-pages.scenario.js b/docs/app/e2e/api-docs/api-pages.scenario.js
index 5c026bfa4feb..f30e4d1cffa7 100644
--- a/docs/app/e2e/api-docs/api-pages.scenario.js
+++ b/docs/app/e2e/api-docs/api-pages.scenario.js
@@ -12,7 +12,7 @@ describe("doc.angularjs.org", function() {
       expect(element(by.css('.view-source')).getAttribute('href')).toMatch(/https?:\/\/github\.com\/angular\/angular\.js\/tree\/.+\/src\/ng\/http\.js#L\d+/);
     });
 
-    it('should change the page content when clicking a link to a service', function () {
+    it('should change the page content when clicking a link to a service', function() {
       browser.get('build/docs/index.html');
 
       var ngBindLink = element(by.css('.definition-table td a[href="api/ng/directive/ngClick"]'));
@@ -23,7 +23,7 @@ describe("doc.angularjs.org", function() {
     });
 
 
-    it('should show the functioning input directive example', function () {
+    it('should show the functioning input directive example', function() {
       browser.get('build/docs/index.html#!/api/ng/directive/input');
 
       // Ensure that the page is loaded before trying to switch frames.
@@ -48,4 +48,4 @@ describe("doc.angularjs.org", function() {
       });
     });
   });
-});
\ No newline at end of file
+});
diff --git a/docs/app/e2e/api-docs/provider-pages.scenario.js b/docs/app/e2e/api-docs/provider-pages.scenario.js
index 5b9094c019e1..b83af4614d18 100644
--- a/docs/app/e2e/api-docs/provider-pages.scenario.js
+++ b/docs/app/e2e/api-docs/provider-pages.scenario.js
@@ -9,4 +9,4 @@ describe("provider pages", function() {
     expect(serviceLink.getAttribute('href')).toMatch(/api\/ng\/service\/\$compile/);
   });
 
-});
\ No newline at end of file
+});
diff --git a/docs/app/e2e/app.scenario.js b/docs/app/e2e/app.scenario.js
index 7dfe4b15434c..e8e675328845 100644
--- a/docs/app/e2e/app.scenario.js
+++ b/docs/app/e2e/app.scenario.js
@@ -2,7 +2,7 @@
 
 var webdriver = require('protractor/node_modules/selenium-webdriver');
 
-describe('docs.angularjs.org', function () {
+describe('docs.angularjs.org', function() {
 
   beforeEach(function() {
     // read and clear logs from previous tests
@@ -24,7 +24,7 @@ describe('docs.angularjs.org', function () {
   });
 
 
-  describe('App', function () {
+  describe('App', function() {
     // it('should filter the module list when searching', function () {
     //   browser.get();
     //   browser.waitForAngular();
@@ -38,7 +38,7 @@ describe('docs.angularjs.org', function () {
     // });
 
 
-    it('should change the page content when clicking a link to a service', function () {
+    it('should change the page content when clicking a link to a service', function() {
       browser.get('build/docs/index-production.html');
 
       var ngBindLink = element(by.css('.definition-table td a[href="api/ng/directive/ngClick"]'));
@@ -83,4 +83,4 @@ describe('docs.angularjs.org', function () {
 
   });
 
-});
\ No newline at end of file
+});
diff --git a/docs/app/src/.eslintrc.json b/docs/app/src/.eslintrc.json
new file mode 100644
index 000000000000..247b283233ea
--- /dev/null
+++ b/docs/app/src/.eslintrc.json
@@ -0,0 +1,12 @@
+{
+  "root": true,
+  "extends": "../../../.eslintrc-browser.json",
+
+  "globals": {
+    // ngMocks
+    "module": false,
+    "inject": true,
+
+    "lunr": false
+  }
+}
diff --git a/docs/app/src/app.js b/docs/app/src/app.js
index 157985f05705..607cc0f0e1ec 100644
--- a/docs/app/src/app.js
+++ b/docs/app/src/app.js
@@ -1,3 +1,5 @@
+'use strict';
+
 angular.module('docsApp', [
   'ngRoute',
   'ngCookies',
diff --git a/docs/app/src/directives.js b/docs/app/src/directives.js
index c7c14eda1e3f..229da10f3bc3 100644
--- a/docs/app/src/directives.js
+++ b/docs/app/src/directives.js
@@ -1,3 +1,5 @@
+'use strict';
+
 angular.module('directives', [])
 
 /**
diff --git a/docs/app/src/docs.js b/docs/app/src/docs.js
index 44524e38b771..fb6a35565e8c 100644
--- a/docs/app/src/docs.js
+++ b/docs/app/src/docs.js
@@ -1,3 +1,5 @@
+'use strict';
+
 angular.module('DocsController', [])
 
 .controller('DocsController', [
@@ -27,9 +29,9 @@ angular.module('DocsController', [])
 
     path = path.replace(/^\/?(.+?)(\/index)?\/?$/, '$1');
 
-    currentPage = $scope.currentPage = NG_PAGES[path];
+    var currentPage = $scope.currentPage = NG_PAGES[path];
 
-    if ( currentPage ) {
+    if (currentPage) {
       $scope.partialPath = 'partials/' + path + '.html';
       $scope.currentArea = NG_NAVIGATION[currentPage.area];
       var pathParts = currentPage.path.split('/');
@@ -37,7 +39,7 @@ angular.module('DocsController', [])
       var breadcrumbPath = '';
       angular.forEach(pathParts, function(part) {
         breadcrumbPath += part;
-        breadcrumb.push({ name: (NG_PAGES[breadcrumbPath]&&NG_PAGES[breadcrumbPath].name) || part, url: breadcrumbPath });
+        breadcrumb.push({ name: (NG_PAGES[breadcrumbPath] && NG_PAGES[breadcrumbPath].name) || part, url: breadcrumbPath });
         breadcrumbPath += '/';
       });
     } else {
diff --git a/docs/app/src/errors.js b/docs/app/src/errors.js
index 79f508ec3447..2d9f8b5d91e1 100644
--- a/docs/app/src/errors.js
+++ b/docs/app/src/errors.js
@@ -1,23 +1,25 @@
+'use strict';
+
 angular.module('errors', ['ngSanitize'])
 
-.filter('errorLink', ['$sanitize', function ($sanitize) {
-  var LINKY_URL_REGEXP = /((ftp|https?):\/\/|(mailto:)?[A-Za-z0-9._%+-]+@)\S*[^\s\.\;\,\(\)\{\}<>]/g,
+.filter('errorLink', ['$sanitize', function($sanitize) {
+  var LINKY_URL_REGEXP = /((ftp|https?):\/\/|(mailto:)?[A-Za-z0-9._%+-]+@)\S*[^\s\.;,\(\)\{\}<>]/g,
       MAILTO_REGEXP = /^mailto:/,
       STACK_TRACE_REGEXP = /:\d+:\d+$/;
 
-  var truncate = function (text, nchars) {
+  var truncate = function(text, nchars) {
     if (text.length > nchars) {
       return text.substr(0, nchars - 3) + '...';
     }
     return text;
   };
 
-  return function (text, target) {
+  return function(text, target) {
     if (!text) return text;
 
     var targetHtml = target ? ' target="' + target + '"' : '';
 
-    return $sanitize(text.replace(LINKY_URL_REGEXP, function (url) {
+    return $sanitize(text.replace(LINKY_URL_REGEXP, function(url) {
       if (STACK_TRACE_REGEXP.test(url)) {
         return url;
       }
@@ -25,7 +27,7 @@ angular.module('errors', ['ngSanitize'])
       // if we did not match ftp/http/mailto then assume mailto
       if (!/^((ftp|https?):\/\/|mailto:)/.test(url)) url = 'mailto:' + url;
 
-      return '<a' + targetHtml + ' href="' + url +'">' +
+      return '<a' + targetHtml + ' href="' + url + '">' +
                 truncate(url.replace(MAILTO_REGEXP, ''), 60) +
               '</a>';
     }));
@@ -33,33 +35,33 @@ angular.module('errors', ['ngSanitize'])
 }])
 
 
-.directive('errorDisplay', ['$location', 'errorLinkFilter', function ($location, errorLinkFilter) {
-  var encodeAngleBrackets = function (text) {
+.directive('errorDisplay', ['$location', 'errorLinkFilter', function($location, errorLinkFilter) {
+  var encodeAngleBrackets = function(text) {
     return text.replace(/</g, '&lt;').replace(/>/g, '&gt;');
   };
 
-  var interpolate = function (formatString) {
+  var interpolate = function(formatString) {
     var formatArgs = arguments;
-    return formatString.replace(/\{\d+\}/g, function (match) {
+    return formatString.replace(/\{\d+\}/g, function(match) {
       // Drop the braces and use the unary plus to convert to an integer.
       // The index will be off by one because of the formatString.
       var index = +match.slice(1, -1);
       if (index + 1 >= formatArgs.length) {
         return match;
       }
-      return formatArgs[index+1];
+      return formatArgs[index + 1];
     });
   };
 
   return {
-    link: function (scope, element, attrs) {
+    link: function(scope, element, attrs) {
       var search = $location.search(),
         formatArgs = [attrs.errorDisplay],
         formattedText,
         i;
 
-      for (i = 0; angular.isDefined(search['p'+i]); i++) {
-        formatArgs.push(search['p'+i]);
+      for (i = 0; angular.isDefined(search['p' + i]); i++) {
+        formatArgs.push(search['p' + i]);
       }
 
       formattedText = encodeAngleBrackets(interpolate.apply(null, formatArgs));
diff --git a/docs/app/src/examples.js b/docs/app/src/examples.js
index eaafd82f93b2..b6e8d5760256 100644
--- a/docs/app/src/examples.js
+++ b/docs/app/src/examples.js
@@ -1,8 +1,9 @@
+'use strict';
+
 angular.module('examples', [])
 
-.directive('runnableExample', ['$templateCache', '$document', function($templateCache, $document) {
+.directive('runnableExample', [function() {
   var exampleClassNameSelector = '.runnable-example-file';
-  var doc = $document[0];
   var tpl =
     '<nav class="runnable-example-tabs" ng-if="tabs">' +
     '  <a ng-class="{active:$index==activeTabIndex}"' +
@@ -29,12 +30,12 @@ angular.module('examples', [])
       return function(scope, element) {
         var node = element[0];
         var examples = node.querySelectorAll(exampleClassNameSelector);
-        var tabs = [], now = Date.now();
+        var tabs = [];
         angular.forEach(examples, function(child, index) {
           tabs.push(child.getAttribute('name'));
         });
 
-        if(tabs.length > 0) {
+        if (tabs.length > 0) {
           scope.tabs = tabs;
           scope.$on('tabChange', function(e, index, title) {
             angular.forEach(examples, function(child) {
@@ -101,7 +102,7 @@ angular.module('examples', [])
     },
     controllerAs: 'plnkr',
     template: '<button ng-click="plnkr.open($event)" class="btn pull-right"> <i class="glyphicon glyphicon-edit">&nbsp;</i> Edit in Plunker</button> ',
-    controller: [function() {
+    controller: [function PlnkrOpenerCtrl() {
       var ctrl = this;
 
       ctrl.example = {
@@ -167,7 +168,7 @@ angular.module('examples', [])
 }])
 
 .factory('getExampleData', ['$http', '$q', function($http, $q) {
-  return function(exampleFolder){
+  return function(exampleFolder) {
     // Load the manifest for the example
     return $http.get(exampleFolder + '/manifest.json')
       .then(function(response) {
@@ -199,4 +200,4 @@ angular.module('examples', [])
         });
       });
   };
-}]);
\ No newline at end of file
+}]);
diff --git a/docs/app/src/search.js b/docs/app/src/search.js
index 7b064763b728..5a49b11bc104 100644
--- a/docs/app/src/search.js
+++ b/docs/app/src/search.js
@@ -1,3 +1,5 @@
+'use strict';
+
 angular.module('search', [])
 
 .controller('DocsSearchCtrl', ['$scope', '$location', 'docsSearch', function($scope, $location, docsSearch) {
@@ -9,7 +11,7 @@ angular.module('search', [])
 
   $scope.search = function(q) {
     var MIN_SEARCH_LENGTH = 2;
-    if(q.length >= MIN_SEARCH_LENGTH) {
+    if (q.length >= MIN_SEARCH_LENGTH) {
       docsSearch(q).then(function(hits) {
         // Make sure the areas are always in the same order
         var results = {
@@ -23,28 +25,24 @@ angular.module('search', [])
         angular.forEach(hits, function(hit) {
           var area = hit.area;
 
-          var limit = (area == 'api') ? 40 : 14;
+          var limit = (area === 'api') ? 40 : 14;
           results[area] = results[area] || [];
-          if(results[area].length < limit) {
+          if (results[area].length < limit) {
             results[area].push(hit);
           }
         });
 
-        var totalAreas = 0;
-        for(var i in results) {
-          ++totalAreas;
-        }
-        if(totalAreas > 0) {
+        var totalAreas = Object.keys(results).length;
+        if (totalAreas > 0) {
           $scope.colClassName = 'cols-' + totalAreas;
         }
         $scope.hasResults = totalAreas > 0;
         $scope.results = results;
       });
-    }
-    else {
+    } else {
       clearResults();
     }
-    if(!$scope.$$phase) $scope.$apply();
+    if (!$scope.$$phase) $scope.$apply();
   };
 
   $scope.submit = function() {
@@ -52,14 +50,14 @@ angular.module('search', [])
     if ($scope.results.api) {
       result = $scope.results.api[0];
     } else {
-      for(var i in $scope.results) {
+      for (var i in $scope.results) {
         result = $scope.results[i][0];
-        if(result) {
+        if (result) {
           break;
         }
       }
     }
-    if(result) {
+    if (result) {
       $location.path(result.path);
       $scope.hideResults();
     }
@@ -92,10 +90,12 @@ angular.module('search', [])
   // It should only be used where the browser does not support WebWorkers
   function localSearchFactory($http, $timeout, NG_PAGES) {
 
-    console.log('Using Local Search Index');
+    if (window.console && window.console.log) {
+      window.console.log('Using Local Search Index');
+    }
 
     // Create the lunr index
-    var index = lunr(function() {
+    var index = lunr(/* @this */ function() {
       this.ref('path');
       this.field('titleWords', {boost: 50});
       this.field('members', { boost: 40});
@@ -136,12 +136,14 @@ angular.module('search', [])
   // It should only be used where the browser does support WebWorkers
   function webWorkerSearchFactory($q, $rootScope, NG_PAGES) {
 
-    console.log('Using WebWorker Search Index')
+    if (window.console && window.console.log) {
+      window.console.log('Using WebWorker Search Index');
+    }
 
     var searchIndex = $q.defer();
     var results;
 
-    var worker = new Worker('js/search-worker.js');
+    var worker = new window.Worker('js/search-worker.js');
 
     // The worker will send us a message in two situations:
     // - when the index has been built, ready to run a query
@@ -149,7 +151,7 @@ angular.module('search', [])
     worker.onmessage = function(oEvent) {
       $rootScope.$apply(function() {
 
-        switch(oEvent.data.e) {
+        switch (oEvent.data.e) {
           case 'index-ready':
             searchIndex.resolve();
             break;
@@ -206,7 +208,7 @@ angular.module('search', [])
         FORWARD_SLASH_KEYCODE = 191;
     angular.element($document[0].body).on('keydown', function(event) {
       var input = element[0];
-      if(event.keyCode == FORWARD_SLASH_KEYCODE && document.activeElement != input) {
+      if (event.keyCode === FORWARD_SLASH_KEYCODE && window.document.activeElement !== input) {
         event.stopPropagation();
         event.preventDefault();
         input.focus();
@@ -214,7 +216,7 @@ angular.module('search', [])
     });
 
     element.on('keydown', function(event) {
-      if(event.keyCode == ESCAPE_KEY_KEYCODE) {
+      if (event.keyCode === ESCAPE_KEY_KEYCODE) {
         event.stopPropagation();
         event.preventDefault();
         scope.$apply(function() {
diff --git a/docs/app/src/tutorials.js b/docs/app/src/tutorials.js
index 09df4138fc96..2a020281045f 100644
--- a/docs/app/src/tutorials.js
+++ b/docs/app/src/tutorials.js
@@ -1,3 +1,5 @@
+'use strict';
+
 angular.module('tutorials', [])
 
 .directive('docTutorialNav', function() {
@@ -20,7 +22,7 @@ angular.module('tutorials', [])
       scope.seq = seq;
       scope.prev = pages[seq];
       scope.next = pages[2 + seq];
-      scope.diffLo = seq ? (seq - 1): '0~1';
+      scope.diffLo = seq ? (seq - 1) : '0~1';
       scope.diffHi = seq;
 
       element.addClass('btn-group');
@@ -40,7 +42,7 @@ angular.module('tutorials', [])
       '<div class="alert alert-info" ng-show="show">\n' +
       '  <p>Reset the workspace to step {{step}}.</p>' +
       '  <p><pre>git checkout -f step-{{step}}</pre></p>\n' +
-      '  <p>Refresh your browser or check out this step online: '+
+      '  <p>Refresh your browser or check out this step online: ' +
           '<a href="http://angular.github.io/angular-phonecat/step-{{step}}/app">Step {{step}} Live Demo</a>.</p>\n' +
       '</div>\n' +
       '<p>The most important changes are listed below. You can see the full diff on ' +
diff --git a/docs/app/src/versions.js b/docs/app/src/versions.js
index 4f299c265bf2..d9f4ab0507f5 100644
--- a/docs/app/src/versions.js
+++ b/docs/app/src/versions.js
@@ -1,4 +1,4 @@
-"use strict";
+'use strict';
 
 angular.module('versions', [])
 
@@ -6,7 +6,7 @@ angular.module('versions', [])
   $scope.docs_version  = NG_VERSIONS[0];
   $scope.docs_versions = NG_VERSIONS;
 
-  for(var i=0, minor = NaN; i < NG_VERSIONS.length; i++) {
+  for (var i = 0, minor = NaN; i < NG_VERSIONS.length; i++) {
     var version = NG_VERSIONS[i];
     // NaN will give false here
     if (minor <= version.minor) {
@@ -25,7 +25,7 @@ angular.module('versions', [])
         url = '';
     if (version.isOldDocsUrl) {
       url = version.docsUrl;
-    }else{
+    } else {
       url = version.docsUrl + currentPagePath;
     }
     $window.location = url;
diff --git a/docs/app/test/.eslintrc.json b/docs/app/test/.eslintrc.json
new file mode 100644
index 000000000000..c972310be12c
--- /dev/null
+++ b/docs/app/test/.eslintrc.json
@@ -0,0 +1,23 @@
+{
+  "root": true,
+  "extends": "../../../.eslintrc-browser.json",
+
+  "env": {
+    "jasmine": true
+  },
+
+  "rules": {
+    // Some rules are not that important in tests and conflict with
+    // Jasmine or would make it easier to write some tests; we disable
+    // those ones here.
+    "no-invalid-this": "off",
+    "no-throw-literal": "off",
+    "no-unused-vars": "off"
+  },
+
+  "globals": {
+    // ngMocks
+    "module": false,
+    "inject": true
+  }
+}
diff --git a/docs/app/test/.jshintrc b/docs/app/test/.jshintrc
deleted file mode 100644
index f9d367561198..000000000000
--- a/docs/app/test/.jshintrc
+++ /dev/null
@@ -1,25 +0,0 @@
-{
-  "extends": "../../../.jshintrc-base",
-  "browser": true,
-  "globals": {
-    // AngularJS
-    "angular": false,
-
-    // ngMocks
-    "module": false,
-    "inject": true,
-
-    // Jasmine
-    "jasmine": false,
-    "describe": false,
-    "ddescribe": false,
-    "xdescribe": false,
-    "it": false,
-    "iit": false,
-    "xit": false,
-    "beforeEach": false,
-    "afterEach": false,
-    "spyOn": false,
-    "expect": false
-  }
-}
diff --git a/docs/app/test/directivesSpec.js b/docs/app/test/directivesSpec.js
index 549e90e4d00b..7966bb4be7f6 100644
--- a/docs/app/test/directivesSpec.js
+++ b/docs/app/test/directivesSpec.js
@@ -1,3 +1,5 @@
+'use strict';
+
 describe("code", function() {
   var prettyPrintOne, oldPP;
   var compile, scope;
diff --git a/docs/app/test/docsSpec.js b/docs/app/test/docsSpec.js
index 0ceeacfd348a..26f708976395 100644
--- a/docs/app/test/docsSpec.js
+++ b/docs/app/test/docsSpec.js
@@ -1,3 +1,5 @@
+'use strict';
+
 describe("DocsController", function() {
   var $scope;
 
diff --git a/docs/app/test/errorsSpec.js b/docs/app/test/errorsSpec.js
index 7ef3f12a8920..4e906ef42440 100644
--- a/docs/app/test/errorsSpec.js
+++ b/docs/app/test/errorsSpec.js
@@ -135,7 +135,7 @@ describe('errors', function() {
     }));
 
 
-    it('should set the element\s HTML', function() {
+    it('should set the element\'s HTML', function() {
       var elem = $compile('<span error-display="bar">foo</span>')($rootScope);
       expect(elem.html()).toBe('bar');
     });
@@ -152,7 +152,7 @@ describe('errors', function() {
     it('should pass the interpolated text through `errorLinkFilter`', function() {
       $location.search = jasmine.createSpy('search').and.returnValue({p0: 'foo'});
 
-      var elem = $compile('<span error-display="foo = {0}"></span>')($rootScope);
+      $compile('<span error-display="foo = {0}"></span>')($rootScope);
       expect(errorLinkFilter).toHaveBeenCalledTimes(1);
       expect(errorLinkFilter).toHaveBeenCalledWith('foo = foo', '_blank');
     });
diff --git a/docs/config/index.js b/docs/config/index.js
index c5d37a464b30..ad43a442121e 100644
--- a/docs/config/index.js
+++ b/docs/config/index.js
@@ -87,7 +87,7 @@ module.exports = new Package('angularjs', [
     docTypes: ['overview', 'tutorial'],
     getPath: function(doc) {
       var docPath = path.dirname(doc.fileInfo.relativePath);
-      if ( doc.fileInfo.baseName !== 'index' ) {
+      if (doc.fileInfo.baseName !== 'index') {
         docPath = path.join(docPath, doc.fileInfo.baseName);
       }
       return docPath;
@@ -108,12 +108,12 @@ module.exports = new Package('angularjs', [
   });
 
   computePathsProcessor.pathTemplates.push({
-    docTypes: ['module' ],
+    docTypes: ['module'],
     pathTemplate: '${area}/${name}',
     outputPathTemplate: 'partials/${area}/${name}.html'
   });
   computePathsProcessor.pathTemplates.push({
-    docTypes: ['componentGroup' ],
+    docTypes: ['componentGroup'],
     pathTemplate: '${area}/${moduleName}/${groupType}',
     outputPathTemplate: 'partials/${area}/${moduleName}/${groupType}.html'
   });
diff --git a/docs/config/inline-tag-defs/type.js b/docs/config/inline-tag-defs/type.js
index 6228a0766fec..7c5ca13ad729 100644
--- a/docs/config/inline-tag-defs/type.js
+++ b/docs/config/inline-tag-defs/type.js
@@ -1,5 +1,6 @@
-"use strict";
+'use strict';
 
+// eslint-disable-next-line new-cap
 var encoder = new require('node-html-encoder').Encoder();
 
 /**
@@ -11,7 +12,7 @@ module.exports = function typeInlineTagDef(getTypeClass) {
   return {
     name: 'type',
     handler: function(doc, tagName, tagDescription) {
-      return '<a href="" class="' + getTypeClass(tagDescription) + '">'+encoder.htmlEncode(tagDescription) + '</a>';
+      return '<a href="" class="' + getTypeClass(tagDescription) + '">' + encoder.htmlEncode(tagDescription) + '</a>';
     }
   };
-};
\ No newline at end of file
+};
diff --git a/docs/config/processors/error-docs.js b/docs/config/processors/error-docs.js
index a86be71df881..c80297efbba5 100644
--- a/docs/config/processors/error-docs.js
+++ b/docs/config/processors/error-docs.js
@@ -1,7 +1,4 @@
-"use strict";
-
-var _ = require('lodash');
-var path = require('canonical-path');
+'use strict';
 
 /**
  * @dgProcessor errorDocsProcessor
@@ -18,7 +15,7 @@ module.exports = function errorDocsProcessor(errorNamespaceMap, getMinerrInfo) {
       docs.forEach(function(doc) {
         var parts, namespaceDoc;
 
-        if ( doc.docType === 'error' ) {
+        if (doc.docType === 'error') {
 
           // Parse out the error info from the id
           parts = doc.name.split(':');
@@ -27,7 +24,7 @@ module.exports = function errorDocsProcessor(errorNamespaceMap, getMinerrInfo) {
 
           // Get or create the relevant errorNamespace doc
           namespaceDoc = errorNamespaceMap.get(doc.namespace);
-          if ( !namespaceDoc ) {
+          if (!namespaceDoc) {
             namespaceDoc = {
               area: 'error',
               name: doc.namespace,
@@ -49,4 +46,4 @@ module.exports = function errorDocsProcessor(errorNamespaceMap, getMinerrInfo) {
       });
     }
   };
-};
\ No newline at end of file
+};
diff --git a/docs/config/processors/index-page.js b/docs/config/processors/index-page.js
index 9232f7f2a136..5b07daa3982d 100644
--- a/docs/config/processors/index-page.js
+++ b/docs/config/processors/index-page.js
@@ -1,7 +1,6 @@
 "use strict";
 
 var _ = require('lodash');
-var path = require('canonical-path');
 
 /**
  * @dgProcessor generateIndexPagesProcessor
@@ -21,7 +20,7 @@ module.exports = function generateIndexPagesProcessor() {
       // Collect up all the areas in the docs
       var areas = {};
       docs.forEach(function(doc) {
-        if ( doc.area ) {
+        if (doc.area) {
           areas[doc.area] = doc.area;
         }
       });
@@ -40,4 +39,4 @@ module.exports = function generateIndexPagesProcessor() {
       });
     }
   };
-};
\ No newline at end of file
+};
diff --git a/docs/config/processors/keywords.js b/docs/config/processors/keywords.js
index 62f01a9da163..2028d6e01f91 100644
--- a/docs/config/processors/keywords.js
+++ b/docs/config/processors/keywords.js
@@ -37,7 +37,7 @@ module.exports = function generateKeywordsProcessor(log, readFilesProcessor) {
       var KEYWORD_REGEX = /^((ng:|[\$_a-z])[\w\-_]+)/;
 
       // Load up the keywords to ignore, if specified in the config
-      if ( this.ignoreWordsFile ) {
+      if (this.ignoreWordsFile) {
 
         var ignoreWordsPath = path.resolve(readFilesProcessor.basePath, this.ignoreWordsFile);
         wordsToIgnore = fs.readFileSync(ignoreWordsPath, 'utf8').toString().split(/[,\s\n\r]+/gm);
@@ -59,7 +59,7 @@ module.exports = function generateKeywordsProcessor(log, readFilesProcessor) {
       // without the ng to the title text, e.g. "controller".
       function extractTitleWords(title) {
         var match = /ng([A-Z]\w*)/.exec(title);
-        if ( match ) {
+        if (match) {
           title = title + ' ' + match[1].toLowerCase();
         }
         return title;
@@ -68,11 +68,11 @@ module.exports = function generateKeywordsProcessor(log, readFilesProcessor) {
     function extractWords(text, words, keywordMap) {
 
       var tokens = text.toLowerCase().split(/[\.\s,`'"#]+/mg);
-      _.forEach(tokens, function(token){
+      _.forEach(tokens, function(token) {
         var match = token.match(KEYWORD_REGEX);
-        if (match){
+        if (match) {
           var key = match[1];
-          if ( !keywordMap[key]) {
+          if (!keywordMap[key]) {
             keywordMap[key] = true;
             words.push(key);
           }
@@ -96,11 +96,11 @@ module.exports = function generateKeywordsProcessor(log, readFilesProcessor) {
         // Search each top level property of the document for search terms
         _.forEach(doc, function(value, key) {
 
-          if ( _.isString(value) && !propertiesToIgnore[key] ) {
+          if (_.isString(value) && !propertiesToIgnore[key]) {
             extractWords(value, words, keywordMap);
           }
 
-          if ( key === 'methods' || key === 'properties' || key === 'events' ) {
+          if (key === 'methods' || key === 'properties' || key === 'events') {
             _.forEach(value, function(member) {
               extractWords(member.name, members, membersMap);
             });
diff --git a/docs/config/processors/pages-data.js b/docs/config/processors/pages-data.js
index efa79a5de4f2..9dc39b331257 100644
--- a/docs/config/processors/pages-data.js
+++ b/docs/config/processors/pages-data.js
@@ -1,4 +1,4 @@
-"use strict";
+'use strict';
 
 var _ = require('lodash');
 var path = require('canonical-path');
@@ -67,7 +67,7 @@ module.exports = function generatePagesDataProcessor(log) {
             })
 
             .tap(function(docTypes) {
-              if ( docTypes.input ) {
+              if (docTypes.input) {
                 docTypes.directive = docTypes.directive || [];
                 // Combine input docTypes into directive docTypes
                 docTypes.directive = docTypes.directive.concat(docTypes.input);
@@ -79,7 +79,7 @@ module.exports = function generatePagesDataProcessor(log) {
 
               sectionPages = _.sortBy(sectionPages, 'name');
 
-              if ( sectionPages.length > 0 ) {
+              if (sectionPages.length > 0) {
                 // Push a navItem for this section
                 navItems.push({
                   name: sectionName,
@@ -158,7 +158,7 @@ module.exports = function generatePagesDataProcessor(log) {
 
       // We are only interested in pages that are not landing pages
       var navPages = _.filter(pages, function(page) {
-        return page.docType != 'componentGroup';
+        return page.docType !== 'componentGroup';
       });
 
       // Generate an object collection of pages that is grouped by area e.g.
diff --git a/docs/config/processors/versions-data.js b/docs/config/processors/versions-data.js
index 636cf78e35c4..b2dbf5cb55da 100644
--- a/docs/config/processors/versions-data.js
+++ b/docs/config/processors/versions-data.js
@@ -31,4 +31,4 @@ module.exports = function generateVersionDocProcessor(gitData) {
       docs.push(versionDoc);
     }
   };
-};
\ No newline at end of file
+};
diff --git a/docs/config/services/deployments/debug.js b/docs/config/services/deployments/debug.js
index 9fe969b60ad2..991b9c79ce1d 100644
--- a/docs/config/services/deployments/debug.js
+++ b/docs/config/services/deployments/debug.js
@@ -5,7 +5,7 @@ module.exports = function debugDeployment(getVersion) {
     name: 'debug',
     examples: {
       commonFiles: {
-        scripts: [ '../../../angular.js' ]
+        scripts: ['../../../angular.js']
       },
       dependencyPath: '../../../'
     },
@@ -35,4 +35,4 @@ module.exports = function debugDeployment(getVersion) {
       'css/animations.css'
     ]
   };
-};
\ No newline at end of file
+};
diff --git a/docs/config/services/deployments/default.js b/docs/config/services/deployments/default.js
index 31ab6041e45e..51e8dde3f466 100644
--- a/docs/config/services/deployments/default.js
+++ b/docs/config/services/deployments/default.js
@@ -5,7 +5,7 @@ module.exports = function defaultDeployment(getVersion) {
     name: 'default',
     examples: {
       commonFiles: {
-        scripts: [ '../../../angular.min.js' ]
+        scripts: ['../../../angular.min.js']
       },
       dependencyPath: '../../../'
     },
@@ -35,4 +35,4 @@ module.exports = function defaultDeployment(getVersion) {
       'css/animations.css'
     ]
   };
-};
\ No newline at end of file
+};
diff --git a/docs/config/services/deployments/jquery.js b/docs/config/services/deployments/jquery.js
index 13099ef23f93..ea7b640d4e70 100644
--- a/docs/config/services/deployments/jquery.js
+++ b/docs/config/services/deployments/jquery.js
@@ -39,4 +39,4 @@ module.exports = function jqueryDeployment(getVersion) {
       'css/animations.css'
     ]
   };
-};
\ No newline at end of file
+};
diff --git a/docs/config/services/deployments/production.js b/docs/config/services/deployments/production.js
index aa740ed5e8c9..5d680b82bd3e 100644
--- a/docs/config/services/deployments/production.js
+++ b/docs/config/services/deployments/production.js
@@ -8,7 +8,7 @@ module.exports = function productionDeployment(getVersion) {
     name: 'production',
     examples: {
       commonFiles: {
-        scripts: [ cdnUrl + '/angular.min.js' ]
+        scripts: [cdnUrl + '/angular.min.js']
       },
       dependencyPath: cdnUrl + '/'
     },
@@ -38,4 +38,4 @@ module.exports = function productionDeployment(getVersion) {
       'css/animations.css'
     ]
   };
-};
\ No newline at end of file
+};
diff --git a/docs/config/services/errorNamespaceMap.js b/docs/config/services/errorNamespaceMap.js
index 632a625c3ac5..e1f3b9b37f28 100644
--- a/docs/config/services/errorNamespaceMap.js
+++ b/docs/config/services/errorNamespaceMap.js
@@ -7,4 +7,4 @@ var StringMap = require('stringmap');
  */
 module.exports = function errorNamespaceMap() {
   return new StringMap();
-};
\ No newline at end of file
+};
diff --git a/docs/config/services/getVersion.js b/docs/config/services/getVersion.js
index e719196c11a1..fa7a5d42e1b8 100644
--- a/docs/config/services/getVersion.js
+++ b/docs/config/services/getVersion.js
@@ -14,4 +14,4 @@ module.exports = function getVersion(readFilesProcessor) {
     packageFile = packageFile || 'bower.json';
     return require(path.join(sourceFolder,component,packageFile)).version;
   };
-};
\ No newline at end of file
+};
diff --git a/docs/config/tag-defs/installation.js b/docs/config/tag-defs/installation.js
index 17305a902143..91843ecd8ec1 100644
--- a/docs/config/tag-defs/installation.js
+++ b/docs/config/tag-defs/installation.js
@@ -1,3 +1,5 @@
+'use strict';
+
 module.exports = {
   name: 'installation'
-};
\ No newline at end of file
+};
diff --git a/docs/config/tag-defs/sortOrder.js b/docs/config/tag-defs/sortOrder.js
index 5d67e143dce8..6e2b6642eda6 100644
--- a/docs/config/tag-defs/sortOrder.js
+++ b/docs/config/tag-defs/sortOrder.js
@@ -1,6 +1,8 @@
+'use strict';
+
 module.exports = {
   name: 'sortOrder',
   transforms: function(doc, tag, value) {
     return parseInt(value, 10);
   }
-};
\ No newline at end of file
+};
diff --git a/docs/config/tag-defs/tutorial-step.js b/docs/config/tag-defs/tutorial-step.js
index 3c5b44a1be6b..d5297065dcaa 100644
--- a/docs/config/tag-defs/tutorial-step.js
+++ b/docs/config/tag-defs/tutorial-step.js
@@ -1,7 +1,9 @@
+'use strict';
+
 module.exports = {
   name: 'step',
   transforms: function(doc, tag, value) {
-    if ( doc.docType !== 'tutorial' ) {
+    if (doc.docType !== 'tutorial') {
       throw new Error('Invalid tag, step.  You should only use this tag on tutorial docs');
     }
     return parseInt(value,10);
diff --git a/docs/config/templates/nav-data.template.js b/docs/config/templates/nav-data.template.js
index 13910b48d476..d7adcdd64254 100644
--- a/docs/config/templates/nav-data.template.js
+++ b/docs/config/templates/nav-data.template.js
@@ -1,3 +1,5 @@
+'use strict';
+
 // Meta data used by the AngularJS docs app
 angular.module('navData', [])
   .value('NG_NAVIGATION', {$ doc.areas | json $});
diff --git a/docs/config/templates/pages-data.template.js b/docs/config/templates/pages-data.template.js
index 1be7df506bd4..c87a864c09b6 100644
--- a/docs/config/templates/pages-data.template.js
+++ b/docs/config/templates/pages-data.template.js
@@ -1,3 +1,5 @@
+'use strict';
+
 // Meta data used by the AngularJS docs app
 angular.module('pagesData', [])
   .value('NG_PAGES', {$ doc.pages | json $});
diff --git a/docs/config/templates/versions-data.template.js b/docs/config/templates/versions-data.template.js
index 4db313314a8a..df8eba87769d 100644
--- a/docs/config/templates/versions-data.template.js
+++ b/docs/config/templates/versions-data.template.js
@@ -1,3 +1,5 @@
+'use strict';
+
 // Meta data used by the AngularJS docs app
 angular.module('versionsData', [])
   .value('NG_VERSION', {$ doc.currentVersion | json $})
diff --git a/docs/content/error/$rootScope/inprog.ngdoc b/docs/content/error/$rootScope/inprog.ngdoc
index 10da4c211516..fab262072880 100644
--- a/docs/content/error/$rootScope/inprog.ngdoc
+++ b/docs/content/error/$rootScope/inprog.ngdoc
@@ -222,7 +222,7 @@ value of its attribute becomes true.
     angular.module('app', []).directive('setFocusIf', function() {
       return function link($scope, $element, $attr) {
         $scope.$watch($attr.setFocusIf, function(value) {
-          if ( value ) { $element[0].focus(); }
+          if (value) { $element[0].focus(); }
         });
       };
     });
diff --git a/docs/content/guide/$location.ngdoc b/docs/content/guide/$location.ngdoc
index cc41d81c92a5..db121430cd24 100644
--- a/docs/content/guide/$location.ngdoc
+++ b/docs/content/guide/$location.ngdoc
@@ -227,18 +227,18 @@ it('should show example', inject(
   },
   function($location) {
     // open http://example.com/base/index.html#!/a
-    $location.absUrl() == 'http://example.com/base/index.html#!/a'
-    $location.path() == '/a'
+    $location.absUrl() === 'http://example.com/base/index.html#!/a'
+    $location.path() === '/a'
 
     $location.path('/foo')
-    $location.absUrl() == 'http://example.com/base/index.html#!/foo'
+    $location.absUrl() === 'http://example.com/base/index.html#!/foo'
 
-    $location.search() == {}
+    $location.search() === {}
     $location.search({a: 'b', c: true});
-    $location.absUrl() == 'http://example.com/base/index.html#!/foo?a=b&c'
+    $location.absUrl() === 'http://example.com/base/index.html#!/foo?a=b&c'
 
     $location.path('/new').search('x=y');
-    $location.absUrl() == 'http://example.com/base/index.html#!/new?x=y'
+    $location.absUrl() === 'http://example.com/base/index.html#!/new?x=y'
   }
 ));
 ```
@@ -271,29 +271,29 @@ it('should show example', inject(
     // in browser with HTML5 history support:
     // open http://example.com/#!/a -> rewrite to http://example.com/a
     // (replacing the http://example.com/#!/a history record)
-    $location.path() == '/a'
+    $location.path() === '/a'
 
     $location.path('/foo');
-    $location.absUrl() == 'http://example.com/foo'
+    $location.absUrl() === 'http://example.com/foo'
 
-    $location.search() == {}
+    $location.search() === {}
     $location.search({a: 'b', c: true});
-    $location.absUrl() == 'http://example.com/foo?a=b&c'
+    $location.absUrl() === 'http://example.com/foo?a=b&c'
 
     $location.path('/new').search('x=y');
-    $location.url() == 'new?x=y'
-    $location.absUrl() == 'http://example.com/new?x=y'
+    $location.url() === 'new?x=y'
+    $location.absUrl() === 'http://example.com/new?x=y'
 
     // in browser without html5 history support:
     // open http://example.com/new?x=y -> redirect to http://example.com/#!/new?x=y
     // (again replacing the http://example.com/new?x=y history item)
-    $location.path() == '/new'
-    $location.search() == {x: 'y'}
+    $location.path() === '/new'
+    $location.search() === {x: 'y'}
 
     $location.path('/foo/bar');
-    $location.path() == '/foo/bar'
-    $location.url() == '/foo/bar?x=y'
-    $location.absUrl() == 'http://example.com/#!/foo/bar?x=y'
+    $location.path() === '/foo/bar'
+    $location.url() === '/foo/bar?x=y'
+    $location.absUrl() === 'http://example.com/#!/foo/bar?x=y'
   }
 ));
 ```
@@ -411,9 +411,9 @@ In these examples we use `<base href="/base/index.html" />`. The inputs represen
 
    .controller("LocationController", function($scope, $location) {
      $scope.$location = {};
-     angular.forEach("protocol host port path search hash".split(" "), function(method){
-      $scope.$location[method] = function(){
-        var result = $location[method].call($location);
+     angular.forEach("protocol host port path search hash".split(" "), function(method) {
+      $scope.$location[method] = function() {
+        var result = $location[method]();
         return angular.isObject(result) ? angular.toJson(result) : result;
       };
      });
@@ -460,7 +460,7 @@ In these examples we use `<base href="/base/index.html" />`. The inputs represen
    .directive('ngAddressBar', function($browser, $timeout) {
       return {
         template: 'Address: <input id="addressBar" type="text" style="width: 400px" >',
-        link: function(scope, element, attrs){
+        link: function(scope, element, attrs) {
           var input = element.children("input"), delay;
 
           input.on('keypress keyup keydown', function(event) {
@@ -488,7 +488,7 @@ In these examples we use `<base href="/base/index.html" />`. The inputs represen
         url = 'http://www.example.com/base/path?a=b#h';
 
 
-    it("should show fake browser info on load", function(){
+    it("should show fake browser info on load", function() {
       expect(addressBar.getAttribute('value')).toBe(url);
 
       expect(element(by.binding('$location.protocol()')).getText()).toBe('http');
@@ -500,7 +500,7 @@ In these examples we use `<base href="/base/index.html" />`. The inputs represen
 
     });
 
-    it("should change $location accordingly", function(){
+    it("should change $location accordingly", function() {
       var navigation = element.all(by.css("#navigation a"));
 
       navigation.get(0).click();
@@ -565,9 +565,9 @@ In these examples we use `<base href="/base/index.html" />`. The inputs represen
 
     .controller("LocationController", function($scope, $location) {
       $scope.$location = {};
-      angular.forEach("protocol host port path search hash".split(" "), function(method){
-        $scope.$location[method] = function(){
-          var result = $location[method].call($location);
+      angular.forEach("protocol host port path search hash".split(" "), function(method) {
+        $scope.$location[method] = function() {
+          var result = $location[method]();
           return angular.isObject(result) ? angular.toJson(result) : result;
         };
       });
@@ -614,7 +614,7 @@ In these examples we use `<base href="/base/index.html" />`. The inputs represen
    .directive('ngAddressBar', function($browser, $timeout) {
       return {
         template: 'Address: <input id="addressBar" type="text" style="width: 400px" >',
-        link: function(scope, element, attrs){
+        link: function(scope, element, attrs) {
           var input = element.children("input"), delay;
 
           input.on('keypress keyup keydown', function(event) {
@@ -641,7 +641,7 @@ In these examples we use `<base href="/base/index.html" />`. The inputs represen
     var addressBar = element(by.css("#addressBar")),
          url = 'http://www.example.com/base/index.html#!/path?a=b#h';
 
-    it("should show fake browser info on load", function(){
+    it("should show fake browser info on load", function() {
       expect(addressBar.getAttribute('value')).toBe(url);
 
       expect(element(by.binding('$location.protocol()')).getText()).toBe('http');
@@ -653,7 +653,7 @@ In these examples we use `<base href="/base/index.html" />`. The inputs represen
 
     });
 
-    it("should change $location accordingly", function(){
+    it("should change $location accordingly", function() {
       var navigation = element.all(by.css("#navigation a"));
 
       navigation.get(0).click();
@@ -735,7 +735,7 @@ ng.$rootScope.Scope scope} life-cycle. This means it's your responsibility to ca
 ```js
 describe('serviceUnderTest', function() {
   beforeEach(module(function($provide) {
-    $provide.factory('serviceUnderTest', function($location){
+    $provide.factory('serviceUnderTest', function($location) {
       // whatever it does...
     });
   });
@@ -843,7 +843,7 @@ to bind it to `ngModel`:
 <file name="script.js">
 angular.module('locationExample', [])
   .controller('LocationController', ['$scope', '$location', function($scope, $location) {
-    $scope.locationPath = function (newLocation) {
+    $scope.locationPath = function(newLocation) {
       return $location.path(newLocation);
     };
   }]);
diff --git a/docs/content/guide/accessibility.ngdoc b/docs/content/guide/accessibility.ngdoc
index 411492060502..8947fb3bebd1 100644
--- a/docs/content/guide/accessibility.ngdoc
+++ b/docs/content/guide/accessibility.ngdoc
@@ -74,20 +74,20 @@ attributes (if they have not been explicitly specified by the developer):
     </form>
   </file>
   <file name="script.js">
-    var app = angular.module('ngAria_ngModelExample', ['ngAria'])
-    .controller('formsController', function($scope){
+    angular.module('ngAria_ngModelExample', ['ngAria'])
+    .controller('formsController', function($scope) {
       $scope.checked = false;
-      $scope.toggleCheckbox = function(){
+      $scope.toggleCheckbox = function() {
         $scope.checked = !$scope.checked;
       };
     })
-    .directive('someCheckbox', function(){
+    .directive('someCheckbox', function() {
       return {
         restrict: 'E',
         link: function($scope, $el, $attrs) {
-          $el.on('keypress', function(event){
+          $el.on('keypress', function(event) {
             event.preventDefault();
-            if(event.keyCode === 32 || event.keyCode === 13){
+            if (event.keyCode === 32 || event.keyCode === 13) {
               $scope.toggleCheckbox();
               $scope.$apply();
             }
diff --git a/docs/content/guide/component-router.ngdoc b/docs/content/guide/component-router.ngdoc
index 25c08b12a8ce..13d3710c6b32 100644
--- a/docs/content/guide/component-router.ngdoc
+++ b/docs/content/guide/component-router.ngdoc
@@ -230,8 +230,8 @@ You can see the complete application running below.
 
       this.getHero = function(id) {
         return heroesPromise.then(function(heroes) {
-          for(var i=0; i<heroes.length; i++) {
-            if ( heroes[i].id == id) return heroes[i];
+          for (var i = 0; i < heroes.length; i++) {
+            if (heroes[i].id === id) return heroes[i];
           }
         });
       };
@@ -250,7 +250,7 @@ You can see the complete application running below.
       };
 
       this.isSelected = function(hero) {
-        return (hero.id == selectedId);
+        return (hero.id === selectedId);
       };
     }
 
@@ -321,8 +321,8 @@ You can see the complete application running below.
 
       this.getCrisis = function(id) {
         return crisesPromise.then(function(crises) {
-          for(var i=0; i<crises.length; i++) {
-            if ( crises[i].id == id) return crises[i];
+          for (var i = 0; i < crises.length; i++) {
+            if (crises[i].id === id) return crises[i];
           }
         });
       };
@@ -342,7 +342,7 @@ You can see the complete application running below.
       };
 
       this.isSelected = function(crisis) {
-        return (crisis.id == selectedId);
+        return (crisis.id === selectedId);
       };
 
       this.onSelect = function(crisis) {
@@ -725,8 +725,8 @@ function HeroService($q) {
 
   this.getHero = function(id) {
     return heroesPromise.then(function(heroes) {
-      for(var i=0; i<heroes.length; i++) {
-        if ( heroes[i].id == id) return heroes[i];
+      for (var i = 0; i < heroes.length; i++) {
+        if (heroes[i].id === id) return heroes[i];
       }
     });
   };
@@ -924,7 +924,7 @@ function HeroListComponent(heroService) {
   };
 
   this.isSelected = function(hero) {
-    return (hero.id == selectedId);
+    return (hero.id === selectedId);
   };
 }
 ```
diff --git a/docs/content/guide/component.ngdoc b/docs/content/guide/component.ngdoc
index 7e537b6cd7f8..d0142bf36a5a 100644
--- a/docs/content/guide/component.ngdoc
+++ b/docs/content/guide/component.ngdoc
@@ -33,7 +33,7 @@ Components can be registered using the `.component()` method of an Angular modul
 
 <example name="heroComponentSimple" module="heroApp">
 <file name="index.js">
-  angular.module('heroApp', []).controller('mainCtrl', function() {
+  angular.module('heroApp', []).controller('MainCtrl', function MainCtrl() {
     this.hero = {
       name: 'Spawn'
     };
@@ -55,7 +55,7 @@ Components can be registered using the `.component()` method of an Angular modul
 </file>
 <file name="index.html">
   <!-- components match only elements -->
-  <div ng-controller="mainCtrl as ctrl">
+  <div ng-controller="MainCtrl as ctrl">
     <b>Hero</b><br>
     <hero-detail hero="ctrl.hero"></hero-detail>
   </div>
@@ -200,7 +200,7 @@ it upwards to the heroList component, which updates the original data.
 
 <example name="heroComponentTree" module="heroApp">
 <file name="index.js">
-  var mode = angular.module('heroApp', []);
+  angular.module('heroApp', []);
 </file>
 
 <file name="heroList.js">
@@ -388,7 +388,7 @@ Here is a tab pane example built from components:
 angular.module('docsTabsExample', [])
   .component('myTabs', {
     transclude: true,
-    controller: function() {
+    controller: function MyTabsController() {
       var panes = this.panes = [];
       this.select = function(pane) {
         angular.forEach(panes, function(pane) {
diff --git a/docs/content/guide/concepts.ngdoc b/docs/content/guide/concepts.ngdoc
index 0c6c74119ad8..3e8d941f9c27 100644
--- a/docs/content/guide/concepts.ngdoc
+++ b/docs/content/guide/concepts.ngdoc
@@ -103,7 +103,7 @@ different currencies and also pay the invoice.
 <example name="guide-concepts-2" ng-app-included="true" >
   <file name="invoice1.js">
     angular.module('invoice1', [])
-      .controller('InvoiceController', function() {
+      .controller('InvoiceController', function InvoiceController() {
         this.qty = 1;
         this.cost = 2;
         this.inCurr = 'EUR';
@@ -199,7 +199,7 @@ Let's refactor our example and move the currency conversion into a service in an
           EUR: 0.74,
           CNY: 6.09
         };
-        var convert = function (amount, inCurr, outCurr) {
+        var convert = function(amount, inCurr, outCurr) {
           return amount * usdToForeignRates[outCurr] / usdToForeignRates[inCurr];
         };
 
@@ -211,7 +211,7 @@ Let's refactor our example and move the currency conversion into a service in an
   </file>
   <file name="invoice2.js">
     angular.module('invoice2', ['finance2'])
-      .controller('InvoiceController', ['currencyConverter', function(currencyConverter) {
+      .controller('InvoiceController', ['currencyConverter', function InvoiceController(currencyConverter) {
         this.qty = 1;
         this.cost = 2;
         this.inCurr = 'EUR';
@@ -277,7 +277,7 @@ Now that Angular knows of all the parts of the application, it needs to create t
 In the previous section we saw that controllers are created using a factory function.
 For services there are multiple ways to define their factory
 (see the {@link services service guide}).
-In the example above, we are using an anonymous function as the factory function for `currencyConverter` service. 
+In the example above, we are using an anonymous function as the factory function for `currencyConverter` service.
 This function should return the `currencyConverter` service instance.
 
 Back to the initial question: How does the `InvoiceController` get a reference to the `currencyConverter` function?
@@ -303,7 +303,7 @@ The following example shows how this is done with Angular:
 <example name="guide-concepts-3" ng-app-included="true">
   <file name="invoice3.js">
     angular.module('invoice3', ['finance3'])
-      .controller('InvoiceController', ['currencyConverter', function(currencyConverter) {
+      .controller('InvoiceController', ['currencyConverter', function InvoiceController(currencyConverter) {
         this.qty = 1;
         this.cost = 2;
         this.inCurr = 'EUR';
@@ -321,13 +321,13 @@ The following example shows how this is done with Angular:
     angular.module('finance3', [])
       .factory('currencyConverter', ['$http', function($http) {
         var YAHOO_FINANCE_URL_PATTERN =
-              '//query.yahooapis.com/v1/public/yql?q=select * from '+
-              'yahoo.finance.xchange where pair in ("PAIRS")&format=json&'+
+              '//query.yahooapis.com/v1/public/yql?q=select * from ' +
+              'yahoo.finance.xchange where pair in ("PAIRS")&format=json&' +
               'env=store://datatables.org/alltableswithkeys&callback=JSON_CALLBACK';
         var currencies = ['USD', 'EUR', 'CNY'];
         var usdToForeignRates = {};
 
-        var convert = function (amount, inCurr, outCurr) {
+        var convert = function(amount, inCurr, outCurr) {
           return amount * usdToForeignRates[outCurr] / usdToForeignRates[inCurr];
         };
 
diff --git a/docs/content/guide/decorators.ngdoc b/docs/content/guide/decorators.ngdoc
index 494208b1c084..d143ac4b287a 100644
--- a/docs/content/guide/decorators.ngdoc
+++ b/docs/content/guide/decorators.ngdoc
@@ -311,7 +311,7 @@ those conditions.
   <file name="script.js">
     angular.module('urlDecorator', []).
 
-      controller('Ctrl', ['$scope', function ($scope) {
+      controller('Ctrl', ['$scope', function($scope) {
         $scope.id = 3;
         $scope.warnCount = 0; // for testing
       }]).
@@ -354,8 +354,8 @@ those conditions.
               var exps = matchExpressions(originalExp);
 
               // create and store the getters using $parse
-              var getters = exps.map(function(el) {
-                if (el) return $parse(el);
+              var getters = exps.map(function(exp) {
+                return exp && $parse(exp);
               });
 
               return function newLinkFn(scope, elem, attr) {
@@ -406,13 +406,13 @@ those conditions.
   <file name="index.html">
     <div ng-controller="Ctrl">
       <a ng-href="/products/{{ id }}/view" id="id3">View Product {{ id }}</a>
-      - <strong>id == 3</strong>, so no warning<br>
+      - <strong>id === 3</strong>, so no warning<br>
       <a ng-href="/products/{{ id + 5 }}/view" id="id8">View Product {{ id + 5 }}</a>
-      - <strong>id + 5 == 8</strong>, so no warning<br>
+      - <strong>id + 5 === 8</strong>, so no warning<br>
       <a ng-href="/products/{{ someOtherId }}/view" id="someOtherId">View Product {{ someOtherId }}</a>
-      - <strong style="background-color: #ffff00;">someOtherId == undefined</strong>, so warn<br>
+      - <strong style="background-color: #ffff00;">someOtherId === undefined</strong>, so warn<br>
       <a ng-href="/products/{{ someOtherId + 5 }}/view" id="someOtherId5">View Product {{ someOtherId + 5 }}</a>
-      - <strong>someOtherId + 5 == 5</strong>, so no warning<br>
+      - <strong>someOtherId + 5 === 5</strong>, so no warning<br>
       <div>Warn Count: {{ warnCount }}</div>
     </div>
   </file>
@@ -450,7 +450,7 @@ changed (that never happens) and we need all of our default dates to be `'shortD
   <file name="script.js">
     angular.module('filterDecorator', []).
 
-      controller('Ctrl', ['$scope', function ($scope) {
+      controller('Ctrl', ['$scope', function($scope) {
         $scope.genesis = new Date(2010, 0, 5);
         $scope.ngConf = new Date(2016, 4, 4);
       }]).
@@ -498,7 +498,7 @@ changed (that never happens) and we need all of our default dates to be `'shortD
 
     it('should still allow dates to be formatted', function() {
       expect(element(by.id('ngConf')).getText())
-        .toMatch(/ng-conf 2016 with full date format\: [A-Za-z]+, [A-Za-z]+ \d{1,2}, \d{4}/);
+        .toMatch(/ng-conf 2016 with full date format: [A-Za-z]+, [A-Za-z]+ \d{1,2}, \d{4}/);
     });
   </file>
 </example>
diff --git a/docs/content/guide/directive.ngdoc b/docs/content/guide/directive.ngdoc
index beaf54235a9a..b9c2f5733ae5 100644
--- a/docs/content/guide/directive.ngdoc
+++ b/docs/content/guide/directive.ngdoc
@@ -269,8 +269,8 @@ function, since the template is requested before the scope is initialized.
       }])
       .directive('myCustomer', function() {
         return {
-          templateUrl: function(elem, attr){
-            return 'customer-'+attr.type+'.html';
+          templateUrl: function(elem, attr) {
+            return 'customer-' + attr.type + '.html';
           }
         };
       });
@@ -676,7 +676,7 @@ that redefines `name` as `Jeff`. What do you think the `{{name}}` binding will r
           transclude: true,
           scope: {},
           templateUrl: 'my-dialog.html',
-          link: function (scope) {
+          link: function(scope) {
             scope.name = 'Jeff';
           }
         };
@@ -720,10 +720,10 @@ own behavior to it.
       .controller('Controller', ['$scope', '$timeout', function($scope, $timeout) {
         $scope.name = 'Tobias';
         $scope.message = '';
-        $scope.hideDialog = function (message) {
+        $scope.hideDialog = function(message) {
           $scope.message = message;
           $scope.dialogIsHidden = true;
-          $timeout(function () {
+          $timeout(function() {
             $scope.message = '';
             $scope.dialogIsHidden = false;
           }, 2000);
@@ -856,7 +856,7 @@ to which tab is active.
           restrict: 'E',
           transclude: true,
           scope: {},
-          controller: ['$scope', function($scope) {
+          controller: ['$scope', function MyTabsController($scope) {
             var panes = $scope.panes = [];
 
             $scope.select = function(pane) {
diff --git a/docs/content/guide/expression.ngdoc b/docs/content/guide/expression.ngdoc
index 0a0fe0a762f3..824facd9dfb3 100644
--- a/docs/content/guide/expression.ngdoc
+++ b/docs/content/guide/expression.ngdoc
@@ -144,7 +144,7 @@ identifier `$locals`.
 
   <file name="protractor.js" type="protractor">
     it('should calculate expression in binding', function() {
-      if (browser.params.browser == 'safari') {
+      if (browser.params.browser === 'safari') {
         // Safari can't handle dialogs.
         return;
       }
@@ -221,8 +221,8 @@ similar jqLite object.
          * return a copy of an object with only non-object keys
          * we need this to avoid circular references
          */
-        function simpleKeys (original) {
-          return Object.keys(original).reduce(function (obj, key) {
+        function simpleKeys(original) {
+          return Object.keys(original).reduce(function(obj, key) {
             obj[key] = typeof original[key] === 'object' ? '{ ... }' : original[key];
             return obj;
           }, {});
diff --git a/docs/content/guide/filter.ngdoc b/docs/content/guide/filter.ngdoc
index d438157d119c..7e9b4ec33dc3 100644
--- a/docs/content/guide/filter.ngdoc
+++ b/docs/content/guide/filter.ngdoc
@@ -85,7 +85,7 @@ or the filter expression is changed).
 
   <file name="script.js">
     angular.module('FilterInControllerModule', []).
-      controller('FilterController', ['filterFilter', function(filterFilter) {
+      controller('FilterController', ['filterFilter', function FilterController(filterFilter) {
         this.array = [
           {name: 'Tobias'},
           {name: 'Jeff'},
diff --git a/docs/content/guide/i18n.ngdoc b/docs/content/guide/i18n.ngdoc
index cc11040bc5a4..f419f4a0dbc8 100644
--- a/docs/content/guide/i18n.ngdoc
+++ b/docs/content/guide/i18n.ngdoc
@@ -225,10 +225,10 @@ You may find it helpful to play with the following example as you read the expla
     }
 
     angular.module('messageFormatExample', ['ngMessageFormat'])
-      .controller('ckCtrl', function ($scope, $injector, $parse) {
-        var people = [ new Person("Alice", "female"),
-                       new Person("Bob", "male"),
-                       new Person("Charlie", "male") ];
+      .controller('ckCtrl', function($scope, $injector, $parse) {
+        var people = [new Person("Alice", "female"),
+                      new Person("Bob", "male"),
+                      new Person("Charlie", "male")];
 
         $scope.sender = new Person("Harry Potter", "male");
         $scope.recipients = people.slice();
diff --git a/docs/content/guide/migration.ngdoc b/docs/content/guide/migration.ngdoc
index bf1e1645ff38..6ddb29cb5a25 100644
--- a/docs/content/guide/migration.ngdoc
+++ b/docs/content/guide/migration.ngdoc
@@ -965,7 +965,7 @@ Before:
 
 ```js
 $scope.resetWithCancel = function (e) {
-  if (e.keyCode == 27) {
+  if (e.keyCode === 27) {
     $scope.myForm.myInput1.$cancelUpdate();
     $scope.myValue = '';
   }
@@ -976,7 +976,7 @@ After:
 
 ```js
 $scope.resetWithCancel = function (e) {
-  if (e.keyCode == 27) {
+  if (e.keyCode === 27) {
     $scope.myForm.myInput1.$rollbackViewValue();
     $scope.myValue = '';
   }
diff --git a/docs/content/guide/module.ngdoc b/docs/content/guide/module.ngdoc
index 879ee4fc10c3..62ab1c51f73f 100644
--- a/docs/content/guide/module.ngdoc
+++ b/docs/content/guide/module.ngdoc
@@ -120,7 +120,7 @@ The above is a suggestion. Tailor it to your needs.
         user.load('World');
       })
 
-      .controller('XmplController', function($scope, greeter, user){
+      .controller('XmplController', function($scope, greeter, user) {
         $scope.greeting = greeter.greet(user.name);
       });
 
diff --git a/docs/content/guide/services.ngdoc b/docs/content/guide/services.ngdoc
index 4428b7cdd662..4fb2fd93f7a9 100644
--- a/docs/content/guide/services.ngdoc
+++ b/docs/content/guide/services.ngdoc
@@ -43,7 +43,7 @@ subsystem takes care of the rest.
   <file name="script.js">
     angular.
      module('myServiceModule', []).
-      controller('MyController', ['$scope', 'notify', function ($scope, notify) {
+      controller('MyController', ['$scope', 'notify', function($scope, notify) {
         $scope.callNotify = function(msg) {
           notify(msg);
         };
@@ -52,7 +52,7 @@ subsystem takes care of the rest.
         var msgs = [];
         return function(msg) {
           msgs.push(msg);
-          if (msgs.length == 3) {
+          if (msgs.length === 3) {
             win.alert(msgs.join("\n"));
             msgs = [];
           }
diff --git a/docs/gulpfile.js b/docs/gulpfile.js
index b81bcd3e3ebe..67cdd922c249 100644
--- a/docs/gulpfile.js
+++ b/docs/gulpfile.js
@@ -1,13 +1,9 @@
-"use strict";
-
-var fs = require('fs');
-var _ = require('lodash');
-var stripJsonComments = require('strip-json-comments');
+'use strict';
 
 var gulp = require('gulp');
 var log = require('gulp-util').log;
 var concat = require('gulp-concat');
-var jshint = require('gulp-jshint');
+var eslint = require('gulp-eslint');
 var bower = require('bower');
 var Dgeni = require('dgeni');
 var merge = require('event-stream').merge;
@@ -29,28 +25,31 @@ var ignoredFiles = '!src/angular.bind.js';
 var assets = 'app/assets/**/*';
 
 
-var getJshintConfig = function(filepath) {
-    return JSON.parse(stripJsonComments(fs.readFileSync(filepath, {encoding: 'utf-8'})));
-};
-
-var getMergedJshintConfig = function(filepath) {
-  // "extends" doesn't work in configuration passed by an object, we need to do the extending ourselves.
-  var config = getJshintConfig(filepath);
-  var baseConfig = getJshintConfig('../.jshintrc-base');
-  _.merge(config, baseConfig);
-  delete config.extends;
-
-  // Examples don't run in strict mode; accept that for now.
-  config.strict = false;
-
-  return config;
+var getMergedEslintConfig = function(filepath) {
+  return {
+    configFile: filepath,
+    baseConfig: '../.eslintrc.json',
+    rules: {
+      // Examples don't run in strict mode; accept that for now.
+      strict: 'off',
+      // Generated examples may miss the final EOL; ignore that.
+      'eol-last': 'off',
+      // While alerts would be bad to have in the library or test code,
+      // they're perfectly fine in examples.
+      'no-alert': 'off',
+      // some dgeni-packages templates generate whitespace-only lines
+      'no-trailing-spaces': ['error', { 'skipBlankLines': true }]
+    },
+    ignore: false,
+    useEslintrc: false
+  };
 };
 
 var copyComponent = function(component, pattern, sourceFolder, packageFile) {
   pattern = pattern || '/**/*';
   sourceFolder = sourceFolder || bowerFolder;
   packageFile = packageFile || 'bower.json';
-  var version = require(path.resolve(sourceFolder,component,packageFile)).version;
+  var version = require(path.resolve(sourceFolder, component, packageFile)).version;
   return gulp
     .src(sourceFolder + '/' + component + pattern)
     .pipe(gulp.dest(outputFolder + '/components/' + component + '-' + version));
@@ -59,7 +58,7 @@ var copyComponent = function(component, pattern, sourceFolder, packageFile) {
 
 gulp.task('bower', function() {
   var bowerTask = bower.commands.install();
-  bowerTask.on('log', function (result) {
+  bowerTask.on('log', function(result) {
     log('bower:', result.id, result.data.endpoint.name);
   });
   bowerTask.on('error', function(error) {
@@ -104,7 +103,7 @@ gulp.task('assets', ['bower'], function() {
       })),
     copyComponent('bootstrap', '/dist/**/*'),
     copyComponent('open-sans-fontface'),
-    copyComponent('lunr.js','/*.js'),
+    copyComponent('lunr.js', '/*.js'),
     copyComponent('google-code-prettify'),
     copyComponent('jquery', '/dist/*.js'),
     copyComponent('marked', '/**/*.js', '../node_modules', 'package.json')
@@ -120,35 +119,50 @@ gulp.task('doc-gen', ['bower'], function() {
 });
 
 
-// JSHint the example and protractor test files
-gulp.task('jshint', ['doc-gen'], function() {
-  var examplesConfig = getMergedJshintConfig('../docs/app/test/.jshintrc');
-  // Some tests use `alert` which is not assumed to be available even with `"browser": true`.
-  examplesConfig.globals.alert = false;
+// Lint the example and protractor test files
+gulp.task('eslint', ['doc-gen'], function() {
+  var examplesConfig = getMergedEslintConfig('../docs/app/test/.eslintrc.json');
+  // While in source we don't want to assume the browser environment so that we're
+  // compatible with non-browser window implementations like jsdom, it's not necessary
+  // in examples and may look weird to casual readers.
+  examplesConfig.envs = ['browser'];
 
-  var protractorConfig = getMergedJshintConfig('../docs/app/e2e/.jshintrc');
+  var protractorConfig = getMergedEslintConfig('../docs/app/e2e/.eslintrc.json');
+  protractorConfig.rules['no-unused-vars'] = ['error', {
+    vars: 'local',
+    args: 'none',
+    // This variable is declared in code generated by dgeni-packages
+    // and not always used.
+    varsIgnorePattern: '^rootEl$'
+  }];
 
   return merge(
     gulp.src([
       outputFolder + '/examples/**/*.js',
-      '!' + outputFolder + '/examples/**/protractor.js',
+      '!' + outputFolder + '/examples/**/protractor.js'
     ])
-      .pipe(jshint(examplesConfig))
-      .pipe(jshint.reporter('jshint-stylish'))
-      .pipe(jshint.reporter('fail')),
+      // eslint() attaches the lint output to the "eslint" property
+      // of the file object so it can be used by other modules.
+      .pipe(eslint(examplesConfig))
+      // eslint.format() outputs the lint results to the console.
+      // Alternatively use eslint.formatEach() (see Docs).
+      .pipe(eslint.format())
+      // To have the process exit with an error code (1) on
+      // lint error, return the stream and pipe to failAfterError last.
+      .pipe(eslint.failAfterError()),
     gulp.src([
       outputFolder + '/ptore2e/**/*.js',
-      outputFolder + '/examples/**/protractor.js',
+      outputFolder + '/examples/**/protractor.js'
     ])
-      .pipe(jshint(protractorConfig))
-      .pipe(jshint.reporter('jshint-stylish'))
-      .pipe(jshint.reporter('fail'))
+      .pipe(eslint(protractorConfig))
+      .pipe(eslint.format())
+      .pipe(eslint.failAfterError())
   );
 });
 
 
 // The default task that will be run if no task is supplied
-gulp.task('default', ['assets', 'doc-gen', 'build-app', 'jshint']);
+gulp.task('default', ['assets', 'doc-gen', 'build-app', 'eslint']);
 
 gulp.task('watch', function() {
   gulp.watch([src, ignoredFiles, assets], ['assets', 'build-app']);
diff --git a/gdocs.js b/gdocs.js
index f54183aa5e71..dab9b083221d 100755
--- a/gdocs.js
+++ b/gdocs.js
@@ -17,16 +17,16 @@ var collections = {
 console.log('Google Docs...');
 
 var flag = process && process.argv[2];
-if (flag == '--login') {
+if (flag === '--login') {
   var username = process.argv[3];
   if (username) {
-    askPassword(function(password){
+    askPassword(function(password) {
       login(username, password);
     });
   } else {
     console.log('Missing username!');
   }
-} else if (flag == '--fetch') {
+} else if (flag === '--fetch') {
   var collection = process.argv[3];
   if (collection) {
     fetch(collection, collections[collection]);
@@ -46,7 +46,7 @@ function help() {
 }
 
 
-function fetch(collection, url){
+function fetch(collection, url) {
   console.log('fetching a list of docs in collection ' + collection + '...');
   request('GET', url, {
       headers: {
@@ -54,10 +54,10 @@ function fetch(collection, url){
         'Authorization': 'GoogleLogin auth=' + getAuthToken()
       }
     },
-    function(chunk){
+    function(chunk) {
       var entries = chunk.split('<entry');
       entries.shift();
-      entries.forEach(function(entry){
+      entries.forEach(function(entry) {
         var title = entry.match(/<title>(.*?)<\/title>/)[1];
         if (title.match(/\.ngdoc$/)) {
           var exportUrl = entry.match(/<content type='text\/html' src='(.*?)'\/>/)[1];
@@ -77,7 +77,7 @@ function download(collection, name, url) {
         'Authorization': 'GoogleLogin auth=' + getAuthToken()
       }
     },
-    function(data){
+    function(data) {
       data = data.replace('\ufeff', '');
       data = data.replace(/\r\n/mg, '\n');
 
@@ -111,7 +111,7 @@ function download(collection, name, url) {
  *    -d service=writely
  *    -d Gdata-version=3.0 | cut -d "=" -f 2)
  */
-function login(username, password){
+function login(username, password) {
   request('POST', 'https://www.google.com/accounts/ClientLogin',
     {
       data: {
@@ -125,11 +125,11 @@ function login(username, password){
         'Content-type': 'application/x-www-form-urlencoded'
       }
     },
-    function(chunk){
+    function(chunk) {
       var token;
-      chunk.split('\n').forEach(function(line){
+      chunk.split('\n').forEach(function(line) {
         var parts = line.split('=');
-        if (parts[0] == 'Auth') {
+        if (parts[0] === 'Auth') {
           token = parts[1];
         }
       });
@@ -161,16 +161,16 @@ function request(method, url, options, response) {
     port: (url[1] ? 443 : 80),
     path: url[3],
     method: method
-  }, function(res){
+  }, function(res) {
     var data;
     switch (res.statusCode) {
       case 200:
         data = [];
         res.setEncoding('utf8');
-        res.on('end', function () { response(data.join('')); });
-        res.on('close', function () { response(data.join('')); });  // https
-        res.on('data', function (chunk) { data.push(chunk); });
-        res.on('error', function (e) { console.log(e); });
+        res.on('end', function() { response(data.join('')); });
+        res.on('close', function() { response(data.join('')); });  // https
+        res.on('data', function(chunk) { data.push(chunk); });
+        res.on('error', function(e) { console.log(e); });
         break;
       case 401:
         console.log('Error: Login credentials expired! Please login.');
@@ -182,13 +182,13 @@ function request(method, url, options, response) {
         console.log('REQUEST POST: ', options.data);
         console.log('REQUEST HEADERS: ', options.headers);
         console.log('RESPONSE HEADERS: ', res.headers);
-        res.on('end', function (){ console.log('BODY: ', data.join('')); });
-        res.on('close', function (){ console.log('BODY: ', data.join('')); }); // https
-        res.on('data', function (chunk) { data.push(chunk); });
-        res.on('error', function (e){ console.log(e); });
+        res.on('end', function() { console.log('BODY: ', data.join('')); });
+        res.on('close', function() { console.log('BODY: ', data.join('')); }); // https
+        res.on('data', function(chunk) { data.push(chunk); });
+        res.on('error', function(e) { console.log(e); });
     }
   });
-  for(var header in options.headers) {
+  for (var header in options.headers) {
     req.setHeader(header, options.headers[header]);
   }
   if (options.data)
@@ -201,7 +201,7 @@ function request(method, url, options, response) {
 
 function encodeData(obj) {
   var pairs = [];
-  for(var key in obj) {
+  for (var key in obj) {
     pairs.push(key + '=' + obj[key]);
   }
   return pairs.join('&') + '\n';
@@ -247,7 +247,7 @@ function reflow(text, margin) {
       reflowLine = '';
       col = 0;
     }
-    line.replace(/\s*\S*\s*/g, function(chunk){
+    line.replace(/\s*\S*\s*/g, function(chunk) {
       if (col + chunk.length > margin) flush();
       reflowLine += chunk;
       col += chunk.length;
diff --git a/i18n/e2e/.eslintrc.json b/i18n/e2e/.eslintrc.json
new file mode 100644
index 000000000000..c0ce78c4b702
--- /dev/null
+++ b/i18n/e2e/.eslintrc.json
@@ -0,0 +1,14 @@
+{
+  "root": true,
+  "extends": "../../.eslintrc-node.json",
+
+  "env": {
+    "jasmine": true,
+    "protractor": true
+  },
+
+  "globals": {
+    "binding": false,
+    "input": false
+  }
+}
diff --git a/i18n/e2e/i18n-e2e.js b/i18n/e2e/i18n-e2e.js
index 8909a2aba66c..dd01295db5c4 100644
--- a/i18n/e2e/i18n-e2e.js
+++ b/i18n/e2e/i18n-e2e.js
@@ -1,3 +1,5 @@
+'use strict';
+
 describe("localized filters", function() {
   describe("es locale", function() {
     beforeEach(function() {
@@ -90,7 +92,7 @@ describe("localized filters", function() {
         input('person2').enter('Vojta');
         expect(element('ng-pluralize:last').html()).toBe('Igor and Vojta are viewing!');
       });
-    })
+    });
   });
 
   describe("sk locale", function() {
@@ -129,7 +131,7 @@ describe("localized filters", function() {
 
       it('should show pluralized strings with correct data-binding', function() {
       });
-    })
+    });
   });
 
   describe("zh locale", function() {
@@ -180,6 +182,6 @@ describe("localized filters", function() {
         input('person2').enter('一哥');
         expect(element('ng-pluralize:last').html()).toBe('彭迪 和 一哥 在浏览该文件!');
       });
-    })
+    });
   });
 });
diff --git a/i18n/spec/.eslintrc.json b/i18n/spec/.eslintrc.json
new file mode 100644
index 000000000000..4eabc1c93ed4
--- /dev/null
+++ b/i18n/spec/.eslintrc.json
@@ -0,0 +1,8 @@
+{
+  "root": true,
+  "extends": "../../.eslintrc-node.json",
+
+  "env": {
+    "jasmine": true
+  }
+}
diff --git a/i18n/spec/closureI18nExtractorSpec.js b/i18n/spec/closureI18nExtractorSpec.js
index 63157e5eb123..822aea4065b3 100644
--- a/i18n/spec/closureI18nExtractorSpec.js
+++ b/i18n/spec/closureI18nExtractorSpec.js
@@ -1,10 +1,12 @@
+'use strict';
+
 var closureI18nExtractor = require('../src/closureI18nExtractor.js');
 var converter = require('../src/converter.js');
-findLocaleId = closureI18nExtractor.findLocaleId;
-extractNumberSymbols = closureI18nExtractor.extractNumberSymbols;
-extractCurrencySymbols = closureI18nExtractor.extractCurrencySymbols;
-extractDateTimeSymbols = closureI18nExtractor.extractDateTimeSymbols;
-outputLocale = closureI18nExtractor.outputLocale;
+var findLocaleId = closureI18nExtractor.findLocaleId;
+var extractNumberSymbols = closureI18nExtractor.extractNumberSymbols;
+var extractCurrencySymbols = closureI18nExtractor.extractCurrencySymbols;
+var extractDateTimeSymbols = closureI18nExtractor.extractDateTimeSymbols;
+var outputLocale = closureI18nExtractor.outputLocale;
 
 
 function newTestLocaleInfo() {
@@ -59,21 +61,29 @@ function newTestLocaleInfo() {
 }
 
 
-describe("findLocaleId", function() {
-  it("should find the id from numbers", function() {
-    expect(findLocaleId("NumberFormatSymbols_en_GB", "num")).toEqual("en_GB");
+describe('findLocaleId', function() {
+  it('should find the id from numbers', function() {
+    expect(findLocaleId('NumberFormatSymbols_en_GB', 'num')).toEqual('en_GB');
   });
 
 
-  it("should find the id from datetime", function() {
-    expect(findLocaleId("DateTimeSymbols_en_ISO", "datetime")).toEqual("en_ISO");
+  it('should find the id from datetime', function() {
+    expect(findLocaleId('DateTimeSymbols_en', 'datetime')).toBe('en');
+    expect(findLocaleId('DateTimeSymbols_en_ISO', 'datetime')).toEqual('en_ISO');
   });
 
+  it('should not find localeId if data is missing', function() {
+    expect(findLocaleId('', 'num')).toBeUndefined();
+    expect(findLocaleId('aa', 'datetime')).toBeUndefined();
+    expect(findLocaleId('aa', 'randomType')).toBeUndefined();
+    expect(findLocaleId('NumberFormatSymbols_en', 'datetime')).toBeUndefined();
+    expect(findLocaleId('DateTimeSymbols_en', 'num')).toBeUndefined();
+  });
 
-  it("should throw an error otherwise", function() {
+  it('should throw an error otherwise', function() {
     expect(function() {
-      findLocaleId("str", "otherwise")
-    }).toThrowError("unknown type in findLocaleId: otherwise");
+      findLocaleId('str', 'otherwise');
+    }).toThrowError('unknown type in findLocaleId: otherwise');
   });
 });
 
@@ -117,7 +127,7 @@ describe("extractNumberSymbols", function() {
     expect(localeInfo).toEqual({
       'en_GB': { NUMBER_FORMATS: expectedNumberFormats }
     });
-  })
+  });
 });
 
 describe("extractCurrencySymbols", function() {
@@ -131,7 +141,6 @@ describe("extractCurrencySymbols", function() {
       "};"
     ].join('\n');
 
-    var localeInfo = {};
     var currencySymbols = extractCurrencySymbols(CONTENT);
     expect(currencySymbols.GBP).toEqual([2, '£', 'GB£']);
     expect(currencySymbols.AOA).toEqual([2, 'Kz', 'Kz']);
@@ -215,7 +224,6 @@ describe("extractDateTimeSymbols", function() {
 
 describe("pluralExtractor", function() {
   it("should output PLURAL_CAT in the output string code", function() {
-    var localeIds = ["fr_CA"];
     var content = (
         "goog.provide('goog.i18n.pluralRules');\n" +
         "\n" +
@@ -248,21 +256,24 @@ describe("pluralExtractor", function() {
     // Ref: closureI18nExtractor.pluralExtractor.
     pluralCat = pluralCat.replace(/^@@|@@$/g, '');
     // pluralCat requires these constants to exist.
+    // eslint-disable-next-line no-unused-vars
     var PLURAL_CATEGORY = {
       ZERO: "zero", ONE: "one", TWO: "two",
       FEW: "few", MANY: "many", OTHER: "other"
       };
     // Obtain the function by evaluating the source text.
+    // eslint-disable-next-line no-eval
     pluralCat = eval("(" + pluralCat + ")");
     // Confirm some expectations for pluralCat in fr_CA.
     expect(pluralCat(0)).toEqual("one");
     expect(pluralCat(3)).toEqual("other");
-  })
+  });
 });
 
 describe("serializeContent", function() {
   it("should not make any modifications to the content of the locale", function() {
     var serializedContent = closureI18nExtractor.serializeContent(newTestLocaleInfo());
+    // eslint-disable-next-line no-eval
     expect(eval("(" + serializedContent + ")")).toEqual(newTestLocaleInfo());
   });
   it("should only have ascii characters", function() {
@@ -271,6 +282,7 @@ describe("serializeContent", function() {
   });
   it("should not transform arrays into objects", function() {
     var serializedContent = closureI18nExtractor.serializeContent(newTestLocaleInfo().fr_CA);
+    // eslint-disable-next-line no-eval
     var deserializedLocale = eval("(" + serializedContent + ")");
     expect(deserializedLocale.DATETIME_FORMATS.MONTH.length).not.toBeUndefined();
   });
diff --git a/i18n/spec/converterSpec.js b/i18n/spec/converterSpec.js
index 43b8d7223507..decaf04033d4 100644
--- a/i18n/spec/converterSpec.js
+++ b/i18n/spec/converterSpec.js
@@ -1,3 +1,5 @@
+'use strict';
+
 var converter = require('../src/converter.js');
 
 describe("convertNumberData", function() {
diff --git a/i18n/spec/parserSpec.js b/i18n/spec/parserSpec.js
index aea80a885abb..968185af1e20 100644
--- a/i18n/spec/parserSpec.js
+++ b/i18n/spec/parserSpec.js
@@ -1,3 +1,5 @@
+'use strict';
+
 var parsePattern = require('../src/parser.js').parsePattern;
 
 describe('parsePattern', function() {
@@ -22,7 +24,7 @@ describe('parsePattern', function() {
     parseAndExpect('#,##0.###', '', '-', '', '', 1, 0, 3, 3, 3);
     parseAndExpect('#,##0.###;#,##0.###-', '', '', '', '-', 1, 0, 3, 3, 3);
     parseAndExpect('#,##,##0.###', '', '-', '', '', 1, 0, 3, 2, 3);
-    parseAndExpect("#,##0.###;\'\u202A\'-#,##0.###\'\u202C\'",
+    parseAndExpect("#,##0.###;'\u202A'-#,##0.###'\u202C'",
         '', '\u202A-', '', '\u202C', 1, 0, 3, 3, 3);
     parseAndExpect('#0.###;#0.###-', '', '', '', '-', 1, 0, 3, 0, 0);
 
@@ -31,7 +33,7 @@ describe('parsePattern', function() {
   it('should parse CURRENCY patterns', function() {
     // all CURRENCY patterns from closure
     parseAndExpect('#,##0.00 \u00A4', '', '-', ' \u00A4', ' \u00A4', 1, 2, 2, 3, 3);
-    parseAndExpect("#,##0.00\u00A0\u00A4;\'\u202A\'-#,##0.00\'\u202C\'\u00A0\u00A4",
+    parseAndExpect("#,##0.00\u00A0\u00A4;'\u202A'-#,##0.00'\u202C'\u00A0\u00A4",
                    '', '\u202A-', '\u00A0\u00A4', '\u202C\u00A0\u00A4', 1, 2, 2, 3, 3);
     parseAndExpect('#,##0.00 \u00A4;(#,##0.00 \u00A4)',
                    '', '(', ' \u00A4', ' \u00A4)', 1, 2, 2, 3, 3);
diff --git a/i18n/spec/utilSpec.js b/i18n/spec/utilSpec.js
deleted file mode 100644
index e6304254c41c..000000000000
--- a/i18n/spec/utilSpec.js
+++ /dev/null
@@ -1,14 +0,0 @@
-var util = require('../src/util.js');
-
-describe('findLocaleId', function() {
-  it('should find localeId', function() {
-    expect(util.findLocaleId('', 'num')).toBeUndefined();
-    expect(util.findLocaleId('aa', 'datetime')).toBeUndefined();
-    expect(util.findLocaleId('aa', 'randomType')).toBeUndefined();
-    expect(util.findLocaleId('NumberFormatSymbols_en', 'datetime')).toBeUndefined();
-    expect(util.findLocaleId('DateTimeSymbols_en', 'num')).toBeUndefined();
-
-    expect(util.findLocaleId('DateTimeSymbols_en', 'datetime')).toBe('en');
-    expect(util.findLocaleId('NumberFormatSymbols_en_US', 'num')).toBe('en_US');
-  });
-});
diff --git a/i18n/src/.eslintrc.json b/i18n/src/.eslintrc.json
new file mode 100644
index 000000000000..54bd17c95c46
--- /dev/null
+++ b/i18n/src/.eslintrc.json
@@ -0,0 +1,4 @@
+{
+  "root": true,
+  "extends": "../../.eslintrc-node.json"
+}
diff --git a/i18n/src/closureI18nExtractor.js b/i18n/src/closureI18nExtractor.js
index 411d5531740a..45b32a229b53 100644
--- a/i18n/src/closureI18nExtractor.js
+++ b/i18n/src/closureI18nExtractor.js
@@ -20,7 +20,7 @@ function findLocaleId(str, type) {
     return (str.match(/^NumberFormatSymbols_(.+)$/) || [])[1];
   }
 
-  if (type != 'datetime') { throw new Error('unknown type in findLocaleId: ' + type); }
+  if (type !== 'datetime') { throw new Error('unknown type in findLocaleId: ' + type); }
 
   return (str.match(/^DateTimeSymbols_(.+)$/) || [])[1];
 }
@@ -36,6 +36,7 @@ function getInfoForLocale(localeInfo, localeID) {
 
 function extractNumberSymbols(content, localeInfo, currencySymbols) {
   //eval script in the current context so that we get access to all the symbols
+  // eslint-disable-next-line no-eval
   eval(content.toString());
   for (var propName in goog.i18n) {
     var localeID = findLocaleId(propName, 'num');
@@ -49,6 +50,7 @@ function extractNumberSymbols(content, localeInfo, currencySymbols) {
 
 function extractCurrencySymbols(content) {
   //eval script in the current context so that we get access to all the symbols
+  // eslint-disable-next-line no-eval
   eval(content.toString());
   // var currencySymbols = goog.i18n.currency.CurrencyInfo;
   // currencySymbols.__proto__ = goog.i18n.currency.CurrencyInfoTier2;
@@ -58,12 +60,13 @@ function extractCurrencySymbols(content) {
 
 function extractDateTimeSymbols(content, localeInfo) {
   //eval script in the current context so that we get access to all the symbols
+  // eslint-disable-next-line no-eval
   eval(content.toString());
   for (var propName in goog.i18n) {
     var localeID = findLocaleId(propName, 'datetime');
     if (localeID) {
       var info = getInfoForLocale(localeInfo, localeID);
-      localeInfo[localeID].DATETIME_FORMATS =
+      info.DATETIME_FORMATS =
           converter.convertDatetimeData(goog.i18n[propName]);
     }
   }
@@ -78,6 +81,7 @@ function pluralExtractor(content, localeInfo) {
     // e.g. plural rules for en_SG is the same as those for en.
     goog.LOCALE = localeIds[i].match(/[^_]+/)[0];
     try {
+      // eslint-disable-next-line no-eval
       eval(contentText);
     } catch (e) {
       console.log("Error in eval(contentText): " + e.stack);
@@ -121,7 +125,7 @@ function canonicalizeForJsonStringify(unused_key, object) {
   //    2. https://code.google.com/p/v8/issues/detail?id=164
   //       ECMA-262 does not specify enumeration order. The de facto standard
   //       is to match insertion order, which V8 also does ...
-  if (typeof object != "object" || Object.prototype.toString.apply(object) === '[object Array]') {
+  if (typeof object !== "object" || Object.prototype.toString.apply(object) === '[object Array]') {
     return object;
   }
   var result = {};
diff --git a/i18n/src/closureSlurper.js b/i18n/src/closureSlurper.js
index 764818373cbb..4cc23358ab3a 100755
--- a/i18n/src/closureSlurper.js
+++ b/i18n/src/closureSlurper.js
@@ -3,14 +3,8 @@
 
 var Q  = require('q'),
     qfs  = require('q-io/fs'),
-    converter = require('./converter.js'),
-    util = require('./util.js'),
     closureI18nExtractor = require('./closureI18nExtractor.js'),
-    localeInfo = {},
-    currencySymbols,
-    goog = { provide: function() {},
-             require: function() {},
-             i18n: {currency: {}, pluralRules: {}} };
+    localeInfo = {};
 
 
 var NG_LOCALE_DIR = '../src/ngLocale/';
@@ -77,7 +71,7 @@ function writeLocaleFiles() {
     var content = closureI18nExtractor.outputLocale(localeInfo, localeID);
     if (!content) return;
     var correctedLocaleId = closureI18nExtractor.correctedLocaleId(localeID);
-    var filename = NG_LOCALE_DIR + 'angular-locale_' + correctedLocaleId + '.js'
+    var filename = NG_LOCALE_DIR + 'angular-locale_' + correctedLocaleId + '.js';
     console.log('Writing ' + filename);
     return qfs.write(filename, content)
         .then(function() {
@@ -95,7 +89,8 @@ function writeLocaleFiles() {
 function createFolder(folder) {
   return qfs.isDirectory(folder).then(function(isDir) {
     if (!isDir) return qfs.makeDirectory(folder).then(function() {
-        console.log('Created directory %j', folder); });
+      console.log('Created directory %j', folder);
+    });
   });
 }
 
diff --git a/i18n/src/converter.js b/i18n/src/converter.js
index 9f5c3527677e..c71f3c47b7cd 100644
--- a/i18n/src/converter.js
+++ b/i18n/src/converter.js
@@ -1,3 +1,5 @@
+'use strict';
+
 /**
  * after obtaining data from closure files, use converter to massage the data into the formats
  * we want
@@ -10,24 +12,22 @@ var parsePattern = require('./parser').parsePattern;
 
 
 function convertNumberData(dataObj, currencySymbols) {
-  var numberFormats = {},
-
-  numberFormats = {
+  var numberFormats = {
     DECIMAL_SEP: dataObj.DECIMAL_SEP,
     GROUP_SEP: dataObj.GROUP_SEP,
     PATTERNS: [parsePattern(dataObj.DECIMAL_PATTERN),
                parsePattern(dataObj.CURRENCY_PATTERN)]
-  }
+  };
 
   if (currencySymbols[dataObj.DEF_CURRENCY_CODE]) {
     numberFormats.CURRENCY_SYM = currencySymbols[dataObj.DEF_CURRENCY_CODE][1];
   } else {
-    if (dataObj.DEF_CURRENCY_CODE == 'MTL') {
+    if (dataObj.DEF_CURRENCY_CODE === 'MTL') {
       numberFormats.CURRENCY_SYM = '₤'; //for some reason this is missing in closure
     } else {
       // if there is no corresponding currency symbol, just use currency code.
       var code = numberFormats.CURRENCY_SYM = dataObj.DEF_CURRENCY_CODE;
-      console.log(code +' has no currency symbol in closure, used ' + code + ' instead!');
+      console.log(code + ' has no currency symbol in closure, used ' + code + ' instead!');
     }
   }
   return numberFormats;
diff --git a/i18n/src/parser.js b/i18n/src/parser.js
index 69802ce2b526..a33a67c39ee3 100644
--- a/i18n/src/parser.js
+++ b/i18n/src/parser.js
@@ -1,3 +1,5 @@
+'use strict';
+
 /**
 * A simple parser to parse a number format into a pattern object
 */
@@ -27,20 +29,20 @@ function parsePattern(pattern) {
             lgSize: 0
           };
 
-  var parts = pattern.split(PATTERN_SEP),
-      positive = parts[0],
-      negative = parts[1];
+  var patternParts = pattern.split(PATTERN_SEP),
+      positive = patternParts[0],
+      negative = patternParts[1];
 
-  var parts = positive.split(DECIMAL_SEP),
-      integer = parts[0],
-      fraction = parts[1];
+  var positiveParts = positive.split(DECIMAL_SEP),
+      integer = positiveParts[0],
+      fraction = positiveParts[1];
 
   p.posPre = integer.substr(0, integer.indexOf(DIGIT));
 
   for (var i = 0; i < fraction.length; i++) {
     var ch = fraction.charAt(i);
-    if (ch == ZERO) p.minFrac = p.maxFrac = i + 1;
-    else if (ch == DIGIT) p.maxFrac = i + 1;
+    if (ch === ZERO) p.minFrac = p.maxFrac = i + 1;
+    else if (ch === DIGIT) p.maxFrac = i + 1;
     else p.posSuf += ch;
   }
 
@@ -52,8 +54,8 @@ function parsePattern(pattern) {
     var trunkLen = positive.length - p.posPre.length - p.posSuf.length,
         pos = negative.indexOf(DIGIT);
 
-    p.negPre = negative.substr(0, pos).replace(/\'/g, '');
-    p.negSuf = negative.substr(pos + trunkLen).replace(/\'/g, '');
+    p.negPre = negative.substr(0, pos).replace(/'/g, '');
+    p.negSuf = negative.substr(pos + trunkLen).replace(/'/g, '');
   } else {
     // hardcoded '-' sign is fine as all locale use '-' as MINUS_SIGN. (\u2212 is the same as '-')
     p.negPre = '-' + p.posPre;
diff --git a/i18n/src/util.js b/i18n/src/util.js
deleted file mode 100644
index 82e2a7e4681a..000000000000
--- a/i18n/src/util.js
+++ /dev/null
@@ -1,7 +0,0 @@
-exports.findLocaleId = function findLocaleId(str, type) {
-  if (type === 'num') {
-    return (str.match(/^NumberFormatSymbols_(.+)$/) || [])[1];
-  } else if (type == 'datetime') {
-    return (str.match(/^DateTimeSymbols_(.+)$/) || [])[1];
-  }
-}
diff --git a/i18n/ucd/.eslintrc.json b/i18n/ucd/.eslintrc.json
new file mode 100644
index 000000000000..4bd89ff5005a
--- /dev/null
+++ b/i18n/ucd/.eslintrc.json
@@ -0,0 +1,5 @@
+{
+  "root": true,
+  "extends": "../../.eslintrc-node.json"
+
+}
diff --git a/i18n/ucd/spec/.eslintrc.json b/i18n/ucd/spec/.eslintrc.json
new file mode 100644
index 000000000000..86dc549c58cb
--- /dev/null
+++ b/i18n/ucd/spec/.eslintrc.json
@@ -0,0 +1,8 @@
+{
+  "env": {
+    "jasmine": true
+  },
+  "rules": {
+    "no-multi-str": "off"
+  }
+}
diff --git a/i18n/ucd/spec/extactValuesSpec.js b/i18n/ucd/spec/extactValuesSpec.js
index 28f09acbff65..b4ae735757a9 100644
--- a/i18n/ucd/spec/extactValuesSpec.js
+++ b/i18n/ucd/spec/extactValuesSpec.js
@@ -1,7 +1,9 @@
+'use strict';
+
 var extractValues = require('../src/extractValues.js').extractValues;
 var stream = require('stream');
 
-function StringStream(str) {
+function stringStream(str) {
   return new stream.Readable({
     read: function(n) {
       this.push(str);
@@ -12,41 +14,46 @@ function StringStream(str) {
 
 describe('extractValues', function() {
   it('should extract the values from the xml', function(done) {
-    var str = '<ucd><repertoire><char cp="0000" IDS="N"></char><char cp="0001" IDS="Y"></char><char cp="0002" IDS="Y"></char><char cp="0003" IDS="N"></char></repertoire></ucd>';
-    extractValues(StringStream(str), {'IDS': 'Y'}, function(values) {
-      expect(values).toEqual({ IDS_Y : [ [ '0001', '0002' ] ] });
+    var str = '<ucd><repertoire><char cp="0000" IDS="N"></char><char cp="0001" IDS="Y"></char>' +
+      '<char cp="0002" IDS="Y"></char><char cp="0003" IDS="N"></char></repertoire></ucd>';
+    extractValues(stringStream(str), {'IDS': 'Y'}, function(values) {
+      expect(values).toEqual({ IDS_Y : [['0001', '0002']] });
       done();
     });
   });
 
   it('should extract the values from the xml if the last element matches', function(done) {
-    var str = '<ucd><repertoire><char cp="0000" IDS="N"></char><char cp="0001" IDS="Y"></char><char cp="0002" IDS="Y"></char><char cp="0003" IDS="Y"></char></repertoire></ucd>';
-    extractValues(StringStream(str), {'IDS': 'Y'}, function(values) {
-      expect(values).toEqual({ IDS_Y : [ [ '0001', '0003' ] ] });
+    var str = '<ucd><repertoire><char cp="0000" IDS="N"></char><char cp="0001" IDS="Y"></char>' +
+      '<char cp="0002" IDS="Y"></char><char cp="0003" IDS="Y"></char></repertoire></ucd>';
+    extractValues(stringStream(str), {'IDS': 'Y'}, function(values) {
+      expect(values).toEqual({ IDS_Y : [['0001', '0003']] });
       done();
     });
   });
 
   it('should support `reserved`', function(done) {
-    var str = '<ucd><repertoire><char cp="0000" IDS="N"></char><char cp="0001" IDS="Y"></char><reserved first-cp="0002" last-cp="0005" IDS="N"></reserved><char cp="0006" IDS="Y"></char></repertoire></ucd>';
-    extractValues(StringStream(str), {'IDS': 'Y'}, function(values) {
-      expect(values).toEqual({ IDS_Y : [ [ '0001', '0001' ], [ '0006', '0006' ] ] });
+    var str = '<ucd><repertoire><char cp="0000" IDS="N"></char><char cp="0001" IDS="Y"></char>' +
+      '<reserved first-cp="0002" last-cp="0005" IDS="N"></reserved><char cp="0006" IDS="Y"></char></repertoire></ucd>';
+    extractValues(stringStream(str), {'IDS': 'Y'}, function(values) {
+      expect(values).toEqual({ IDS_Y : [['0001', '0001'], ['0006', '0006']] });
       done();
     });
   });
 
   it('should support `surrogate`', function(done) {
-    var str = '<ucd><repertoire><char cp="0000" IDS="N"></char><char cp="0001" IDS="Y"></char><surrogate first-cp="0002" last-cp="0005" IDS="N"></surrogate><char cp="0006" IDS="Y"></char></repertoire></ucd>';
-    extractValues(StringStream(str), {'IDS': 'Y'}, function(values) {
-      expect(values).toEqual({ IDS_Y : [ [ '0001', '0001' ], [ '0006', '0006' ] ] });
+    var str = '<ucd><repertoire><char cp="0000" IDS="N"></char><char cp="0001" IDS="Y"></char>' +
+      '<surrogate first-cp="0002" last-cp="0005" IDS="N"></surrogate><char cp="0006" IDS="Y"></char></repertoire></ucd>';
+    extractValues(stringStream(str), {'IDS': 'Y'}, function(values) {
+      expect(values).toEqual({ IDS_Y : [['0001', '0001'], ['0006', '0006']] });
       done();
     });
   });
 
   it('should support `noncharactere`', function(done) {
-    var str = '<ucd><repertoire><char cp="0000" IDS="N"></char><char cp="0001" IDS="Y"></char><noncharacter first-cp="0002" last-cp="0005" IDS="N"></noncharacter><char cp="0006" IDS="Y"></char></repertoire></ucd>';
-    extractValues(StringStream(str), {'IDS': 'Y'}, function(values) {
-      expect(values).toEqual({ IDS_Y : [ [ '0001', '0001' ], [ '0006', '0006' ] ] });
+    var str = '<ucd><repertoire><char cp="0000" IDS="N"></char><char cp="0001" IDS="Y"></char>' +
+      '<noncharacter first-cp="0002" last-cp="0005" IDS="N"></noncharacter><char cp="0006" IDS="Y"></char></repertoire></ucd>';
+    extractValues(stringStream(str), {'IDS': 'Y'}, function(values) {
+      expect(values).toEqual({ IDS_Y : [['0001', '0001'], ['0006', '0006']] });
       done();
     });
   });
diff --git a/i18n/ucd/spec/generateCodeSpec.js b/i18n/ucd/spec/generateCodeSpec.js
index 2a08b3c97c23..76c78ca7e736 100644
--- a/i18n/ucd/spec/generateCodeSpec.js
+++ b/i18n/ucd/spec/generateCodeSpec.js
@@ -1,3 +1,4 @@
+'use strict';
 
 var generateCodeModule = require('../src/generateCode.js');
 var generateCode = generateCodeModule.generateCode;
@@ -5,7 +6,7 @@ var generateFunction = generateCodeModule.generateFunction;
 
 describe('generateFunction', function() {
   it('should generate function with ranges', function() {
-    expect(generateFunction([ [ '0001', '0003' ] ], 'IDS_Y')).toEqual('\
+    expect(generateFunction([['0001', '0003']], 'IDS_Y')).toEqual('\
 function IDS_Y(cp) {\n\
   if (0x0001 <= cp && cp <= 0x0003) return true;\n\
   return false;\n\
@@ -13,7 +14,7 @@ function IDS_Y(cp) {\n\
   });
 
   it('should generate function with multiple ranges', function() {
-    expect(generateFunction([ [ '0001', '0003' ], [ '0005', '0009'] ], 'IDS_Y')).toEqual('\
+    expect(generateFunction([['0001', '0003'], ['0005', '0009']], 'IDS_Y')).toEqual('\
 function IDS_Y(cp) {\n\
   if (0x0001 <= cp && cp <= 0x0003) return true;\n\
   if (0x0005 <= cp && cp <= 0x0009) return true;\n\
@@ -22,7 +23,7 @@ function IDS_Y(cp) {\n\
   });
 
   it('should generate function with unique values', function() {
-    expect(generateFunction([ [ '0001', '0001' ], [ '0005', '0009'] ], 'IDS_Y')).toEqual('\
+    expect(generateFunction([['0001', '0001'], ['0005', '0009']], 'IDS_Y')).toEqual('\
 function IDS_Y(cp) {\n\
   if (cp === 0x0001) return true;\n\
   if (0x0005 <= cp && cp <= 0x0009) return true;\n\
@@ -33,7 +34,7 @@ function IDS_Y(cp) {\n\
 
 describe('generateCode', function() {
   it('should generate the function for all the values', function() {
-    expect(generateCode({ IDS_Y : [ [ '0001', '0001' ], [ '0006', '0006' ] ], IDC_Y : [ [ '0002', '0002' ], [ '0007', '0007' ] ] })).toEqual('\
+    expect(generateCode({ IDS_Y : [['0001', '0001'], ['0006', '0006']], IDC_Y : [['0002', '0002'], ['0007', '0007']] })).toEqual('\
 /******************************************************\n\
  *         Generated file, do not modify              *\n\
  *                                                    *\n\
diff --git a/i18n/ucd/src/extract.js b/i18n/ucd/src/extract.js
index 4bf0c06b1eec..5c6352f75d76 100644
--- a/i18n/ucd/src/extract.js
+++ b/i18n/ucd/src/extract.js
@@ -1,10 +1,9 @@
-"use strict";
+'use strict';
 
 var fs = require('fs');
 var zlib = require('zlib');
 var extractValues = require('./extractValues').extractValues;
 var generateCode = require('./generateCode').generateCode;
-var generateextractValues = require('./extractValues').extractValues;
 // ID_Start and ID_Continue
 var propertiesToExtract = {'IDS': 'Y', 'IDC': 'Y'};
 
@@ -17,7 +16,7 @@ function main() {
   function writeFile(validRanges) {
     var code = generateCode(validRanges);
     try {
-      var stats = fs.lstatSync('../src/ngParseExt');
+      fs.lstatSync('../src/ngParseExt');
     } catch (e) {
       fs.mkdirSync('../src/ngParseExt');
     }
diff --git a/i18n/ucd/src/extractValues.js b/i18n/ucd/src/extractValues.js
index 9ab4942ea60c..e91332897155 100644
--- a/i18n/ucd/src/extractValues.js
+++ b/i18n/ucd/src/extractValues.js
@@ -1,3 +1,4 @@
+'use strict';
 /**
  * Extract values from a stream.
  */
@@ -50,7 +51,7 @@ function extractValues(stream, propertiesToExtract, callback) {
 
   function doCallback() {
     for (var i in keys) {
-      property = keys[i] + '_' + keyValues[i];
+      var property = keys[i] + '_' + keyValues[i];
       invalidProperty(property);
     }
     callback(validRanges);
diff --git a/i18n/ucd/src/generateCode.js b/i18n/ucd/src/generateCode.js
index 28a2832f935e..0360689a9bcc 100644
--- a/i18n/ucd/src/generateCode.js
+++ b/i18n/ucd/src/generateCode.js
@@ -1,3 +1,4 @@
+'use strict';
 
 exports.generateCode = generateCode;
 exports.generateFunction = generateFunction;
diff --git a/karma-jquery.conf-factory.js b/karma-jquery.conf-factory.js
index 993bca028997..71eecb68571d 100644
--- a/karma-jquery.conf-factory.js
+++ b/karma-jquery.conf-factory.js
@@ -3,7 +3,7 @@
 var angularFiles = require('./angularFiles');
 var sharedConfig = require('./karma-shared.conf');
 
-module.exports = function (version) {
+module.exports = function(version) {
   version = version || '';
 
   return function(config) {
diff --git a/lib/grunt/plugins.js b/lib/grunt/plugins.js
index cbf32cf360c7..6a436505a727 100644
--- a/lib/grunt/plugins.js
+++ b/lib/grunt/plugins.js
@@ -1,42 +1,44 @@
 'use strict';
 
+/* eslint-disable no-invalid-this */
+
 var bower = require('bower');
 var util = require('./utils.js');
 var shelljs = require('shelljs');
 
 module.exports = function(grunt) {
 
-  grunt.registerMultiTask('min', 'minify JS files', function(){
-    util.min.call(util, this.data, this.async());
+  grunt.registerMultiTask('min', 'minify JS files', function() {
+    util.min(this.data, this.async());
   });
 
 
-  grunt.registerTask('minall', 'minify all the JS files in parallel', function(){
+  grunt.registerTask('minall', 'minify all the JS files in parallel', function() {
     var files = grunt.config('min');
-    files = Object.keys(files).map(function(key){ return files[key]; });
+    files = Object.keys(files).map(function(key) { return files[key]; });
     grunt.util.async.forEach(files, util.min.bind(util), this.async());
   });
 
 
-  grunt.registerMultiTask('build', 'build JS files', function(){
-    util.build.call(util, this.data, this.async());
+  grunt.registerMultiTask('build', 'build JS files', function() {
+    util.build(this.data, this.async());
   });
 
 
-  grunt.registerTask('buildall', 'build all the JS files in parallel', function(){
+  grunt.registerTask('buildall', 'build all the JS files in parallel', function() {
     var builds = grunt.config('build');
-    builds = Object.keys(builds).map(function(key){ return builds[key]; });
+    builds = Object.keys(builds).map(function(key) { return builds[key]; });
     grunt.util.async.forEach(builds, util.build.bind(util), this.async());
   });
 
 
-  grunt.registerMultiTask('write', 'write content to a file', function(){
+  grunt.registerMultiTask('write', 'write content to a file', function() {
     grunt.file.write(this.data.file, this.data.val);
     grunt.log.ok('wrote to ' + this.data.file);
   });
 
 
-  grunt.registerTask('docs', 'create angular docs', function(){
+  grunt.registerTask('docs', 'create angular docs', function() {
     var gruntProc = shelljs.exec('"node_modules/.bin/gulp" --gulpfile docs/gulpfile.js');
     if (gruntProc.code !== 0) {
       throw new Error('doc generation failed');
@@ -44,32 +46,32 @@ module.exports = function(grunt) {
   });
 
 
-  grunt.registerMultiTask('tests', '**Use `grunt test` instead**', function(){
-    util.startKarma.call(util, this.data, true, this.async());
+  grunt.registerMultiTask('tests', '**Use `grunt test` instead**', function() {
+    util.startKarma(this.data, true, this.async());
   });
 
 
-  grunt.registerMultiTask('autotest', 'Run and watch the unit tests with Karma', function(){
-    util.startKarma.call(util, this.data, false, this.async());
+  grunt.registerMultiTask('autotest', 'Run and watch the unit tests with Karma', function() {
+    util.startKarma(this.data, false, this.async());
   });
 
   grunt.registerTask('webdriver', 'Update webdriver', function() {
-    util.updateWebdriver.call(util, this.async());
+    util.updateWebdriver(this.async());
   });
 
   grunt.registerMultiTask('protractor', 'Run Protractor integration tests', function() {
-    util.startProtractor.call(util, this.data, this.async());
+    util.startProtractor(this.data, this.async());
   });
 
-  grunt.registerTask('collect-errors', 'Combine stripped error files', function () {
+  grunt.registerTask('collect-errors', 'Combine stripped error files', function() {
     util.collectErrors();
   });
 
-  grunt.registerTask('bower', 'Install Bower packages.', function () {
+  grunt.registerTask('bower', 'Install Bower packages.', function() {
     var done = this.async();
 
     bower.commands.install()
-      .on('log', function (result) {
+      .on('log', function(result) {
         grunt.log.ok('bower: ' + result.id + ' ' + result.data.endpoint.name);
       })
       .on('error', grunt.fail.warn.bind(grunt.fail))
diff --git a/lib/grunt/utils.js b/lib/grunt/utils.js
index 8bec36769ac9..dc925339f271 100644
--- a/lib/grunt/utils.js
+++ b/lib/grunt/utils.js
@@ -1,20 +1,16 @@
 'use strict';
 
 var fs = require('fs');
-var path = require('path');
 var shell = require('shelljs');
 var grunt = require('grunt');
 var spawn = require('child_process').spawn;
-var semver = require('semver');
-
-var _ = require('lodash');
 
 var CSP_CSS_HEADER = '/* Include this file in your html if you are using the CSP mode. */\n\n';
 
 
 module.exports = {
 
-  startKarma: function(config, singleRun, done){
+  startKarma: function(config, singleRun, done) {
     var browsers = grunt.option('browsers');
     var reporters = grunt.option('reporters');
     var noColor = grunt.option('no-colors');
@@ -28,14 +24,14 @@ module.exports = {
     ]);
     p.stdout.pipe(process.stdout);
     p.stderr.pipe(process.stderr);
-    p.on('exit', function(code){
-      if(code !== 0) grunt.fail.warn("Karma test(s) failed. Exit code: " + code);
+    p.on('exit', function(code) {
+      if (code !== 0) grunt.fail.warn("Karma test(s) failed. Exit code: " + code);
       done();
     });
   },
 
 
-  updateWebdriver: function(done){
+  updateWebdriver: function(done) {
     if (process.env.TRAVIS) {
       // Skip the webdriver-manager update on Travis, since the browsers will
       // be provided remotely.
@@ -45,13 +41,13 @@ module.exports = {
     var p = spawn('node', ['node_modules/protractor/bin/webdriver-manager', 'update']);
     p.stdout.pipe(process.stdout);
     p.stderr.pipe(process.stderr);
-    p.on('exit', function(code){
-      if(code !== 0) grunt.fail.warn('Webdriver failed to update');
+    p.on('exit', function(code) {
+      if (code !== 0) grunt.fail.warn('Webdriver failed to update');
       done();
     });
   },
 
-  startProtractor: function(config, done){
+  startProtractor: function(config, done) {
     var sauceUser = grunt.option('sauceUser');
     var sauceKey = grunt.option('sauceKey');
     var tunnelIdentifier = grunt.option('capabilities.tunnel-identifier');
@@ -72,21 +68,21 @@ module.exports = {
     var p = spawn('node', args);
     p.stdout.pipe(process.stdout);
     p.stderr.pipe(process.stderr);
-    p.on('exit', function(code){
-      if(code !== 0) grunt.fail.warn('Protractor test(s) failed. Exit code: ' + code);
+    p.on('exit', function(code) {
+      if (code !== 0) grunt.fail.warn('Protractor test(s) failed. Exit code: ' + code);
       done();
     });
   },
 
 
-  wrap: function(src, name){
+  wrap: function(src, name) {
     src.unshift('src/' + name + '.prefix');
     src.push('src/' + name + '.suffix');
     return src;
   },
 
 
-  addStyle: function(src, styles, minify){
+  addStyle: function(src, styles, minify) {
     styles = styles.reduce(processCSS.bind(this), {
       js: [src],
       css: []
@@ -101,15 +97,15 @@ module.exports = {
         js;
       state.css.push(css);
 
-      if(minify){
+      if (minify) {
         css = css
           .replace(/\r?\n/g, '')
           .replace(/\/\*.*?\*\//g, '')
           .replace(/:\s+/g, ':')
           .replace(/\s*\{\s*/g, '{')
           .replace(/\s*\}\s*/g, '}')
-          .replace(/\s*\,\s*/g, ',')
-          .replace(/\s*\;\s*/g, ';');
+          .replace(/\s*,\s*/g, ',')
+          .replace(/\s*;\s*/g, ';');
       }
       //escape for js
       css = css
@@ -124,7 +120,7 @@ module.exports = {
   },
 
 
-  process: function(src, NG_VERSION, strict){
+  process: function(src, NG_VERSION, strict) {
     var processed = src
       .replace(/"NG_VERSION_FULL"/g, NG_VERSION.full)
       .replace(/"NG_VERSION_MAJOR"/, NG_VERSION.major)
@@ -137,7 +133,7 @@ module.exports = {
   },
 
 
-  build: function(config, fn){
+  build: function(config, fn) {
     var files = grunt.file.expand(config.src);
     var styles = config.styles;
     var processedStyles;
@@ -165,7 +161,7 @@ module.exports = {
   },
 
 
-  singleStrict: function(src, insert){
+  singleStrict: function(src, insert) {
     return src
       .replace(/\s*("|')use strict("|');\s*/g, insert) // remove all file-specific strict mode flags
       .replace(/(\(function\([^)]*\)\s*\{)/, "$1'use strict';"); // add single strict mode flag
@@ -223,7 +219,7 @@ module.exports = {
 
 
   //returns the 32-bit mode force flags for java compiler if supported, this makes the build much faster
-  java32flags: function(){
+  java32flags: function() {
     if (process.platform === "win32") return '';
     if (shell.exec('java -version -d32 2>&1', {silent: true}).code !== 0) return '';
     return ' -d32 -client';
@@ -231,20 +227,20 @@ module.exports = {
 
 
   //collects and combines error messages stripped out in minify step
-  collectErrors: function () {
+  collectErrors: function() {
     var combined = {
       id: 'ng',
       generated: new Date().toString(),
       errors: {}
     };
-    grunt.file.expand('build/*-errors.json').forEach(function (file) {
+    grunt.file.expand('build/*-errors.json').forEach(function(file) {
       var errors = grunt.file.readJSON(file),
         namespace;
-      Object.keys(errors).forEach(function (prop) {
+      Object.keys(errors).forEach(function(prop) {
         if (typeof errors[prop] === 'object') {
           namespace = errors[prop];
           if (combined.errors[prop]) {
-            Object.keys(namespace).forEach(function (code) {
+            Object.keys(namespace).forEach(function(code) {
               if (combined.errors[prop][code] && combined.errors[prop][code] !== namespace[code]) {
                 grunt.warn('[collect-errors] Duplicate minErr codes don\'t match!');
               } else {
@@ -269,8 +265,8 @@ module.exports = {
 
 
   //csp connect middleware
-  conditionalCsp: function(){
-    return function(req, res, next){
+  conditionalCsp: function() {
+    return function(req, res, next) {
       var CSP = /\.csp\W/;
 
       if (CSP.test(req.url)) {
@@ -284,8 +280,8 @@ module.exports = {
 
 
   //rewrite connect middleware
-  rewrite: function(){
-    return function(req, res, next){
+  rewrite: function() {
+    return function(req, res, next) {
       var REWRITE = /\/(guide|api|cookbook|misc|tutorial|error).*$/,
           IGNORED = /(\.(css|js|png|jpg|gif|svg)$|partials\/.*\.html$)/,
           match;
diff --git a/lib/grunt/validate-angular-files.js b/lib/grunt/validate-angular-files.js
index 74352abcbfab..94829f9e729a 100644
--- a/lib/grunt/validate-angular-files.js
+++ b/lib/grunt/validate-angular-files.js
@@ -20,7 +20,7 @@ module.exports = function(grunt) {
     for (var section in combinedFiles) {
       var sectionFiles = combinedFiles[section];
 
-      if (section != 'angularLoader') {
+      if (section !== 'angularLoader') {
         directories.push('src/' + section);
       }
 
@@ -40,7 +40,7 @@ module.exports = function(grunt) {
       glob.sync(directory + '/**/*').forEach(function(filePath) {
         if (!fs.lstatSync(filePath).isDirectory()) {
           var fileName = path.basename(filePath);
-          var isHiddenFile = fileName[0] == '.';
+          var isHiddenFile = fileName[0] === '.';
           if (!isHiddenFile && !detectedFiles[filePath]) {
             grunt.log.error(filePath + ' exists in the local file structure but isn\'t used by any module.');
             errorsDetected = true;
diff --git a/lib/promises-aplus/promises-aplus-test-adapter.js b/lib/promises-aplus/promises-aplus-test-adapter.js
index 169d3403e065..bcd16da7e70b 100644
--- a/lib/promises-aplus/promises-aplus-test-adapter.js
+++ b/lib/promises-aplus/promises-aplus-test-adapter.js
@@ -1,13 +1,23 @@
-/* global qFactory: false */
 'use strict';
 
-var isFunction = function isFunction(value){return typeof value == 'function';};
+/* global qFactory: false */
+/* exported
+ isFunction,
+ isPromiseLike,
+ isObject,
+ isUndefined,
+ minErr,
+ extend
+*/
+/* eslint-disable no-unused-vars */
+
+var isFunction = function isFunction(value) {return typeof value === 'function';};
 var isPromiseLike = function isPromiseLike(obj) {return obj && isFunction(obj.then);};
-var isObject = function isObject(value){return value != null && typeof value === 'object';};
+var isObject = function isObject(value) {return value != null && typeof value === 'object';};
 var isUndefined = function isUndefined(value) {return typeof value === 'undefined';};
 
-var minErr = function minErr (module, constructor) {
-  return function (){
+var minErr = function minErr(module, constructor) {
+  return function() {
     var ErrorConstructor = constructor || Error;
     throw new ErrorConstructor(module + arguments[0] + arguments[1]);
   };
@@ -31,7 +41,7 @@ var $q = qFactory(process.nextTick, function noopExceptionHandler() {});
 
 exports.resolved = $q.resolve;
 exports.rejected = $q.reject;
-exports.deferred = function () {
+exports.deferred = function() {
     var deferred = $q.defer();
 
     return {
diff --git a/lib/versions/version-info.js b/lib/versions/version-info.js
index e66379c3f8f0..7baef6500b04 100644
--- a/lib/versions/version-info.js
+++ b/lib/versions/version-info.js
@@ -11,7 +11,7 @@ var process = require('process');
 var NO_REMOTE_REQUESTS = !!process.env['NG1_BUILD_NO_REMOTE_VERSION_REQUESTS'];
 var versionSource = NO_REMOTE_REQUESTS ? 'local' : 'remote';
 
-var currentPackage, previousVersions, cdnVersion, gitRepoInfo;
+var currentPackage, previousVersions, cdnVersion;
 
 
 /**
@@ -211,7 +211,7 @@ var getSnapshotVersion = function() {
 
 
 exports.currentPackage = currentPackage = getPackage();
-exports.gitRepoInfo = gitRepoInfo = getGitRepoInfo();
+exports.gitRepoInfo = getGitRepoInfo();
 exports.previousVersions = previousVersions = getPreviousVersions();
 exports.cdnVersion = cdnVersion = getCdnVersion();
 exports.currentVersion = getTaggedVersion() || getSnapshotVersion();
diff --git a/npm-shrinkwrap.clean.json b/npm-shrinkwrap.clean.json
index 49665e2cbc7f..53c84d8a7264 100644
--- a/npm-shrinkwrap.clean.json
+++ b/npm-shrinkwrap.clean.json
@@ -2279,7 +2279,7 @@
       }
     },
     "commitizen": {
-      "version": "2.8.1",
+      "version": "2.8.4",
       "dependencies": {
         "chalk": {
           "version": "1.1.3",
@@ -2341,7 +2341,7 @@
           }
         },
         "find-node-modules": {
-          "version": "1.0.1",
+          "version": "1.0.3",
           "dependencies": {
             "findup-sync": {
               "version": "0.2.1",
@@ -2350,10 +2350,10 @@
                   "version": "4.3.5",
                   "dependencies": {
                     "inflight": {
-                      "version": "1.0.4",
+                      "version": "1.0.5",
                       "dependencies": {
                         "wrappy": {
-                          "version": "1.0.1"
+                          "version": "1.0.2"
                         }
                       }
                     },
@@ -2364,10 +2364,10 @@
                       "version": "2.0.10",
                       "dependencies": {
                         "brace-expansion": {
-                          "version": "1.1.4",
+                          "version": "1.1.6",
                           "dependencies": {
                             "balanced-match": {
-                              "version": "0.4.1"
+                              "version": "0.4.2"
                             },
                             "concat-map": {
                               "version": "0.0.1"
@@ -2380,7 +2380,7 @@
                       "version": "1.3.3",
                       "dependencies": {
                         "wrappy": {
-                          "version": "1.0.1"
+                          "version": "1.0.2"
                         }
                       }
                     }
@@ -2397,13 +2397,16 @@
           "version": "1.0.0"
         },
         "glob": {
-          "version": "7.0.3",
+          "version": "7.0.5",
           "dependencies": {
+            "fs.realpath": {
+              "version": "1.0.0"
+            },
             "inflight": {
-              "version": "1.0.4",
+              "version": "1.0.5",
               "dependencies": {
                 "wrappy": {
-                  "version": "1.0.1"
+                  "version": "1.0.2"
                 }
               }
             },
@@ -2411,13 +2414,13 @@
               "version": "2.0.1"
             },
             "minimatch": {
-              "version": "3.0.0",
+              "version": "3.0.2",
               "dependencies": {
                 "brace-expansion": {
-                  "version": "1.1.4",
+                  "version": "1.1.6",
                   "dependencies": {
                     "balanced-match": {
-                      "version": "0.4.1"
+                      "version": "0.4.2"
                     },
                     "concat-map": {
                       "version": "0.0.1"
@@ -2430,7 +2433,7 @@
               "version": "1.3.3",
               "dependencies": {
                 "wrappy": {
-                  "version": "1.0.1"
+                  "version": "1.0.2"
                 }
               }
             },
@@ -2439,413 +2442,148 @@
             }
           }
         },
-        "gulp": {
-          "version": "3.9.1",
+        "home-or-tmp": {
+          "version": "2.0.0",
           "dependencies": {
-            "archy": {
-              "version": "1.0.0"
-            },
-            "deprecated": {
-              "version": "0.0.1"
+            "os-homedir": {
+              "version": "1.0.1"
             },
-            "interpret": {
+            "os-tmpdir": {
               "version": "1.0.1"
+            }
+          }
+        },
+        "inquirer": {
+          "version": "1.1.2",
+          "dependencies": {
+            "ansi-escapes": {
+              "version": "1.4.0"
             },
-            "liftoff": {
-              "version": "2.2.1",
+            "cli-cursor": {
+              "version": "1.0.2",
+              "dependencies": {
+                "restore-cursor": {
+                  "version": "1.0.1",
+                  "dependencies": {
+                    "exit-hook": {
+                      "version": "1.1.1"
+                    },
+                    "onetime": {
+                      "version": "1.1.0"
+                    }
+                  }
+                }
+              }
+            },
+            "cli-width": {
+              "version": "2.1.0"
+            },
+            "external-editor": {
+              "version": "1.0.3",
               "dependencies": {
                 "extend": {
-                  "version": "2.0.1"
+                  "version": "3.0.0"
                 },
-                "findup-sync": {
-                  "version": "0.3.0",
+                "spawn-sync": {
+                  "version": "1.0.15",
                   "dependencies": {
-                    "glob": {
-                      "version": "5.0.15",
+                    "concat-stream": {
+                      "version": "1.5.1",
                       "dependencies": {
-                        "inflight": {
-                          "version": "1.0.4",
-                          "dependencies": {
-                            "wrappy": {
-                              "version": "1.0.1"
-                            }
-                          }
-                        },
                         "inherits": {
                           "version": "2.0.1"
                         },
-                        "minimatch": {
-                          "version": "3.0.0",
-                          "dependencies": {
-                            "brace-expansion": {
-                              "version": "1.1.4",
-                              "dependencies": {
-                                "balanced-match": {
-                                  "version": "0.4.1"
-                                },
-                                "concat-map": {
-                                  "version": "0.0.1"
-                                }
-                              }
-                            }
-                          }
+                        "typedarray": {
+                          "version": "0.0.6"
                         },
-                        "once": {
-                          "version": "1.3.3",
+                        "readable-stream": {
+                          "version": "2.0.6",
                           "dependencies": {
-                            "wrappy": {
-                              "version": "1.0.1"
+                            "core-util-is": {
+                              "version": "1.0.2"
+                            },
+                            "isarray": {
+                              "version": "1.0.0"
+                            },
+                            "process-nextick-args": {
+                              "version": "1.0.7"
+                            },
+                            "string_decoder": {
+                              "version": "0.10.31"
+                            },
+                            "util-deprecate": {
+                              "version": "1.0.2"
                             }
                           }
-                        },
-                        "path-is-absolute": {
-                          "version": "1.0.0"
                         }
                       }
+                    },
+                    "os-shim": {
+                      "version": "0.1.3"
                     }
                   }
                 },
-                "flagged-respawn": {
-                  "version": "0.3.2"
-                },
-                "rechoir": {
-                  "version": "0.6.2"
-                },
-                "resolve": {
-                  "version": "1.1.7"
+                "temp": {
+                  "version": "0.8.3",
+                  "dependencies": {
+                    "os-tmpdir": {
+                      "version": "1.0.1"
+                    },
+                    "rimraf": {
+                      "version": "2.2.8"
+                    }
+                  }
                 }
               }
             },
-            "orchestrator": {
-              "version": "0.3.7",
+            "figures": {
+              "version": "1.7.0",
               "dependencies": {
-                "end-of-stream": {
-                  "version": "0.1.5",
-                  "dependencies": {
-                    "once": {
-                      "version": "1.3.3",
-                      "dependencies": {
-                        "wrappy": {
-                          "version": "1.0.1"
-                        }
-                      }
-                    }
-                  }
-                },
-                "sequencify": {
-                  "version": "0.0.7"
+                "escape-string-regexp": {
+                  "version": "1.0.5"
                 },
-                "stream-consume": {
-                  "version": "0.1.0"
+                "object-assign": {
+                  "version": "4.1.0"
                 }
               }
             },
-            "pretty-hrtime": {
-              "version": "1.0.2"
-            },
-            "semver": {
-              "version": "4.3.6"
+            "mute-stream": {
+              "version": "0.0.6"
             },
-            "tildify": {
-              "version": "1.2.0",
+            "pinkie-promise": {
+              "version": "2.0.1",
               "dependencies": {
-                "os-homedir": {
-                  "version": "1.0.1"
+                "pinkie": {
+                  "version": "2.0.4"
                 }
               }
             },
-            "v8flags": {
-              "version": "2.0.11",
+            "run-async": {
+              "version": "2.2.0",
               "dependencies": {
-                "user-home": {
-                  "version": "1.1.1"
+                "is-promise": {
+                  "version": "2.1.0"
                 }
               }
             },
-            "vinyl-fs": {
-              "version": "0.3.14",
+            "rx": {
+              "version": "4.1.0"
+            },
+            "string-width": {
+              "version": "1.0.1",
               "dependencies": {
-                "defaults": {
-                  "version": "1.0.3",
-                  "dependencies": {
-                    "clone": {
-                      "version": "1.0.2"
-                    }
-                  }
-                },
-                "glob-stream": {
-                  "version": "3.1.18",
+                "code-point-at": {
+                  "version": "1.0.0",
                   "dependencies": {
-                    "glob": {
-                      "version": "4.5.3",
-                      "dependencies": {
-                        "inflight": {
-                          "version": "1.0.4",
-                          "dependencies": {
-                            "wrappy": {
-                              "version": "1.0.1"
-                            }
-                          }
-                        },
-                        "inherits": {
-                          "version": "2.0.1"
-                        },
-                        "once": {
-                          "version": "1.3.3",
-                          "dependencies": {
-                            "wrappy": {
-                              "version": "1.0.1"
-                            }
-                          }
-                        }
-                      }
-                    },
-                    "minimatch": {
-                      "version": "2.0.10",
-                      "dependencies": {
-                        "brace-expansion": {
-                          "version": "1.1.4",
-                          "dependencies": {
-                            "balanced-match": {
-                              "version": "0.4.1"
-                            },
-                            "concat-map": {
-                              "version": "0.0.1"
-                            }
-                          }
-                        }
-                      }
-                    },
-                    "ordered-read-streams": {
-                      "version": "0.1.0"
-                    },
-                    "glob2base": {
-                      "version": "0.0.12",
-                      "dependencies": {
-                        "find-index": {
-                          "version": "0.1.1"
-                        }
-                      }
-                    },
-                    "unique-stream": {
+                    "number-is-nan": {
                       "version": "1.0.0"
                     }
                   }
                 },
-                "glob-watcher": {
-                  "version": "0.0.6",
-                  "dependencies": {
-                    "gaze": {
-                      "version": "0.5.2",
-                      "dependencies": {
-                        "globule": {
-                          "version": "0.1.0",
-                          "dependencies": {
-                            "lodash": {
-                              "version": "1.0.2"
-                            },
-                            "glob": {
-                              "version": "3.1.21",
-                              "dependencies": {
-                                "graceful-fs": {
-                                  "version": "1.2.3"
-                                },
-                                "inherits": {
-                                  "version": "1.0.2"
-                                }
-                              }
-                            },
-                            "minimatch": {
-                              "version": "0.2.14",
-                              "dependencies": {
-                                "lru-cache": {
-                                  "version": "2.7.3"
-                                },
-                                "sigmund": {
-                                  "version": "1.0.1"
-                                }
-                              }
-                            }
-                          }
-                        }
-                      }
-                    }
-                  }
-                },
-                "graceful-fs": {
-                  "version": "3.0.8"
-                },
-                "mkdirp": {
-                  "version": "0.5.1",
-                  "dependencies": {
-                    "minimist": {
-                      "version": "0.0.8"
-                    }
-                  }
-                },
-                "strip-bom": {
+                "is-fullwidth-code-point": {
                   "version": "1.0.0",
                   "dependencies": {
-                    "first-chunk-stream": {
-                      "version": "1.0.0"
-                    },
-                    "is-utf8": {
-                      "version": "0.2.1"
-                    }
-                  }
-                },
-                "through2": {
-                  "version": "0.6.5",
-                  "dependencies": {
-                    "readable-stream": {
-                      "version": "1.0.34",
-                      "dependencies": {
-                        "core-util-is": {
-                          "version": "1.0.2"
-                        },
-                        "isarray": {
-                          "version": "0.0.1"
-                        },
-                        "string_decoder": {
-                          "version": "0.10.31"
-                        },
-                        "inherits": {
-                          "version": "2.0.1"
-                        }
-                      }
-                    },
-                    "xtend": {
-                      "version": "4.0.1"
-                    }
-                  }
-                },
-                "vinyl": {
-                  "version": "0.4.6",
-                  "dependencies": {
-                    "clone": {
-                      "version": "0.2.0"
-                    },
-                    "clone-stats": {
-                      "version": "0.0.1"
-                    }
-                  }
-                }
-              }
-            }
-          }
-        },
-        "gulp-git": {
-          "version": "1.7.1",
-          "dependencies": {
-            "any-shell-escape": {
-              "version": "0.1.1"
-            },
-            "require-dir": {
-              "version": "0.1.0"
-            },
-            "through2": {
-              "version": "0.6.5",
-              "dependencies": {
-                "readable-stream": {
-                  "version": "1.0.34",
-                  "dependencies": {
-                    "core-util-is": {
-                      "version": "1.0.2"
-                    },
-                    "isarray": {
-                      "version": "0.0.1"
-                    },
-                    "string_decoder": {
-                      "version": "0.10.31"
-                    },
-                    "inherits": {
-                      "version": "2.0.1"
-                    }
-                  }
-                },
-                "xtend": {
-                  "version": "4.0.1"
-                }
-              }
-            }
-          }
-        },
-        "home-or-tmp": {
-          "version": "2.0.0",
-          "dependencies": {
-            "os-homedir": {
-              "version": "1.0.1"
-            },
-            "os-tmpdir": {
-              "version": "1.0.1"
-            }
-          }
-        },
-        "inquirer": {
-          "version": "1.0.2",
-          "dependencies": {
-            "ansi-escapes": {
-              "version": "1.4.0"
-            },
-            "cli-cursor": {
-              "version": "1.0.2",
-              "dependencies": {
-                "restore-cursor": {
-                  "version": "1.0.1",
-                  "dependencies": {
-                    "exit-hook": {
-                      "version": "1.1.1"
-                    },
-                    "onetime": {
-                      "version": "1.1.0"
-                    }
-                  }
-                }
-              }
-            },
-            "cli-width": {
-              "version": "2.1.0"
-            },
-            "figures": {
-              "version": "1.6.0"
-            },
-            "mute-stream": {
-              "version": "0.0.6"
-            },
-            "pinkie-promise": {
-              "version": "2.0.1",
-              "dependencies": {
-                "pinkie": {
-                  "version": "2.0.4"
-                }
-              }
-            },
-            "run-async": {
-              "version": "2.2.0",
-              "dependencies": {
-                "is-promise": {
-                  "version": "2.1.0"
-                }
-              }
-            },
-            "rx": {
-              "version": "4.1.0"
-            },
-            "string-width": {
-              "version": "1.0.1",
-              "dependencies": {
-                "code-point-at": {
-                  "version": "1.0.0",
-                  "dependencies": {
-                    "number-is-nan": {
-                      "version": "1.0.0"
-                    }
-                  }
-                },
-                "is-fullwidth-code-point": {
-                  "version": "1.0.0",
-                  "dependencies": {
-                    "number-is-nan": {
+                    "number-is-nan": {
                       "version": "1.0.0"
                     }
                   }
@@ -2866,13 +2604,29 @@
           }
         },
         "lodash": {
-          "version": "4.11.1"
+          "version": "4.14.1"
         },
         "minimist": {
           "version": "1.2.0"
         },
+        "path-exists": {
+          "version": "2.1.0",
+          "dependencies": {
+            "pinkie-promise": {
+              "version": "2.0.1",
+              "dependencies": {
+                "pinkie": {
+                  "version": "2.0.4"
+                }
+              }
+            }
+          }
+        },
         "shelljs": {
           "version": "0.5.3"
+        },
+        "strip-json-comments": {
+          "version": "2.0.1"
         }
       }
     },
@@ -2942,7 +2696,7 @@
       }
     },
     "dgeni-packages": {
-      "version": "0.13.0",
+      "version": "0.14.0",
       "dependencies": {
         "catharsis": {
           "version": "0.8.8",
@@ -2958,16 +2712,19 @@
           }
         },
         "change-case": {
-          "version": "2.3.1",
+          "version": "3.0.0",
           "dependencies": {
             "camel-case": {
-              "version": "1.2.2"
+              "version": "3.0.0"
             },
             "constant-case": {
-              "version": "1.1.2"
+              "version": "2.0.0"
             },
             "dot-case": {
-              "version": "1.1.2"
+              "version": "2.1.0"
+            },
+            "header-case": {
+              "version": "1.0.0"
             },
             "is-lower-case": {
               "version": "1.1.3"
@@ -2981,26 +2738,29 @@
             "lower-case-first": {
               "version": "1.0.2"
             },
+            "no-case": {
+              "version": "2.3.0"
+            },
             "param-case": {
-              "version": "1.1.2"
+              "version": "2.1.0"
             },
             "pascal-case": {
-              "version": "1.1.2"
+              "version": "2.0.0"
             },
             "path-case": {
-              "version": "1.1.2"
+              "version": "2.1.0"
             },
             "sentence-case": {
-              "version": "1.1.3"
+              "version": "2.1.0"
             },
             "snake-case": {
-              "version": "1.1.2"
+              "version": "2.1.0"
             },
             "swap-case": {
               "version": "1.1.2"
             },
             "title-case": {
-              "version": "1.1.2"
+              "version": "2.1.0"
             },
             "upper-case": {
               "version": "1.1.3"
@@ -3017,15 +2777,37 @@
           "version": "4.2.0"
         },
         "glob": {
-          "version": "3.2.11",
+          "version": "7.0.5",
           "dependencies": {
+            "fs.realpath": {
+              "version": "1.0.0"
+            },
+            "inflight": {
+              "version": "1.0.5",
+              "dependencies": {
+                "wrappy": {
+                  "version": "1.0.2"
+                }
+              }
+            },
             "inherits": {
               "version": "2.0.1"
+            },
+            "once": {
+              "version": "1.3.3",
+              "dependencies": {
+                "wrappy": {
+                  "version": "1.0.2"
+                }
+              }
+            },
+            "path-is-absolute": {
+              "version": "1.0.0"
             }
           }
         },
         "htmlparser2": {
-          "version": "3.9.0",
+          "version": "3.9.1",
           "dependencies": {
             "domelementtype": {
               "version": "1.3.0"
@@ -3049,15 +2831,18 @@
             "entities": {
               "version": "1.1.1"
             },
+            "inherits": {
+              "version": "2.0.1"
+            },
             "readable-stream": {
-              "version": "2.1.2",
+              "version": "2.1.4",
               "dependencies": {
+                "buffer-shims": {
+                  "version": "1.0.0"
+                },
                 "core-util-is": {
                   "version": "1.0.2"
                 },
-                "inherits": {
-                  "version": "2.0.1"
-                },
                 "isarray": {
                   "version": "1.0.0"
                 },
@@ -3074,14 +2859,22 @@
             }
           }
         },
+        "lodash": {
+          "version": "4.14.1"
+        },
         "minimatch": {
-          "version": "0.3.0",
+          "version": "3.0.2",
           "dependencies": {
-            "lru-cache": {
-              "version": "2.7.3"
-            },
-            "sigmund": {
-              "version": "1.0.1"
+            "brace-expansion": {
+              "version": "1.1.6",
+              "dependencies": {
+                "balanced-match": {
+                  "version": "0.4.2"
+                },
+                "concat-map": {
+                  "version": "0.0.1"
+                }
+              }
             }
           }
         },
@@ -3140,135 +2933,46 @@
                 },
                 "async-each": {
                   "version": "0.1.6"
+                },
+                "fsevents": {
+                  "version": "0.3.8",
+                  "dependencies": {
+                    "nan": {
+                      "version": "2.4.0"
+                    }
+                  }
                 }
               }
             }
           }
         },
-        "q-io": {
-          "version": "1.10.9",
+        "q": {
+          "version": "1.4.1"
+        },
+        "semver": {
+          "version": "5.3.0"
+        },
+        "shelljs": {
+          "version": "0.7.3",
           "dependencies": {
-            "q": {
-              "version": "0.9.7"
-            },
-            "qs": {
-              "version": "0.1.0"
+            "interpret": {
+              "version": "1.0.1"
             },
-            "url2": {
-              "version": "0.0.0"
-            },
-            "mime": {
-              "version": "1.2.11"
-            },
-            "mimeparse": {
-              "version": "0.1.4"
-            },
-            "collections": {
-              "version": "0.2.2",
+            "rechoir": {
+              "version": "0.6.2",
               "dependencies": {
-                "weak-map": {
-                  "version": "1.0.0"
+                "resolve": {
+                  "version": "1.1.7"
                 }
               }
             }
           }
         },
-        "semver": {
-          "version": "4.3.6"
-        },
-        "shelljs": {
-          "version": "0.5.3"
-        },
         "spdx-license-list": {
           "version": "2.1.0"
         },
         "typescript": {
           "version": "1.8.10"
-        },
-        "winston": {
-          "version": "0.7.3",
-          "dependencies": {
-            "async": {
-              "version": "0.2.10"
-            },
-            "colors": {
-              "version": "0.6.2"
-            },
-            "cycle": {
-              "version": "1.0.3"
-            },
-            "eyes": {
-              "version": "0.1.8"
-            },
-            "pkginfo": {
-              "version": "0.3.1"
-            },
-            "request": {
-              "version": "2.16.6",
-              "dependencies": {
-                "form-data": {
-                  "version": "0.0.10",
-                  "dependencies": {
-                    "combined-stream": {
-                      "version": "0.0.7",
-                      "dependencies": {
-                        "delayed-stream": {
-                          "version": "0.0.5"
-                        }
-                      }
-                    }
-                  }
-                },
-                "mime": {
-                  "version": "1.2.11"
-                },
-                "hawk": {
-                  "version": "0.10.2",
-                  "dependencies": {
-                    "hoek": {
-                      "version": "0.7.6"
-                    },
-                    "boom": {
-                      "version": "0.3.8"
-                    },
-                    "cryptiles": {
-                      "version": "0.1.3"
-                    },
-                    "sntp": {
-                      "version": "0.1.4"
-                    }
-                  }
-                },
-                "node-uuid": {
-                  "version": "1.4.7"
-                },
-                "cookie-jar": {
-                  "version": "0.2.0"
-                },
-                "aws-sign": {
-                  "version": "0.2.0"
-                },
-                "oauth-sign": {
-                  "version": "0.2.0"
-                },
-                "forever-agent": {
-                  "version": "0.2.0"
-                },
-                "tunnel-agent": {
-                  "version": "0.2.0"
-                },
-                "json-stringify-safe": {
-                  "version": "3.0.0"
-                },
-                "qs": {
-                  "version": "0.5.6"
-                }
-              }
-            },
-            "stack-trace": {
-              "version": "0.0.9"
-            }
-          }
         }
       }
     },
@@ -4241,8 +3945,19 @@
         }
       }
     },
-    "grunt-contrib-jshint": {
-      "version": "1.0.0",
+    "grunt-ddescribe-iit": {
+      "version": "0.0.6",
+      "dependencies": {
+        "bluebird": {
+          "version": "2.10.2"
+        },
+        "win-spawn": {
+          "version": "2.0.0"
+        }
+      }
+    },
+    "grunt-eslint": {
+      "version": "19.0.0",
       "dependencies": {
         "chalk": {
           "version": "1.1.3",
@@ -4274,484 +3989,551 @@
             }
           }
         },
-        "hooker": {
-          "version": "0.2.3"
-        }
-      }
-    },
-    "grunt-ddescribe-iit": {
-      "version": "0.0.6",
-      "dependencies": {
-        "bluebird": {
-          "version": "2.10.2"
-        },
-        "win-spawn": {
-          "version": "2.0.0"
-        }
-      }
-    },
-    "grunt-jscs": {
-      "version": "3.0.1",
-      "dependencies": {
-        "hooker": {
-          "version": "0.2.3"
-        },
-        "jscs": {
-          "version": "3.0.7",
+        "eslint": {
+          "version": "3.2.2",
           "dependencies": {
-            "chalk": {
-              "version": "1.1.3",
+            "concat-stream": {
+              "version": "1.5.1",
               "dependencies": {
-                "ansi-styles": {
-                  "version": "2.2.1"
-                },
-                "escape-string-regexp": {
-                  "version": "1.0.5"
+                "inherits": {
+                  "version": "2.0.1"
                 },
-                "has-ansi": {
-                  "version": "2.0.0",
-                  "dependencies": {
-                    "ansi-regex": {
-                      "version": "2.0.0"
-                    }
-                  }
+                "typedarray": {
+                  "version": "0.0.6"
                 },
-                "strip-ansi": {
-                  "version": "3.0.1",
+                "readable-stream": {
+                  "version": "2.0.6",
                   "dependencies": {
-                    "ansi-regex": {
-                      "version": "2.0.0"
+                    "core-util-is": {
+                      "version": "1.0.2"
+                    },
+                    "isarray": {
+                      "version": "1.0.0"
+                    },
+                    "process-nextick-args": {
+                      "version": "1.0.7"
+                    },
+                    "string_decoder": {
+                      "version": "0.10.31"
+                    },
+                    "util-deprecate": {
+                      "version": "1.0.2"
                     }
                   }
-                },
-                "supports-color": {
-                  "version": "2.0.0"
                 }
               }
             },
-            "cli-table": {
-              "version": "0.3.1",
+            "debug": {
+              "version": "2.2.0",
               "dependencies": {
-                "colors": {
-                  "version": "1.0.3"
+                "ms": {
+                  "version": "0.7.1"
                 }
               }
             },
-            "commander": {
-              "version": "2.9.0",
+            "doctrine": {
+              "version": "1.2.2",
               "dependencies": {
-                "graceful-readlink": {
-                  "version": "1.0.1"
+                "esutils": {
+                  "version": "1.1.6"
+                },
+                "isarray": {
+                  "version": "1.0.0"
                 }
               }
             },
-            "cst": {
-              "version": "0.4.6",
+            "escope": {
+              "version": "3.6.0",
               "dependencies": {
-                "babel-runtime": {
-                  "version": "6.11.6",
+                "es6-map": {
+                  "version": "0.1.4",
                   "dependencies": {
-                    "core-js": {
-                      "version": "2.4.1"
+                    "d": {
+                      "version": "0.1.1"
                     },
-                    "regenerator-runtime": {
-                      "version": "0.9.5"
+                    "es5-ext": {
+                      "version": "0.10.12"
+                    },
+                    "es6-iterator": {
+                      "version": "2.0.0"
+                    },
+                    "es6-set": {
+                      "version": "0.1.4"
+                    },
+                    "es6-symbol": {
+                      "version": "3.1.0"
+                    },
+                    "event-emitter": {
+                      "version": "0.3.4"
                     }
                   }
                 },
-                "babylon": {
-                  "version": "6.8.4"
+                "es6-weak-map": {
+                  "version": "2.0.1",
+                  "dependencies": {
+                    "d": {
+                      "version": "0.1.1"
+                    },
+                    "es5-ext": {
+                      "version": "0.10.12"
+                    },
+                    "es6-iterator": {
+                      "version": "2.0.0"
+                    },
+                    "es6-symbol": {
+                      "version": "3.1.0"
+                    }
+                  }
                 },
-                "source-map-support": {
-                  "version": "0.4.2",
+                "esrecurse": {
+                  "version": "4.1.0",
                   "dependencies": {
-                    "source-map": {
-                      "version": "0.1.32",
-                      "dependencies": {
-                        "amdefine": {
-                          "version": "1.0.0"
-                        }
-                      }
+                    "estraverse": {
+                      "version": "4.1.1"
+                    },
+                    "object-assign": {
+                      "version": "4.1.0"
                     }
                   }
                 }
               }
             },
-            "estraverse": {
-              "version": "4.2.0"
-            },
-            "exit": {
-              "version": "0.1.2"
-            },
-            "glob": {
-              "version": "5.0.15",
+            "espree": {
+              "version": "3.1.7",
               "dependencies": {
-                "inflight": {
-                  "version": "1.0.5",
-                  "dependencies": {
-                    "wrappy": {
-                      "version": "1.0.2"
-                    }
-                  }
-                },
-                "inherits": {
-                  "version": "2.0.1"
-                },
-                "once": {
-                  "version": "1.3.3",
-                  "dependencies": {
-                    "wrappy": {
-                      "version": "1.0.2"
-                    }
-                  }
+                "acorn": {
+                  "version": "3.3.0"
                 },
-                "path-is-absolute": {
-                  "version": "1.0.0"
+                "acorn-jsx": {
+                  "version": "3.0.1"
                 }
               }
             },
-            "htmlparser2": {
-              "version": "3.8.3",
+            "estraverse": {
+              "version": "4.2.0"
+            },
+            "esutils": {
+              "version": "2.0.2"
+            },
+            "file-entry-cache": {
+              "version": "1.3.1",
               "dependencies": {
-                "domhandler": {
-                  "version": "2.3.0"
-                },
-                "domutils": {
-                  "version": "1.5.1",
+                "flat-cache": {
+                  "version": "1.2.1",
                   "dependencies": {
-                    "dom-serializer": {
-                      "version": "0.1.0",
+                    "circular-json": {
+                      "version": "0.3.1"
+                    },
+                    "del": {
+                      "version": "2.2.1",
                       "dependencies": {
-                        "domelementtype": {
-                          "version": "1.1.3"
-                        },
-                        "entities": {
-                          "version": "1.1.1"
-                        }
-                      }
-                    }
-                  }
-                },
-                "domelementtype": {
-                  "version": "1.3.0"
-                },
-                "readable-stream": {
-                  "version": "1.1.14",
-                  "dependencies": {
-                    "core-util-is": {
-                      "version": "1.0.2"
-                    },
-                    "isarray": {
-                      "version": "0.0.1"
+                        "globby": {
+                          "version": "5.0.0",
+                          "dependencies": {
+                            "array-union": {
+                              "version": "1.0.2",
+                              "dependencies": {
+                                "array-uniq": {
+                                  "version": "1.0.3"
+                                }
+                              }
+                            },
+                            "arrify": {
+                              "version": "1.0.1"
+                            }
+                          }
+                        },
+                        "is-path-cwd": {
+                          "version": "1.0.0"
+                        },
+                        "is-path-in-cwd": {
+                          "version": "1.0.0",
+                          "dependencies": {
+                            "is-path-inside": {
+                              "version": "1.0.0"
+                            }
+                          }
+                        },
+                        "pify": {
+                          "version": "2.3.0"
+                        },
+                        "pinkie-promise": {
+                          "version": "2.0.1",
+                          "dependencies": {
+                            "pinkie": {
+                              "version": "2.0.4"
+                            }
+                          }
+                        },
+                        "rimraf": {
+                          "version": "2.5.4"
+                        }
+                      }
                     },
-                    "string_decoder": {
-                      "version": "0.10.31"
+                    "graceful-fs": {
+                      "version": "4.1.5"
                     },
-                    "inherits": {
-                      "version": "2.0.1"
+                    "write": {
+                      "version": "0.2.1"
                     }
                   }
                 },
-                "entities": {
-                  "version": "1.0.0"
+                "object-assign": {
+                  "version": "4.1.0"
                 }
               }
             },
-            "js-yaml": {
-              "version": "3.4.6",
+            "glob": {
+              "version": "7.0.5",
               "dependencies": {
-                "argparse": {
-                  "version": "1.0.7",
+                "fs.realpath": {
+                  "version": "1.0.0"
+                },
+                "inflight": {
+                  "version": "1.0.5",
                   "dependencies": {
-                    "sprintf-js": {
-                      "version": "1.0.3"
+                    "wrappy": {
+                      "version": "1.0.2"
                     }
                   }
                 },
-                "esprima": {
-                  "version": "2.7.2"
+                "inherits": {
+                  "version": "2.0.1"
                 },
-                "inherit": {
-                  "version": "2.2.5"
-                }
-              }
-            },
-            "jscs-jsdoc": {
-              "version": "2.0.0",
-              "dependencies": {
-                "comment-parser": {
-                  "version": "0.3.1",
+                "minimatch": {
+                  "version": "3.0.2",
                   "dependencies": {
-                    "readable-stream": {
-                      "version": "2.1.4",
+                    "brace-expansion": {
+                      "version": "1.1.6",
                       "dependencies": {
-                        "buffer-shims": {
-                          "version": "1.0.0"
-                        },
-                        "core-util-is": {
-                          "version": "1.0.2"
-                        },
-                        "inherits": {
-                          "version": "2.0.1"
-                        },
-                        "isarray": {
-                          "version": "1.0.0"
-                        },
-                        "process-nextick-args": {
-                          "version": "1.0.7"
-                        },
-                        "string_decoder": {
-                          "version": "0.10.31"
+                        "balanced-match": {
+                          "version": "0.4.2"
                         },
-                        "util-deprecate": {
-                          "version": "1.0.2"
+                        "concat-map": {
+                          "version": "0.0.1"
                         }
                       }
                     }
                   }
                 },
-                "jsdoctypeparser": {
-                  "version": "1.2.0"
+                "once": {
+                  "version": "1.3.3",
+                  "dependencies": {
+                    "wrappy": {
+                      "version": "1.0.2"
+                    }
+                  }
+                },
+                "path-is-absolute": {
+                  "version": "1.0.0"
                 }
               }
             },
-            "jscs-preset-wikimedia": {
-              "version": "1.0.0"
+            "globals": {
+              "version": "9.9.0"
             },
-            "jsonlint": {
-              "version": "1.6.2",
+            "ignore": {
+              "version": "3.1.3"
+            },
+            "imurmurhash": {
+              "version": "0.1.4"
+            },
+            "inquirer": {
+              "version": "0.12.0",
               "dependencies": {
-                "nomnom": {
-                  "version": "1.8.1",
+                "ansi-escapes": {
+                  "version": "1.4.0"
+                },
+                "ansi-regex": {
+                  "version": "2.0.0"
+                },
+                "cli-cursor": {
+                  "version": "1.0.2",
                   "dependencies": {
-                    "underscore": {
-                      "version": "1.6.0"
-                    },
-                    "chalk": {
-                      "version": "0.4.0",
+                    "restore-cursor": {
+                      "version": "1.0.1",
                       "dependencies": {
-                        "has-color": {
-                          "version": "0.1.7"
-                        },
-                        "ansi-styles": {
-                          "version": "1.0.0"
+                        "exit-hook": {
+                          "version": "1.1.1"
                         },
-                        "strip-ansi": {
-                          "version": "0.1.1"
+                        "onetime": {
+                          "version": "1.1.0"
                         }
                       }
                     }
                   }
                 },
-                "JSV": {
-                  "version": "4.0.2"
-                }
-              }
-            },
-            "lodash": {
-              "version": "3.10.1"
-            },
-            "minimatch": {
-              "version": "3.0.2",
-              "dependencies": {
-                "brace-expansion": {
-                  "version": "1.1.6",
+                "cli-width": {
+                  "version": "2.1.0"
+                },
+                "figures": {
+                  "version": "1.7.0",
                   "dependencies": {
-                    "balanced-match": {
-                      "version": "0.4.2"
+                    "escape-string-regexp": {
+                      "version": "1.0.5"
                     },
-                    "concat-map": {
-                      "version": "0.0.1"
+                    "object-assign": {
+                      "version": "4.1.0"
                     }
                   }
-                }
-              }
-            },
-            "natural-compare": {
-              "version": "1.2.2"
-            },
-            "pathval": {
-              "version": "0.1.1"
-            },
-            "prompt": {
-              "version": "0.2.14",
-              "dependencies": {
-                "pkginfo": {
-                  "version": "0.4.0"
                 },
-                "read": {
-                  "version": "1.0.7",
+                "readline2": {
+                  "version": "1.0.1",
                   "dependencies": {
+                    "code-point-at": {
+                      "version": "1.0.0",
+                      "dependencies": {
+                        "number-is-nan": {
+                          "version": "1.0.0"
+                        }
+                      }
+                    },
+                    "is-fullwidth-code-point": {
+                      "version": "1.0.0",
+                      "dependencies": {
+                        "number-is-nan": {
+                          "version": "1.0.0"
+                        }
+                      }
+                    },
                     "mute-stream": {
-                      "version": "0.0.6"
+                      "version": "0.0.5"
+                    }
+                  }
+                },
+                "run-async": {
+                  "version": "0.1.0",
+                  "dependencies": {
+                    "once": {
+                      "version": "1.3.3",
+                      "dependencies": {
+                        "wrappy": {
+                          "version": "1.0.2"
+                        }
+                      }
                     }
                   }
                 },
-                "revalidator": {
-                  "version": "0.1.8"
+                "rx-lite": {
+                  "version": "3.1.2"
                 },
-                "utile": {
-                  "version": "0.2.1",
+                "string-width": {
+                  "version": "1.0.1",
                   "dependencies": {
-                    "async": {
-                      "version": "0.2.10"
-                    },
-                    "deep-equal": {
-                      "version": "1.0.1"
-                    },
-                    "i": {
-                      "version": "0.3.5"
-                    },
-                    "mkdirp": {
-                      "version": "0.5.1",
+                    "code-point-at": {
+                      "version": "1.0.0",
                       "dependencies": {
-                        "minimist": {
-                          "version": "0.0.8"
+                        "number-is-nan": {
+                          "version": "1.0.0"
                         }
                       }
                     },
-                    "ncp": {
-                      "version": "0.4.2"
-                    },
-                    "rimraf": {
-                      "version": "2.5.4",
+                    "is-fullwidth-code-point": {
+                      "version": "1.0.0",
                       "dependencies": {
-                        "glob": {
-                          "version": "7.0.5",
-                          "dependencies": {
-                            "fs.realpath": {
-                              "version": "1.0.0"
-                            },
-                            "inflight": {
-                              "version": "1.0.5",
-                              "dependencies": {
-                                "wrappy": {
-                                  "version": "1.0.2"
-                                }
-                              }
-                            },
-                            "inherits": {
-                              "version": "2.0.1"
-                            },
-                            "once": {
-                              "version": "1.3.3",
-                              "dependencies": {
-                                "wrappy": {
-                                  "version": "1.0.2"
-                                }
-                              }
-                            },
-                            "path-is-absolute": {
-                              "version": "1.0.0"
-                            }
-                          }
+                        "number-is-nan": {
+                          "version": "1.0.0"
                         }
                       }
                     }
                   }
                 },
-                "winston": {
-                  "version": "0.8.3",
-                  "dependencies": {
-                    "async": {
-                      "version": "0.2.10"
-                    },
-                    "colors": {
-                      "version": "0.6.2"
-                    },
-                    "cycle": {
-                      "version": "1.0.3"
-                    },
-                    "eyes": {
-                      "version": "0.1.8"
-                    },
-                    "isstream": {
-                      "version": "0.1.2"
-                    },
-                    "pkginfo": {
-                      "version": "0.3.1"
-                    },
-                    "stack-trace": {
-                      "version": "0.0.9"
-                    }
-                  }
+                "strip-ansi": {
+                  "version": "3.0.1"
+                },
+                "through": {
+                  "version": "2.3.8"
                 }
               }
             },
-            "reserved-words": {
-              "version": "0.1.1"
-            },
-            "resolve": {
-              "version": "1.1.7"
-            },
-            "strip-bom": {
-              "version": "2.0.0",
+            "is-my-json-valid": {
+              "version": "2.13.1",
               "dependencies": {
-                "is-utf8": {
-                  "version": "0.2.1"
-                }
+                "generate-function": {
+                  "version": "2.0.0"
+                },
+                "generate-object-property": {
+                  "version": "1.2.0",
+                  "dependencies": {
+                    "is-property": {
+                      "version": "1.0.2"
+                    }
+                  }
+                },
+                "jsonpointer": {
+                  "version": "2.0.0"
+                },
+                "xtend": {
+                  "version": "4.0.1"
+                }
               }
             },
-            "strip-json-comments": {
-              "version": "1.0.4"
+            "is-resolvable": {
+              "version": "1.0.0",
+              "dependencies": {
+                "tryit": {
+                  "version": "1.0.2"
+                }
+              }
             },
-            "to-double-quotes": {
-              "version": "2.0.0"
+            "js-yaml": {
+              "version": "3.6.1",
+              "dependencies": {
+                "argparse": {
+                  "version": "1.0.7",
+                  "dependencies": {
+                    "sprintf-js": {
+                      "version": "1.0.3"
+                    }
+                  }
+                },
+                "esprima": {
+                  "version": "2.7.2"
+                }
+              }
             },
-            "to-single-quotes": {
-              "version": "2.0.1"
+            "json-stable-stringify": {
+              "version": "1.0.1",
+              "dependencies": {
+                "jsonify": {
+                  "version": "0.0.0"
+                }
+              }
             },
-            "vow-fs": {
-              "version": "0.3.6",
+            "levn": {
+              "version": "0.3.0",
               "dependencies": {
-                "uuid": {
-                  "version": "2.0.2"
+                "prelude-ls": {
+                  "version": "1.1.2"
                 },
-                "vow-queue": {
-                  "version": "0.4.2"
+                "type-check": {
+                  "version": "0.3.2"
+                }
+              }
+            },
+            "lodash": {
+              "version": "4.14.1"
+            },
+            "mkdirp": {
+              "version": "0.5.1",
+              "dependencies": {
+                "minimist": {
+                  "version": "0.0.8"
+                }
+              }
+            },
+            "optionator": {
+              "version": "0.8.1",
+              "dependencies": {
+                "prelude-ls": {
+                  "version": "1.1.2"
                 },
-                "glob": {
-                  "version": "7.0.5",
+                "deep-is": {
+                  "version": "0.1.3"
+                },
+                "wordwrap": {
+                  "version": "1.0.0"
+                },
+                "type-check": {
+                  "version": "0.3.2"
+                },
+                "fast-levenshtein": {
+                  "version": "1.1.4"
+                }
+              }
+            },
+            "path-is-inside": {
+              "version": "1.0.1"
+            },
+            "pluralize": {
+              "version": "1.2.1"
+            },
+            "progress": {
+              "version": "1.1.8"
+            },
+            "require-uncached": {
+              "version": "1.0.2",
+              "dependencies": {
+                "caller-path": {
+                  "version": "0.1.0",
                   "dependencies": {
-                    "fs.realpath": {
-                      "version": "1.0.0"
-                    },
-                    "inflight": {
-                      "version": "1.0.5",
+                    "callsites": {
+                      "version": "0.2.0"
+                    }
+                  }
+                },
+                "resolve-from": {
+                  "version": "1.0.1"
+                }
+              }
+            },
+            "shelljs": {
+              "version": "0.6.0"
+            },
+            "strip-bom": {
+              "version": "3.0.0"
+            },
+            "strip-json-comments": {
+              "version": "1.0.4"
+            },
+            "table": {
+              "version": "3.7.8",
+              "dependencies": {
+                "bluebird": {
+                  "version": "3.4.1"
+                },
+                "slice-ansi": {
+                  "version": "0.0.4"
+                },
+                "string-width": {
+                  "version": "1.0.1",
+                  "dependencies": {
+                    "code-point-at": {
+                      "version": "1.0.0",
                       "dependencies": {
-                        "wrappy": {
-                          "version": "1.0.2"
+                        "number-is-nan": {
+                          "version": "1.0.0"
                         }
                       }
                     },
-                    "inherits": {
-                      "version": "2.0.1"
-                    },
-                    "once": {
-                      "version": "1.3.3",
+                    "is-fullwidth-code-point": {
+                      "version": "1.0.0",
                       "dependencies": {
-                        "wrappy": {
-                          "version": "1.0.2"
+                        "number-is-nan": {
+                          "version": "1.0.0"
                         }
                       }
-                    },
-                    "path-is-absolute": {
-                      "version": "1.0.0"
                     }
                   }
+                },
+                "strip-ansi": {
+                  "version": "3.0.1",
+                  "dependencies": {
+                    "ansi-regex": {
+                      "version": "2.0.0"
+                    }
+                  }
+                },
+                "tv4": {
+                  "version": "1.2.7"
+                },
+                "xregexp": {
+                  "version": "3.1.1"
                 }
               }
             },
-            "xmlbuilder": {
-              "version": "3.1.0"
+            "text-table": {
+              "version": "0.2.0"
+            },
+            "user-home": {
+              "version": "2.0.0",
+              "dependencies": {
+                "os-homedir": {
+                  "version": "1.0.1"
+                }
+              }
             }
           }
-        },
-        "lodash": {
-          "version": "4.6.1"
-        },
-        "vow": {
-          "version": "0.4.12"
         }
       }
     },
@@ -4971,107 +4753,693 @@
                 }
               }
             },
-            "glob-stream": {
-              "version": "3.1.18",
+            "glob-stream": {
+              "version": "3.1.18",
+              "dependencies": {
+                "glob": {
+                  "version": "4.5.3",
+                  "dependencies": {
+                    "inflight": {
+                      "version": "1.0.4",
+                      "dependencies": {
+                        "wrappy": {
+                          "version": "1.0.1"
+                        }
+                      }
+                    },
+                    "inherits": {
+                      "version": "2.0.1"
+                    },
+                    "once": {
+                      "version": "1.3.3",
+                      "dependencies": {
+                        "wrappy": {
+                          "version": "1.0.1"
+                        }
+                      }
+                    }
+                  }
+                },
+                "minimatch": {
+                  "version": "2.0.10",
+                  "dependencies": {
+                    "brace-expansion": {
+                      "version": "1.1.4",
+                      "dependencies": {
+                        "balanced-match": {
+                          "version": "0.4.1"
+                        },
+                        "concat-map": {
+                          "version": "0.0.1"
+                        }
+                      }
+                    }
+                  }
+                },
+                "ordered-read-streams": {
+                  "version": "0.1.0"
+                },
+                "glob2base": {
+                  "version": "0.0.12",
+                  "dependencies": {
+                    "find-index": {
+                      "version": "0.1.1"
+                    }
+                  }
+                },
+                "unique-stream": {
+                  "version": "1.0.0"
+                }
+              }
+            },
+            "glob-watcher": {
+              "version": "0.0.6",
+              "dependencies": {
+                "gaze": {
+                  "version": "0.5.2",
+                  "dependencies": {
+                    "globule": {
+                      "version": "0.1.0",
+                      "dependencies": {
+                        "lodash": {
+                          "version": "1.0.2"
+                        },
+                        "glob": {
+                          "version": "3.1.21",
+                          "dependencies": {
+                            "graceful-fs": {
+                              "version": "1.2.3"
+                            },
+                            "inherits": {
+                              "version": "1.0.2"
+                            }
+                          }
+                        },
+                        "minimatch": {
+                          "version": "0.2.14",
+                          "dependencies": {
+                            "lru-cache": {
+                              "version": "2.7.3"
+                            },
+                            "sigmund": {
+                              "version": "1.0.1"
+                            }
+                          }
+                        }
+                      }
+                    }
+                  }
+                }
+              }
+            },
+            "graceful-fs": {
+              "version": "3.0.8"
+            },
+            "mkdirp": {
+              "version": "0.5.1",
+              "dependencies": {
+                "minimist": {
+                  "version": "0.0.8"
+                }
+              }
+            },
+            "strip-bom": {
+              "version": "1.0.0",
+              "dependencies": {
+                "first-chunk-stream": {
+                  "version": "1.0.0"
+                },
+                "is-utf8": {
+                  "version": "0.2.1"
+                }
+              }
+            },
+            "through2": {
+              "version": "0.6.5",
+              "dependencies": {
+                "readable-stream": {
+                  "version": "1.0.34",
+                  "dependencies": {
+                    "core-util-is": {
+                      "version": "1.0.2"
+                    },
+                    "isarray": {
+                      "version": "0.0.1"
+                    },
+                    "string_decoder": {
+                      "version": "0.10.31"
+                    },
+                    "inherits": {
+                      "version": "2.0.1"
+                    }
+                  }
+                },
+                "xtend": {
+                  "version": "4.0.1"
+                }
+              }
+            },
+            "vinyl": {
+              "version": "0.4.6",
+              "dependencies": {
+                "clone": {
+                  "version": "0.2.0"
+                },
+                "clone-stats": {
+                  "version": "0.0.1"
+                }
+              }
+            }
+          }
+        }
+      }
+    },
+    "gulp-concat": {
+      "version": "2.6.0",
+      "dependencies": {
+        "concat-with-sourcemaps": {
+          "version": "1.0.4",
+          "dependencies": {
+            "source-map": {
+              "version": "0.5.6"
+            }
+          }
+        },
+        "through2": {
+          "version": "0.6.5",
+          "dependencies": {
+            "readable-stream": {
+              "version": "1.0.34",
+              "dependencies": {
+                "core-util-is": {
+                  "version": "1.0.2"
+                },
+                "isarray": {
+                  "version": "0.0.1"
+                },
+                "string_decoder": {
+                  "version": "0.10.31"
+                },
+                "inherits": {
+                  "version": "2.0.1"
+                }
+              }
+            },
+            "xtend": {
+              "version": "4.0.1"
+            }
+          }
+        }
+      }
+    },
+    "gulp-eslint": {
+      "version": "3.0.1",
+      "dependencies": {
+        "bufferstreams": {
+          "version": "1.1.1",
+          "dependencies": {
+            "readable-stream": {
+              "version": "2.1.4",
+              "dependencies": {
+                "buffer-shims": {
+                  "version": "1.0.0"
+                },
+                "core-util-is": {
+                  "version": "1.0.2"
+                },
+                "inherits": {
+                  "version": "2.0.1"
+                },
+                "isarray": {
+                  "version": "1.0.0"
+                },
+                "process-nextick-args": {
+                  "version": "1.0.7"
+                },
+                "string_decoder": {
+                  "version": "0.10.31"
+                },
+                "util-deprecate": {
+                  "version": "1.0.2"
+                }
+              }
+            }
+          }
+        },
+        "eslint": {
+          "version": "3.2.2",
+          "dependencies": {
+            "chalk": {
+              "version": "1.1.3",
+              "dependencies": {
+                "ansi-styles": {
+                  "version": "2.2.1"
+                },
+                "escape-string-regexp": {
+                  "version": "1.0.5"
+                },
+                "has-ansi": {
+                  "version": "2.0.0",
+                  "dependencies": {
+                    "ansi-regex": {
+                      "version": "2.0.0"
+                    }
+                  }
+                },
+                "strip-ansi": {
+                  "version": "3.0.1",
+                  "dependencies": {
+                    "ansi-regex": {
+                      "version": "2.0.0"
+                    }
+                  }
+                },
+                "supports-color": {
+                  "version": "2.0.0"
+                }
+              }
+            },
+            "concat-stream": {
+              "version": "1.5.1",
+              "dependencies": {
+                "inherits": {
+                  "version": "2.0.1"
+                },
+                "typedarray": {
+                  "version": "0.0.6"
+                },
+                "readable-stream": {
+                  "version": "2.0.6",
+                  "dependencies": {
+                    "core-util-is": {
+                      "version": "1.0.2"
+                    },
+                    "isarray": {
+                      "version": "1.0.0"
+                    },
+                    "process-nextick-args": {
+                      "version": "1.0.7"
+                    },
+                    "string_decoder": {
+                      "version": "0.10.31"
+                    },
+                    "util-deprecate": {
+                      "version": "1.0.2"
+                    }
+                  }
+                }
+              }
+            },
+            "debug": {
+              "version": "2.2.0",
+              "dependencies": {
+                "ms": {
+                  "version": "0.7.1"
+                }
+              }
+            },
+            "doctrine": {
+              "version": "1.2.2",
+              "dependencies": {
+                "esutils": {
+                  "version": "1.1.6"
+                },
+                "isarray": {
+                  "version": "1.0.0"
+                }
+              }
+            },
+            "escope": {
+              "version": "3.6.0",
+              "dependencies": {
+                "es6-map": {
+                  "version": "0.1.4",
+                  "dependencies": {
+                    "d": {
+                      "version": "0.1.1"
+                    },
+                    "es5-ext": {
+                      "version": "0.10.12"
+                    },
+                    "es6-iterator": {
+                      "version": "2.0.0"
+                    },
+                    "es6-set": {
+                      "version": "0.1.4"
+                    },
+                    "es6-symbol": {
+                      "version": "3.1.0"
+                    },
+                    "event-emitter": {
+                      "version": "0.3.4"
+                    }
+                  }
+                },
+                "es6-weak-map": {
+                  "version": "2.0.1",
+                  "dependencies": {
+                    "d": {
+                      "version": "0.1.1"
+                    },
+                    "es5-ext": {
+                      "version": "0.10.12"
+                    },
+                    "es6-iterator": {
+                      "version": "2.0.0"
+                    },
+                    "es6-symbol": {
+                      "version": "3.1.0"
+                    }
+                  }
+                },
+                "esrecurse": {
+                  "version": "4.1.0",
+                  "dependencies": {
+                    "estraverse": {
+                      "version": "4.1.1"
+                    },
+                    "object-assign": {
+                      "version": "4.1.0"
+                    }
+                  }
+                }
+              }
+            },
+            "espree": {
+              "version": "3.1.7",
+              "dependencies": {
+                "acorn": {
+                  "version": "3.3.0"
+                },
+                "acorn-jsx": {
+                  "version": "3.0.1"
+                }
+              }
+            },
+            "estraverse": {
+              "version": "4.2.0"
+            },
+            "esutils": {
+              "version": "2.0.2"
+            },
+            "file-entry-cache": {
+              "version": "1.3.1",
+              "dependencies": {
+                "flat-cache": {
+                  "version": "1.2.1",
+                  "dependencies": {
+                    "circular-json": {
+                      "version": "0.3.1"
+                    },
+                    "del": {
+                      "version": "2.2.1",
+                      "dependencies": {
+                        "globby": {
+                          "version": "5.0.0",
+                          "dependencies": {
+                            "array-union": {
+                              "version": "1.0.2",
+                              "dependencies": {
+                                "array-uniq": {
+                                  "version": "1.0.3"
+                                }
+                              }
+                            },
+                            "arrify": {
+                              "version": "1.0.1"
+                            }
+                          }
+                        },
+                        "is-path-cwd": {
+                          "version": "1.0.0"
+                        },
+                        "is-path-in-cwd": {
+                          "version": "1.0.0",
+                          "dependencies": {
+                            "is-path-inside": {
+                              "version": "1.0.0"
+                            }
+                          }
+                        },
+                        "pify": {
+                          "version": "2.3.0"
+                        },
+                        "pinkie-promise": {
+                          "version": "2.0.1",
+                          "dependencies": {
+                            "pinkie": {
+                              "version": "2.0.4"
+                            }
+                          }
+                        },
+                        "rimraf": {
+                          "version": "2.5.4"
+                        }
+                      }
+                    },
+                    "graceful-fs": {
+                      "version": "4.1.5"
+                    },
+                    "write": {
+                      "version": "0.2.1"
+                    }
+                  }
+                },
+                "object-assign": {
+                  "version": "4.1.0"
+                }
+              }
+            },
+            "glob": {
+              "version": "7.0.5",
+              "dependencies": {
+                "fs.realpath": {
+                  "version": "1.0.0"
+                },
+                "inflight": {
+                  "version": "1.0.5",
+                  "dependencies": {
+                    "wrappy": {
+                      "version": "1.0.2"
+                    }
+                  }
+                },
+                "inherits": {
+                  "version": "2.0.1"
+                },
+                "minimatch": {
+                  "version": "3.0.2",
+                  "dependencies": {
+                    "brace-expansion": {
+                      "version": "1.1.6",
+                      "dependencies": {
+                        "balanced-match": {
+                          "version": "0.4.2"
+                        },
+                        "concat-map": {
+                          "version": "0.0.1"
+                        }
+                      }
+                    }
+                  }
+                },
+                "once": {
+                  "version": "1.3.3",
+                  "dependencies": {
+                    "wrappy": {
+                      "version": "1.0.2"
+                    }
+                  }
+                },
+                "path-is-absolute": {
+                  "version": "1.0.0"
+                }
+              }
+            },
+            "globals": {
+              "version": "9.9.0"
+            },
+            "ignore": {
+              "version": "3.1.3"
+            },
+            "imurmurhash": {
+              "version": "0.1.4"
+            },
+            "inquirer": {
+              "version": "0.12.0",
               "dependencies": {
-                "glob": {
-                  "version": "4.5.3",
+                "ansi-escapes": {
+                  "version": "1.4.0"
+                },
+                "ansi-regex": {
+                  "version": "2.0.0"
+                },
+                "cli-cursor": {
+                  "version": "1.0.2",
                   "dependencies": {
-                    "inflight": {
-                      "version": "1.0.4",
+                    "restore-cursor": {
+                      "version": "1.0.1",
                       "dependencies": {
-                        "wrappy": {
-                          "version": "1.0.1"
+                        "exit-hook": {
+                          "version": "1.1.1"
+                        },
+                        "onetime": {
+                          "version": "1.1.0"
+                        }
+                      }
+                    }
+                  }
+                },
+                "cli-width": {
+                  "version": "2.1.0"
+                },
+                "figures": {
+                  "version": "1.7.0",
+                  "dependencies": {
+                    "escape-string-regexp": {
+                      "version": "1.0.5"
+                    },
+                    "object-assign": {
+                      "version": "4.1.0"
+                    }
+                  }
+                },
+                "readline2": {
+                  "version": "1.0.1",
+                  "dependencies": {
+                    "code-point-at": {
+                      "version": "1.0.0",
+                      "dependencies": {
+                        "number-is-nan": {
+                          "version": "1.0.0"
                         }
                       }
                     },
-                    "inherits": {
-                      "version": "2.0.1"
+                    "is-fullwidth-code-point": {
+                      "version": "1.0.0",
+                      "dependencies": {
+                        "number-is-nan": {
+                          "version": "1.0.0"
+                        }
+                      }
                     },
+                    "mute-stream": {
+                      "version": "0.0.5"
+                    }
+                  }
+                },
+                "run-async": {
+                  "version": "0.1.0",
+                  "dependencies": {
                     "once": {
                       "version": "1.3.3",
                       "dependencies": {
                         "wrappy": {
-                          "version": "1.0.1"
+                          "version": "1.0.2"
                         }
                       }
                     }
                   }
                 },
-                "minimatch": {
-                  "version": "2.0.10",
+                "rx-lite": {
+                  "version": "3.1.2"
+                },
+                "string-width": {
+                  "version": "1.0.1",
                   "dependencies": {
-                    "brace-expansion": {
-                      "version": "1.1.4",
+                    "code-point-at": {
+                      "version": "1.0.0",
                       "dependencies": {
-                        "balanced-match": {
-                          "version": "0.4.1"
-                        },
-                        "concat-map": {
-                          "version": "0.0.1"
+                        "number-is-nan": {
+                          "version": "1.0.0"
+                        }
+                      }
+                    },
+                    "is-fullwidth-code-point": {
+                      "version": "1.0.0",
+                      "dependencies": {
+                        "number-is-nan": {
+                          "version": "1.0.0"
                         }
                       }
                     }
                   }
                 },
-                "ordered-read-streams": {
-                  "version": "0.1.0"
+                "strip-ansi": {
+                  "version": "3.0.1"
                 },
-                "glob2base": {
-                  "version": "0.0.12",
+                "through": {
+                  "version": "2.3.8"
+                }
+              }
+            },
+            "is-my-json-valid": {
+              "version": "2.13.1",
+              "dependencies": {
+                "generate-function": {
+                  "version": "2.0.0"
+                },
+                "generate-object-property": {
+                  "version": "1.2.0",
                   "dependencies": {
-                    "find-index": {
-                      "version": "0.1.1"
+                    "is-property": {
+                      "version": "1.0.2"
                     }
                   }
                 },
-                "unique-stream": {
-                  "version": "1.0.0"
+                "jsonpointer": {
+                  "version": "2.0.0"
+                },
+                "xtend": {
+                  "version": "4.0.1"
                 }
               }
             },
-            "glob-watcher": {
-              "version": "0.0.6",
+            "is-resolvable": {
+              "version": "1.0.0",
               "dependencies": {
-                "gaze": {
-                  "version": "0.5.2",
+                "tryit": {
+                  "version": "1.0.2"
+                }
+              }
+            },
+            "js-yaml": {
+              "version": "3.6.1",
+              "dependencies": {
+                "argparse": {
+                  "version": "1.0.7",
                   "dependencies": {
-                    "globule": {
-                      "version": "0.1.0",
-                      "dependencies": {
-                        "lodash": {
-                          "version": "1.0.2"
-                        },
-                        "glob": {
-                          "version": "3.1.21",
-                          "dependencies": {
-                            "graceful-fs": {
-                              "version": "1.2.3"
-                            },
-                            "inherits": {
-                              "version": "1.0.2"
-                            }
-                          }
-                        },
-                        "minimatch": {
-                          "version": "0.2.14",
-                          "dependencies": {
-                            "lru-cache": {
-                              "version": "2.7.3"
-                            },
-                            "sigmund": {
-                              "version": "1.0.1"
-                            }
-                          }
-                        }
-                      }
+                    "sprintf-js": {
+                      "version": "1.0.3"
                     }
                   }
+                },
+                "esprima": {
+                  "version": "2.7.2"
                 }
               }
             },
-            "graceful-fs": {
-              "version": "3.0.8"
+            "json-stable-stringify": {
+              "version": "1.0.1",
+              "dependencies": {
+                "jsonify": {
+                  "version": "0.0.0"
+                }
+              }
+            },
+            "levn": {
+              "version": "0.3.0",
+              "dependencies": {
+                "prelude-ls": {
+                  "version": "1.1.2"
+                },
+                "type-check": {
+                  "version": "0.3.2"
+                }
+              }
+            },
+            "lodash": {
+              "version": "4.14.1"
             },
             "mkdirp": {
               "version": "0.5.1",
@@ -5081,90 +5449,116 @@
                 }
               }
             },
-            "strip-bom": {
-              "version": "1.0.0",
+            "optionator": {
+              "version": "0.8.1",
               "dependencies": {
-                "first-chunk-stream": {
+                "prelude-ls": {
+                  "version": "1.1.2"
+                },
+                "deep-is": {
+                  "version": "0.1.3"
+                },
+                "wordwrap": {
                   "version": "1.0.0"
                 },
-                "is-utf8": {
-                  "version": "0.2.1"
+                "type-check": {
+                  "version": "0.3.2"
+                },
+                "fast-levenshtein": {
+                  "version": "1.1.4"
                 }
               }
             },
-            "through2": {
-              "version": "0.6.5",
+            "path-is-inside": {
+              "version": "1.0.1"
+            },
+            "pluralize": {
+              "version": "1.2.1"
+            },
+            "progress": {
+              "version": "1.1.8"
+            },
+            "require-uncached": {
+              "version": "1.0.2",
               "dependencies": {
-                "readable-stream": {
-                  "version": "1.0.34",
+                "caller-path": {
+                  "version": "0.1.0",
                   "dependencies": {
-                    "core-util-is": {
-                      "version": "1.0.2"
-                    },
-                    "isarray": {
-                      "version": "0.0.1"
-                    },
-                    "string_decoder": {
-                      "version": "0.10.31"
-                    },
-                    "inherits": {
-                      "version": "2.0.1"
+                    "callsites": {
+                      "version": "0.2.0"
                     }
                   }
                 },
-                "xtend": {
-                  "version": "4.0.1"
+                "resolve-from": {
+                  "version": "1.0.1"
                 }
               }
             },
-            "vinyl": {
-              "version": "0.4.6",
-              "dependencies": {
-                "clone": {
-                  "version": "0.2.0"
-                },
-                "clone-stats": {
-                  "version": "0.0.1"
-                }
-              }
-            }
-          }
-        }
-      }
-    },
-    "gulp-concat": {
-      "version": "2.6.0",
-      "dependencies": {
-        "concat-with-sourcemaps": {
-          "version": "1.0.4",
-          "dependencies": {
-            "source-map": {
-              "version": "0.5.6"
-            }
-          }
-        },
-        "through2": {
-          "version": "0.6.5",
-          "dependencies": {
-            "readable-stream": {
-              "version": "1.0.34",
+            "shelljs": {
+              "version": "0.6.0"
+            },
+            "strip-bom": {
+              "version": "3.0.0"
+            },
+            "strip-json-comments": {
+              "version": "1.0.4"
+            },
+            "table": {
+              "version": "3.7.8",
               "dependencies": {
-                "core-util-is": {
-                  "version": "1.0.2"
+                "bluebird": {
+                  "version": "3.4.1"
                 },
-                "isarray": {
-                  "version": "0.0.1"
+                "slice-ansi": {
+                  "version": "0.0.4"
                 },
-                "string_decoder": {
-                  "version": "0.10.31"
+                "string-width": {
+                  "version": "1.0.1",
+                  "dependencies": {
+                    "code-point-at": {
+                      "version": "1.0.0",
+                      "dependencies": {
+                        "number-is-nan": {
+                          "version": "1.0.0"
+                        }
+                      }
+                    },
+                    "is-fullwidth-code-point": {
+                      "version": "1.0.0",
+                      "dependencies": {
+                        "number-is-nan": {
+                          "version": "1.0.0"
+                        }
+                      }
+                    }
+                  }
                 },
-                "inherits": {
-                  "version": "2.0.1"
+                "strip-ansi": {
+                  "version": "3.0.1",
+                  "dependencies": {
+                    "ansi-regex": {
+                      "version": "2.0.0"
+                    }
+                  }
+                },
+                "tv4": {
+                  "version": "1.2.7"
+                },
+                "xregexp": {
+                  "version": "3.1.1"
                 }
               }
             },
-            "xtend": {
-              "version": "4.0.1"
+            "text-table": {
+              "version": "0.2.0"
+            },
+            "user-home": {
+              "version": "2.0.0",
+              "dependencies": {
+                "os-homedir": {
+                  "version": "1.0.1"
+                }
+              }
             }
           }
         }
@@ -5544,76 +5938,6 @@
         }
       }
     },
-    "gulp-jshint": {
-      "version": "2.0.1",
-      "dependencies": {
-        "lodash": {
-          "version": "4.12.0"
-        },
-        "minimatch": {
-          "version": "2.0.10",
-          "dependencies": {
-            "brace-expansion": {
-              "version": "1.1.4",
-              "dependencies": {
-                "balanced-match": {
-                  "version": "0.4.1"
-                },
-                "concat-map": {
-                  "version": "0.0.1"
-                }
-              }
-            }
-          }
-        },
-        "rcloader": {
-          "version": "0.1.2",
-          "dependencies": {
-            "rcfinder": {
-              "version": "0.1.9",
-              "dependencies": {
-                "lodash.clonedeep": {
-                  "version": "4.3.2",
-                  "dependencies": {
-                    "lodash._baseclone": {
-                      "version": "4.5.6"
-                    }
-                  }
-                }
-              }
-            },
-            "lodash": {
-              "version": "2.4.2"
-            }
-          }
-        },
-        "through2": {
-          "version": "0.6.5",
-          "dependencies": {
-            "readable-stream": {
-              "version": "1.0.34",
-              "dependencies": {
-                "core-util-is": {
-                  "version": "1.0.2"
-                },
-                "isarray": {
-                  "version": "0.0.1"
-                },
-                "string_decoder": {
-                  "version": "0.10.31"
-                },
-                "inherits": {
-                  "version": "2.0.1"
-                }
-              }
-            },
-            "xtend": {
-              "version": "4.0.1"
-            }
-          }
-        }
-      }
-    },
     "gulp-rename": {
       "version": "1.2.2"
     },
@@ -6373,180 +6697,6 @@
         }
       }
     },
-    "jshint": {
-      "version": "2.9.2",
-      "dependencies": {
-        "cli": {
-          "version": "0.6.6",
-          "dependencies": {
-            "glob": {
-              "version": "3.2.11",
-              "dependencies": {
-                "inherits": {
-                  "version": "2.0.1"
-                },
-                "minimatch": {
-                  "version": "0.3.0",
-                  "dependencies": {
-                    "lru-cache": {
-                      "version": "2.7.3"
-                    },
-                    "sigmund": {
-                      "version": "1.0.1"
-                    }
-                  }
-                }
-              }
-            }
-          }
-        },
-        "console-browserify": {
-          "version": "1.1.0",
-          "dependencies": {
-            "date-now": {
-              "version": "0.1.4"
-            }
-          }
-        },
-        "exit": {
-          "version": "0.1.2"
-        },
-        "htmlparser2": {
-          "version": "3.8.3",
-          "dependencies": {
-            "domhandler": {
-              "version": "2.3.0"
-            },
-            "domutils": {
-              "version": "1.5.1",
-              "dependencies": {
-                "dom-serializer": {
-                  "version": "0.1.0",
-                  "dependencies": {
-                    "domelementtype": {
-                      "version": "1.1.3"
-                    },
-                    "entities": {
-                      "version": "1.1.1"
-                    }
-                  }
-                }
-              }
-            },
-            "domelementtype": {
-              "version": "1.3.0"
-            },
-            "readable-stream": {
-              "version": "1.1.14",
-              "dependencies": {
-                "core-util-is": {
-                  "version": "1.0.2"
-                },
-                "isarray": {
-                  "version": "0.0.1"
-                },
-                "string_decoder": {
-                  "version": "0.10.31"
-                },
-                "inherits": {
-                  "version": "2.0.1"
-                }
-              }
-            },
-            "entities": {
-              "version": "1.0.0"
-            }
-          }
-        },
-        "minimatch": {
-          "version": "2.0.10",
-          "dependencies": {
-            "brace-expansion": {
-              "version": "1.1.4",
-              "dependencies": {
-                "balanced-match": {
-                  "version": "0.4.1"
-                },
-                "concat-map": {
-                  "version": "0.0.1"
-                }
-              }
-            }
-          }
-        },
-        "strip-json-comments": {
-          "version": "1.0.4"
-        },
-        "lodash": {
-          "version": "3.7.0"
-        }
-      }
-    },
-    "jshint-stylish": {
-      "version": "2.2.0",
-      "dependencies": {
-        "chalk": {
-          "version": "1.1.3",
-          "dependencies": {
-            "ansi-styles": {
-              "version": "2.2.1"
-            },
-            "escape-string-regexp": {
-              "version": "1.0.5"
-            },
-            "has-ansi": {
-              "version": "2.0.0",
-              "dependencies": {
-                "ansi-regex": {
-                  "version": "2.0.0"
-                }
-              }
-            },
-            "strip-ansi": {
-              "version": "3.0.1",
-              "dependencies": {
-                "ansi-regex": {
-                  "version": "2.0.0"
-                }
-              }
-            },
-            "supports-color": {
-              "version": "2.0.0"
-            }
-          }
-        },
-        "log-symbols": {
-          "version": "1.0.2"
-        },
-        "plur": {
-          "version": "2.1.2",
-          "dependencies": {
-            "irregular-plurals": {
-              "version": "1.1.0"
-            }
-          }
-        },
-        "string-length": {
-          "version": "1.0.1",
-          "dependencies": {
-            "strip-ansi": {
-              "version": "3.0.1",
-              "dependencies": {
-                "ansi-regex": {
-                  "version": "2.0.0"
-                }
-              }
-            }
-          }
-        },
-        "text-table": {
-          "version": "0.2.0"
-        },
-        "beeper": {
-          "version": "1.1.0"
-        }
-      }
-    },
     "karma": {
       "version": "1.1.2",
       "dependencies": {
@@ -8999,9 +9149,6 @@
     },
     "stringmap": {
       "version": "0.2.2"
-    },
-    "strip-json-comments": {
-      "version": "2.0.1"
     }
   },
   "name": "angularjs"
diff --git a/npm-shrinkwrap.json b/npm-shrinkwrap.json
index 375b93810ab1..c176d82cb3ec 100644
--- a/npm-shrinkwrap.json
+++ b/npm-shrinkwrap.json
@@ -3199,86 +3199,86 @@
     },
     "browserstacktunnel-wrapper": {
       "version": "1.4.2",
-      "from": "browserstacktunnel-wrapper@1.4.2",
+      "from": "https://registry.npmjs.org/browserstacktunnel-wrapper/-/browserstacktunnel-wrapper-1.4.2.tgz",
       "resolved": "https://registry.npmjs.org/browserstacktunnel-wrapper/-/browserstacktunnel-wrapper-1.4.2.tgz",
       "dependencies": {
         "unzip": {
           "version": "0.1.11",
-          "from": "unzip@>=0.1.9 <0.2.0",
+          "from": "https://registry.npmjs.org/unzip/-/unzip-0.1.11.tgz",
           "resolved": "https://registry.npmjs.org/unzip/-/unzip-0.1.11.tgz",
           "dependencies": {
             "fstream": {
               "version": "0.1.31",
-              "from": "fstream@>=0.1.30 <1.0.0",
+              "from": "https://registry.npmjs.org/fstream/-/fstream-0.1.31.tgz",
               "resolved": "https://registry.npmjs.org/fstream/-/fstream-0.1.31.tgz",
               "dependencies": {
                 "graceful-fs": {
                   "version": "3.0.8",
-                  "from": "graceful-fs@>=3.0.2 <3.1.0",
+                  "from": "https://registry.npmjs.org/graceful-fs/-/graceful-fs-3.0.8.tgz",
                   "resolved": "https://registry.npmjs.org/graceful-fs/-/graceful-fs-3.0.8.tgz"
                 },
                 "inherits": {
                   "version": "2.0.1",
-                  "from": "inherits@>=2.0.0 <2.1.0",
+                  "from": "https://registry.npmjs.org/inherits/-/inherits-2.0.1.tgz",
                   "resolved": "https://registry.npmjs.org/inherits/-/inherits-2.0.1.tgz"
                 },
                 "mkdirp": {
                   "version": "0.5.1",
-                  "from": "mkdirp@>=0.5.0 <0.6.0",
+                  "from": "https://registry.npmjs.org/mkdirp/-/mkdirp-0.5.1.tgz",
                   "resolved": "https://registry.npmjs.org/mkdirp/-/mkdirp-0.5.1.tgz",
                   "dependencies": {
                     "minimist": {
                       "version": "0.0.8",
-                      "from": "minimist@0.0.8",
+                      "from": "https://registry.npmjs.org/minimist/-/minimist-0.0.8.tgz",
                       "resolved": "https://registry.npmjs.org/minimist/-/minimist-0.0.8.tgz"
                     }
                   }
                 },
                 "rimraf": {
                   "version": "2.5.4",
-                  "from": "rimraf@>=2.0.0 <3.0.0",
+                  "from": "https://registry.npmjs.org/rimraf/-/rimraf-2.5.4.tgz",
                   "resolved": "https://registry.npmjs.org/rimraf/-/rimraf-2.5.4.tgz",
                   "dependencies": {
                     "glob": {
                       "version": "7.0.5",
-                      "from": "glob@>=7.0.5 <8.0.0",
+                      "from": "https://registry.npmjs.org/glob/-/glob-7.0.5.tgz",
                       "resolved": "https://registry.npmjs.org/glob/-/glob-7.0.5.tgz",
                       "dependencies": {
                         "fs.realpath": {
                           "version": "1.0.0",
-                          "from": "fs.realpath@>=1.0.0 <2.0.0",
+                          "from": "https://registry.npmjs.org/fs.realpath/-/fs.realpath-1.0.0.tgz",
                           "resolved": "https://registry.npmjs.org/fs.realpath/-/fs.realpath-1.0.0.tgz"
                         },
                         "inflight": {
                           "version": "1.0.5",
-                          "from": "inflight@>=1.0.4 <2.0.0",
+                          "from": "https://registry.npmjs.org/inflight/-/inflight-1.0.5.tgz",
                           "resolved": "https://registry.npmjs.org/inflight/-/inflight-1.0.5.tgz",
                           "dependencies": {
                             "wrappy": {
                               "version": "1.0.2",
-                              "from": "wrappy@>=1.0.0 <2.0.0",
+                              "from": "https://registry.npmjs.org/wrappy/-/wrappy-1.0.2.tgz",
                               "resolved": "https://registry.npmjs.org/wrappy/-/wrappy-1.0.2.tgz"
                             }
                           }
                         },
                         "minimatch": {
                           "version": "3.0.2",
-                          "from": "minimatch@>=3.0.2 <4.0.0",
+                          "from": "https://registry.npmjs.org/minimatch/-/minimatch-3.0.2.tgz",
                           "resolved": "https://registry.npmjs.org/minimatch/-/minimatch-3.0.2.tgz",
                           "dependencies": {
                             "brace-expansion": {
                               "version": "1.1.6",
-                              "from": "brace-expansion@>=1.0.0 <2.0.0",
+                              "from": "https://registry.npmjs.org/brace-expansion/-/brace-expansion-1.1.6.tgz",
                               "resolved": "https://registry.npmjs.org/brace-expansion/-/brace-expansion-1.1.6.tgz",
                               "dependencies": {
                                 "balanced-match": {
                                   "version": "0.4.2",
-                                  "from": "balanced-match@>=0.4.1 <0.5.0",
+                                  "from": "https://registry.npmjs.org/balanced-match/-/balanced-match-0.4.2.tgz",
                                   "resolved": "https://registry.npmjs.org/balanced-match/-/balanced-match-0.4.2.tgz"
                                 },
                                 "concat-map": {
                                   "version": "0.0.1",
-                                  "from": "concat-map@0.0.1",
+                                  "from": "https://registry.npmjs.org/concat-map/-/concat-map-0.0.1.tgz",
                                   "resolved": "https://registry.npmjs.org/concat-map/-/concat-map-0.0.1.tgz"
                                 }
                               }
@@ -3287,19 +3287,19 @@
                         },
                         "once": {
                           "version": "1.3.3",
-                          "from": "once@>=1.3.0 <2.0.0",
+                          "from": "https://registry.npmjs.org/once/-/once-1.3.3.tgz",
                           "resolved": "https://registry.npmjs.org/once/-/once-1.3.3.tgz",
                           "dependencies": {
                             "wrappy": {
                               "version": "1.0.2",
-                              "from": "wrappy@>=1.0.0 <2.0.0",
+                              "from": "https://registry.npmjs.org/wrappy/-/wrappy-1.0.2.tgz",
                               "resolved": "https://registry.npmjs.org/wrappy/-/wrappy-1.0.2.tgz"
                             }
                           }
                         },
                         "path-is-absolute": {
                           "version": "1.0.0",
-                          "from": "path-is-absolute@>=1.0.0 <2.0.0",
+                          "from": "https://registry.npmjs.org/path-is-absolute/-/path-is-absolute-1.0.0.tgz",
                           "resolved": "https://registry.npmjs.org/path-is-absolute/-/path-is-absolute-1.0.0.tgz"
                         }
                       }
@@ -3310,85 +3310,85 @@
             },
             "pullstream": {
               "version": "0.4.1",
-              "from": "pullstream@>=0.4.1 <1.0.0",
+              "from": "https://registry.npmjs.org/pullstream/-/pullstream-0.4.1.tgz",
               "resolved": "https://registry.npmjs.org/pullstream/-/pullstream-0.4.1.tgz",
               "dependencies": {
                 "over": {
                   "version": "0.0.5",
-                  "from": "over@>=0.0.5 <1.0.0",
+                  "from": "https://registry.npmjs.org/over/-/over-0.0.5.tgz",
                   "resolved": "https://registry.npmjs.org/over/-/over-0.0.5.tgz"
                 },
                 "slice-stream": {
                   "version": "1.0.0",
-                  "from": "slice-stream@>=1.0.0 <2.0.0",
+                  "from": "https://registry.npmjs.org/slice-stream/-/slice-stream-1.0.0.tgz",
                   "resolved": "https://registry.npmjs.org/slice-stream/-/slice-stream-1.0.0.tgz"
                 }
               }
             },
             "binary": {
               "version": "0.3.0",
-              "from": "binary@>=0.3.0 <1.0.0",
+              "from": "https://registry.npmjs.org/binary/-/binary-0.3.0.tgz",
               "resolved": "https://registry.npmjs.org/binary/-/binary-0.3.0.tgz",
               "dependencies": {
                 "chainsaw": {
                   "version": "0.1.0",
-                  "from": "chainsaw@>=0.1.0 <0.2.0",
+                  "from": "https://registry.npmjs.org/chainsaw/-/chainsaw-0.1.0.tgz",
                   "resolved": "https://registry.npmjs.org/chainsaw/-/chainsaw-0.1.0.tgz",
                   "dependencies": {
                     "traverse": {
                       "version": "0.3.9",
-                      "from": "traverse@>=0.3.0 <0.4.0",
+                      "from": "https://registry.npmjs.org/traverse/-/traverse-0.3.9.tgz",
                       "resolved": "https://registry.npmjs.org/traverse/-/traverse-0.3.9.tgz"
                     }
                   }
                 },
                 "buffers": {
                   "version": "0.1.1",
-                  "from": "buffers@>=0.1.1 <0.2.0",
+                  "from": "https://registry.npmjs.org/buffers/-/buffers-0.1.1.tgz",
                   "resolved": "https://registry.npmjs.org/buffers/-/buffers-0.1.1.tgz"
                 }
               }
             },
             "readable-stream": {
               "version": "1.0.34",
-              "from": "readable-stream@>=1.0.31 <1.1.0",
+              "from": "https://registry.npmjs.org/readable-stream/-/readable-stream-1.0.34.tgz",
               "resolved": "https://registry.npmjs.org/readable-stream/-/readable-stream-1.0.34.tgz",
               "dependencies": {
                 "core-util-is": {
                   "version": "1.0.2",
-                  "from": "core-util-is@>=1.0.0 <1.1.0",
+                  "from": "https://registry.npmjs.org/core-util-is/-/core-util-is-1.0.2.tgz",
                   "resolved": "https://registry.npmjs.org/core-util-is/-/core-util-is-1.0.2.tgz"
                 },
                 "isarray": {
                   "version": "0.0.1",
-                  "from": "isarray@0.0.1",
+                  "from": "https://registry.npmjs.org/isarray/-/isarray-0.0.1.tgz",
                   "resolved": "https://registry.npmjs.org/isarray/-/isarray-0.0.1.tgz"
                 },
                 "string_decoder": {
                   "version": "0.10.31",
-                  "from": "string_decoder@>=0.10.0 <0.11.0",
+                  "from": "https://registry.npmjs.org/string_decoder/-/string_decoder-0.10.31.tgz",
                   "resolved": "https://registry.npmjs.org/string_decoder/-/string_decoder-0.10.31.tgz"
                 },
                 "inherits": {
                   "version": "2.0.1",
-                  "from": "inherits@>=2.0.1 <2.1.0",
+                  "from": "https://registry.npmjs.org/inherits/-/inherits-2.0.1.tgz",
                   "resolved": "https://registry.npmjs.org/inherits/-/inherits-2.0.1.tgz"
                 }
               }
             },
             "setimmediate": {
               "version": "1.0.4",
-              "from": "setimmediate@>=1.0.1 <2.0.0",
+              "from": "https://registry.npmjs.org/setimmediate/-/setimmediate-1.0.4.tgz",
               "resolved": "https://registry.npmjs.org/setimmediate/-/setimmediate-1.0.4.tgz"
             },
             "match-stream": {
               "version": "0.0.2",
-              "from": "match-stream@>=0.0.2 <1.0.0",
+              "from": "https://registry.npmjs.org/match-stream/-/match-stream-0.0.2.tgz",
               "resolved": "https://registry.npmjs.org/match-stream/-/match-stream-0.0.2.tgz",
               "dependencies": {
                 "buffers": {
                   "version": "0.1.1",
-                  "from": "buffers@>=0.1.1 <0.2.0",
+                  "from": "https://registry.npmjs.org/buffers/-/buffers-0.1.1.tgz",
                   "resolved": "https://registry.npmjs.org/buffers/-/buffers-0.1.1.tgz"
                 }
               }
@@ -3505,91 +3505,91 @@
       }
     },
     "commitizen": {
-      "version": "2.8.1",
-      "from": "https://registry.npmjs.org/commitizen/-/commitizen-2.8.1.tgz",
-      "resolved": "https://registry.npmjs.org/commitizen/-/commitizen-2.8.1.tgz",
+      "version": "2.8.4",
+      "from": "commitizen@>=2.3.0 <3.0.0",
+      "resolved": "https://registry.npmjs.org/commitizen/-/commitizen-2.8.4.tgz",
       "dependencies": {
         "chalk": {
           "version": "1.1.3",
-          "from": "https://registry.npmjs.org/chalk/-/chalk-1.1.3.tgz",
+          "from": "chalk@1.1.3",
           "resolved": "https://registry.npmjs.org/chalk/-/chalk-1.1.3.tgz",
           "dependencies": {
             "ansi-styles": {
               "version": "2.2.1",
-              "from": "https://registry.npmjs.org/ansi-styles/-/ansi-styles-2.2.1.tgz",
+              "from": "ansi-styles@>=2.2.1 <3.0.0",
               "resolved": "https://registry.npmjs.org/ansi-styles/-/ansi-styles-2.2.1.tgz"
             },
             "escape-string-regexp": {
               "version": "1.0.5",
-              "from": "https://registry.npmjs.org/escape-string-regexp/-/escape-string-regexp-1.0.5.tgz",
+              "from": "escape-string-regexp@>=1.0.2 <2.0.0",
               "resolved": "https://registry.npmjs.org/escape-string-regexp/-/escape-string-regexp-1.0.5.tgz"
             },
             "has-ansi": {
               "version": "2.0.0",
-              "from": "https://registry.npmjs.org/has-ansi/-/has-ansi-2.0.0.tgz",
+              "from": "has-ansi@>=2.0.0 <3.0.0",
               "resolved": "https://registry.npmjs.org/has-ansi/-/has-ansi-2.0.0.tgz",
               "dependencies": {
                 "ansi-regex": {
                   "version": "2.0.0",
-                  "from": "https://registry.npmjs.org/ansi-regex/-/ansi-regex-2.0.0.tgz",
+                  "from": "ansi-regex@>=2.0.0 <3.0.0",
                   "resolved": "https://registry.npmjs.org/ansi-regex/-/ansi-regex-2.0.0.tgz"
                 }
               }
             },
             "strip-ansi": {
               "version": "3.0.1",
-              "from": "https://registry.npmjs.org/strip-ansi/-/strip-ansi-3.0.1.tgz",
+              "from": "strip-ansi@>=3.0.0 <4.0.0",
               "resolved": "https://registry.npmjs.org/strip-ansi/-/strip-ansi-3.0.1.tgz",
               "dependencies": {
                 "ansi-regex": {
                   "version": "2.0.0",
-                  "from": "https://registry.npmjs.org/ansi-regex/-/ansi-regex-2.0.0.tgz",
+                  "from": "ansi-regex@>=2.0.0 <3.0.0",
                   "resolved": "https://registry.npmjs.org/ansi-regex/-/ansi-regex-2.0.0.tgz"
                 }
               }
             },
             "supports-color": {
               "version": "2.0.0",
-              "from": "https://registry.npmjs.org/supports-color/-/supports-color-2.0.0.tgz",
+              "from": "supports-color@>=2.0.0 <3.0.0",
               "resolved": "https://registry.npmjs.org/supports-color/-/supports-color-2.0.0.tgz"
             }
           }
         },
         "cz-conventional-changelog": {
           "version": "1.1.6",
-          "from": "https://registry.npmjs.org/cz-conventional-changelog/-/cz-conventional-changelog-1.1.6.tgz",
+          "from": "cz-conventional-changelog@1.1.6",
           "resolved": "https://registry.npmjs.org/cz-conventional-changelog/-/cz-conventional-changelog-1.1.6.tgz",
           "dependencies": {
             "word-wrap": {
               "version": "1.1.0",
-              "from": "https://registry.npmjs.org/word-wrap/-/word-wrap-1.1.0.tgz",
+              "from": "word-wrap@>=1.0.3 <2.0.0",
               "resolved": "https://registry.npmjs.org/word-wrap/-/word-wrap-1.1.0.tgz"
             }
           }
         },
         "dedent": {
           "version": "0.6.0",
-          "from": "https://registry.npmjs.org/dedent/-/dedent-0.6.0.tgz",
+          "from": "dedent@0.6.0",
           "resolved": "https://registry.npmjs.org/dedent/-/dedent-0.6.0.tgz"
         },
         "detect-indent": {
           "version": "4.0.0",
-          "from": "https://registry.npmjs.org/detect-indent/-/detect-indent-4.0.0.tgz",
+          "from": "detect-indent@4.0.0",
           "resolved": "https://registry.npmjs.org/detect-indent/-/detect-indent-4.0.0.tgz",
           "dependencies": {
             "repeating": {
               "version": "2.0.1",
-              "from": "https://registry.npmjs.org/repeating/-/repeating-2.0.1.tgz",
+              "from": "repeating@>=2.0.0 <3.0.0",
               "resolved": "https://registry.npmjs.org/repeating/-/repeating-2.0.1.tgz",
               "dependencies": {
                 "is-finite": {
                   "version": "1.0.1",
-                  "from": "https://registry.npmjs.org/is-finite/-/is-finite-1.0.1.tgz",
+                  "from": "is-finite@>=1.0.0 <2.0.0",
                   "resolved": "https://registry.npmjs.org/is-finite/-/is-finite-1.0.1.tgz",
                   "dependencies": {
                     "number-is-nan": {
                       "version": "1.0.0",
-                      "from": "https://registry.npmjs.org/number-is-nan/-/number-is-nan-1.0.0.tgz",
+                      "from": "number-is-nan@>=1.0.0 <2.0.0",
                       "resolved": "https://registry.npmjs.org/number-is-nan/-/number-is-nan-1.0.0.tgz"
                     }
                   }
@@ -3599,55 +3599,55 @@
           }
         },
         "find-node-modules": {
-          "version": "1.0.1",
-          "from": "https://registry.npmjs.org/find-node-modules/-/find-node-modules-1.0.1.tgz",
-          "resolved": "https://registry.npmjs.org/find-node-modules/-/find-node-modules-1.0.1.tgz",
+          "version": "1.0.3",
+          "from": "find-node-modules@1.0.3",
+          "resolved": "https://registry.npmjs.org/find-node-modules/-/find-node-modules-1.0.3.tgz",
           "dependencies": {
             "findup-sync": {
               "version": "0.2.1",
-              "from": "https://registry.npmjs.org/findup-sync/-/findup-sync-0.2.1.tgz",
+              "from": "findup-sync@>=0.2.1 <0.3.0",
               "resolved": "https://registry.npmjs.org/findup-sync/-/findup-sync-0.2.1.tgz",
               "dependencies": {
                 "glob": {
                   "version": "4.3.5",
-                  "from": "https://registry.npmjs.org/glob/-/glob-4.3.5.tgz",
+                  "from": "glob@>=4.3.0 <4.4.0",
                   "resolved": "https://registry.npmjs.org/glob/-/glob-4.3.5.tgz",
                   "dependencies": {
                     "inflight": {
-                      "version": "1.0.4",
-                      "from": "https://registry.npmjs.org/inflight/-/inflight-1.0.4.tgz",
-                      "resolved": "https://registry.npmjs.org/inflight/-/inflight-1.0.4.tgz",
+                      "version": "1.0.5",
+                      "from": "inflight@>=1.0.4 <2.0.0",
+                      "resolved": "https://registry.npmjs.org/inflight/-/inflight-1.0.5.tgz",
                       "dependencies": {
                         "wrappy": {
-                          "version": "1.0.1",
-                          "from": "https://registry.npmjs.org/wrappy/-/wrappy-1.0.1.tgz",
-                          "resolved": "https://registry.npmjs.org/wrappy/-/wrappy-1.0.1.tgz"
+                          "version": "1.0.2",
+                          "from": "wrappy@>=1.0.0 <2.0.0",
+                          "resolved": "https://registry.npmjs.org/wrappy/-/wrappy-1.0.2.tgz"
                         }
                       }
                     },
                     "inherits": {
                       "version": "2.0.1",
-                      "from": "https://registry.npmjs.org/inherits/-/inherits-2.0.1.tgz",
+                      "from": "inherits@>=2.0.0 <3.0.0",
                       "resolved": "https://registry.npmjs.org/inherits/-/inherits-2.0.1.tgz"
                     },
                     "minimatch": {
                       "version": "2.0.10",
-                      "from": "https://registry.npmjs.org/minimatch/-/minimatch-2.0.10.tgz",
+                      "from": "minimatch@>=2.0.1 <3.0.0",
                       "resolved": "https://registry.npmjs.org/minimatch/-/minimatch-2.0.10.tgz",
                       "dependencies": {
                         "brace-expansion": {
-                          "version": "1.1.4",
-                          "from": "https://registry.npmjs.org/brace-expansion/-/brace-expansion-1.1.4.tgz",
-                          "resolved": "https://registry.npmjs.org/brace-expansion/-/brace-expansion-1.1.4.tgz",
+                          "version": "1.1.6",
+                          "from": "brace-expansion@>=1.0.0 <2.0.0",
+                          "resolved": "https://registry.npmjs.org/brace-expansion/-/brace-expansion-1.1.6.tgz",
                           "dependencies": {
                             "balanced-match": {
-                              "version": "0.4.1",
-                              "from": "https://registry.npmjs.org/balanced-match/-/balanced-match-0.4.1.tgz",
-                              "resolved": "https://registry.npmjs.org/balanced-match/-/balanced-match-0.4.1.tgz"
+                              "version": "0.4.2",
+                              "from": "balanced-match@>=0.4.1 <0.5.0",
+                              "resolved": "https://registry.npmjs.org/balanced-match/-/balanced-match-0.4.2.tgz"
                             },
                             "concat-map": {
                               "version": "0.0.1",
-                              "from": "https://registry.npmjs.org/concat-map/-/concat-map-0.0.1.tgz",
+                              "from": "concat-map@0.0.1",
                               "resolved": "https://registry.npmjs.org/concat-map/-/concat-map-0.0.1.tgz"
                             }
                           }
@@ -3656,13 +3656,13 @@
                     },
                     "once": {
                       "version": "1.3.3",
-                      "from": "https://registry.npmjs.org/once/-/once-1.3.3.tgz",
+                      "from": "once@>=1.3.0 <2.0.0",
                       "resolved": "https://registry.npmjs.org/once/-/once-1.3.3.tgz",
                       "dependencies": {
                         "wrappy": {
-                          "version": "1.0.1",
-                          "from": "https://registry.npmjs.org/wrappy/-/wrappy-1.0.1.tgz",
-                          "resolved": "https://registry.npmjs.org/wrappy/-/wrappy-1.0.1.tgz"
+                          "version": "1.0.2",
+                          "from": "wrappy@>=1.0.0 <2.0.0",
+                          "resolved": "https://registry.npmjs.org/wrappy/-/wrappy-1.0.2.tgz"
                         }
                       }
                     }
@@ -3672,56 +3672,61 @@
             },
             "merge": {
               "version": "1.2.0",
-              "from": "https://registry.npmjs.org/merge/-/merge-1.2.0.tgz",
+              "from": "merge@>=1.2.0 <2.0.0",
               "resolved": "https://registry.npmjs.org/merge/-/merge-1.2.0.tgz"
             }
           }
         },
         "find-root": {
           "version": "1.0.0",
-          "from": "https://registry.npmjs.org/find-root/-/find-root-1.0.0.tgz",
+          "from": "find-root@1.0.0",
           "resolved": "https://registry.npmjs.org/find-root/-/find-root-1.0.0.tgz"
         },
         "glob": {
-          "version": "7.0.3",
-          "from": "https://registry.npmjs.org/glob/-/glob-7.0.3.tgz",
-          "resolved": "https://registry.npmjs.org/glob/-/glob-7.0.3.tgz",
+          "version": "7.0.5",
+          "from": "glob@7.0.5",
+          "resolved": "https://registry.npmjs.org/glob/-/glob-7.0.5.tgz",
           "dependencies": {
+            "fs.realpath": {
+              "version": "1.0.0",
+              "from": "fs.realpath@>=1.0.0 <2.0.0",
+              "resolved": "https://registry.npmjs.org/fs.realpath/-/fs.realpath-1.0.0.tgz"
+            },
             "inflight": {
-              "version": "1.0.4",
-              "from": "https://registry.npmjs.org/inflight/-/inflight-1.0.4.tgz",
-              "resolved": "https://registry.npmjs.org/inflight/-/inflight-1.0.4.tgz",
+              "version": "1.0.5",
+              "from": "inflight@>=1.0.4 <2.0.0",
+              "resolved": "https://registry.npmjs.org/inflight/-/inflight-1.0.5.tgz",
               "dependencies": {
                 "wrappy": {
-                  "version": "1.0.1",
-                  "from": "https://registry.npmjs.org/wrappy/-/wrappy-1.0.1.tgz",
-                  "resolved": "https://registry.npmjs.org/wrappy/-/wrappy-1.0.1.tgz"
+                  "version": "1.0.2",
+                  "from": "wrappy@>=1.0.0 <2.0.0",
+                  "resolved": "https://registry.npmjs.org/wrappy/-/wrappy-1.0.2.tgz"
                 }
               }
             },
             "inherits": {
               "version": "2.0.1",
-              "from": "https://registry.npmjs.org/inherits/-/inherits-2.0.1.tgz",
+              "from": "inherits@>=2.0.0 <3.0.0",
               "resolved": "https://registry.npmjs.org/inherits/-/inherits-2.0.1.tgz"
             },
             "minimatch": {
-              "version": "3.0.0",
-              "from": "https://registry.npmjs.org/minimatch/-/minimatch-3.0.0.tgz",
-              "resolved": "https://registry.npmjs.org/minimatch/-/minimatch-3.0.0.tgz",
+              "version": "3.0.2",
+              "from": "minimatch@>=3.0.2 <4.0.0",
+              "resolved": "https://registry.npmjs.org/minimatch/-/minimatch-3.0.2.tgz",
               "dependencies": {
                 "brace-expansion": {
-                  "version": "1.1.4",
-                  "from": "https://registry.npmjs.org/brace-expansion/-/brace-expansion-1.1.4.tgz",
-                  "resolved": "https://registry.npmjs.org/brace-expansion/-/brace-expansion-1.1.4.tgz",
+                  "version": "1.1.6",
+                  "from": "brace-expansion@>=1.0.0 <2.0.0",
+                  "resolved": "https://registry.npmjs.org/brace-expansion/-/brace-expansion-1.1.6.tgz",
                   "dependencies": {
                     "balanced-match": {
-                      "version": "0.4.1",
-                      "from": "https://registry.npmjs.org/balanced-match/-/balanced-match-0.4.1.tgz",
-                      "resolved": "https://registry.npmjs.org/balanced-match/-/balanced-match-0.4.1.tgz"
+                      "version": "0.4.2",
+                      "from": "balanced-match@>=0.4.1 <0.5.0",
+                      "resolved": "https://registry.npmjs.org/balanced-match/-/balanced-match-0.4.2.tgz"
                     },
                     "concat-map": {
                       "version": "0.0.1",
-                      "from": "https://registry.npmjs.org/concat-map/-/concat-map-0.0.1.tgz",
+                      "from": "concat-map@0.0.1",
                       "resolved": "https://registry.npmjs.org/concat-map/-/concat-map-0.0.1.tgz"
                     }
                   }
@@ -3730,687 +3735,308 @@
             },
             "once": {
               "version": "1.3.3",
-              "from": "https://registry.npmjs.org/once/-/once-1.3.3.tgz",
+              "from": "once@>=1.3.0 <2.0.0",
               "resolved": "https://registry.npmjs.org/once/-/once-1.3.3.tgz",
               "dependencies": {
                 "wrappy": {
-                  "version": "1.0.1",
-                  "from": "https://registry.npmjs.org/wrappy/-/wrappy-1.0.1.tgz",
-                  "resolved": "https://registry.npmjs.org/wrappy/-/wrappy-1.0.1.tgz"
+                  "version": "1.0.2",
+                  "from": "wrappy@>=1.0.0 <2.0.0",
+                  "resolved": "https://registry.npmjs.org/wrappy/-/wrappy-1.0.2.tgz"
                 }
               }
             },
             "path-is-absolute": {
               "version": "1.0.0",
-              "from": "https://registry.npmjs.org/path-is-absolute/-/path-is-absolute-1.0.0.tgz",
+              "from": "path-is-absolute@>=1.0.0 <2.0.0",
               "resolved": "https://registry.npmjs.org/path-is-absolute/-/path-is-absolute-1.0.0.tgz"
             }
           }
         },
-        "gulp": {
-          "version": "3.9.1",
-          "from": "https://registry.npmjs.org/gulp/-/gulp-3.9.1.tgz",
-          "resolved": "https://registry.npmjs.org/gulp/-/gulp-3.9.1.tgz",
+        "home-or-tmp": {
+          "version": "2.0.0",
+          "from": "home-or-tmp@2.0.0",
+          "resolved": "https://registry.npmjs.org/home-or-tmp/-/home-or-tmp-2.0.0.tgz",
           "dependencies": {
-            "archy": {
-              "version": "1.0.0",
-              "from": "https://registry.npmjs.org/archy/-/archy-1.0.0.tgz",
-              "resolved": "https://registry.npmjs.org/archy/-/archy-1.0.0.tgz"
-            },
-            "deprecated": {
-              "version": "0.0.1",
-              "from": "https://registry.npmjs.org/deprecated/-/deprecated-0.0.1.tgz",
-              "resolved": "https://registry.npmjs.org/deprecated/-/deprecated-0.0.1.tgz"
+            "os-homedir": {
+              "version": "1.0.1",
+              "from": "os-homedir@>=1.0.0 <2.0.0",
+              "resolved": "https://registry.npmjs.org/os-homedir/-/os-homedir-1.0.1.tgz"
             },
-            "interpret": {
+            "os-tmpdir": {
               "version": "1.0.1",
-              "from": "https://registry.npmjs.org/interpret/-/interpret-1.0.1.tgz",
-              "resolved": "https://registry.npmjs.org/interpret/-/interpret-1.0.1.tgz"
+              "from": "os-tmpdir@>=1.0.1 <2.0.0",
+              "resolved": "https://registry.npmjs.org/os-tmpdir/-/os-tmpdir-1.0.1.tgz"
+            }
+          }
+        },
+        "inquirer": {
+          "version": "1.1.2",
+          "from": "inquirer@1.1.2",
+          "resolved": "https://registry.npmjs.org/inquirer/-/inquirer-1.1.2.tgz",
+          "dependencies": {
+            "ansi-escapes": {
+              "version": "1.4.0",
+              "from": "ansi-escapes@>=1.1.0 <2.0.0",
+              "resolved": "https://registry.npmjs.org/ansi-escapes/-/ansi-escapes-1.4.0.tgz"
             },
-            "liftoff": {
-              "version": "2.2.1",
-              "from": "https://registry.npmjs.org/liftoff/-/liftoff-2.2.1.tgz",
-              "resolved": "https://registry.npmjs.org/liftoff/-/liftoff-2.2.1.tgz",
+            "cli-cursor": {
+              "version": "1.0.2",
+              "from": "cli-cursor@>=1.0.1 <2.0.0",
+              "resolved": "https://registry.npmjs.org/cli-cursor/-/cli-cursor-1.0.2.tgz",
+              "dependencies": {
+                "restore-cursor": {
+                  "version": "1.0.1",
+                  "from": "restore-cursor@>=1.0.1 <2.0.0",
+                  "resolved": "https://registry.npmjs.org/restore-cursor/-/restore-cursor-1.0.1.tgz",
+                  "dependencies": {
+                    "exit-hook": {
+                      "version": "1.1.1",
+                      "from": "exit-hook@>=1.0.0 <2.0.0",
+                      "resolved": "https://registry.npmjs.org/exit-hook/-/exit-hook-1.1.1.tgz"
+                    },
+                    "onetime": {
+                      "version": "1.1.0",
+                      "from": "onetime@>=1.0.0 <2.0.0",
+                      "resolved": "https://registry.npmjs.org/onetime/-/onetime-1.1.0.tgz"
+                    }
+                  }
+                }
+              }
+            },
+            "cli-width": {
+              "version": "2.1.0",
+              "from": "cli-width@>=2.0.0 <3.0.0",
+              "resolved": "https://registry.npmjs.org/cli-width/-/cli-width-2.1.0.tgz"
+            },
+            "external-editor": {
+              "version": "1.0.3",
+              "from": "external-editor@>=1.0.1 <2.0.0",
+              "resolved": "https://registry.npmjs.org/external-editor/-/external-editor-1.0.3.tgz",
               "dependencies": {
                 "extend": {
-                  "version": "2.0.1",
-                  "from": "https://registry.npmjs.org/extend/-/extend-2.0.1.tgz",
-                  "resolved": "https://registry.npmjs.org/extend/-/extend-2.0.1.tgz"
+                  "version": "3.0.0",
+                  "from": "extend@>=3.0.0 <4.0.0",
+                  "resolved": "https://registry.npmjs.org/extend/-/extend-3.0.0.tgz"
                 },
-                "findup-sync": {
-                  "version": "0.3.0",
-                  "from": "https://registry.npmjs.org/findup-sync/-/findup-sync-0.3.0.tgz",
-                  "resolved": "https://registry.npmjs.org/findup-sync/-/findup-sync-0.3.0.tgz",
+                "spawn-sync": {
+                  "version": "1.0.15",
+                  "from": "spawn-sync@>=1.0.15 <2.0.0",
+                  "resolved": "https://registry.npmjs.org/spawn-sync/-/spawn-sync-1.0.15.tgz",
                   "dependencies": {
-                    "glob": {
-                      "version": "5.0.15",
-                      "from": "https://registry.npmjs.org/glob/-/glob-5.0.15.tgz",
-                      "resolved": "https://registry.npmjs.org/glob/-/glob-5.0.15.tgz",
+                    "concat-stream": {
+                      "version": "1.5.1",
+                      "from": "concat-stream@>=1.4.7 <2.0.0",
+                      "resolved": "https://registry.npmjs.org/concat-stream/-/concat-stream-1.5.1.tgz",
                       "dependencies": {
-                        "inflight": {
-                          "version": "1.0.4",
-                          "from": "https://registry.npmjs.org/inflight/-/inflight-1.0.4.tgz",
-                          "resolved": "https://registry.npmjs.org/inflight/-/inflight-1.0.4.tgz",
-                          "dependencies": {
-                            "wrappy": {
-                              "version": "1.0.1",
-                              "from": "https://registry.npmjs.org/wrappy/-/wrappy-1.0.1.tgz",
-                              "resolved": "https://registry.npmjs.org/wrappy/-/wrappy-1.0.1.tgz"
-                            }
-                          }
-                        },
                         "inherits": {
                           "version": "2.0.1",
-                          "from": "https://registry.npmjs.org/inherits/-/inherits-2.0.1.tgz",
+                          "from": "inherits@>=2.0.1 <2.1.0",
                           "resolved": "https://registry.npmjs.org/inherits/-/inherits-2.0.1.tgz"
                         },
-                        "minimatch": {
-                          "version": "3.0.0",
-                          "from": "https://registry.npmjs.org/minimatch/-/minimatch-3.0.0.tgz",
-                          "resolved": "https://registry.npmjs.org/minimatch/-/minimatch-3.0.0.tgz",
-                          "dependencies": {
-                            "brace-expansion": {
-                              "version": "1.1.4",
-                              "from": "https://registry.npmjs.org/brace-expansion/-/brace-expansion-1.1.4.tgz",
-                              "resolved": "https://registry.npmjs.org/brace-expansion/-/brace-expansion-1.1.4.tgz",
-                              "dependencies": {
-                                "balanced-match": {
-                                  "version": "0.4.1",
-                                  "from": "https://registry.npmjs.org/balanced-match/-/balanced-match-0.4.1.tgz",
-                                  "resolved": "https://registry.npmjs.org/balanced-match/-/balanced-match-0.4.1.tgz"
-                                },
-                                "concat-map": {
-                                  "version": "0.0.1",
-                                  "from": "https://registry.npmjs.org/concat-map/-/concat-map-0.0.1.tgz",
-                                  "resolved": "https://registry.npmjs.org/concat-map/-/concat-map-0.0.1.tgz"
-                                }
-                              }
-                            }
-                          }
+                        "typedarray": {
+                          "version": "0.0.6",
+                          "from": "typedarray@>=0.0.5 <0.1.0",
+                          "resolved": "https://registry.npmjs.org/typedarray/-/typedarray-0.0.6.tgz"
                         },
-                        "once": {
-                          "version": "1.3.3",
-                          "from": "https://registry.npmjs.org/once/-/once-1.3.3.tgz",
-                          "resolved": "https://registry.npmjs.org/once/-/once-1.3.3.tgz",
+                        "readable-stream": {
+                          "version": "2.0.6",
+                          "from": "readable-stream@>=2.0.0 <2.1.0",
+                          "resolved": "https://registry.npmjs.org/readable-stream/-/readable-stream-2.0.6.tgz",
                           "dependencies": {
-                            "wrappy": {
-                              "version": "1.0.1",
-                              "from": "https://registry.npmjs.org/wrappy/-/wrappy-1.0.1.tgz",
-                              "resolved": "https://registry.npmjs.org/wrappy/-/wrappy-1.0.1.tgz"
+                            "core-util-is": {
+                              "version": "1.0.2",
+                              "from": "core-util-is@>=1.0.0 <1.1.0",
+                              "resolved": "https://registry.npmjs.org/core-util-is/-/core-util-is-1.0.2.tgz"
+                            },
+                            "isarray": {
+                              "version": "1.0.0",
+                              "from": "isarray@>=1.0.0 <1.1.0",
+                              "resolved": "https://registry.npmjs.org/isarray/-/isarray-1.0.0.tgz"
+                            },
+                            "process-nextick-args": {
+                              "version": "1.0.7",
+                              "from": "process-nextick-args@>=1.0.6 <1.1.0",
+                              "resolved": "https://registry.npmjs.org/process-nextick-args/-/process-nextick-args-1.0.7.tgz"
+                            },
+                            "string_decoder": {
+                              "version": "0.10.31",
+                              "from": "string_decoder@>=0.10.0 <0.11.0",
+                              "resolved": "https://registry.npmjs.org/string_decoder/-/string_decoder-0.10.31.tgz"
+                            },
+                            "util-deprecate": {
+                              "version": "1.0.2",
+                              "from": "util-deprecate@>=1.0.1 <1.1.0",
+                              "resolved": "https://registry.npmjs.org/util-deprecate/-/util-deprecate-1.0.2.tgz"
                             }
                           }
-                        },
-                        "path-is-absolute": {
-                          "version": "1.0.0",
-                          "from": "https://registry.npmjs.org/path-is-absolute/-/path-is-absolute-1.0.0.tgz",
-                          "resolved": "https://registry.npmjs.org/path-is-absolute/-/path-is-absolute-1.0.0.tgz"
                         }
                       }
+                    },
+                    "os-shim": {
+                      "version": "0.1.3",
+                      "from": "os-shim@>=0.1.2 <0.2.0",
+                      "resolved": "https://registry.npmjs.org/os-shim/-/os-shim-0.1.3.tgz"
                     }
                   }
                 },
-                "flagged-respawn": {
-                  "version": "0.3.2",
-                  "from": "https://registry.npmjs.org/flagged-respawn/-/flagged-respawn-0.3.2.tgz",
-                  "resolved": "https://registry.npmjs.org/flagged-respawn/-/flagged-respawn-0.3.2.tgz"
-                },
-                "rechoir": {
-                  "version": "0.6.2",
-                  "from": "https://registry.npmjs.org/rechoir/-/rechoir-0.6.2.tgz",
-                  "resolved": "https://registry.npmjs.org/rechoir/-/rechoir-0.6.2.tgz"
-                },
-                "resolve": {
-                  "version": "1.1.7",
-                  "from": "https://registry.npmjs.org/resolve/-/resolve-1.1.7.tgz",
-                  "resolved": "https://registry.npmjs.org/resolve/-/resolve-1.1.7.tgz"
+                "temp": {
+                  "version": "0.8.3",
+                  "from": "temp@>=0.8.3 <0.9.0",
+                  "resolved": "https://registry.npmjs.org/temp/-/temp-0.8.3.tgz",
+                  "dependencies": {
+                    "os-tmpdir": {
+                      "version": "1.0.1",
+                      "from": "os-tmpdir@>=1.0.0 <2.0.0",
+                      "resolved": "https://registry.npmjs.org/os-tmpdir/-/os-tmpdir-1.0.1.tgz"
+                    },
+                    "rimraf": {
+                      "version": "2.2.8",
+                      "from": "rimraf@>=2.2.6 <2.3.0",
+                      "resolved": "https://registry.npmjs.org/rimraf/-/rimraf-2.2.8.tgz"
+                    }
+                  }
                 }
               }
             },
-            "orchestrator": {
-              "version": "0.3.7",
-              "from": "https://registry.npmjs.org/orchestrator/-/orchestrator-0.3.7.tgz",
-              "resolved": "https://registry.npmjs.org/orchestrator/-/orchestrator-0.3.7.tgz",
+            "figures": {
+              "version": "1.7.0",
+              "from": "figures@>=1.3.5 <2.0.0",
+              "resolved": "https://registry.npmjs.org/figures/-/figures-1.7.0.tgz",
               "dependencies": {
-                "end-of-stream": {
-                  "version": "0.1.5",
-                  "from": "https://registry.npmjs.org/end-of-stream/-/end-of-stream-0.1.5.tgz",
-                  "resolved": "https://registry.npmjs.org/end-of-stream/-/end-of-stream-0.1.5.tgz",
-                  "dependencies": {
-                    "once": {
-                      "version": "1.3.3",
-                      "from": "https://registry.npmjs.org/once/-/once-1.3.3.tgz",
-                      "resolved": "https://registry.npmjs.org/once/-/once-1.3.3.tgz",
-                      "dependencies": {
-                        "wrappy": {
-                          "version": "1.0.1",
-                          "from": "https://registry.npmjs.org/wrappy/-/wrappy-1.0.1.tgz",
-                          "resolved": "https://registry.npmjs.org/wrappy/-/wrappy-1.0.1.tgz"
-                        }
-                      }
-                    }
-                  }
-                },
-                "sequencify": {
-                  "version": "0.0.7",
-                  "from": "https://registry.npmjs.org/sequencify/-/sequencify-0.0.7.tgz",
-                  "resolved": "https://registry.npmjs.org/sequencify/-/sequencify-0.0.7.tgz"
+                "escape-string-regexp": {
+                  "version": "1.0.5",
+                  "from": "escape-string-regexp@>=1.0.5 <2.0.0",
+                  "resolved": "https://registry.npmjs.org/escape-string-regexp/-/escape-string-regexp-1.0.5.tgz"
                 },
-                "stream-consume": {
-                  "version": "0.1.0",
-                  "from": "https://registry.npmjs.org/stream-consume/-/stream-consume-0.1.0.tgz",
-                  "resolved": "https://registry.npmjs.org/stream-consume/-/stream-consume-0.1.0.tgz"
+                "object-assign": {
+                  "version": "4.1.0",
+                  "from": "object-assign@>=4.1.0 <5.0.0",
+                  "resolved": "https://registry.npmjs.org/object-assign/-/object-assign-4.1.0.tgz"
                 }
               }
             },
-            "pretty-hrtime": {
-              "version": "1.0.2",
-              "from": "https://registry.npmjs.org/pretty-hrtime/-/pretty-hrtime-1.0.2.tgz",
-              "resolved": "https://registry.npmjs.org/pretty-hrtime/-/pretty-hrtime-1.0.2.tgz"
-            },
-            "semver": {
-              "version": "4.3.6",
-              "from": "https://registry.npmjs.org/semver/-/semver-4.3.6.tgz",
-              "resolved": "https://registry.npmjs.org/semver/-/semver-4.3.6.tgz"
+            "mute-stream": {
+              "version": "0.0.6",
+              "from": "mute-stream@0.0.6",
+              "resolved": "https://registry.npmjs.org/mute-stream/-/mute-stream-0.0.6.tgz"
             },
-            "tildify": {
-              "version": "1.2.0",
-              "from": "https://registry.npmjs.org/tildify/-/tildify-1.2.0.tgz",
-              "resolved": "https://registry.npmjs.org/tildify/-/tildify-1.2.0.tgz",
+            "pinkie-promise": {
+              "version": "2.0.1",
+              "from": "pinkie-promise@>=2.0.0 <3.0.0",
+              "resolved": "https://registry.npmjs.org/pinkie-promise/-/pinkie-promise-2.0.1.tgz",
               "dependencies": {
-                "os-homedir": {
-                  "version": "1.0.1",
-                  "from": "https://registry.npmjs.org/os-homedir/-/os-homedir-1.0.1.tgz",
-                  "resolved": "https://registry.npmjs.org/os-homedir/-/os-homedir-1.0.1.tgz"
+                "pinkie": {
+                  "version": "2.0.4",
+                  "from": "pinkie@>=2.0.0 <3.0.0",
+                  "resolved": "https://registry.npmjs.org/pinkie/-/pinkie-2.0.4.tgz"
                 }
               }
             },
-            "v8flags": {
-              "version": "2.0.11",
-              "from": "https://registry.npmjs.org/v8flags/-/v8flags-2.0.11.tgz",
-              "resolved": "https://registry.npmjs.org/v8flags/-/v8flags-2.0.11.tgz",
+            "run-async": {
+              "version": "2.2.0",
+              "from": "run-async@>=2.2.0 <3.0.0",
+              "resolved": "https://registry.npmjs.org/run-async/-/run-async-2.2.0.tgz",
               "dependencies": {
-                "user-home": {
-                  "version": "1.1.1",
-                  "from": "https://registry.npmjs.org/user-home/-/user-home-1.1.1.tgz",
-                  "resolved": "https://registry.npmjs.org/user-home/-/user-home-1.1.1.tgz"
+                "is-promise": {
+                  "version": "2.1.0",
+                  "from": "is-promise@>=2.1.0 <3.0.0",
+                  "resolved": "https://registry.npmjs.org/is-promise/-/is-promise-2.1.0.tgz"
                 }
               }
             },
-            "vinyl-fs": {
-              "version": "0.3.14",
-              "from": "https://registry.npmjs.org/vinyl-fs/-/vinyl-fs-0.3.14.tgz",
-              "resolved": "https://registry.npmjs.org/vinyl-fs/-/vinyl-fs-0.3.14.tgz",
+            "rx": {
+              "version": "4.1.0",
+              "from": "rx@>=4.1.0 <5.0.0",
+              "resolved": "https://registry.npmjs.org/rx/-/rx-4.1.0.tgz"
+            },
+            "string-width": {
+              "version": "1.0.1",
+              "from": "string-width@>=1.0.1 <2.0.0",
+              "resolved": "https://registry.npmjs.org/string-width/-/string-width-1.0.1.tgz",
               "dependencies": {
-                "defaults": {
-                  "version": "1.0.3",
-                  "from": "https://registry.npmjs.org/defaults/-/defaults-1.0.3.tgz",
-                  "resolved": "https://registry.npmjs.org/defaults/-/defaults-1.0.3.tgz",
-                  "dependencies": {
-                    "clone": {
-                      "version": "1.0.2",
-                      "from": "https://registry.npmjs.org/clone/-/clone-1.0.2.tgz",
-                      "resolved": "https://registry.npmjs.org/clone/-/clone-1.0.2.tgz"
-                    }
-                  }
-                },
-                "glob-stream": {
-                  "version": "3.1.18",
-                  "from": "https://registry.npmjs.org/glob-stream/-/glob-stream-3.1.18.tgz",
-                  "resolved": "https://registry.npmjs.org/glob-stream/-/glob-stream-3.1.18.tgz",
+                "code-point-at": {
+                  "version": "1.0.0",
+                  "from": "code-point-at@>=1.0.0 <2.0.0",
+                  "resolved": "https://registry.npmjs.org/code-point-at/-/code-point-at-1.0.0.tgz",
                   "dependencies": {
-                    "glob": {
-                      "version": "4.5.3",
-                      "from": "https://registry.npmjs.org/glob/-/glob-4.5.3.tgz",
-                      "resolved": "https://registry.npmjs.org/glob/-/glob-4.5.3.tgz",
-                      "dependencies": {
-                        "inflight": {
-                          "version": "1.0.4",
-                          "from": "https://registry.npmjs.org/inflight/-/inflight-1.0.4.tgz",
-                          "resolved": "https://registry.npmjs.org/inflight/-/inflight-1.0.4.tgz",
-                          "dependencies": {
-                            "wrappy": {
-                              "version": "1.0.1",
-                              "from": "https://registry.npmjs.org/wrappy/-/wrappy-1.0.1.tgz",
-                              "resolved": "https://registry.npmjs.org/wrappy/-/wrappy-1.0.1.tgz"
-                            }
-                          }
-                        },
-                        "inherits": {
-                          "version": "2.0.1",
-                          "from": "https://registry.npmjs.org/inherits/-/inherits-2.0.1.tgz",
-                          "resolved": "https://registry.npmjs.org/inherits/-/inherits-2.0.1.tgz"
-                        },
-                        "once": {
-                          "version": "1.3.3",
-                          "from": "https://registry.npmjs.org/once/-/once-1.3.3.tgz",
-                          "resolved": "https://registry.npmjs.org/once/-/once-1.3.3.tgz",
-                          "dependencies": {
-                            "wrappy": {
-                              "version": "1.0.1",
-                              "from": "https://registry.npmjs.org/wrappy/-/wrappy-1.0.1.tgz",
-                              "resolved": "https://registry.npmjs.org/wrappy/-/wrappy-1.0.1.tgz"
-                            }
-                          }
-                        }
-                      }
-                    },
-                    "minimatch": {
-                      "version": "2.0.10",
-                      "from": "https://registry.npmjs.org/minimatch/-/minimatch-2.0.10.tgz",
-                      "resolved": "https://registry.npmjs.org/minimatch/-/minimatch-2.0.10.tgz",
-                      "dependencies": {
-                        "brace-expansion": {
-                          "version": "1.1.4",
-                          "from": "https://registry.npmjs.org/brace-expansion/-/brace-expansion-1.1.4.tgz",
-                          "resolved": "https://registry.npmjs.org/brace-expansion/-/brace-expansion-1.1.4.tgz",
-                          "dependencies": {
-                            "balanced-match": {
-                              "version": "0.4.1",
-                              "from": "https://registry.npmjs.org/balanced-match/-/balanced-match-0.4.1.tgz",
-                              "resolved": "https://registry.npmjs.org/balanced-match/-/balanced-match-0.4.1.tgz"
-                            },
-                            "concat-map": {
-                              "version": "0.0.1",
-                              "from": "https://registry.npmjs.org/concat-map/-/concat-map-0.0.1.tgz",
-                              "resolved": "https://registry.npmjs.org/concat-map/-/concat-map-0.0.1.tgz"
-                            }
-                          }
-                        }
-                      }
-                    },
-                    "ordered-read-streams": {
-                      "version": "0.1.0",
-                      "from": "https://registry.npmjs.org/ordered-read-streams/-/ordered-read-streams-0.1.0.tgz",
-                      "resolved": "https://registry.npmjs.org/ordered-read-streams/-/ordered-read-streams-0.1.0.tgz"
-                    },
-                    "glob2base": {
-                      "version": "0.0.12",
-                      "from": "https://registry.npmjs.org/glob2base/-/glob2base-0.0.12.tgz",
-                      "resolved": "https://registry.npmjs.org/glob2base/-/glob2base-0.0.12.tgz",
-                      "dependencies": {
-                        "find-index": {
-                          "version": "0.1.1",
-                          "from": "https://registry.npmjs.org/find-index/-/find-index-0.1.1.tgz",
-                          "resolved": "https://registry.npmjs.org/find-index/-/find-index-0.1.1.tgz"
-                        }
-                      }
-                    },
-                    "unique-stream": {
+                    "number-is-nan": {
                       "version": "1.0.0",
-                      "from": "https://registry.npmjs.org/unique-stream/-/unique-stream-1.0.0.tgz",
-                      "resolved": "https://registry.npmjs.org/unique-stream/-/unique-stream-1.0.0.tgz"
-                    }
-                  }
-                },
-                "glob-watcher": {
-                  "version": "0.0.6",
-                  "from": "https://registry.npmjs.org/glob-watcher/-/glob-watcher-0.0.6.tgz",
-                  "resolved": "https://registry.npmjs.org/glob-watcher/-/glob-watcher-0.0.6.tgz",
-                  "dependencies": {
-                    "gaze": {
-                      "version": "0.5.2",
-                      "from": "https://registry.npmjs.org/gaze/-/gaze-0.5.2.tgz",
-                      "resolved": "https://registry.npmjs.org/gaze/-/gaze-0.5.2.tgz",
-                      "dependencies": {
-                        "globule": {
-                          "version": "0.1.0",
-                          "from": "https://registry.npmjs.org/globule/-/globule-0.1.0.tgz",
-                          "resolved": "https://registry.npmjs.org/globule/-/globule-0.1.0.tgz",
-                          "dependencies": {
-                            "lodash": {
-                              "version": "1.0.2",
-                              "from": "https://registry.npmjs.org/lodash/-/lodash-1.0.2.tgz",
-                              "resolved": "https://registry.npmjs.org/lodash/-/lodash-1.0.2.tgz"
-                            },
-                            "glob": {
-                              "version": "3.1.21",
-                              "from": "https://registry.npmjs.org/glob/-/glob-3.1.21.tgz",
-                              "resolved": "https://registry.npmjs.org/glob/-/glob-3.1.21.tgz",
-                              "dependencies": {
-                                "graceful-fs": {
-                                  "version": "1.2.3",
-                                  "from": "https://registry.npmjs.org/graceful-fs/-/graceful-fs-1.2.3.tgz",
-                                  "resolved": "https://registry.npmjs.org/graceful-fs/-/graceful-fs-1.2.3.tgz"
-                                },
-                                "inherits": {
-                                  "version": "1.0.2",
-                                  "from": "https://registry.npmjs.org/inherits/-/inherits-1.0.2.tgz",
-                                  "resolved": "https://registry.npmjs.org/inherits/-/inherits-1.0.2.tgz"
-                                }
-                              }
-                            },
-                            "minimatch": {
-                              "version": "0.2.14",
-                              "from": "https://registry.npmjs.org/minimatch/-/minimatch-0.2.14.tgz",
-                              "resolved": "https://registry.npmjs.org/minimatch/-/minimatch-0.2.14.tgz",
-                              "dependencies": {
-                                "lru-cache": {
-                                  "version": "2.7.3",
-                                  "from": "https://registry.npmjs.org/lru-cache/-/lru-cache-2.7.3.tgz",
-                                  "resolved": "https://registry.npmjs.org/lru-cache/-/lru-cache-2.7.3.tgz"
-                                },
-                                "sigmund": {
-                                  "version": "1.0.1",
-                                  "from": "https://registry.npmjs.org/sigmund/-/sigmund-1.0.1.tgz",
-                                  "resolved": "https://registry.npmjs.org/sigmund/-/sigmund-1.0.1.tgz"
-                                }
-                              }
-                            }
-                          }
-                        }
-                      }
-                    }
-                  }
-                },
-                "graceful-fs": {
-                  "version": "3.0.8",
-                  "from": "https://registry.npmjs.org/graceful-fs/-/graceful-fs-3.0.8.tgz",
-                  "resolved": "https://registry.npmjs.org/graceful-fs/-/graceful-fs-3.0.8.tgz"
-                },
-                "mkdirp": {
-                  "version": "0.5.1",
-                  "from": "https://registry.npmjs.org/mkdirp/-/mkdirp-0.5.1.tgz",
-                  "resolved": "https://registry.npmjs.org/mkdirp/-/mkdirp-0.5.1.tgz",
-                  "dependencies": {
-                    "minimist": {
-                      "version": "0.0.8",
-                      "from": "https://registry.npmjs.org/minimist/-/minimist-0.0.8.tgz",
-                      "resolved": "https://registry.npmjs.org/minimist/-/minimist-0.0.8.tgz"
+                      "from": "number-is-nan@>=1.0.0 <2.0.0",
+                      "resolved": "https://registry.npmjs.org/number-is-nan/-/number-is-nan-1.0.0.tgz"
                     }
                   }
                 },
-                "strip-bom": {
+                "is-fullwidth-code-point": {
                   "version": "1.0.0",
-                  "from": "https://registry.npmjs.org/strip-bom/-/strip-bom-1.0.0.tgz",
-                  "resolved": "https://registry.npmjs.org/strip-bom/-/strip-bom-1.0.0.tgz",
+                  "from": "is-fullwidth-code-point@>=1.0.0 <2.0.0",
+                  "resolved": "https://registry.npmjs.org/is-fullwidth-code-point/-/is-fullwidth-code-point-1.0.0.tgz",
                   "dependencies": {
-                    "first-chunk-stream": {
+                    "number-is-nan": {
                       "version": "1.0.0",
-                      "from": "https://registry.npmjs.org/first-chunk-stream/-/first-chunk-stream-1.0.0.tgz",
-                      "resolved": "https://registry.npmjs.org/first-chunk-stream/-/first-chunk-stream-1.0.0.tgz"
-                    },
-                    "is-utf8": {
-                      "version": "0.2.1",
-                      "from": "https://registry.npmjs.org/is-utf8/-/is-utf8-0.2.1.tgz",
-                      "resolved": "https://registry.npmjs.org/is-utf8/-/is-utf8-0.2.1.tgz"
-                    }
-                  }
-                },
-                "through2": {
-                  "version": "0.6.5",
-                  "from": "https://registry.npmjs.org/through2/-/through2-0.6.5.tgz",
-                  "resolved": "https://registry.npmjs.org/through2/-/through2-0.6.5.tgz",
-                  "dependencies": {
-                    "readable-stream": {
-                      "version": "1.0.34",
-                      "from": "https://registry.npmjs.org/readable-stream/-/readable-stream-1.0.34.tgz",
-                      "resolved": "https://registry.npmjs.org/readable-stream/-/readable-stream-1.0.34.tgz",
-                      "dependencies": {
-                        "core-util-is": {
-                          "version": "1.0.2",
-                          "from": "https://registry.npmjs.org/core-util-is/-/core-util-is-1.0.2.tgz",
-                          "resolved": "https://registry.npmjs.org/core-util-is/-/core-util-is-1.0.2.tgz"
-                        },
-                        "isarray": {
-                          "version": "0.0.1",
-                          "from": "https://registry.npmjs.org/isarray/-/isarray-0.0.1.tgz",
-                          "resolved": "https://registry.npmjs.org/isarray/-/isarray-0.0.1.tgz"
-                        },
-                        "string_decoder": {
-                          "version": "0.10.31",
-                          "from": "https://registry.npmjs.org/string_decoder/-/string_decoder-0.10.31.tgz",
-                          "resolved": "https://registry.npmjs.org/string_decoder/-/string_decoder-0.10.31.tgz"
-                        },
-                        "inherits": {
-                          "version": "2.0.1",
-                          "from": "https://registry.npmjs.org/inherits/-/inherits-2.0.1.tgz",
-                          "resolved": "https://registry.npmjs.org/inherits/-/inherits-2.0.1.tgz"
-                        }
-                      }
-                    },
-                    "xtend": {
-                      "version": "4.0.1",
-                      "from": "https://registry.npmjs.org/xtend/-/xtend-4.0.1.tgz",
-                      "resolved": "https://registry.npmjs.org/xtend/-/xtend-4.0.1.tgz"
-                    }
-                  }
-                },
-                "vinyl": {
-                  "version": "0.4.6",
-                  "from": "https://registry.npmjs.org/vinyl/-/vinyl-0.4.6.tgz",
-                  "resolved": "https://registry.npmjs.org/vinyl/-/vinyl-0.4.6.tgz",
-                  "dependencies": {
-                    "clone": {
-                      "version": "0.2.0",
-                      "from": "https://registry.npmjs.org/clone/-/clone-0.2.0.tgz",
-                      "resolved": "https://registry.npmjs.org/clone/-/clone-0.2.0.tgz"
-                    },
-                    "clone-stats": {
-                      "version": "0.0.1",
-                      "from": "https://registry.npmjs.org/clone-stats/-/clone-stats-0.0.1.tgz",
-                      "resolved": "https://registry.npmjs.org/clone-stats/-/clone-stats-0.0.1.tgz"
+                      "from": "number-is-nan@>=1.0.0 <2.0.0",
+                      "resolved": "https://registry.npmjs.org/number-is-nan/-/number-is-nan-1.0.0.tgz"
                     }
                   }
                 }
               }
+            },
+            "strip-ansi": {
+              "version": "3.0.1",
+              "from": "strip-ansi@>=3.0.0 <4.0.0",
+              "resolved": "https://registry.npmjs.org/strip-ansi/-/strip-ansi-3.0.1.tgz",
+              "dependencies": {
+                "ansi-regex": {
+                  "version": "2.0.0",
+                  "from": "ansi-regex@>=2.0.0 <3.0.0",
+                  "resolved": "https://registry.npmjs.org/ansi-regex/-/ansi-regex-2.0.0.tgz"
+                }
+              }
+            },
+            "through": {
+              "version": "2.3.8",
+              "from": "through@>=2.3.6 <3.0.0",
+              "resolved": "https://registry.npmjs.org/through/-/through-2.3.8.tgz"
             }
           }
         },
-        "gulp-git": {
-          "version": "1.7.1",
-          "from": "https://registry.npmjs.org/gulp-git/-/gulp-git-1.7.1.tgz",
-          "resolved": "https://registry.npmjs.org/gulp-git/-/gulp-git-1.7.1.tgz",
+        "lodash": {
+          "version": "4.14.1",
+          "from": "lodash@4.14.1",
+          "resolved": "https://registry.npmjs.org/lodash/-/lodash-4.14.1.tgz"
+        },
+        "minimist": {
+          "version": "1.2.0",
+          "from": "minimist@1.2.0",
+          "resolved": "https://registry.npmjs.org/minimist/-/minimist-1.2.0.tgz"
+        },
+        "path-exists": {
+          "version": "2.1.0",
+          "from": "path-exists@2.1.0",
+          "resolved": "https://registry.npmjs.org/path-exists/-/path-exists-2.1.0.tgz",
           "dependencies": {
-            "any-shell-escape": {
-              "version": "0.1.1",
-              "from": "https://registry.npmjs.org/any-shell-escape/-/any-shell-escape-0.1.1.tgz",
-              "resolved": "https://registry.npmjs.org/any-shell-escape/-/any-shell-escape-0.1.1.tgz"
-            },
-            "require-dir": {
-              "version": "0.1.0",
-              "from": "https://registry.npmjs.org/require-dir/-/require-dir-0.1.0.tgz",
-              "resolved": "https://registry.npmjs.org/require-dir/-/require-dir-0.1.0.tgz"
-            },
-            "through2": {
-              "version": "0.6.5",
-              "from": "https://registry.npmjs.org/through2/-/through2-0.6.5.tgz",
-              "resolved": "https://registry.npmjs.org/through2/-/through2-0.6.5.tgz",
-              "dependencies": {
-                "readable-stream": {
-                  "version": "1.0.34",
-                  "from": "https://registry.npmjs.org/readable-stream/-/readable-stream-1.0.34.tgz",
-                  "resolved": "https://registry.npmjs.org/readable-stream/-/readable-stream-1.0.34.tgz",
-                  "dependencies": {
-                    "core-util-is": {
-                      "version": "1.0.2",
-                      "from": "https://registry.npmjs.org/core-util-is/-/core-util-is-1.0.2.tgz",
-                      "resolved": "https://registry.npmjs.org/core-util-is/-/core-util-is-1.0.2.tgz"
-                    },
-                    "isarray": {
-                      "version": "0.0.1",
-                      "from": "https://registry.npmjs.org/isarray/-/isarray-0.0.1.tgz",
-                      "resolved": "https://registry.npmjs.org/isarray/-/isarray-0.0.1.tgz"
-                    },
-                    "string_decoder": {
-                      "version": "0.10.31",
-                      "from": "https://registry.npmjs.org/string_decoder/-/string_decoder-0.10.31.tgz",
-                      "resolved": "https://registry.npmjs.org/string_decoder/-/string_decoder-0.10.31.tgz"
-                    },
-                    "inherits": {
-                      "version": "2.0.1",
-                      "from": "https://registry.npmjs.org/inherits/-/inherits-2.0.1.tgz",
-                      "resolved": "https://registry.npmjs.org/inherits/-/inherits-2.0.1.tgz"
-                    }
-                  }
-                },
-                "xtend": {
-                  "version": "4.0.1",
-                  "from": "https://registry.npmjs.org/xtend/-/xtend-4.0.1.tgz",
-                  "resolved": "https://registry.npmjs.org/xtend/-/xtend-4.0.1.tgz"
-                }
-              }
-            }
-          }
-        },
-        "home-or-tmp": {
-          "version": "2.0.0",
-          "from": "https://registry.npmjs.org/home-or-tmp/-/home-or-tmp-2.0.0.tgz",
-          "resolved": "https://registry.npmjs.org/home-or-tmp/-/home-or-tmp-2.0.0.tgz",
-          "dependencies": {
-            "os-homedir": {
-              "version": "1.0.1",
-              "from": "https://registry.npmjs.org/os-homedir/-/os-homedir-1.0.1.tgz",
-              "resolved": "https://registry.npmjs.org/os-homedir/-/os-homedir-1.0.1.tgz"
-            },
-            "os-tmpdir": {
-              "version": "1.0.1",
-              "from": "https://registry.npmjs.org/os-tmpdir/-/os-tmpdir-1.0.1.tgz",
-              "resolved": "https://registry.npmjs.org/os-tmpdir/-/os-tmpdir-1.0.1.tgz"
-            }
-          }
-        },
-        "inquirer": {
-          "version": "1.0.2",
-          "from": "https://registry.npmjs.org/inquirer/-/inquirer-1.0.2.tgz",
-          "resolved": "https://registry.npmjs.org/inquirer/-/inquirer-1.0.2.tgz",
-          "dependencies": {
-            "ansi-escapes": {
-              "version": "1.4.0",
-              "from": "https://registry.npmjs.org/ansi-escapes/-/ansi-escapes-1.4.0.tgz",
-              "resolved": "https://registry.npmjs.org/ansi-escapes/-/ansi-escapes-1.4.0.tgz"
-            },
-            "cli-cursor": {
-              "version": "1.0.2",
-              "from": "https://registry.npmjs.org/cli-cursor/-/cli-cursor-1.0.2.tgz",
-              "resolved": "https://registry.npmjs.org/cli-cursor/-/cli-cursor-1.0.2.tgz",
-              "dependencies": {
-                "restore-cursor": {
-                  "version": "1.0.1",
-                  "from": "https://registry.npmjs.org/restore-cursor/-/restore-cursor-1.0.1.tgz",
-                  "resolved": "https://registry.npmjs.org/restore-cursor/-/restore-cursor-1.0.1.tgz",
-                  "dependencies": {
-                    "exit-hook": {
-                      "version": "1.1.1",
-                      "from": "https://registry.npmjs.org/exit-hook/-/exit-hook-1.1.1.tgz",
-                      "resolved": "https://registry.npmjs.org/exit-hook/-/exit-hook-1.1.1.tgz"
-                    },
-                    "onetime": {
-                      "version": "1.1.0",
-                      "from": "https://registry.npmjs.org/onetime/-/onetime-1.1.0.tgz",
-                      "resolved": "https://registry.npmjs.org/onetime/-/onetime-1.1.0.tgz"
-                    }
-                  }
-                }
-              }
-            },
-            "cli-width": {
-              "version": "2.1.0",
-              "from": "https://registry.npmjs.org/cli-width/-/cli-width-2.1.0.tgz",
-              "resolved": "https://registry.npmjs.org/cli-width/-/cli-width-2.1.0.tgz"
-            },
-            "figures": {
-              "version": "1.6.0",
-              "from": "https://registry.npmjs.org/figures/-/figures-1.6.0.tgz",
-              "resolved": "https://registry.npmjs.org/figures/-/figures-1.6.0.tgz"
-            },
-            "mute-stream": {
-              "version": "0.0.6",
-              "from": "https://registry.npmjs.org/mute-stream/-/mute-stream-0.0.6.tgz",
-              "resolved": "https://registry.npmjs.org/mute-stream/-/mute-stream-0.0.6.tgz"
-            },
             "pinkie-promise": {
               "version": "2.0.1",
-              "from": "https://registry.npmjs.org/pinkie-promise/-/pinkie-promise-2.0.1.tgz",
+              "from": "pinkie-promise@>=2.0.0 <3.0.0",
               "resolved": "https://registry.npmjs.org/pinkie-promise/-/pinkie-promise-2.0.1.tgz",
               "dependencies": {
                 "pinkie": {
                   "version": "2.0.4",
-                  "from": "https://registry.npmjs.org/pinkie/-/pinkie-2.0.4.tgz",
+                  "from": "pinkie@>=2.0.0 <3.0.0",
                   "resolved": "https://registry.npmjs.org/pinkie/-/pinkie-2.0.4.tgz"
                 }
               }
-            },
-            "run-async": {
-              "version": "2.2.0",
-              "from": "https://registry.npmjs.org/run-async/-/run-async-2.2.0.tgz",
-              "resolved": "https://registry.npmjs.org/run-async/-/run-async-2.2.0.tgz",
-              "dependencies": {
-                "is-promise": {
-                  "version": "2.1.0",
-                  "from": "https://registry.npmjs.org/is-promise/-/is-promise-2.1.0.tgz",
-                  "resolved": "https://registry.npmjs.org/is-promise/-/is-promise-2.1.0.tgz"
-                }
-              }
-            },
-            "rx": {
-              "version": "4.1.0",
-              "from": "https://registry.npmjs.org/rx/-/rx-4.1.0.tgz",
-              "resolved": "https://registry.npmjs.org/rx/-/rx-4.1.0.tgz"
-            },
-            "string-width": {
-              "version": "1.0.1",
-              "from": "https://registry.npmjs.org/string-width/-/string-width-1.0.1.tgz",
-              "resolved": "https://registry.npmjs.org/string-width/-/string-width-1.0.1.tgz",
-              "dependencies": {
-                "code-point-at": {
-                  "version": "1.0.0",
-                  "from": "https://registry.npmjs.org/code-point-at/-/code-point-at-1.0.0.tgz",
-                  "resolved": "https://registry.npmjs.org/code-point-at/-/code-point-at-1.0.0.tgz",
-                  "dependencies": {
-                    "number-is-nan": {
-                      "version": "1.0.0",
-                      "from": "https://registry.npmjs.org/number-is-nan/-/number-is-nan-1.0.0.tgz",
-                      "resolved": "https://registry.npmjs.org/number-is-nan/-/number-is-nan-1.0.0.tgz"
-                    }
-                  }
-                },
-                "is-fullwidth-code-point": {
-                  "version": "1.0.0",
-                  "from": "https://registry.npmjs.org/is-fullwidth-code-point/-/is-fullwidth-code-point-1.0.0.tgz",
-                  "resolved": "https://registry.npmjs.org/is-fullwidth-code-point/-/is-fullwidth-code-point-1.0.0.tgz",
-                  "dependencies": {
-                    "number-is-nan": {
-                      "version": "1.0.0",
-                      "from": "https://registry.npmjs.org/number-is-nan/-/number-is-nan-1.0.0.tgz",
-                      "resolved": "https://registry.npmjs.org/number-is-nan/-/number-is-nan-1.0.0.tgz"
-                    }
-                  }
-                }
-              }
-            },
-            "strip-ansi": {
-              "version": "3.0.1",
-              "from": "https://registry.npmjs.org/strip-ansi/-/strip-ansi-3.0.1.tgz",
-              "resolved": "https://registry.npmjs.org/strip-ansi/-/strip-ansi-3.0.1.tgz",
-              "dependencies": {
-                "ansi-regex": {
-                  "version": "2.0.0",
-                  "from": "https://registry.npmjs.org/ansi-regex/-/ansi-regex-2.0.0.tgz",
-                  "resolved": "https://registry.npmjs.org/ansi-regex/-/ansi-regex-2.0.0.tgz"
-                }
-              }
-            },
-            "through": {
-              "version": "2.3.8",
-              "from": "https://registry.npmjs.org/through/-/through-2.3.8.tgz",
-              "resolved": "https://registry.npmjs.org/through/-/through-2.3.8.tgz"
             }
           }
         },
-        "lodash": {
-          "version": "4.11.1",
-          "from": "https://registry.npmjs.org/lodash/-/lodash-4.11.1.tgz",
-          "resolved": "https://registry.npmjs.org/lodash/-/lodash-4.11.1.tgz"
-        },
-        "minimist": {
-          "version": "1.2.0",
-          "from": "https://registry.npmjs.org/minimist/-/minimist-1.2.0.tgz",
-          "resolved": "https://registry.npmjs.org/minimist/-/minimist-1.2.0.tgz"
-        },
         "shelljs": {
           "version": "0.5.3",
-          "from": "https://registry.npmjs.org/shelljs/-/shelljs-0.5.3.tgz",
+          "from": "shelljs@0.5.3",
           "resolved": "https://registry.npmjs.org/shelljs/-/shelljs-0.5.3.tgz"
+        },
+        "strip-json-comments": {
+          "version": "2.0.1",
+          "from": "strip-json-comments@2.0.1",
+          "resolved": "https://registry.npmjs.org/strip-json-comments/-/strip-json-comments-2.0.1.tgz"
         }
       }
     },
@@ -4518,23 +4144,23 @@
       }
     },
     "dgeni-packages": {
-      "version": "0.13.0",
-      "from": "https://registry.npmjs.org/dgeni-packages/-/dgeni-packages-0.13.0.tgz",
-      "resolved": "https://registry.npmjs.org/dgeni-packages/-/dgeni-packages-0.13.0.tgz",
+      "version": "0.14.0",
+      "from": "dgeni-packages@>=0.14.0 <0.15.0",
+      "resolved": "https://registry.npmjs.org/dgeni-packages/-/dgeni-packages-0.14.0.tgz",
       "dependencies": {
         "catharsis": {
           "version": "0.8.8",
-          "from": "https://registry.npmjs.org/catharsis/-/catharsis-0.8.8.tgz",
+          "from": "catharsis@>=0.8.1 <0.9.0",
           "resolved": "https://registry.npmjs.org/catharsis/-/catharsis-0.8.8.tgz",
           "dependencies": {
             "underscore-contrib": {
               "version": "0.3.0",
-              "from": "https://registry.npmjs.org/underscore-contrib/-/underscore-contrib-0.3.0.tgz",
+              "from": "underscore-contrib@>=0.3.0 <0.4.0",
               "resolved": "https://registry.npmjs.org/underscore-contrib/-/underscore-contrib-0.3.0.tgz",
               "dependencies": {
                 "underscore": {
                   "version": "1.6.0",
-                  "from": "https://registry.npmjs.org/underscore/-/underscore-1.6.0.tgz",
+                  "from": "underscore@1.6.0",
                   "resolved": "https://registry.npmjs.org/underscore/-/underscore-1.6.0.tgz"
                 }
               }
@@ -4542,142 +4168,186 @@
           }
         },
         "change-case": {
-          "version": "2.3.1",
-          "from": "https://registry.npmjs.org/change-case/-/change-case-2.3.1.tgz",
-          "resolved": "https://registry.npmjs.org/change-case/-/change-case-2.3.1.tgz",
+          "version": "3.0.0",
+          "from": "change-case@3.0.0",
+          "resolved": "https://registry.npmjs.org/change-case/-/change-case-3.0.0.tgz",
           "dependencies": {
             "camel-case": {
-              "version": "1.2.2",
-              "from": "https://registry.npmjs.org/camel-case/-/camel-case-1.2.2.tgz",
-              "resolved": "https://registry.npmjs.org/camel-case/-/camel-case-1.2.2.tgz"
+              "version": "3.0.0",
+              "from": "camel-case@>=3.0.0 <4.0.0",
+              "resolved": "https://registry.npmjs.org/camel-case/-/camel-case-3.0.0.tgz"
             },
             "constant-case": {
-              "version": "1.1.2",
-              "from": "https://registry.npmjs.org/constant-case/-/constant-case-1.1.2.tgz",
-              "resolved": "https://registry.npmjs.org/constant-case/-/constant-case-1.1.2.tgz"
+              "version": "2.0.0",
+              "from": "constant-case@>=2.0.0 <3.0.0",
+              "resolved": "https://registry.npmjs.org/constant-case/-/constant-case-2.0.0.tgz"
             },
             "dot-case": {
-              "version": "1.1.2",
-              "from": "https://registry.npmjs.org/dot-case/-/dot-case-1.1.2.tgz",
-              "resolved": "https://registry.npmjs.org/dot-case/-/dot-case-1.1.2.tgz"
+              "version": "2.1.0",
+              "from": "dot-case@>=2.1.0 <3.0.0",
+              "resolved": "https://registry.npmjs.org/dot-case/-/dot-case-2.1.0.tgz"
+            },
+            "header-case": {
+              "version": "1.0.0",
+              "from": "header-case@>=1.0.0 <2.0.0",
+              "resolved": "https://registry.npmjs.org/header-case/-/header-case-1.0.0.tgz"
             },
             "is-lower-case": {
               "version": "1.1.3",
-              "from": "https://registry.npmjs.org/is-lower-case/-/is-lower-case-1.1.3.tgz",
+              "from": "is-lower-case@>=1.1.0 <2.0.0",
               "resolved": "https://registry.npmjs.org/is-lower-case/-/is-lower-case-1.1.3.tgz"
             },
             "is-upper-case": {
               "version": "1.1.2",
-              "from": "https://registry.npmjs.org/is-upper-case/-/is-upper-case-1.1.2.tgz",
+              "from": "is-upper-case@>=1.1.0 <2.0.0",
               "resolved": "https://registry.npmjs.org/is-upper-case/-/is-upper-case-1.1.2.tgz"
             },
             "lower-case": {
               "version": "1.1.3",
-              "from": "https://registry.npmjs.org/lower-case/-/lower-case-1.1.3.tgz",
+              "from": "lower-case@>=1.1.1 <2.0.0",
               "resolved": "https://registry.npmjs.org/lower-case/-/lower-case-1.1.3.tgz"
             },
             "lower-case-first": {
               "version": "1.0.2",
-              "from": "https://registry.npmjs.org/lower-case-first/-/lower-case-first-1.0.2.tgz",
+              "from": "lower-case-first@>=1.0.0 <2.0.0",
               "resolved": "https://registry.npmjs.org/lower-case-first/-/lower-case-first-1.0.2.tgz"
             },
+            "no-case": {
+              "version": "2.3.0",
+              "from": "no-case@>=2.2.0 <3.0.0",
+              "resolved": "https://registry.npmjs.org/no-case/-/no-case-2.3.0.tgz"
+            },
             "param-case": {
-              "version": "1.1.2",
-              "from": "https://registry.npmjs.org/param-case/-/param-case-1.1.2.tgz",
-              "resolved": "https://registry.npmjs.org/param-case/-/param-case-1.1.2.tgz"
+              "version": "2.1.0",
+              "from": "param-case@>=2.1.0 <3.0.0",
+              "resolved": "https://registry.npmjs.org/param-case/-/param-case-2.1.0.tgz"
             },
             "pascal-case": {
-              "version": "1.1.2",
-              "from": "https://registry.npmjs.org/pascal-case/-/pascal-case-1.1.2.tgz",
-              "resolved": "https://registry.npmjs.org/pascal-case/-/pascal-case-1.1.2.tgz"
+              "version": "2.0.0",
+              "from": "pascal-case@>=2.0.0 <3.0.0",
+              "resolved": "https://registry.npmjs.org/pascal-case/-/pascal-case-2.0.0.tgz"
             },
             "path-case": {
-              "version": "1.1.2",
-              "from": "https://registry.npmjs.org/path-case/-/path-case-1.1.2.tgz",
-              "resolved": "https://registry.npmjs.org/path-case/-/path-case-1.1.2.tgz"
+              "version": "2.1.0",
+              "from": "path-case@>=2.1.0 <3.0.0",
+              "resolved": "https://registry.npmjs.org/path-case/-/path-case-2.1.0.tgz"
             },
             "sentence-case": {
-              "version": "1.1.3",
-              "from": "https://registry.npmjs.org/sentence-case/-/sentence-case-1.1.3.tgz",
-              "resolved": "https://registry.npmjs.org/sentence-case/-/sentence-case-1.1.3.tgz"
+              "version": "2.1.0",
+              "from": "sentence-case@>=2.1.0 <3.0.0",
+              "resolved": "https://registry.npmjs.org/sentence-case/-/sentence-case-2.1.0.tgz"
             },
             "snake-case": {
-              "version": "1.1.2",
-              "from": "https://registry.npmjs.org/snake-case/-/snake-case-1.1.2.tgz",
-              "resolved": "https://registry.npmjs.org/snake-case/-/snake-case-1.1.2.tgz"
+              "version": "2.1.0",
+              "from": "snake-case@>=2.1.0 <3.0.0",
+              "resolved": "https://registry.npmjs.org/snake-case/-/snake-case-2.1.0.tgz"
             },
             "swap-case": {
               "version": "1.1.2",
-              "from": "https://registry.npmjs.org/swap-case/-/swap-case-1.1.2.tgz",
+              "from": "swap-case@>=1.1.0 <2.0.0",
               "resolved": "https://registry.npmjs.org/swap-case/-/swap-case-1.1.2.tgz"
             },
             "title-case": {
-              "version": "1.1.2",
-              "from": "https://registry.npmjs.org/title-case/-/title-case-1.1.2.tgz",
-              "resolved": "https://registry.npmjs.org/title-case/-/title-case-1.1.2.tgz"
+              "version": "2.1.0",
+              "from": "title-case@>=2.1.0 <3.0.0",
+              "resolved": "https://registry.npmjs.org/title-case/-/title-case-2.1.0.tgz"
             },
             "upper-case": {
               "version": "1.1.3",
-              "from": "https://registry.npmjs.org/upper-case/-/upper-case-1.1.3.tgz",
+              "from": "upper-case@>=1.1.1 <2.0.0",
               "resolved": "https://registry.npmjs.org/upper-case/-/upper-case-1.1.3.tgz"
             },
             "upper-case-first": {
               "version": "1.1.2",
-              "from": "https://registry.npmjs.org/upper-case-first/-/upper-case-first-1.1.2.tgz",
+              "from": "upper-case-first@>=1.1.0 <2.0.0",
               "resolved": "https://registry.npmjs.org/upper-case-first/-/upper-case-first-1.1.2.tgz"
             }
           }
         },
         "espree": {
           "version": "2.2.5",
-          "from": "https://registry.npmjs.org/espree/-/espree-2.2.5.tgz",
+          "from": "espree@>=2.2.3 <3.0.0",
           "resolved": "https://registry.npmjs.org/espree/-/espree-2.2.5.tgz"
         },
         "estraverse": {
           "version": "4.2.0",
-          "from": "https://registry.npmjs.org/estraverse/-/estraverse-4.2.0.tgz",
+          "from": "estraverse@>=4.1.0 <5.0.0",
           "resolved": "https://registry.npmjs.org/estraverse/-/estraverse-4.2.0.tgz"
         },
         "glob": {
-          "version": "3.2.11",
-          "from": "https://registry.npmjs.org/glob/-/glob-3.2.11.tgz",
-          "resolved": "https://registry.npmjs.org/glob/-/glob-3.2.11.tgz",
+          "version": "7.0.5",
+          "from": "glob@>=7.0.5 <8.0.0",
+          "resolved": "https://registry.npmjs.org/glob/-/glob-7.0.5.tgz",
           "dependencies": {
+            "fs.realpath": {
+              "version": "1.0.0",
+              "from": "fs.realpath@>=1.0.0 <2.0.0",
+              "resolved": "https://registry.npmjs.org/fs.realpath/-/fs.realpath-1.0.0.tgz"
+            },
+            "inflight": {
+              "version": "1.0.5",
+              "from": "inflight@>=1.0.4 <2.0.0",
+              "resolved": "https://registry.npmjs.org/inflight/-/inflight-1.0.5.tgz",
+              "dependencies": {
+                "wrappy": {
+                  "version": "1.0.2",
+                  "from": "wrappy@>=1.0.0 <2.0.0",
+                  "resolved": "https://registry.npmjs.org/wrappy/-/wrappy-1.0.2.tgz"
+                }
+              }
+            },
             "inherits": {
               "version": "2.0.1",
-              "from": "https://registry.npmjs.org/inherits/-/inherits-2.0.1.tgz",
+              "from": "inherits@>=2.0.0 <3.0.0",
               "resolved": "https://registry.npmjs.org/inherits/-/inherits-2.0.1.tgz"
+            },
+            "once": {
+              "version": "1.3.3",
+              "from": "once@>=1.3.0 <2.0.0",
+              "resolved": "https://registry.npmjs.org/once/-/once-1.3.3.tgz",
+              "dependencies": {
+                "wrappy": {
+                  "version": "1.0.2",
+                  "from": "wrappy@>=1.0.0 <2.0.0",
+                  "resolved": "https://registry.npmjs.org/wrappy/-/wrappy-1.0.2.tgz"
+                }
+              }
+            },
+            "path-is-absolute": {
+              "version": "1.0.0",
+              "from": "path-is-absolute@>=1.0.0 <2.0.0",
+              "resolved": "https://registry.npmjs.org/path-is-absolute/-/path-is-absolute-1.0.0.tgz"
             }
           }
         },
         "htmlparser2": {
-          "version": "3.9.0",
-          "from": "https://registry.npmjs.org/htmlparser2/-/htmlparser2-3.9.0.tgz",
-          "resolved": "https://registry.npmjs.org/htmlparser2/-/htmlparser2-3.9.0.tgz",
+          "version": "3.9.1",
+          "from": "htmlparser2@>=3.7.3 <4.0.0",
+          "resolved": "https://registry.npmjs.org/htmlparser2/-/htmlparser2-3.9.1.tgz",
           "dependencies": {
             "domelementtype": {
               "version": "1.3.0",
-              "from": "https://registry.npmjs.org/domelementtype/-/domelementtype-1.3.0.tgz",
+              "from": "domelementtype@>=1.3.0 <2.0.0",
               "resolved": "https://registry.npmjs.org/domelementtype/-/domelementtype-1.3.0.tgz"
             },
             "domhandler": {
               "version": "2.3.0",
-              "from": "https://registry.npmjs.org/domhandler/-/domhandler-2.3.0.tgz",
+              "from": "domhandler@>=2.3.0 <3.0.0",
               "resolved": "https://registry.npmjs.org/domhandler/-/domhandler-2.3.0.tgz"
             },
             "domutils": {
               "version": "1.5.1",
-              "from": "https://registry.npmjs.org/domutils/-/domutils-1.5.1.tgz",
+              "from": "domutils@>=1.5.1 <2.0.0",
               "resolved": "https://registry.npmjs.org/domutils/-/domutils-1.5.1.tgz",
               "dependencies": {
                 "dom-serializer": {
                   "version": "0.1.0",
-                  "from": "https://registry.npmjs.org/dom-serializer/-/dom-serializer-0.1.0.tgz",
+                  "from": "dom-serializer@>=0.0.0 <1.0.0",
                   "resolved": "https://registry.npmjs.org/dom-serializer/-/dom-serializer-0.1.0.tgz",
                   "dependencies": {
                     "domelementtype": {
                       "version": "1.1.3",
-                      "from": "https://registry.npmjs.org/domelementtype/-/domelementtype-1.1.3.tgz",
+                      "from": "domelementtype@>=1.1.1 <1.2.0",
                       "resolved": "https://registry.npmjs.org/domelementtype/-/domelementtype-1.1.3.tgz"
                     }
                   }
@@ -4686,142 +4356,159 @@
             },
             "entities": {
               "version": "1.1.1",
-              "from": "https://registry.npmjs.org/entities/-/entities-1.1.1.tgz",
+              "from": "entities@>=1.1.1 <2.0.0",
               "resolved": "https://registry.npmjs.org/entities/-/entities-1.1.1.tgz"
             },
+            "inherits": {
+              "version": "2.0.1",
+              "from": "inherits@>=2.0.0 <3.0.0",
+              "resolved": "https://registry.npmjs.org/inherits/-/inherits-2.0.1.tgz"
+            },
             "readable-stream": {
-              "version": "2.1.2",
-              "from": "https://registry.npmjs.org/readable-stream/-/readable-stream-2.1.2.tgz",
-              "resolved": "https://registry.npmjs.org/readable-stream/-/readable-stream-2.1.2.tgz",
+              "version": "2.1.4",
+              "from": "readable-stream@>=2.0.2 <3.0.0",
+              "resolved": "https://registry.npmjs.org/readable-stream/-/readable-stream-2.1.4.tgz",
               "dependencies": {
+                "buffer-shims": {
+                  "version": "1.0.0",
+                  "from": "buffer-shims@>=1.0.0 <2.0.0",
+                  "resolved": "https://registry.npmjs.org/buffer-shims/-/buffer-shims-1.0.0.tgz"
+                },
                 "core-util-is": {
                   "version": "1.0.2",
-                  "from": "https://registry.npmjs.org/core-util-is/-/core-util-is-1.0.2.tgz",
+                  "from": "core-util-is@>=1.0.0 <1.1.0",
                   "resolved": "https://registry.npmjs.org/core-util-is/-/core-util-is-1.0.2.tgz"
                 },
-                "inherits": {
-                  "version": "2.0.1",
-                  "from": "https://registry.npmjs.org/inherits/-/inherits-2.0.1.tgz",
-                  "resolved": "https://registry.npmjs.org/inherits/-/inherits-2.0.1.tgz"
-                },
                 "isarray": {
                   "version": "1.0.0",
-                  "from": "https://registry.npmjs.org/isarray/-/isarray-1.0.0.tgz",
+                  "from": "isarray@>=1.0.0 <1.1.0",
                   "resolved": "https://registry.npmjs.org/isarray/-/isarray-1.0.0.tgz"
                 },
                 "process-nextick-args": {
                   "version": "1.0.7",
-                  "from": "https://registry.npmjs.org/process-nextick-args/-/process-nextick-args-1.0.7.tgz",
+                  "from": "process-nextick-args@>=1.0.6 <1.1.0",
                   "resolved": "https://registry.npmjs.org/process-nextick-args/-/process-nextick-args-1.0.7.tgz"
                 },
                 "string_decoder": {
                   "version": "0.10.31",
-                  "from": "https://registry.npmjs.org/string_decoder/-/string_decoder-0.10.31.tgz",
+                  "from": "string_decoder@>=0.10.0 <0.11.0",
                   "resolved": "https://registry.npmjs.org/string_decoder/-/string_decoder-0.10.31.tgz"
                 },
                 "util-deprecate": {
                   "version": "1.0.2",
-                  "from": "https://registry.npmjs.org/util-deprecate/-/util-deprecate-1.0.2.tgz",
+                  "from": "util-deprecate@>=1.0.1 <1.1.0",
                   "resolved": "https://registry.npmjs.org/util-deprecate/-/util-deprecate-1.0.2.tgz"
                 }
               }
             }
           }
         },
-        "minimatch": {
-          "version": "0.3.0",
-          "from": "https://registry.npmjs.org/minimatch/-/minimatch-0.3.0.tgz",
-          "resolved": "https://registry.npmjs.org/minimatch/-/minimatch-0.3.0.tgz",
-          "dependencies": {
-            "lru-cache": {
-              "version": "2.7.3",
-              "from": "https://registry.npmjs.org/lru-cache/-/lru-cache-2.7.3.tgz",
-              "resolved": "https://registry.npmjs.org/lru-cache/-/lru-cache-2.7.3.tgz"
-            },
-            "sigmund": {
-              "version": "1.0.1",
-              "from": "https://registry.npmjs.org/sigmund/-/sigmund-1.0.1.tgz",
-              "resolved": "https://registry.npmjs.org/sigmund/-/sigmund-1.0.1.tgz"
+        "lodash": {
+          "version": "4.14.1",
+          "from": "lodash@>=4.13.1 <5.0.0",
+          "resolved": "https://registry.npmjs.org/lodash/-/lodash-4.14.1.tgz"
+        },
+        "minimatch": {
+          "version": "3.0.2",
+          "from": "minimatch@>=3.0.2 <4.0.0",
+          "resolved": "https://registry.npmjs.org/minimatch/-/minimatch-3.0.2.tgz",
+          "dependencies": {
+            "brace-expansion": {
+              "version": "1.1.6",
+              "from": "brace-expansion@>=1.0.0 <2.0.0",
+              "resolved": "https://registry.npmjs.org/brace-expansion/-/brace-expansion-1.1.6.tgz",
+              "dependencies": {
+                "balanced-match": {
+                  "version": "0.4.2",
+                  "from": "balanced-match@>=0.4.1 <0.5.0",
+                  "resolved": "https://registry.npmjs.org/balanced-match/-/balanced-match-0.4.2.tgz"
+                },
+                "concat-map": {
+                  "version": "0.0.1",
+                  "from": "concat-map@0.0.1",
+                  "resolved": "https://registry.npmjs.org/concat-map/-/concat-map-0.0.1.tgz"
+                }
+              }
             }
           }
         },
         "nunjucks": {
           "version": "1.3.4",
-          "from": "https://registry.npmjs.org/nunjucks/-/nunjucks-1.3.4.tgz",
+          "from": "nunjucks@>=1.2.0 <2.0.0",
           "resolved": "https://registry.npmjs.org/nunjucks/-/nunjucks-1.3.4.tgz",
           "dependencies": {
             "optimist": {
               "version": "0.6.1",
-              "from": "https://registry.npmjs.org/optimist/-/optimist-0.6.1.tgz",
+              "from": "optimist@*",
               "resolved": "https://registry.npmjs.org/optimist/-/optimist-0.6.1.tgz",
               "dependencies": {
                 "wordwrap": {
                   "version": "0.0.3",
-                  "from": "https://registry.npmjs.org/wordwrap/-/wordwrap-0.0.3.tgz",
+                  "from": "wordwrap@>=0.0.2 <0.1.0",
                   "resolved": "https://registry.npmjs.org/wordwrap/-/wordwrap-0.0.3.tgz"
                 },
                 "minimist": {
                   "version": "0.0.10",
-                  "from": "https://registry.npmjs.org/minimist/-/minimist-0.0.10.tgz",
+                  "from": "minimist@>=0.0.1 <0.1.0",
                   "resolved": "https://registry.npmjs.org/minimist/-/minimist-0.0.10.tgz"
                 }
               }
             },
             "chokidar": {
               "version": "0.12.6",
-              "from": "https://registry.npmjs.org/chokidar/-/chokidar-0.12.6.tgz",
+              "from": "chokidar@>=0.12.5 <0.13.0",
               "resolved": "https://registry.npmjs.org/chokidar/-/chokidar-0.12.6.tgz",
               "dependencies": {
                 "readdirp": {
                   "version": "1.3.0",
-                  "from": "https://registry.npmjs.org/readdirp/-/readdirp-1.3.0.tgz",
+                  "from": "readdirp@>=1.3.0 <1.4.0",
                   "resolved": "https://registry.npmjs.org/readdirp/-/readdirp-1.3.0.tgz",
                   "dependencies": {
                     "graceful-fs": {
                       "version": "2.0.3",
-                      "from": "https://registry.npmjs.org/graceful-fs/-/graceful-fs-2.0.3.tgz",
+                      "from": "graceful-fs@>=2.0.0 <2.1.0",
                       "resolved": "https://registry.npmjs.org/graceful-fs/-/graceful-fs-2.0.3.tgz"
                     },
                     "minimatch": {
                       "version": "0.2.14",
-                      "from": "https://registry.npmjs.org/minimatch/-/minimatch-0.2.14.tgz",
+                      "from": "minimatch@>=0.2.12 <0.3.0",
                       "resolved": "https://registry.npmjs.org/minimatch/-/minimatch-0.2.14.tgz",
                       "dependencies": {
                         "lru-cache": {
                           "version": "2.7.3",
-                          "from": "https://registry.npmjs.org/lru-cache/-/lru-cache-2.7.3.tgz",
+                          "from": "lru-cache@>=2.0.0 <3.0.0",
                           "resolved": "https://registry.npmjs.org/lru-cache/-/lru-cache-2.7.3.tgz"
                         },
                         "sigmund": {
                           "version": "1.0.1",
-                          "from": "https://registry.npmjs.org/sigmund/-/sigmund-1.0.1.tgz",
+                          "from": "sigmund@>=1.0.0 <1.1.0",
                           "resolved": "https://registry.npmjs.org/sigmund/-/sigmund-1.0.1.tgz"
                         }
                       }
                     },
                     "readable-stream": {
                       "version": "1.0.34",
-                      "from": "https://registry.npmjs.org/readable-stream/-/readable-stream-1.0.34.tgz",
+                      "from": "readable-stream@>=1.0.26-2 <1.1.0",
                       "resolved": "https://registry.npmjs.org/readable-stream/-/readable-stream-1.0.34.tgz",
                       "dependencies": {
                         "core-util-is": {
                           "version": "1.0.2",
-                          "from": "https://registry.npmjs.org/core-util-is/-/core-util-is-1.0.2.tgz",
+                          "from": "core-util-is@>=1.0.0 <1.1.0",
                           "resolved": "https://registry.npmjs.org/core-util-is/-/core-util-is-1.0.2.tgz"
                         },
                         "isarray": {
                           "version": "0.0.1",
-                          "from": "https://registry.npmjs.org/isarray/-/isarray-0.0.1.tgz",
+                          "from": "isarray@0.0.1",
                           "resolved": "https://registry.npmjs.org/isarray/-/isarray-0.0.1.tgz"
                         },
                         "string_decoder": {
                           "version": "0.10.31",
-                          "from": "https://registry.npmjs.org/string_decoder/-/string_decoder-0.10.31.tgz",
+                          "from": "string_decoder@>=0.10.0 <0.11.0",
                           "resolved": "https://registry.npmjs.org/string_decoder/-/string_decoder-0.10.31.tgz"
                         },
                         "inherits": {
                           "version": "2.0.1",
-                          "from": "https://registry.npmjs.org/inherits/-/inherits-2.0.1.tgz",
+                          "from": "inherits@>=2.0.1 <2.1.0",
                           "resolved": "https://registry.npmjs.org/inherits/-/inherits-2.0.1.tgz"
                         }
                       }
@@ -4830,211 +4517,68 @@
                 },
                 "async-each": {
                   "version": "0.1.6",
-                  "from": "https://registry.npmjs.org/async-each/-/async-each-0.1.6.tgz",
+                  "from": "async-each@>=0.1.5 <0.2.0",
                   "resolved": "https://registry.npmjs.org/async-each/-/async-each-0.1.6.tgz"
+                },
+                "fsevents": {
+                  "version": "0.3.8",
+                  "from": "fsevents@>=0.3.1 <0.4.0",
+                  "resolved": "https://registry.npmjs.org/fsevents/-/fsevents-0.3.8.tgz",
+                  "dependencies": {
+                    "nan": {
+                      "version": "2.4.0",
+                      "from": "nan@>=2.0.2 <3.0.0",
+                      "resolved": "https://registry.npmjs.org/nan/-/nan-2.4.0.tgz"
+                    }
+                  }
                 }
               }
             }
           }
         },
-        "q-io": {
-          "version": "1.10.9",
-          "from": "https://registry.npmjs.org/q-io/-/q-io-1.10.9.tgz",
-          "resolved": "https://registry.npmjs.org/q-io/-/q-io-1.10.9.tgz",
+        "q": {
+          "version": "1.4.1",
+          "from": "q@>=1.4.1 <1.5.0",
+          "resolved": "https://registry.npmjs.org/q/-/q-1.4.1.tgz"
+        },
+        "semver": {
+          "version": "5.3.0",
+          "from": "semver@>=5.2.0 <6.0.0",
+          "resolved": "https://registry.npmjs.org/semver/-/semver-5.3.0.tgz"
+        },
+        "shelljs": {
+          "version": "0.7.3",
+          "from": "shelljs@>=0.7.0 <0.8.0",
+          "resolved": "https://registry.npmjs.org/shelljs/-/shelljs-0.7.3.tgz",
           "dependencies": {
-            "q": {
-              "version": "0.9.7",
-              "from": "https://registry.npmjs.org/q/-/q-0.9.7.tgz",
-              "resolved": "https://registry.npmjs.org/q/-/q-0.9.7.tgz"
-            },
-            "qs": {
-              "version": "0.1.0",
-              "from": "https://registry.npmjs.org/qs/-/qs-0.1.0.tgz",
-              "resolved": "https://registry.npmjs.org/qs/-/qs-0.1.0.tgz"
-            },
-            "url2": {
-              "version": "0.0.0",
-              "from": "https://registry.npmjs.org/url2/-/url2-0.0.0.tgz",
-              "resolved": "https://registry.npmjs.org/url2/-/url2-0.0.0.tgz"
-            },
-            "mime": {
-              "version": "1.2.11",
-              "from": "https://registry.npmjs.org/mime/-/mime-1.2.11.tgz",
-              "resolved": "https://registry.npmjs.org/mime/-/mime-1.2.11.tgz"
-            },
-            "mimeparse": {
-              "version": "0.1.4",
-              "from": "https://registry.npmjs.org/mimeparse/-/mimeparse-0.1.4.tgz",
-              "resolved": "https://registry.npmjs.org/mimeparse/-/mimeparse-0.1.4.tgz"
+            "interpret": {
+              "version": "1.0.1",
+              "from": "interpret@>=1.0.0 <2.0.0",
+              "resolved": "https://registry.npmjs.org/interpret/-/interpret-1.0.1.tgz"
             },
-            "collections": {
-              "version": "0.2.2",
-              "from": "https://registry.npmjs.org/collections/-/collections-0.2.2.tgz",
-              "resolved": "https://registry.npmjs.org/collections/-/collections-0.2.2.tgz",
+            "rechoir": {
+              "version": "0.6.2",
+              "from": "rechoir@>=0.6.2 <0.7.0",
+              "resolved": "https://registry.npmjs.org/rechoir/-/rechoir-0.6.2.tgz",
               "dependencies": {
-                "weak-map": {
-                  "version": "1.0.0",
-                  "from": "https://registry.npmjs.org/weak-map/-/weak-map-1.0.0.tgz",
-                  "resolved": "https://registry.npmjs.org/weak-map/-/weak-map-1.0.0.tgz"
+                "resolve": {
+                  "version": "1.1.7",
+                  "from": "resolve@>=1.1.6 <2.0.0",
+                  "resolved": "https://registry.npmjs.org/resolve/-/resolve-1.1.7.tgz"
                 }
               }
             }
           }
         },
-        "semver": {
-          "version": "4.3.6",
-          "from": "https://registry.npmjs.org/semver/-/semver-4.3.6.tgz",
-          "resolved": "https://registry.npmjs.org/semver/-/semver-4.3.6.tgz"
-        },
-        "shelljs": {
-          "version": "0.5.3",
-          "from": "https://registry.npmjs.org/shelljs/-/shelljs-0.5.3.tgz",
-          "resolved": "https://registry.npmjs.org/shelljs/-/shelljs-0.5.3.tgz"
-        },
         "spdx-license-list": {
           "version": "2.1.0",
-          "from": "https://registry.npmjs.org/spdx-license-list/-/spdx-license-list-2.1.0.tgz",
+          "from": "spdx-license-list@>=2.1.0 <3.0.0",
           "resolved": "https://registry.npmjs.org/spdx-license-list/-/spdx-license-list-2.1.0.tgz"
         },
         "typescript": {
           "version": "1.8.10",
-          "from": "https://registry.npmjs.org/typescript/-/typescript-1.8.10.tgz",
+          "from": "typescript@>=1.7.5 <2.0.0",
           "resolved": "https://registry.npmjs.org/typescript/-/typescript-1.8.10.tgz"
-        },
-        "winston": {
-          "version": "0.7.3",
-          "from": "https://registry.npmjs.org/winston/-/winston-0.7.3.tgz",
-          "resolved": "https://registry.npmjs.org/winston/-/winston-0.7.3.tgz",
-          "dependencies": {
-            "async": {
-              "version": "0.2.10",
-              "from": "https://registry.npmjs.org/async/-/async-0.2.10.tgz",
-              "resolved": "https://registry.npmjs.org/async/-/async-0.2.10.tgz"
-            },
-            "colors": {
-              "version": "0.6.2",
-              "from": "https://registry.npmjs.org/colors/-/colors-0.6.2.tgz",
-              "resolved": "https://registry.npmjs.org/colors/-/colors-0.6.2.tgz"
-            },
-            "cycle": {
-              "version": "1.0.3",
-              "from": "https://registry.npmjs.org/cycle/-/cycle-1.0.3.tgz",
-              "resolved": "https://registry.npmjs.org/cycle/-/cycle-1.0.3.tgz"
-            },
-            "eyes": {
-              "version": "0.1.8",
-              "from": "https://registry.npmjs.org/eyes/-/eyes-0.1.8.tgz",
-              "resolved": "https://registry.npmjs.org/eyes/-/eyes-0.1.8.tgz"
-            },
-            "pkginfo": {
-              "version": "0.3.1",
-              "from": "https://registry.npmjs.org/pkginfo/-/pkginfo-0.3.1.tgz",
-              "resolved": "https://registry.npmjs.org/pkginfo/-/pkginfo-0.3.1.tgz"
-            },
-            "request": {
-              "version": "2.16.6",
-              "from": "https://registry.npmjs.org/request/-/request-2.16.6.tgz",
-              "resolved": "https://registry.npmjs.org/request/-/request-2.16.6.tgz",
-              "dependencies": {
-                "form-data": {
-                  "version": "0.0.10",
-                  "from": "https://registry.npmjs.org/form-data/-/form-data-0.0.10.tgz",
-                  "resolved": "https://registry.npmjs.org/form-data/-/form-data-0.0.10.tgz",
-                  "dependencies": {
-                    "combined-stream": {
-                      "version": "0.0.7",
-                      "from": "https://registry.npmjs.org/combined-stream/-/combined-stream-0.0.7.tgz",
-                      "resolved": "https://registry.npmjs.org/combined-stream/-/combined-stream-0.0.7.tgz",
-                      "dependencies": {
-                        "delayed-stream": {
-                          "version": "0.0.5",
-                          "from": "https://registry.npmjs.org/delayed-stream/-/delayed-stream-0.0.5.tgz",
-                          "resolved": "https://registry.npmjs.org/delayed-stream/-/delayed-stream-0.0.5.tgz"
-                        }
-                      }
-                    }
-                  }
-                },
-                "mime": {
-                  "version": "1.2.11",
-                  "from": "https://registry.npmjs.org/mime/-/mime-1.2.11.tgz",
-                  "resolved": "https://registry.npmjs.org/mime/-/mime-1.2.11.tgz"
-                },
-                "hawk": {
-                  "version": "0.10.2",
-                  "from": "https://registry.npmjs.org/hawk/-/hawk-0.10.2.tgz",
-                  "resolved": "https://registry.npmjs.org/hawk/-/hawk-0.10.2.tgz",
-                  "dependencies": {
-                    "hoek": {
-                      "version": "0.7.6",
-                      "from": "https://registry.npmjs.org/hoek/-/hoek-0.7.6.tgz",
-                      "resolved": "https://registry.npmjs.org/hoek/-/hoek-0.7.6.tgz"
-                    },
-                    "boom": {
-                      "version": "0.3.8",
-                      "from": "https://registry.npmjs.org/boom/-/boom-0.3.8.tgz",
-                      "resolved": "https://registry.npmjs.org/boom/-/boom-0.3.8.tgz"
-                    },
-                    "cryptiles": {
-                      "version": "0.1.3",
-                      "from": "https://registry.npmjs.org/cryptiles/-/cryptiles-0.1.3.tgz",
-                      "resolved": "https://registry.npmjs.org/cryptiles/-/cryptiles-0.1.3.tgz"
-                    },
-                    "sntp": {
-                      "version": "0.1.4",
-                      "from": "https://registry.npmjs.org/sntp/-/sntp-0.1.4.tgz",
-                      "resolved": "https://registry.npmjs.org/sntp/-/sntp-0.1.4.tgz"
-                    }
-                  }
-                },
-                "node-uuid": {
-                  "version": "1.4.7",
-                  "from": "https://registry.npmjs.org/node-uuid/-/node-uuid-1.4.7.tgz",
-                  "resolved": "https://registry.npmjs.org/node-uuid/-/node-uuid-1.4.7.tgz"
-                },
-                "cookie-jar": {
-                  "version": "0.2.0",
-                  "from": "https://registry.npmjs.org/cookie-jar/-/cookie-jar-0.2.0.tgz",
-                  "resolved": "https://registry.npmjs.org/cookie-jar/-/cookie-jar-0.2.0.tgz"
-                },
-                "aws-sign": {
-                  "version": "0.2.0",
-                  "from": "https://registry.npmjs.org/aws-sign/-/aws-sign-0.2.0.tgz",
-                  "resolved": "https://registry.npmjs.org/aws-sign/-/aws-sign-0.2.0.tgz"
-                },
-                "oauth-sign": {
-                  "version": "0.2.0",
-                  "from": "https://registry.npmjs.org/oauth-sign/-/oauth-sign-0.2.0.tgz",
-                  "resolved": "https://registry.npmjs.org/oauth-sign/-/oauth-sign-0.2.0.tgz"
-                },
-                "forever-agent": {
-                  "version": "0.2.0",
-                  "from": "https://registry.npmjs.org/forever-agent/-/forever-agent-0.2.0.tgz",
-                  "resolved": "https://registry.npmjs.org/forever-agent/-/forever-agent-0.2.0.tgz"
-                },
-                "tunnel-agent": {
-                  "version": "0.2.0",
-                  "from": "https://registry.npmjs.org/tunnel-agent/-/tunnel-agent-0.2.0.tgz",
-                  "resolved": "https://registry.npmjs.org/tunnel-agent/-/tunnel-agent-0.2.0.tgz"
-                },
-                "json-stringify-safe": {
-                  "version": "3.0.0",
-                  "from": "https://registry.npmjs.org/json-stringify-safe/-/json-stringify-safe-3.0.0.tgz",
-                  "resolved": "https://registry.npmjs.org/json-stringify-safe/-/json-stringify-safe-3.0.0.tgz"
-                },
-                "qs": {
-                  "version": "0.5.6",
-                  "from": "https://registry.npmjs.org/qs/-/qs-0.5.6.tgz",
-                  "resolved": "https://registry.npmjs.org/qs/-/qs-0.5.6.tgz"
-                }
-              }
-            },
-            "stack-trace": {
-              "version": "0.0.9",
-              "from": "https://registry.npmjs.org/stack-trace/-/stack-trace-0.0.9.tgz",
-              "resolved": "https://registry.npmjs.org/stack-trace/-/stack-trace-0.0.9.tgz"
-            }
-          }
         }
       }
     },
@@ -6517,797 +6061,915 @@
         }
       }
     },
-    "grunt-contrib-jshint": {
-      "version": "1.0.0",
-      "from": "https://registry.npmjs.org/grunt-contrib-jshint/-/grunt-contrib-jshint-1.0.0.tgz",
-      "resolved": "https://registry.npmjs.org/grunt-contrib-jshint/-/grunt-contrib-jshint-1.0.0.tgz",
+    "grunt-ddescribe-iit": {
+      "version": "0.0.6",
+      "from": "https://registry.npmjs.org/grunt-ddescribe-iit/-/grunt-ddescribe-iit-0.0.6.tgz",
+      "resolved": "https://registry.npmjs.org/grunt-ddescribe-iit/-/grunt-ddescribe-iit-0.0.6.tgz",
+      "dependencies": {
+        "bluebird": {
+          "version": "2.10.2",
+          "from": "https://registry.npmjs.org/bluebird/-/bluebird-2.10.2.tgz",
+          "resolved": "https://registry.npmjs.org/bluebird/-/bluebird-2.10.2.tgz"
+        },
+        "win-spawn": {
+          "version": "2.0.0",
+          "from": "https://registry.npmjs.org/win-spawn/-/win-spawn-2.0.0.tgz",
+          "resolved": "https://registry.npmjs.org/win-spawn/-/win-spawn-2.0.0.tgz"
+        }
+      }
+    },
+    "grunt-eslint": {
+      "version": "19.0.0",
+      "from": "grunt-eslint@latest",
+      "resolved": "https://registry.npmjs.org/grunt-eslint/-/grunt-eslint-19.0.0.tgz",
       "dependencies": {
         "chalk": {
           "version": "1.1.3",
-          "from": "https://registry.npmjs.org/chalk/-/chalk-1.1.3.tgz",
+          "from": "chalk@>=1.0.0 <2.0.0",
           "resolved": "https://registry.npmjs.org/chalk/-/chalk-1.1.3.tgz",
           "dependencies": {
             "ansi-styles": {
               "version": "2.2.1",
-              "from": "https://registry.npmjs.org/ansi-styles/-/ansi-styles-2.2.1.tgz",
+              "from": "ansi-styles@>=2.2.1 <3.0.0",
               "resolved": "https://registry.npmjs.org/ansi-styles/-/ansi-styles-2.2.1.tgz"
             },
             "escape-string-regexp": {
               "version": "1.0.5",
-              "from": "https://registry.npmjs.org/escape-string-regexp/-/escape-string-regexp-1.0.5.tgz",
+              "from": "escape-string-regexp@>=1.0.2 <2.0.0",
               "resolved": "https://registry.npmjs.org/escape-string-regexp/-/escape-string-regexp-1.0.5.tgz"
             },
             "has-ansi": {
               "version": "2.0.0",
-              "from": "https://registry.npmjs.org/has-ansi/-/has-ansi-2.0.0.tgz",
+              "from": "has-ansi@>=2.0.0 <3.0.0",
               "resolved": "https://registry.npmjs.org/has-ansi/-/has-ansi-2.0.0.tgz",
               "dependencies": {
                 "ansi-regex": {
                   "version": "2.0.0",
-                  "from": "https://registry.npmjs.org/ansi-regex/-/ansi-regex-2.0.0.tgz",
+                  "from": "ansi-regex@>=2.0.0 <3.0.0",
                   "resolved": "https://registry.npmjs.org/ansi-regex/-/ansi-regex-2.0.0.tgz"
                 }
               }
             },
             "strip-ansi": {
               "version": "3.0.1",
-              "from": "https://registry.npmjs.org/strip-ansi/-/strip-ansi-3.0.1.tgz",
+              "from": "strip-ansi@>=3.0.0 <4.0.0",
               "resolved": "https://registry.npmjs.org/strip-ansi/-/strip-ansi-3.0.1.tgz",
               "dependencies": {
                 "ansi-regex": {
                   "version": "2.0.0",
-                  "from": "https://registry.npmjs.org/ansi-regex/-/ansi-regex-2.0.0.tgz",
+                  "from": "ansi-regex@>=2.0.0 <3.0.0",
                   "resolved": "https://registry.npmjs.org/ansi-regex/-/ansi-regex-2.0.0.tgz"
                 }
               }
             },
             "supports-color": {
               "version": "2.0.0",
-              "from": "https://registry.npmjs.org/supports-color/-/supports-color-2.0.0.tgz",
+              "from": "supports-color@>=2.0.0 <3.0.0",
               "resolved": "https://registry.npmjs.org/supports-color/-/supports-color-2.0.0.tgz"
             }
           }
         },
-        "hooker": {
-          "version": "0.2.3",
-          "from": "https://registry.npmjs.org/hooker/-/hooker-0.2.3.tgz",
-          "resolved": "https://registry.npmjs.org/hooker/-/hooker-0.2.3.tgz"
-        }
-      }
-    },
-    "grunt-ddescribe-iit": {
-      "version": "0.0.6",
-      "from": "https://registry.npmjs.org/grunt-ddescribe-iit/-/grunt-ddescribe-iit-0.0.6.tgz",
-      "resolved": "https://registry.npmjs.org/grunt-ddescribe-iit/-/grunt-ddescribe-iit-0.0.6.tgz",
-      "dependencies": {
-        "bluebird": {
-          "version": "2.10.2",
-          "from": "https://registry.npmjs.org/bluebird/-/bluebird-2.10.2.tgz",
-          "resolved": "https://registry.npmjs.org/bluebird/-/bluebird-2.10.2.tgz"
-        },
-        "win-spawn": {
-          "version": "2.0.0",
-          "from": "https://registry.npmjs.org/win-spawn/-/win-spawn-2.0.0.tgz",
-          "resolved": "https://registry.npmjs.org/win-spawn/-/win-spawn-2.0.0.tgz"
-        }
-      }
-    },
-    "grunt-jscs": {
-      "version": "3.0.1",
-      "from": "https://registry.npmjs.org/grunt-jscs/-/grunt-jscs-3.0.1.tgz",
-      "resolved": "https://registry.npmjs.org/grunt-jscs/-/grunt-jscs-3.0.1.tgz",
-      "dependencies": {
-        "hooker": {
-          "version": "0.2.3",
-          "from": "https://registry.npmjs.org/hooker/-/hooker-0.2.3.tgz",
-          "resolved": "https://registry.npmjs.org/hooker/-/hooker-0.2.3.tgz"
-        },
-        "jscs": {
-          "version": "3.0.7",
-          "from": "https://registry.npmjs.org/jscs/-/jscs-3.0.7.tgz",
-          "resolved": "https://registry.npmjs.org/jscs/-/jscs-3.0.7.tgz",
+        "eslint": {
+          "version": "3.2.2",
+          "from": "eslint@>=3.0.0 <4.0.0",
+          "resolved": "https://registry.npmjs.org/eslint/-/eslint-3.2.2.tgz",
           "dependencies": {
-            "chalk": {
-              "version": "1.1.3",
-              "from": "https://registry.npmjs.org/chalk/-/chalk-1.1.3.tgz",
-              "resolved": "https://registry.npmjs.org/chalk/-/chalk-1.1.3.tgz",
+            "concat-stream": {
+              "version": "1.5.1",
+              "from": "concat-stream@>=1.4.6 <2.0.0",
+              "resolved": "https://registry.npmjs.org/concat-stream/-/concat-stream-1.5.1.tgz",
               "dependencies": {
-                "ansi-styles": {
-                  "version": "2.2.1",
-                  "from": "https://registry.npmjs.org/ansi-styles/-/ansi-styles-2.2.1.tgz",
-                  "resolved": "https://registry.npmjs.org/ansi-styles/-/ansi-styles-2.2.1.tgz"
+                "inherits": {
+                  "version": "2.0.1",
+                  "from": "inherits@>=2.0.1 <2.1.0",
+                  "resolved": "https://registry.npmjs.org/inherits/-/inherits-2.0.1.tgz"
                 },
-                "escape-string-regexp": {
-                  "version": "1.0.5",
-                  "from": "https://registry.npmjs.org/escape-string-regexp/-/escape-string-regexp-1.0.5.tgz",
-                  "resolved": "https://registry.npmjs.org/escape-string-regexp/-/escape-string-regexp-1.0.5.tgz"
+                "typedarray": {
+                  "version": "0.0.6",
+                  "from": "typedarray@>=0.0.5 <0.1.0",
+                  "resolved": "https://registry.npmjs.org/typedarray/-/typedarray-0.0.6.tgz"
                 },
-                "has-ansi": {
-                  "version": "2.0.0",
-                  "from": "https://registry.npmjs.org/has-ansi/-/has-ansi-2.0.0.tgz",
-                  "resolved": "https://registry.npmjs.org/has-ansi/-/has-ansi-2.0.0.tgz",
-                  "dependencies": {
-                    "ansi-regex": {
-                      "version": "2.0.0",
-                      "from": "https://registry.npmjs.org/ansi-regex/-/ansi-regex-2.0.0.tgz",
-                      "resolved": "https://registry.npmjs.org/ansi-regex/-/ansi-regex-2.0.0.tgz"
-                    }
-                  }
-                },
-                "strip-ansi": {
-                  "version": "3.0.1",
-                  "from": "https://registry.npmjs.org/strip-ansi/-/strip-ansi-3.0.1.tgz",
-                  "resolved": "https://registry.npmjs.org/strip-ansi/-/strip-ansi-3.0.1.tgz",
+                "readable-stream": {
+                  "version": "2.0.6",
+                  "from": "readable-stream@>=2.0.0 <2.1.0",
+                  "resolved": "https://registry.npmjs.org/readable-stream/-/readable-stream-2.0.6.tgz",
                   "dependencies": {
-                    "ansi-regex": {
-                      "version": "2.0.0",
-                      "from": "https://registry.npmjs.org/ansi-regex/-/ansi-regex-2.0.0.tgz",
-                      "resolved": "https://registry.npmjs.org/ansi-regex/-/ansi-regex-2.0.0.tgz"
+                    "core-util-is": {
+                      "version": "1.0.2",
+                      "from": "core-util-is@>=1.0.0 <1.1.0",
+                      "resolved": "https://registry.npmjs.org/core-util-is/-/core-util-is-1.0.2.tgz"
+                    },
+                    "isarray": {
+                      "version": "1.0.0",
+                      "from": "isarray@>=1.0.0 <1.1.0",
+                      "resolved": "https://registry.npmjs.org/isarray/-/isarray-1.0.0.tgz"
+                    },
+                    "process-nextick-args": {
+                      "version": "1.0.7",
+                      "from": "process-nextick-args@>=1.0.6 <1.1.0",
+                      "resolved": "https://registry.npmjs.org/process-nextick-args/-/process-nextick-args-1.0.7.tgz"
+                    },
+                    "string_decoder": {
+                      "version": "0.10.31",
+                      "from": "string_decoder@>=0.10.0 <0.11.0",
+                      "resolved": "https://registry.npmjs.org/string_decoder/-/string_decoder-0.10.31.tgz"
+                    },
+                    "util-deprecate": {
+                      "version": "1.0.2",
+                      "from": "util-deprecate@>=1.0.1 <1.1.0",
+                      "resolved": "https://registry.npmjs.org/util-deprecate/-/util-deprecate-1.0.2.tgz"
                     }
                   }
-                },
-                "supports-color": {
-                  "version": "2.0.0",
-                  "from": "https://registry.npmjs.org/supports-color/-/supports-color-2.0.0.tgz",
-                  "resolved": "https://registry.npmjs.org/supports-color/-/supports-color-2.0.0.tgz"
                 }
               }
             },
-            "cli-table": {
-              "version": "0.3.1",
-              "from": "https://registry.npmjs.org/cli-table/-/cli-table-0.3.1.tgz",
-              "resolved": "https://registry.npmjs.org/cli-table/-/cli-table-0.3.1.tgz",
+            "debug": {
+              "version": "2.2.0",
+              "from": "debug@>=2.1.1 <3.0.0",
+              "resolved": "https://registry.npmjs.org/debug/-/debug-2.2.0.tgz",
               "dependencies": {
-                "colors": {
-                  "version": "1.0.3",
-                  "from": "https://registry.npmjs.org/colors/-/colors-1.0.3.tgz",
-                  "resolved": "https://registry.npmjs.org/colors/-/colors-1.0.3.tgz"
+                "ms": {
+                  "version": "0.7.1",
+                  "from": "ms@0.7.1",
+                  "resolved": "https://registry.npmjs.org/ms/-/ms-0.7.1.tgz"
                 }
               }
             },
-            "commander": {
-              "version": "2.9.0",
-              "from": "https://registry.npmjs.org/commander/-/commander-2.9.0.tgz",
-              "resolved": "https://registry.npmjs.org/commander/-/commander-2.9.0.tgz",
+            "doctrine": {
+              "version": "1.2.2",
+              "from": "doctrine@>=1.2.2 <2.0.0",
+              "resolved": "https://registry.npmjs.org/doctrine/-/doctrine-1.2.2.tgz",
               "dependencies": {
-                "graceful-readlink": {
-                  "version": "1.0.1",
-                  "from": "https://registry.npmjs.org/graceful-readlink/-/graceful-readlink-1.0.1.tgz",
-                  "resolved": "https://registry.npmjs.org/graceful-readlink/-/graceful-readlink-1.0.1.tgz"
+                "esutils": {
+                  "version": "1.1.6",
+                  "from": "esutils@>=1.1.6 <2.0.0",
+                  "resolved": "https://registry.npmjs.org/esutils/-/esutils-1.1.6.tgz"
+                },
+                "isarray": {
+                  "version": "1.0.0",
+                  "from": "isarray@>=1.0.0 <2.0.0",
+                  "resolved": "https://registry.npmjs.org/isarray/-/isarray-1.0.0.tgz"
                 }
               }
             },
-            "cst": {
-              "version": "0.4.6",
-              "from": "https://registry.npmjs.org/cst/-/cst-0.4.6.tgz",
-              "resolved": "https://registry.npmjs.org/cst/-/cst-0.4.6.tgz",
+            "escope": {
+              "version": "3.6.0",
+              "from": "escope@>=3.6.0 <4.0.0",
+              "resolved": "https://registry.npmjs.org/escope/-/escope-3.6.0.tgz",
               "dependencies": {
-                "babel-runtime": {
-                  "version": "6.11.6",
-                  "from": "https://registry.npmjs.org/babel-runtime/-/babel-runtime-6.11.6.tgz",
-                  "resolved": "https://registry.npmjs.org/babel-runtime/-/babel-runtime-6.11.6.tgz",
+                "es6-map": {
+                  "version": "0.1.4",
+                  "from": "es6-map@>=0.1.3 <0.2.0",
+                  "resolved": "https://registry.npmjs.org/es6-map/-/es6-map-0.1.4.tgz",
                   "dependencies": {
-                    "core-js": {
-                      "version": "2.4.1",
-                      "from": "https://registry.npmjs.org/core-js/-/core-js-2.4.1.tgz",
-                      "resolved": "https://registry.npmjs.org/core-js/-/core-js-2.4.1.tgz"
+                    "d": {
+                      "version": "0.1.1",
+                      "from": "d@>=0.1.1 <0.2.0",
+                      "resolved": "https://registry.npmjs.org/d/-/d-0.1.1.tgz"
                     },
-                    "regenerator-runtime": {
-                      "version": "0.9.5",
-                      "from": "https://registry.npmjs.org/regenerator-runtime/-/regenerator-runtime-0.9.5.tgz",
-                      "resolved": "https://registry.npmjs.org/regenerator-runtime/-/regenerator-runtime-0.9.5.tgz"
+                    "es5-ext": {
+                      "version": "0.10.12",
+                      "from": "es5-ext@>=0.10.8 <0.11.0",
+                      "resolved": "https://registry.npmjs.org/es5-ext/-/es5-ext-0.10.12.tgz"
+                    },
+                    "es6-iterator": {
+                      "version": "2.0.0",
+                      "from": "es6-iterator@>=2.0.0 <3.0.0",
+                      "resolved": "https://registry.npmjs.org/es6-iterator/-/es6-iterator-2.0.0.tgz"
+                    },
+                    "es6-set": {
+                      "version": "0.1.4",
+                      "from": "es6-set@>=0.1.3 <0.2.0",
+                      "resolved": "https://registry.npmjs.org/es6-set/-/es6-set-0.1.4.tgz"
+                    },
+                    "es6-symbol": {
+                      "version": "3.1.0",
+                      "from": "es6-symbol@>=3.1.0 <3.2.0",
+                      "resolved": "https://registry.npmjs.org/es6-symbol/-/es6-symbol-3.1.0.tgz"
+                    },
+                    "event-emitter": {
+                      "version": "0.3.4",
+                      "from": "event-emitter@>=0.3.4 <0.4.0",
+                      "resolved": "https://registry.npmjs.org/event-emitter/-/event-emitter-0.3.4.tgz"
                     }
                   }
                 },
-                "babylon": {
-                  "version": "6.8.4",
-                  "from": "https://registry.npmjs.org/babylon/-/babylon-6.8.4.tgz",
-                  "resolved": "https://registry.npmjs.org/babylon/-/babylon-6.8.4.tgz"
+                "es6-weak-map": {
+                  "version": "2.0.1",
+                  "from": "es6-weak-map@>=2.0.1 <3.0.0",
+                  "resolved": "https://registry.npmjs.org/es6-weak-map/-/es6-weak-map-2.0.1.tgz",
+                  "dependencies": {
+                    "d": {
+                      "version": "0.1.1",
+                      "from": "d@>=0.1.1 <0.2.0",
+                      "resolved": "https://registry.npmjs.org/d/-/d-0.1.1.tgz"
+                    },
+                    "es5-ext": {
+                      "version": "0.10.12",
+                      "from": "es5-ext@>=0.10.8 <0.11.0",
+                      "resolved": "https://registry.npmjs.org/es5-ext/-/es5-ext-0.10.12.tgz"
+                    },
+                    "es6-iterator": {
+                      "version": "2.0.0",
+                      "from": "es6-iterator@>=2.0.0 <3.0.0",
+                      "resolved": "https://registry.npmjs.org/es6-iterator/-/es6-iterator-2.0.0.tgz"
+                    },
+                    "es6-symbol": {
+                      "version": "3.1.0",
+                      "from": "es6-symbol@>=3.1.0 <3.2.0",
+                      "resolved": "https://registry.npmjs.org/es6-symbol/-/es6-symbol-3.1.0.tgz"
+                    }
+                  }
                 },
-                "source-map-support": {
-                  "version": "0.4.2",
-                  "from": "https://registry.npmjs.org/source-map-support/-/source-map-support-0.4.2.tgz",
-                  "resolved": "https://registry.npmjs.org/source-map-support/-/source-map-support-0.4.2.tgz",
+                "esrecurse": {
+                  "version": "4.1.0",
+                  "from": "esrecurse@>=4.1.0 <5.0.0",
+                  "resolved": "https://registry.npmjs.org/esrecurse/-/esrecurse-4.1.0.tgz",
                   "dependencies": {
-                    "source-map": {
-                      "version": "0.1.32",
-                      "from": "https://registry.npmjs.org/source-map/-/source-map-0.1.32.tgz",
-                      "resolved": "https://registry.npmjs.org/source-map/-/source-map-0.1.32.tgz",
-                      "dependencies": {
-                        "amdefine": {
-                          "version": "1.0.0",
-                          "from": "https://registry.npmjs.org/amdefine/-/amdefine-1.0.0.tgz",
-                          "resolved": "https://registry.npmjs.org/amdefine/-/amdefine-1.0.0.tgz"
-                        }
-                      }
+                    "estraverse": {
+                      "version": "4.1.1",
+                      "from": "estraverse@>=4.1.0 <4.2.0",
+                      "resolved": "https://registry.npmjs.org/estraverse/-/estraverse-4.1.1.tgz"
+                    },
+                    "object-assign": {
+                      "version": "4.1.0",
+                      "from": "object-assign@>=4.0.1 <5.0.0",
+                      "resolved": "https://registry.npmjs.org/object-assign/-/object-assign-4.1.0.tgz"
                     }
                   }
                 }
               }
             },
+            "espree": {
+              "version": "3.1.7",
+              "from": "espree@>=3.1.6 <4.0.0",
+              "resolved": "https://registry.npmjs.org/espree/-/espree-3.1.7.tgz",
+              "dependencies": {
+                "acorn": {
+                  "version": "3.3.0",
+                  "from": "acorn@>=3.3.0 <4.0.0",
+                  "resolved": "https://registry.npmjs.org/acorn/-/acorn-3.3.0.tgz"
+                },
+                "acorn-jsx": {
+                  "version": "3.0.1",
+                  "from": "acorn-jsx@>=3.0.0 <4.0.0",
+                  "resolved": "https://registry.npmjs.org/acorn-jsx/-/acorn-jsx-3.0.1.tgz"
+                }
+              }
+            },
             "estraverse": {
               "version": "4.2.0",
-              "from": "https://registry.npmjs.org/estraverse/-/estraverse-4.2.0.tgz",
+              "from": "estraverse@>=4.2.0 <5.0.0",
               "resolved": "https://registry.npmjs.org/estraverse/-/estraverse-4.2.0.tgz"
             },
-            "exit": {
-              "version": "0.1.2",
-              "from": "https://registry.npmjs.org/exit/-/exit-0.1.2.tgz",
-              "resolved": "https://registry.npmjs.org/exit/-/exit-0.1.2.tgz"
+            "esutils": {
+              "version": "2.0.2",
+              "from": "esutils@>=2.0.2 <3.0.0",
+              "resolved": "https://registry.npmjs.org/esutils/-/esutils-2.0.2.tgz"
+            },
+            "file-entry-cache": {
+              "version": "1.3.1",
+              "from": "file-entry-cache@>=1.3.1 <2.0.0",
+              "resolved": "https://registry.npmjs.org/file-entry-cache/-/file-entry-cache-1.3.1.tgz",
+              "dependencies": {
+                "flat-cache": {
+                  "version": "1.2.1",
+                  "from": "flat-cache@>=1.2.1 <2.0.0",
+                  "resolved": "https://registry.npmjs.org/flat-cache/-/flat-cache-1.2.1.tgz",
+                  "dependencies": {
+                    "circular-json": {
+                      "version": "0.3.1",
+                      "from": "circular-json@>=0.3.0 <0.4.0",
+                      "resolved": "https://registry.npmjs.org/circular-json/-/circular-json-0.3.1.tgz"
+                    },
+                    "del": {
+                      "version": "2.2.1",
+                      "from": "del@>=2.0.2 <3.0.0",
+                      "resolved": "https://registry.npmjs.org/del/-/del-2.2.1.tgz",
+                      "dependencies": {
+                        "globby": {
+                          "version": "5.0.0",
+                          "from": "globby@>=5.0.0 <6.0.0",
+                          "resolved": "https://registry.npmjs.org/globby/-/globby-5.0.0.tgz",
+                          "dependencies": {
+                            "array-union": {
+                              "version": "1.0.2",
+                              "from": "array-union@>=1.0.1 <2.0.0",
+                              "resolved": "https://registry.npmjs.org/array-union/-/array-union-1.0.2.tgz",
+                              "dependencies": {
+                                "array-uniq": {
+                                  "version": "1.0.3",
+                                  "from": "array-uniq@>=1.0.1 <2.0.0",
+                                  "resolved": "https://registry.npmjs.org/array-uniq/-/array-uniq-1.0.3.tgz"
+                                }
+                              }
+                            },
+                            "arrify": {
+                              "version": "1.0.1",
+                              "from": "arrify@>=1.0.0 <2.0.0",
+                              "resolved": "https://registry.npmjs.org/arrify/-/arrify-1.0.1.tgz"
+                            }
+                          }
+                        },
+                        "is-path-cwd": {
+                          "version": "1.0.0",
+                          "from": "is-path-cwd@>=1.0.0 <2.0.0",
+                          "resolved": "https://registry.npmjs.org/is-path-cwd/-/is-path-cwd-1.0.0.tgz"
+                        },
+                        "is-path-in-cwd": {
+                          "version": "1.0.0",
+                          "from": "is-path-in-cwd@>=1.0.0 <2.0.0",
+                          "resolved": "https://registry.npmjs.org/is-path-in-cwd/-/is-path-in-cwd-1.0.0.tgz",
+                          "dependencies": {
+                            "is-path-inside": {
+                              "version": "1.0.0",
+                              "from": "is-path-inside@>=1.0.0 <2.0.0",
+                              "resolved": "https://registry.npmjs.org/is-path-inside/-/is-path-inside-1.0.0.tgz"
+                            }
+                          }
+                        },
+                        "pify": {
+                          "version": "2.3.0",
+                          "from": "pify@>=2.0.0 <3.0.0",
+                          "resolved": "https://registry.npmjs.org/pify/-/pify-2.3.0.tgz"
+                        },
+                        "pinkie-promise": {
+                          "version": "2.0.1",
+                          "from": "pinkie-promise@>=2.0.0 <3.0.0",
+                          "resolved": "https://registry.npmjs.org/pinkie-promise/-/pinkie-promise-2.0.1.tgz",
+                          "dependencies": {
+                            "pinkie": {
+                              "version": "2.0.4",
+                              "from": "pinkie@>=2.0.0 <3.0.0",
+                              "resolved": "https://registry.npmjs.org/pinkie/-/pinkie-2.0.4.tgz"
+                            }
+                          }
+                        },
+                        "rimraf": {
+                          "version": "2.5.4",
+                          "from": "rimraf@>=2.2.8 <3.0.0",
+                          "resolved": "https://registry.npmjs.org/rimraf/-/rimraf-2.5.4.tgz"
+                        }
+                      }
+                    },
+                    "graceful-fs": {
+                      "version": "4.1.5",
+                      "from": "graceful-fs@>=4.1.2 <5.0.0",
+                      "resolved": "https://registry.npmjs.org/graceful-fs/-/graceful-fs-4.1.5.tgz"
+                    },
+                    "write": {
+                      "version": "0.2.1",
+                      "from": "write@>=0.2.1 <0.3.0",
+                      "resolved": "https://registry.npmjs.org/write/-/write-0.2.1.tgz"
+                    }
+                  }
+                },
+                "object-assign": {
+                  "version": "4.1.0",
+                  "from": "object-assign@>=4.0.1 <5.0.0",
+                  "resolved": "https://registry.npmjs.org/object-assign/-/object-assign-4.1.0.tgz"
+                }
+              }
             },
             "glob": {
-              "version": "5.0.15",
-              "from": "https://registry.npmjs.org/glob/-/glob-5.0.15.tgz",
-              "resolved": "https://registry.npmjs.org/glob/-/glob-5.0.15.tgz",
+              "version": "7.0.5",
+              "from": "glob@>=7.0.3 <8.0.0",
+              "resolved": "https://registry.npmjs.org/glob/-/glob-7.0.5.tgz",
               "dependencies": {
+                "fs.realpath": {
+                  "version": "1.0.0",
+                  "from": "fs.realpath@>=1.0.0 <2.0.0",
+                  "resolved": "https://registry.npmjs.org/fs.realpath/-/fs.realpath-1.0.0.tgz"
+                },
                 "inflight": {
                   "version": "1.0.5",
-                  "from": "https://registry.npmjs.org/inflight/-/inflight-1.0.5.tgz",
+                  "from": "inflight@>=1.0.4 <2.0.0",
                   "resolved": "https://registry.npmjs.org/inflight/-/inflight-1.0.5.tgz",
                   "dependencies": {
                     "wrappy": {
                       "version": "1.0.2",
-                      "from": "https://registry.npmjs.org/wrappy/-/wrappy-1.0.2.tgz",
+                      "from": "wrappy@>=1.0.0 <2.0.0",
                       "resolved": "https://registry.npmjs.org/wrappy/-/wrappy-1.0.2.tgz"
                     }
                   }
                 },
                 "inherits": {
                   "version": "2.0.1",
-                  "from": "https://registry.npmjs.org/inherits/-/inherits-2.0.1.tgz",
+                  "from": "inherits@>=2.0.0 <3.0.0",
                   "resolved": "https://registry.npmjs.org/inherits/-/inherits-2.0.1.tgz"
                 },
+                "minimatch": {
+                  "version": "3.0.2",
+                  "from": "minimatch@>=3.0.2 <4.0.0",
+                  "resolved": "https://registry.npmjs.org/minimatch/-/minimatch-3.0.2.tgz",
+                  "dependencies": {
+                    "brace-expansion": {
+                      "version": "1.1.6",
+                      "from": "brace-expansion@>=1.0.0 <2.0.0",
+                      "resolved": "https://registry.npmjs.org/brace-expansion/-/brace-expansion-1.1.6.tgz",
+                      "dependencies": {
+                        "balanced-match": {
+                          "version": "0.4.2",
+                          "from": "balanced-match@>=0.4.1 <0.5.0",
+                          "resolved": "https://registry.npmjs.org/balanced-match/-/balanced-match-0.4.2.tgz"
+                        },
+                        "concat-map": {
+                          "version": "0.0.1",
+                          "from": "concat-map@0.0.1",
+                          "resolved": "https://registry.npmjs.org/concat-map/-/concat-map-0.0.1.tgz"
+                        }
+                      }
+                    }
+                  }
+                },
                 "once": {
                   "version": "1.3.3",
-                  "from": "https://registry.npmjs.org/once/-/once-1.3.3.tgz",
+                  "from": "once@>=1.3.0 <2.0.0",
                   "resolved": "https://registry.npmjs.org/once/-/once-1.3.3.tgz",
                   "dependencies": {
                     "wrappy": {
                       "version": "1.0.2",
-                      "from": "https://registry.npmjs.org/wrappy/-/wrappy-1.0.2.tgz",
+                      "from": "wrappy@>=1.0.0 <2.0.0",
                       "resolved": "https://registry.npmjs.org/wrappy/-/wrappy-1.0.2.tgz"
                     }
                   }
                 },
                 "path-is-absolute": {
                   "version": "1.0.0",
-                  "from": "https://registry.npmjs.org/path-is-absolute/-/path-is-absolute-1.0.0.tgz",
+                  "from": "path-is-absolute@>=1.0.0 <2.0.0",
                   "resolved": "https://registry.npmjs.org/path-is-absolute/-/path-is-absolute-1.0.0.tgz"
                 }
               }
             },
-            "htmlparser2": {
-              "version": "3.8.3",
-              "from": "https://registry.npmjs.org/htmlparser2/-/htmlparser2-3.8.3.tgz",
-              "resolved": "https://registry.npmjs.org/htmlparser2/-/htmlparser2-3.8.3.tgz",
+            "globals": {
+              "version": "9.9.0",
+              "from": "globals@>=9.2.0 <10.0.0",
+              "resolved": "https://registry.npmjs.org/globals/-/globals-9.9.0.tgz"
+            },
+            "ignore": {
+              "version": "3.1.3",
+              "from": "ignore@>=3.1.2 <4.0.0",
+              "resolved": "https://registry.npmjs.org/ignore/-/ignore-3.1.3.tgz"
+            },
+            "imurmurhash": {
+              "version": "0.1.4",
+              "from": "imurmurhash@>=0.1.4 <0.2.0",
+              "resolved": "https://registry.npmjs.org/imurmurhash/-/imurmurhash-0.1.4.tgz"
+            },
+            "inquirer": {
+              "version": "0.12.0",
+              "from": "inquirer@>=0.12.0 <0.13.0",
+              "resolved": "https://registry.npmjs.org/inquirer/-/inquirer-0.12.0.tgz",
               "dependencies": {
-                "domhandler": {
-                  "version": "2.3.0",
-                  "from": "https://registry.npmjs.org/domhandler/-/domhandler-2.3.0.tgz",
-                  "resolved": "https://registry.npmjs.org/domhandler/-/domhandler-2.3.0.tgz"
+                "ansi-escapes": {
+                  "version": "1.4.0",
+                  "from": "ansi-escapes@>=1.1.0 <2.0.0",
+                  "resolved": "https://registry.npmjs.org/ansi-escapes/-/ansi-escapes-1.4.0.tgz"
+                },
+                "ansi-regex": {
+                  "version": "2.0.0",
+                  "from": "ansi-regex@>=2.0.0 <3.0.0",
+                  "resolved": "https://registry.npmjs.org/ansi-regex/-/ansi-regex-2.0.0.tgz"
                 },
-                "domutils": {
-                  "version": "1.5.1",
-                  "from": "https://registry.npmjs.org/domutils/-/domutils-1.5.1.tgz",
-                  "resolved": "https://registry.npmjs.org/domutils/-/domutils-1.5.1.tgz",
+                "cli-cursor": {
+                  "version": "1.0.2",
+                  "from": "cli-cursor@>=1.0.1 <2.0.0",
+                  "resolved": "https://registry.npmjs.org/cli-cursor/-/cli-cursor-1.0.2.tgz",
                   "dependencies": {
-                    "dom-serializer": {
-                      "version": "0.1.0",
-                      "from": "https://registry.npmjs.org/dom-serializer/-/dom-serializer-0.1.0.tgz",
-                      "resolved": "https://registry.npmjs.org/dom-serializer/-/dom-serializer-0.1.0.tgz",
+                    "restore-cursor": {
+                      "version": "1.0.1",
+                      "from": "restore-cursor@>=1.0.1 <2.0.0",
+                      "resolved": "https://registry.npmjs.org/restore-cursor/-/restore-cursor-1.0.1.tgz",
                       "dependencies": {
-                        "domelementtype": {
-                          "version": "1.1.3",
-                          "from": "https://registry.npmjs.org/domelementtype/-/domelementtype-1.1.3.tgz",
-                          "resolved": "https://registry.npmjs.org/domelementtype/-/domelementtype-1.1.3.tgz"
-                        },
-                        "entities": {
+                        "exit-hook": {
                           "version": "1.1.1",
-                          "from": "https://registry.npmjs.org/entities/-/entities-1.1.1.tgz",
-                          "resolved": "https://registry.npmjs.org/entities/-/entities-1.1.1.tgz"
+                          "from": "exit-hook@>=1.0.0 <2.0.0",
+                          "resolved": "https://registry.npmjs.org/exit-hook/-/exit-hook-1.1.1.tgz"
+                        },
+                        "onetime": {
+                          "version": "1.1.0",
+                          "from": "onetime@>=1.0.0 <2.0.0",
+                          "resolved": "https://registry.npmjs.org/onetime/-/onetime-1.1.0.tgz"
                         }
                       }
                     }
                   }
                 },
-                "domelementtype": {
-                  "version": "1.3.0",
-                  "from": "https://registry.npmjs.org/domelementtype/-/domelementtype-1.3.0.tgz",
-                  "resolved": "https://registry.npmjs.org/domelementtype/-/domelementtype-1.3.0.tgz"
+                "cli-width": {
+                  "version": "2.1.0",
+                  "from": "cli-width@>=2.0.0 <3.0.0",
+                  "resolved": "https://registry.npmjs.org/cli-width/-/cli-width-2.1.0.tgz"
                 },
-                "readable-stream": {
-                  "version": "1.1.14",
-                  "from": "https://registry.npmjs.org/readable-stream/-/readable-stream-1.1.14.tgz",
-                  "resolved": "https://registry.npmjs.org/readable-stream/-/readable-stream-1.1.14.tgz",
+                "figures": {
+                  "version": "1.7.0",
+                  "from": "figures@>=1.3.5 <2.0.0",
+                  "resolved": "https://registry.npmjs.org/figures/-/figures-1.7.0.tgz",
                   "dependencies": {
-                    "core-util-is": {
-                      "version": "1.0.2",
-                      "from": "https://registry.npmjs.org/core-util-is/-/core-util-is-1.0.2.tgz",
-                      "resolved": "https://registry.npmjs.org/core-util-is/-/core-util-is-1.0.2.tgz"
+                    "escape-string-regexp": {
+                      "version": "1.0.5",
+                      "from": "escape-string-regexp@>=1.0.5 <2.0.0",
+                      "resolved": "https://registry.npmjs.org/escape-string-regexp/-/escape-string-regexp-1.0.5.tgz"
                     },
-                    "isarray": {
-                      "version": "0.0.1",
-                      "from": "https://registry.npmjs.org/isarray/-/isarray-0.0.1.tgz",
-                      "resolved": "https://registry.npmjs.org/isarray/-/isarray-0.0.1.tgz"
+                    "object-assign": {
+                      "version": "4.1.0",
+                      "from": "object-assign@>=4.1.0 <5.0.0",
+                      "resolved": "https://registry.npmjs.org/object-assign/-/object-assign-4.1.0.tgz"
+                    }
+                  }
+                },
+                "readline2": {
+                  "version": "1.0.1",
+                  "from": "readline2@>=1.0.1 <2.0.0",
+                  "resolved": "https://registry.npmjs.org/readline2/-/readline2-1.0.1.tgz",
+                  "dependencies": {
+                    "code-point-at": {
+                      "version": "1.0.0",
+                      "from": "code-point-at@>=1.0.0 <2.0.0",
+                      "resolved": "https://registry.npmjs.org/code-point-at/-/code-point-at-1.0.0.tgz",
+                      "dependencies": {
+                        "number-is-nan": {
+                          "version": "1.0.0",
+                          "from": "number-is-nan@>=1.0.0 <2.0.0",
+                          "resolved": "https://registry.npmjs.org/number-is-nan/-/number-is-nan-1.0.0.tgz"
+                        }
+                      }
                     },
-                    "string_decoder": {
-                      "version": "0.10.31",
-                      "from": "https://registry.npmjs.org/string_decoder/-/string_decoder-0.10.31.tgz",
-                      "resolved": "https://registry.npmjs.org/string_decoder/-/string_decoder-0.10.31.tgz"
+                    "is-fullwidth-code-point": {
+                      "version": "1.0.0",
+                      "from": "is-fullwidth-code-point@>=1.0.0 <2.0.0",
+                      "resolved": "https://registry.npmjs.org/is-fullwidth-code-point/-/is-fullwidth-code-point-1.0.0.tgz",
+                      "dependencies": {
+                        "number-is-nan": {
+                          "version": "1.0.0",
+                          "from": "number-is-nan@>=1.0.0 <2.0.0",
+                          "resolved": "https://registry.npmjs.org/number-is-nan/-/number-is-nan-1.0.0.tgz"
+                        }
+                      }
                     },
-                    "inherits": {
-                      "version": "2.0.1",
-                      "from": "https://registry.npmjs.org/inherits/-/inherits-2.0.1.tgz",
-                      "resolved": "https://registry.npmjs.org/inherits/-/inherits-2.0.1.tgz"
+                    "mute-stream": {
+                      "version": "0.0.5",
+                      "from": "mute-stream@0.0.5",
+                      "resolved": "https://registry.npmjs.org/mute-stream/-/mute-stream-0.0.5.tgz"
                     }
                   }
                 },
-                "entities": {
-                  "version": "1.0.0",
-                  "from": "https://registry.npmjs.org/entities/-/entities-1.0.0.tgz",
-                  "resolved": "https://registry.npmjs.org/entities/-/entities-1.0.0.tgz"
+                "run-async": {
+                  "version": "0.1.0",
+                  "from": "run-async@>=0.1.0 <0.2.0",
+                  "resolved": "https://registry.npmjs.org/run-async/-/run-async-0.1.0.tgz",
+                  "dependencies": {
+                    "once": {
+                      "version": "1.3.3",
+                      "from": "once@>=1.3.0 <2.0.0",
+                      "resolved": "https://registry.npmjs.org/once/-/once-1.3.3.tgz",
+                      "dependencies": {
+                        "wrappy": {
+                          "version": "1.0.2",
+                          "from": "wrappy@>=1.0.0 <2.0.0",
+                          "resolved": "https://registry.npmjs.org/wrappy/-/wrappy-1.0.2.tgz"
+                        }
+                      }
+                    }
+                  }
+                },
+                "rx-lite": {
+                  "version": "3.1.2",
+                  "from": "rx-lite@>=3.1.2 <4.0.0",
+                  "resolved": "https://registry.npmjs.org/rx-lite/-/rx-lite-3.1.2.tgz"
+                },
+                "string-width": {
+                  "version": "1.0.1",
+                  "from": "string-width@>=1.0.1 <2.0.0",
+                  "resolved": "https://registry.npmjs.org/string-width/-/string-width-1.0.1.tgz",
+                  "dependencies": {
+                    "code-point-at": {
+                      "version": "1.0.0",
+                      "from": "code-point-at@>=1.0.0 <2.0.0",
+                      "resolved": "https://registry.npmjs.org/code-point-at/-/code-point-at-1.0.0.tgz",
+                      "dependencies": {
+                        "number-is-nan": {
+                          "version": "1.0.0",
+                          "from": "number-is-nan@>=1.0.0 <2.0.0",
+                          "resolved": "https://registry.npmjs.org/number-is-nan/-/number-is-nan-1.0.0.tgz"
+                        }
+                      }
+                    },
+                    "is-fullwidth-code-point": {
+                      "version": "1.0.0",
+                      "from": "is-fullwidth-code-point@>=1.0.0 <2.0.0",
+                      "resolved": "https://registry.npmjs.org/is-fullwidth-code-point/-/is-fullwidth-code-point-1.0.0.tgz",
+                      "dependencies": {
+                        "number-is-nan": {
+                          "version": "1.0.0",
+                          "from": "number-is-nan@>=1.0.0 <2.0.0",
+                          "resolved": "https://registry.npmjs.org/number-is-nan/-/number-is-nan-1.0.0.tgz"
+                        }
+                      }
+                    }
+                  }
+                },
+                "strip-ansi": {
+                  "version": "3.0.1",
+                  "from": "strip-ansi@>=3.0.0 <4.0.0",
+                  "resolved": "https://registry.npmjs.org/strip-ansi/-/strip-ansi-3.0.1.tgz"
+                },
+                "through": {
+                  "version": "2.3.8",
+                  "from": "through@>=2.3.6 <3.0.0",
+                  "resolved": "https://registry.npmjs.org/through/-/through-2.3.8.tgz"
+                }
+              }
+            },
+            "is-my-json-valid": {
+              "version": "2.13.1",
+              "from": "is-my-json-valid@>=2.10.0 <3.0.0",
+              "resolved": "https://registry.npmjs.org/is-my-json-valid/-/is-my-json-valid-2.13.1.tgz",
+              "dependencies": {
+                "generate-function": {
+                  "version": "2.0.0",
+                  "from": "generate-function@>=2.0.0 <3.0.0",
+                  "resolved": "https://registry.npmjs.org/generate-function/-/generate-function-2.0.0.tgz"
+                },
+                "generate-object-property": {
+                  "version": "1.2.0",
+                  "from": "generate-object-property@>=1.1.0 <2.0.0",
+                  "resolved": "https://registry.npmjs.org/generate-object-property/-/generate-object-property-1.2.0.tgz",
+                  "dependencies": {
+                    "is-property": {
+                      "version": "1.0.2",
+                      "from": "is-property@>=1.0.0 <2.0.0",
+                      "resolved": "https://registry.npmjs.org/is-property/-/is-property-1.0.2.tgz"
+                    }
+                  }
+                },
+                "jsonpointer": {
+                  "version": "2.0.0",
+                  "from": "jsonpointer@2.0.0",
+                  "resolved": "https://registry.npmjs.org/jsonpointer/-/jsonpointer-2.0.0.tgz"
+                },
+                "xtend": {
+                  "version": "4.0.1",
+                  "from": "xtend@>=4.0.0 <5.0.0",
+                  "resolved": "https://registry.npmjs.org/xtend/-/xtend-4.0.1.tgz"
+                }
+              }
+            },
+            "is-resolvable": {
+              "version": "1.0.0",
+              "from": "is-resolvable@>=1.0.0 <2.0.0",
+              "resolved": "https://registry.npmjs.org/is-resolvable/-/is-resolvable-1.0.0.tgz",
+              "dependencies": {
+                "tryit": {
+                  "version": "1.0.2",
+                  "from": "tryit@>=1.0.1 <2.0.0",
+                  "resolved": "https://registry.npmjs.org/tryit/-/tryit-1.0.2.tgz"
                 }
               }
             },
             "js-yaml": {
-              "version": "3.4.6",
-              "from": "https://registry.npmjs.org/js-yaml/-/js-yaml-3.4.6.tgz",
-              "resolved": "https://registry.npmjs.org/js-yaml/-/js-yaml-3.4.6.tgz",
+              "version": "3.6.1",
+              "from": "js-yaml@>=3.5.1 <4.0.0",
+              "resolved": "https://registry.npmjs.org/js-yaml/-/js-yaml-3.6.1.tgz",
               "dependencies": {
                 "argparse": {
                   "version": "1.0.7",
-                  "from": "https://registry.npmjs.org/argparse/-/argparse-1.0.7.tgz",
+                  "from": "argparse@>=1.0.7 <2.0.0",
                   "resolved": "https://registry.npmjs.org/argparse/-/argparse-1.0.7.tgz",
                   "dependencies": {
                     "sprintf-js": {
                       "version": "1.0.3",
-                      "from": "https://registry.npmjs.org/sprintf-js/-/sprintf-js-1.0.3.tgz",
+                      "from": "sprintf-js@>=1.0.2 <1.1.0",
                       "resolved": "https://registry.npmjs.org/sprintf-js/-/sprintf-js-1.0.3.tgz"
                     }
                   }
                 },
                 "esprima": {
                   "version": "2.7.2",
-                  "from": "https://registry.npmjs.org/esprima/-/esprima-2.7.2.tgz",
+                  "from": "esprima@>=2.6.0 <3.0.0",
                   "resolved": "https://registry.npmjs.org/esprima/-/esprima-2.7.2.tgz"
-                },
-                "inherit": {
-                  "version": "2.2.5",
-                  "from": "https://registry.npmjs.org/inherit/-/inherit-2.2.5.tgz",
-                  "resolved": "https://registry.npmjs.org/inherit/-/inherit-2.2.5.tgz"
                 }
               }
             },
-            "jscs-jsdoc": {
-              "version": "2.0.0",
-              "from": "https://registry.npmjs.org/jscs-jsdoc/-/jscs-jsdoc-2.0.0.tgz",
-              "resolved": "https://registry.npmjs.org/jscs-jsdoc/-/jscs-jsdoc-2.0.0.tgz",
+            "json-stable-stringify": {
+              "version": "1.0.1",
+              "from": "json-stable-stringify@>=1.0.0 <2.0.0",
+              "resolved": "https://registry.npmjs.org/json-stable-stringify/-/json-stable-stringify-1.0.1.tgz",
               "dependencies": {
-                "comment-parser": {
-                  "version": "0.3.1",
-                  "from": "https://registry.npmjs.org/comment-parser/-/comment-parser-0.3.1.tgz",
-                  "resolved": "https://registry.npmjs.org/comment-parser/-/comment-parser-0.3.1.tgz",
-                  "dependencies": {
-                    "readable-stream": {
-                      "version": "2.1.4",
-                      "from": "https://registry.npmjs.org/readable-stream/-/readable-stream-2.1.4.tgz",
-                      "resolved": "https://registry.npmjs.org/readable-stream/-/readable-stream-2.1.4.tgz",
-                      "dependencies": {
-                        "buffer-shims": {
-                          "version": "1.0.0",
-                          "from": "https://registry.npmjs.org/buffer-shims/-/buffer-shims-1.0.0.tgz",
-                          "resolved": "https://registry.npmjs.org/buffer-shims/-/buffer-shims-1.0.0.tgz"
-                        },
-                        "core-util-is": {
-                          "version": "1.0.2",
-                          "from": "https://registry.npmjs.org/core-util-is/-/core-util-is-1.0.2.tgz",
-                          "resolved": "https://registry.npmjs.org/core-util-is/-/core-util-is-1.0.2.tgz"
-                        },
-                        "inherits": {
-                          "version": "2.0.1",
-                          "from": "https://registry.npmjs.org/inherits/-/inherits-2.0.1.tgz",
-                          "resolved": "https://registry.npmjs.org/inherits/-/inherits-2.0.1.tgz"
-                        },
-                        "isarray": {
-                          "version": "1.0.0",
-                          "from": "https://registry.npmjs.org/isarray/-/isarray-1.0.0.tgz",
-                          "resolved": "https://registry.npmjs.org/isarray/-/isarray-1.0.0.tgz"
-                        },
-                        "process-nextick-args": {
-                          "version": "1.0.7",
-                          "from": "https://registry.npmjs.org/process-nextick-args/-/process-nextick-args-1.0.7.tgz",
-                          "resolved": "https://registry.npmjs.org/process-nextick-args/-/process-nextick-args-1.0.7.tgz"
-                        },
-                        "string_decoder": {
-                          "version": "0.10.31",
-                          "from": "https://registry.npmjs.org/string_decoder/-/string_decoder-0.10.31.tgz",
-                          "resolved": "https://registry.npmjs.org/string_decoder/-/string_decoder-0.10.31.tgz"
-                        },
-                        "util-deprecate": {
-                          "version": "1.0.2",
-                          "from": "https://registry.npmjs.org/util-deprecate/-/util-deprecate-1.0.2.tgz",
-                          "resolved": "https://registry.npmjs.org/util-deprecate/-/util-deprecate-1.0.2.tgz"
-                        }
-                      }
-                    }
-                  }
+                "jsonify": {
+                  "version": "0.0.0",
+                  "from": "jsonify@>=0.0.0 <0.1.0",
+                  "resolved": "https://registry.npmjs.org/jsonify/-/jsonify-0.0.0.tgz"
+                }
+              }
+            },
+            "levn": {
+              "version": "0.3.0",
+              "from": "levn@>=0.3.0 <0.4.0",
+              "resolved": "https://registry.npmjs.org/levn/-/levn-0.3.0.tgz",
+              "dependencies": {
+                "prelude-ls": {
+                  "version": "1.1.2",
+                  "from": "prelude-ls@>=1.1.2 <1.2.0",
+                  "resolved": "https://registry.npmjs.org/prelude-ls/-/prelude-ls-1.1.2.tgz"
                 },
-                "jsdoctypeparser": {
-                  "version": "1.2.0",
-                  "from": "https://registry.npmjs.org/jsdoctypeparser/-/jsdoctypeparser-1.2.0.tgz",
-                  "resolved": "https://registry.npmjs.org/jsdoctypeparser/-/jsdoctypeparser-1.2.0.tgz"
+                "type-check": {
+                  "version": "0.3.2",
+                  "from": "type-check@>=0.3.2 <0.4.0",
+                  "resolved": "https://registry.npmjs.org/type-check/-/type-check-0.3.2.tgz"
                 }
               }
             },
-            "jscs-preset-wikimedia": {
-              "version": "1.0.0",
-              "from": "https://registry.npmjs.org/jscs-preset-wikimedia/-/jscs-preset-wikimedia-1.0.0.tgz",
-              "resolved": "https://registry.npmjs.org/jscs-preset-wikimedia/-/jscs-preset-wikimedia-1.0.0.tgz"
+            "lodash": {
+              "version": "4.14.1",
+              "from": "lodash@>=4.0.0 <5.0.0",
+              "resolved": "https://registry.npmjs.org/lodash/-/lodash-4.14.1.tgz"
             },
-            "jsonlint": {
-              "version": "1.6.2",
-              "from": "https://registry.npmjs.org/jsonlint/-/jsonlint-1.6.2.tgz",
-              "resolved": "https://registry.npmjs.org/jsonlint/-/jsonlint-1.6.2.tgz",
+            "mkdirp": {
+              "version": "0.5.1",
+              "from": "mkdirp@>=0.5.0 <0.6.0",
+              "resolved": "https://registry.npmjs.org/mkdirp/-/mkdirp-0.5.1.tgz",
               "dependencies": {
-                "nomnom": {
-                  "version": "1.8.1",
-                  "from": "https://registry.npmjs.org/nomnom/-/nomnom-1.8.1.tgz",
-                  "resolved": "https://registry.npmjs.org/nomnom/-/nomnom-1.8.1.tgz",
-                  "dependencies": {
-                    "underscore": {
-                      "version": "1.6.0",
-                      "from": "https://registry.npmjs.org/underscore/-/underscore-1.6.0.tgz",
-                      "resolved": "https://registry.npmjs.org/underscore/-/underscore-1.6.0.tgz"
-                    },
-                    "chalk": {
-                      "version": "0.4.0",
-                      "from": "https://registry.npmjs.org/chalk/-/chalk-0.4.0.tgz",
-                      "resolved": "https://registry.npmjs.org/chalk/-/chalk-0.4.0.tgz",
-                      "dependencies": {
-                        "has-color": {
-                          "version": "0.1.7",
-                          "from": "https://registry.npmjs.org/has-color/-/has-color-0.1.7.tgz",
-                          "resolved": "https://registry.npmjs.org/has-color/-/has-color-0.1.7.tgz"
-                        },
-                        "ansi-styles": {
-                          "version": "1.0.0",
-                          "from": "https://registry.npmjs.org/ansi-styles/-/ansi-styles-1.0.0.tgz",
-                          "resolved": "https://registry.npmjs.org/ansi-styles/-/ansi-styles-1.0.0.tgz"
-                        },
-                        "strip-ansi": {
-                          "version": "0.1.1",
-                          "from": "https://registry.npmjs.org/strip-ansi/-/strip-ansi-0.1.1.tgz",
-                          "resolved": "https://registry.npmjs.org/strip-ansi/-/strip-ansi-0.1.1.tgz"
-                        }
-                      }
-                    }
-                  }
+                "minimist": {
+                  "version": "0.0.8",
+                  "from": "minimist@0.0.8",
+                  "resolved": "https://registry.npmjs.org/minimist/-/minimist-0.0.8.tgz"
+                }
+              }
+            },
+            "optionator": {
+              "version": "0.8.1",
+              "from": "optionator@>=0.8.1 <0.9.0",
+              "resolved": "https://registry.npmjs.org/optionator/-/optionator-0.8.1.tgz",
+              "dependencies": {
+                "prelude-ls": {
+                  "version": "1.1.2",
+                  "from": "prelude-ls@>=1.1.2 <1.2.0",
+                  "resolved": "https://registry.npmjs.org/prelude-ls/-/prelude-ls-1.1.2.tgz"
+                },
+                "deep-is": {
+                  "version": "0.1.3",
+                  "from": "deep-is@>=0.1.3 <0.2.0",
+                  "resolved": "https://registry.npmjs.org/deep-is/-/deep-is-0.1.3.tgz"
+                },
+                "wordwrap": {
+                  "version": "1.0.0",
+                  "from": "wordwrap@>=1.0.0 <1.1.0",
+                  "resolved": "https://registry.npmjs.org/wordwrap/-/wordwrap-1.0.0.tgz"
+                },
+                "type-check": {
+                  "version": "0.3.2",
+                  "from": "type-check@>=0.3.2 <0.4.0",
+                  "resolved": "https://registry.npmjs.org/type-check/-/type-check-0.3.2.tgz"
                 },
-                "JSV": {
-                  "version": "4.0.2",
-                  "from": "https://registry.npmjs.org/JSV/-/JSV-4.0.2.tgz",
-                  "resolved": "https://registry.npmjs.org/JSV/-/JSV-4.0.2.tgz"
+                "fast-levenshtein": {
+                  "version": "1.1.4",
+                  "from": "fast-levenshtein@>=1.1.0 <2.0.0",
+                  "resolved": "https://registry.npmjs.org/fast-levenshtein/-/fast-levenshtein-1.1.4.tgz"
                 }
               }
             },
-            "lodash": {
-              "version": "3.10.1",
-              "from": "https://registry.npmjs.org/lodash/-/lodash-3.10.1.tgz",
-              "resolved": "https://registry.npmjs.org/lodash/-/lodash-3.10.1.tgz"
+            "path-is-inside": {
+              "version": "1.0.1",
+              "from": "path-is-inside@>=1.0.1 <2.0.0",
+              "resolved": "https://registry.npmjs.org/path-is-inside/-/path-is-inside-1.0.1.tgz"
             },
-            "minimatch": {
-              "version": "3.0.2",
-              "from": "https://registry.npmjs.org/minimatch/-/minimatch-3.0.2.tgz",
-              "resolved": "https://registry.npmjs.org/minimatch/-/minimatch-3.0.2.tgz",
+            "pluralize": {
+              "version": "1.2.1",
+              "from": "pluralize@>=1.2.1 <2.0.0",
+              "resolved": "https://registry.npmjs.org/pluralize/-/pluralize-1.2.1.tgz"
+            },
+            "progress": {
+              "version": "1.1.8",
+              "from": "progress@>=1.1.8 <2.0.0",
+              "resolved": "https://registry.npmjs.org/progress/-/progress-1.1.8.tgz"
+            },
+            "require-uncached": {
+              "version": "1.0.2",
+              "from": "require-uncached@>=1.0.2 <2.0.0",
+              "resolved": "https://registry.npmjs.org/require-uncached/-/require-uncached-1.0.2.tgz",
               "dependencies": {
-                "brace-expansion": {
-                  "version": "1.1.6",
-                  "from": "https://registry.npmjs.org/brace-expansion/-/brace-expansion-1.1.6.tgz",
-                  "resolved": "https://registry.npmjs.org/brace-expansion/-/brace-expansion-1.1.6.tgz",
+                "caller-path": {
+                  "version": "0.1.0",
+                  "from": "caller-path@>=0.1.0 <0.2.0",
+                  "resolved": "https://registry.npmjs.org/caller-path/-/caller-path-0.1.0.tgz",
                   "dependencies": {
-                    "balanced-match": {
-                      "version": "0.4.2",
-                      "from": "https://registry.npmjs.org/balanced-match/-/balanced-match-0.4.2.tgz",
-                      "resolved": "https://registry.npmjs.org/balanced-match/-/balanced-match-0.4.2.tgz"
-                    },
-                    "concat-map": {
-                      "version": "0.0.1",
-                      "from": "https://registry.npmjs.org/concat-map/-/concat-map-0.0.1.tgz",
-                      "resolved": "https://registry.npmjs.org/concat-map/-/concat-map-0.0.1.tgz"
+                    "callsites": {
+                      "version": "0.2.0",
+                      "from": "callsites@>=0.2.0 <0.3.0",
+                      "resolved": "https://registry.npmjs.org/callsites/-/callsites-0.2.0.tgz"
                     }
                   }
+                },
+                "resolve-from": {
+                  "version": "1.0.1",
+                  "from": "resolve-from@>=1.0.0 <2.0.0",
+                  "resolved": "https://registry.npmjs.org/resolve-from/-/resolve-from-1.0.1.tgz"
                 }
               }
             },
-            "natural-compare": {
-              "version": "1.2.2",
-              "from": "https://registry.npmjs.org/natural-compare/-/natural-compare-1.2.2.tgz",
-              "resolved": "https://registry.npmjs.org/natural-compare/-/natural-compare-1.2.2.tgz"
+            "shelljs": {
+              "version": "0.6.0",
+              "from": "shelljs@>=0.6.0 <0.7.0",
+              "resolved": "https://registry.npmjs.org/shelljs/-/shelljs-0.6.0.tgz"
             },
-            "pathval": {
-              "version": "0.1.1",
-              "from": "https://registry.npmjs.org/pathval/-/pathval-0.1.1.tgz",
-              "resolved": "https://registry.npmjs.org/pathval/-/pathval-0.1.1.tgz"
+            "strip-bom": {
+              "version": "3.0.0",
+              "from": "strip-bom@>=3.0.0 <4.0.0",
+              "resolved": "https://registry.npmjs.org/strip-bom/-/strip-bom-3.0.0.tgz"
+            },
+            "strip-json-comments": {
+              "version": "1.0.4",
+              "from": "strip-json-comments@>=1.0.1 <1.1.0",
+              "resolved": "https://registry.npmjs.org/strip-json-comments/-/strip-json-comments-1.0.4.tgz"
             },
-            "prompt": {
-              "version": "0.2.14",
-              "from": "https://registry.npmjs.org/prompt/-/prompt-0.2.14.tgz",
-              "resolved": "https://registry.npmjs.org/prompt/-/prompt-0.2.14.tgz",
+            "table": {
+              "version": "3.7.8",
+              "from": "table@>=3.7.8 <4.0.0",
+              "resolved": "https://registry.npmjs.org/table/-/table-3.7.8.tgz",
               "dependencies": {
-                "pkginfo": {
-                  "version": "0.4.0",
-                  "from": "https://registry.npmjs.org/pkginfo/-/pkginfo-0.4.0.tgz",
-                  "resolved": "https://registry.npmjs.org/pkginfo/-/pkginfo-0.4.0.tgz"
+                "bluebird": {
+                  "version": "3.4.1",
+                  "from": "bluebird@>=3.1.1 <4.0.0",
+                  "resolved": "https://registry.npmjs.org/bluebird/-/bluebird-3.4.1.tgz"
                 },
-                "read": {
-                  "version": "1.0.7",
-                  "from": "https://registry.npmjs.org/read/-/read-1.0.7.tgz",
-                  "resolved": "https://registry.npmjs.org/read/-/read-1.0.7.tgz",
-                  "dependencies": {
-                    "mute-stream": {
-                      "version": "0.0.6",
-                      "from": "https://registry.npmjs.org/mute-stream/-/mute-stream-0.0.6.tgz",
-                      "resolved": "https://registry.npmjs.org/mute-stream/-/mute-stream-0.0.6.tgz"
-                    }
-                  }
-                },
-                "revalidator": {
-                  "version": "0.1.8",
-                  "from": "https://registry.npmjs.org/revalidator/-/revalidator-0.1.8.tgz",
-                  "resolved": "https://registry.npmjs.org/revalidator/-/revalidator-0.1.8.tgz"
+                "slice-ansi": {
+                  "version": "0.0.4",
+                  "from": "slice-ansi@0.0.4",
+                  "resolved": "https://registry.npmjs.org/slice-ansi/-/slice-ansi-0.0.4.tgz"
                 },
-                "utile": {
-                  "version": "0.2.1",
-                  "from": "https://registry.npmjs.org/utile/-/utile-0.2.1.tgz",
-                  "resolved": "https://registry.npmjs.org/utile/-/utile-0.2.1.tgz",
+                "string-width": {
+                  "version": "1.0.1",
+                  "from": "string-width@>=1.0.1 <2.0.0",
+                  "resolved": "https://registry.npmjs.org/string-width/-/string-width-1.0.1.tgz",
                   "dependencies": {
-                    "async": {
-                      "version": "0.2.10",
-                      "from": "https://registry.npmjs.org/async/-/async-0.2.10.tgz",
-                      "resolved": "https://registry.npmjs.org/async/-/async-0.2.10.tgz"
-                    },
-                    "deep-equal": {
-                      "version": "1.0.1",
-                      "from": "https://registry.npmjs.org/deep-equal/-/deep-equal-1.0.1.tgz",
-                      "resolved": "https://registry.npmjs.org/deep-equal/-/deep-equal-1.0.1.tgz"
-                    },
-                    "i": {
-                      "version": "0.3.5",
-                      "from": "https://registry.npmjs.org/i/-/i-0.3.5.tgz",
-                      "resolved": "https://registry.npmjs.org/i/-/i-0.3.5.tgz"
-                    },
-                    "mkdirp": {
-                      "version": "0.5.1",
-                      "from": "https://registry.npmjs.org/mkdirp/-/mkdirp-0.5.1.tgz",
-                      "resolved": "https://registry.npmjs.org/mkdirp/-/mkdirp-0.5.1.tgz",
+                    "code-point-at": {
+                      "version": "1.0.0",
+                      "from": "code-point-at@>=1.0.0 <2.0.0",
+                      "resolved": "https://registry.npmjs.org/code-point-at/-/code-point-at-1.0.0.tgz",
                       "dependencies": {
-                        "minimist": {
-                          "version": "0.0.8",
-                          "from": "https://registry.npmjs.org/minimist/-/minimist-0.0.8.tgz",
-                          "resolved": "https://registry.npmjs.org/minimist/-/minimist-0.0.8.tgz"
+                        "number-is-nan": {
+                          "version": "1.0.0",
+                          "from": "number-is-nan@>=1.0.0 <2.0.0",
+                          "resolved": "https://registry.npmjs.org/number-is-nan/-/number-is-nan-1.0.0.tgz"
                         }
                       }
                     },
-                    "ncp": {
-                      "version": "0.4.2",
-                      "from": "https://registry.npmjs.org/ncp/-/ncp-0.4.2.tgz",
-                      "resolved": "https://registry.npmjs.org/ncp/-/ncp-0.4.2.tgz"
-                    },
-                    "rimraf": {
-                      "version": "2.5.4",
-                      "from": "https://registry.npmjs.org/rimraf/-/rimraf-2.5.4.tgz",
-                      "resolved": "https://registry.npmjs.org/rimraf/-/rimraf-2.5.4.tgz",
+                    "is-fullwidth-code-point": {
+                      "version": "1.0.0",
+                      "from": "is-fullwidth-code-point@>=1.0.0 <2.0.0",
+                      "resolved": "https://registry.npmjs.org/is-fullwidth-code-point/-/is-fullwidth-code-point-1.0.0.tgz",
                       "dependencies": {
-                        "glob": {
-                          "version": "7.0.5",
-                          "from": "https://registry.npmjs.org/glob/-/glob-7.0.5.tgz",
-                          "resolved": "https://registry.npmjs.org/glob/-/glob-7.0.5.tgz",
-                          "dependencies": {
-                            "fs.realpath": {
-                              "version": "1.0.0",
-                              "from": "https://registry.npmjs.org/fs.realpath/-/fs.realpath-1.0.0.tgz",
-                              "resolved": "https://registry.npmjs.org/fs.realpath/-/fs.realpath-1.0.0.tgz"
-                            },
-                            "inflight": {
-                              "version": "1.0.5",
-                              "from": "https://registry.npmjs.org/inflight/-/inflight-1.0.5.tgz",
-                              "resolved": "https://registry.npmjs.org/inflight/-/inflight-1.0.5.tgz",
-                              "dependencies": {
-                                "wrappy": {
-                                  "version": "1.0.2",
-                                  "from": "https://registry.npmjs.org/wrappy/-/wrappy-1.0.2.tgz",
-                                  "resolved": "https://registry.npmjs.org/wrappy/-/wrappy-1.0.2.tgz"
-                                }
-                              }
-                            },
-                            "inherits": {
-                              "version": "2.0.1",
-                              "from": "https://registry.npmjs.org/inherits/-/inherits-2.0.1.tgz",
-                              "resolved": "https://registry.npmjs.org/inherits/-/inherits-2.0.1.tgz"
-                            },
-                            "once": {
-                              "version": "1.3.3",
-                              "from": "https://registry.npmjs.org/once/-/once-1.3.3.tgz",
-                              "resolved": "https://registry.npmjs.org/once/-/once-1.3.3.tgz",
-                              "dependencies": {
-                                "wrappy": {
-                                  "version": "1.0.2",
-                                  "from": "https://registry.npmjs.org/wrappy/-/wrappy-1.0.2.tgz",
-                                  "resolved": "https://registry.npmjs.org/wrappy/-/wrappy-1.0.2.tgz"
-                                }
-                              }
-                            },
-                            "path-is-absolute": {
-                              "version": "1.0.0",
-                              "from": "https://registry.npmjs.org/path-is-absolute/-/path-is-absolute-1.0.0.tgz",
-                              "resolved": "https://registry.npmjs.org/path-is-absolute/-/path-is-absolute-1.0.0.tgz"
-                            }
-                          }
+                        "number-is-nan": {
+                          "version": "1.0.0",
+                          "from": "number-is-nan@>=1.0.0 <2.0.0",
+                          "resolved": "https://registry.npmjs.org/number-is-nan/-/number-is-nan-1.0.0.tgz"
                         }
                       }
                     }
                   }
                 },
-                "winston": {
-                  "version": "0.8.3",
-                  "from": "https://registry.npmjs.org/winston/-/winston-0.8.3.tgz",
-                  "resolved": "https://registry.npmjs.org/winston/-/winston-0.8.3.tgz",
+                "strip-ansi": {
+                  "version": "3.0.1",
+                  "from": "strip-ansi@>=3.0.0 <4.0.0",
+                  "resolved": "https://registry.npmjs.org/strip-ansi/-/strip-ansi-3.0.1.tgz",
                   "dependencies": {
-                    "async": {
-                      "version": "0.2.10",
-                      "from": "https://registry.npmjs.org/async/-/async-0.2.10.tgz",
-                      "resolved": "https://registry.npmjs.org/async/-/async-0.2.10.tgz"
-                    },
-                    "colors": {
-                      "version": "0.6.2",
-                      "from": "https://registry.npmjs.org/colors/-/colors-0.6.2.tgz",
-                      "resolved": "https://registry.npmjs.org/colors/-/colors-0.6.2.tgz"
-                    },
-                    "cycle": {
-                      "version": "1.0.3",
-                      "from": "https://registry.npmjs.org/cycle/-/cycle-1.0.3.tgz",
-                      "resolved": "https://registry.npmjs.org/cycle/-/cycle-1.0.3.tgz"
-                    },
-                    "eyes": {
-                      "version": "0.1.8",
-                      "from": "https://registry.npmjs.org/eyes/-/eyes-0.1.8.tgz",
-                      "resolved": "https://registry.npmjs.org/eyes/-/eyes-0.1.8.tgz"
-                    },
-                    "isstream": {
-                      "version": "0.1.2",
-                      "from": "https://registry.npmjs.org/isstream/-/isstream-0.1.2.tgz",
-                      "resolved": "https://registry.npmjs.org/isstream/-/isstream-0.1.2.tgz"
-                    },
-                    "pkginfo": {
-                      "version": "0.3.1",
-                      "from": "https://registry.npmjs.org/pkginfo/-/pkginfo-0.3.1.tgz",
-                      "resolved": "https://registry.npmjs.org/pkginfo/-/pkginfo-0.3.1.tgz"
-                    },
-                    "stack-trace": {
-                      "version": "0.0.9",
-                      "from": "https://registry.npmjs.org/stack-trace/-/stack-trace-0.0.9.tgz",
-                      "resolved": "https://registry.npmjs.org/stack-trace/-/stack-trace-0.0.9.tgz"
+                    "ansi-regex": {
+                      "version": "2.0.0",
+                      "from": "ansi-regex@>=2.0.0 <3.0.0",
+                      "resolved": "https://registry.npmjs.org/ansi-regex/-/ansi-regex-2.0.0.tgz"
                     }
                   }
+                },
+                "tv4": {
+                  "version": "1.2.7",
+                  "from": "tv4@>=1.2.7 <2.0.0",
+                  "resolved": "https://registry.npmjs.org/tv4/-/tv4-1.2.7.tgz"
+                },
+                "xregexp": {
+                  "version": "3.1.1",
+                  "from": "xregexp@>=3.0.0 <4.0.0",
+                  "resolved": "https://registry.npmjs.org/xregexp/-/xregexp-3.1.1.tgz"
                 }
               }
             },
-            "reserved-words": {
-              "version": "0.1.1",
-              "from": "https://registry.npmjs.org/reserved-words/-/reserved-words-0.1.1.tgz",
-              "resolved": "https://registry.npmjs.org/reserved-words/-/reserved-words-0.1.1.tgz"
-            },
-            "resolve": {
-              "version": "1.1.7",
-              "from": "https://registry.npmjs.org/resolve/-/resolve-1.1.7.tgz",
-              "resolved": "https://registry.npmjs.org/resolve/-/resolve-1.1.7.tgz"
-            },
-            "strip-bom": {
-              "version": "2.0.0",
-              "from": "https://registry.npmjs.org/strip-bom/-/strip-bom-2.0.0.tgz",
-              "resolved": "https://registry.npmjs.org/strip-bom/-/strip-bom-2.0.0.tgz",
-              "dependencies": {
-                "is-utf8": {
-                  "version": "0.2.1",
-                  "from": "https://registry.npmjs.org/is-utf8/-/is-utf8-0.2.1.tgz",
-                  "resolved": "https://registry.npmjs.org/is-utf8/-/is-utf8-0.2.1.tgz"
-                }
-              }
-            },
-            "strip-json-comments": {
-              "version": "1.0.4",
-              "from": "https://registry.npmjs.org/strip-json-comments/-/strip-json-comments-1.0.4.tgz",
-              "resolved": "https://registry.npmjs.org/strip-json-comments/-/strip-json-comments-1.0.4.tgz"
+            "text-table": {
+              "version": "0.2.0",
+              "from": "text-table@>=0.2.0 <0.3.0",
+              "resolved": "https://registry.npmjs.org/text-table/-/text-table-0.2.0.tgz"
             },
-            "to-double-quotes": {
+            "user-home": {
               "version": "2.0.0",
-              "from": "https://registry.npmjs.org/to-double-quotes/-/to-double-quotes-2.0.0.tgz",
-              "resolved": "https://registry.npmjs.org/to-double-quotes/-/to-double-quotes-2.0.0.tgz"
-            },
-            "to-single-quotes": {
-              "version": "2.0.1",
-              "from": "https://registry.npmjs.org/to-single-quotes/-/to-single-quotes-2.0.1.tgz",
-              "resolved": "https://registry.npmjs.org/to-single-quotes/-/to-single-quotes-2.0.1.tgz"
-            },
-            "vow-fs": {
-              "version": "0.3.6",
-              "from": "https://registry.npmjs.org/vow-fs/-/vow-fs-0.3.6.tgz",
-              "resolved": "https://registry.npmjs.org/vow-fs/-/vow-fs-0.3.6.tgz",
+              "from": "user-home@>=2.0.0 <3.0.0",
+              "resolved": "https://registry.npmjs.org/user-home/-/user-home-2.0.0.tgz",
               "dependencies": {
-                "uuid": {
-                  "version": "2.0.2",
-                  "from": "https://registry.npmjs.org/uuid/-/uuid-2.0.2.tgz",
-                  "resolved": "https://registry.npmjs.org/uuid/-/uuid-2.0.2.tgz"
-                },
-                "vow-queue": {
-                  "version": "0.4.2",
-                  "from": "https://registry.npmjs.org/vow-queue/-/vow-queue-0.4.2.tgz",
-                  "resolved": "https://registry.npmjs.org/vow-queue/-/vow-queue-0.4.2.tgz"
-                },
-                "glob": {
-                  "version": "7.0.5",
-                  "from": "https://registry.npmjs.org/glob/-/glob-7.0.5.tgz",
-                  "resolved": "https://registry.npmjs.org/glob/-/glob-7.0.5.tgz",
-                  "dependencies": {
-                    "fs.realpath": {
-                      "version": "1.0.0",
-                      "from": "https://registry.npmjs.org/fs.realpath/-/fs.realpath-1.0.0.tgz",
-                      "resolved": "https://registry.npmjs.org/fs.realpath/-/fs.realpath-1.0.0.tgz"
-                    },
-                    "inflight": {
-                      "version": "1.0.5",
-                      "from": "https://registry.npmjs.org/inflight/-/inflight-1.0.5.tgz",
-                      "resolved": "https://registry.npmjs.org/inflight/-/inflight-1.0.5.tgz",
-                      "dependencies": {
-                        "wrappy": {
-                          "version": "1.0.2",
-                          "from": "https://registry.npmjs.org/wrappy/-/wrappy-1.0.2.tgz",
-                          "resolved": "https://registry.npmjs.org/wrappy/-/wrappy-1.0.2.tgz"
-                        }
-                      }
-                    },
-                    "inherits": {
-                      "version": "2.0.1",
-                      "from": "https://registry.npmjs.org/inherits/-/inherits-2.0.1.tgz",
-                      "resolved": "https://registry.npmjs.org/inherits/-/inherits-2.0.1.tgz"
-                    },
-                    "once": {
-                      "version": "1.3.3",
-                      "from": "https://registry.npmjs.org/once/-/once-1.3.3.tgz",
-                      "resolved": "https://registry.npmjs.org/once/-/once-1.3.3.tgz",
-                      "dependencies": {
-                        "wrappy": {
-                          "version": "1.0.2",
-                          "from": "https://registry.npmjs.org/wrappy/-/wrappy-1.0.2.tgz",
-                          "resolved": "https://registry.npmjs.org/wrappy/-/wrappy-1.0.2.tgz"
-                        }
-                      }
-                    },
-                    "path-is-absolute": {
-                      "version": "1.0.0",
-                      "from": "https://registry.npmjs.org/path-is-absolute/-/path-is-absolute-1.0.0.tgz",
-                      "resolved": "https://registry.npmjs.org/path-is-absolute/-/path-is-absolute-1.0.0.tgz"
-                    }
-                  }
+                "os-homedir": {
+                  "version": "1.0.1",
+                  "from": "os-homedir@>=1.0.0 <2.0.0",
+                  "resolved": "https://registry.npmjs.org/os-homedir/-/os-homedir-1.0.1.tgz"
                 }
               }
-            },
-            "xmlbuilder": {
-              "version": "3.1.0",
-              "from": "https://registry.npmjs.org/xmlbuilder/-/xmlbuilder-3.1.0.tgz",
-              "resolved": "https://registry.npmjs.org/xmlbuilder/-/xmlbuilder-3.1.0.tgz"
             }
           }
-        },
-        "lodash": {
-          "version": "4.6.1",
-          "from": "https://registry.npmjs.org/lodash/-/lodash-4.6.1.tgz",
-          "resolved": "https://registry.npmjs.org/lodash/-/lodash-4.6.1.tgz"
-        },
-        "vow": {
-          "version": "0.4.12",
-          "from": "https://registry.npmjs.org/vow/-/vow-0.4.12.tgz",
-          "resolved": "https://registry.npmjs.org/vow/-/vow-0.4.12.tgz"
         }
       }
     },
@@ -7462,483 +7124,1427 @@
               "from": "https://registry.npmjs.org/extend/-/extend-2.0.1.tgz",
               "resolved": "https://registry.npmjs.org/extend/-/extend-2.0.1.tgz"
             },
-            "findup-sync": {
-              "version": "0.3.0",
-              "from": "https://registry.npmjs.org/findup-sync/-/findup-sync-0.3.0.tgz",
-              "resolved": "https://registry.npmjs.org/findup-sync/-/findup-sync-0.3.0.tgz",
+            "findup-sync": {
+              "version": "0.3.0",
+              "from": "https://registry.npmjs.org/findup-sync/-/findup-sync-0.3.0.tgz",
+              "resolved": "https://registry.npmjs.org/findup-sync/-/findup-sync-0.3.0.tgz",
+              "dependencies": {
+                "glob": {
+                  "version": "5.0.15",
+                  "from": "https://registry.npmjs.org/glob/-/glob-5.0.15.tgz",
+                  "resolved": "https://registry.npmjs.org/glob/-/glob-5.0.15.tgz",
+                  "dependencies": {
+                    "inflight": {
+                      "version": "1.0.4",
+                      "from": "https://registry.npmjs.org/inflight/-/inflight-1.0.4.tgz",
+                      "resolved": "https://registry.npmjs.org/inflight/-/inflight-1.0.4.tgz",
+                      "dependencies": {
+                        "wrappy": {
+                          "version": "1.0.1",
+                          "from": "https://registry.npmjs.org/wrappy/-/wrappy-1.0.1.tgz",
+                          "resolved": "https://registry.npmjs.org/wrappy/-/wrappy-1.0.1.tgz"
+                        }
+                      }
+                    },
+                    "inherits": {
+                      "version": "2.0.1",
+                      "from": "https://registry.npmjs.org/inherits/-/inherits-2.0.1.tgz",
+                      "resolved": "https://registry.npmjs.org/inherits/-/inherits-2.0.1.tgz"
+                    },
+                    "minimatch": {
+                      "version": "3.0.0",
+                      "from": "https://registry.npmjs.org/minimatch/-/minimatch-3.0.0.tgz",
+                      "resolved": "https://registry.npmjs.org/minimatch/-/minimatch-3.0.0.tgz",
+                      "dependencies": {
+                        "brace-expansion": {
+                          "version": "1.1.4",
+                          "from": "https://registry.npmjs.org/brace-expansion/-/brace-expansion-1.1.4.tgz",
+                          "resolved": "https://registry.npmjs.org/brace-expansion/-/brace-expansion-1.1.4.tgz",
+                          "dependencies": {
+                            "balanced-match": {
+                              "version": "0.4.1",
+                              "from": "https://registry.npmjs.org/balanced-match/-/balanced-match-0.4.1.tgz",
+                              "resolved": "https://registry.npmjs.org/balanced-match/-/balanced-match-0.4.1.tgz"
+                            },
+                            "concat-map": {
+                              "version": "0.0.1",
+                              "from": "https://registry.npmjs.org/concat-map/-/concat-map-0.0.1.tgz",
+                              "resolved": "https://registry.npmjs.org/concat-map/-/concat-map-0.0.1.tgz"
+                            }
+                          }
+                        }
+                      }
+                    },
+                    "once": {
+                      "version": "1.3.3",
+                      "from": "https://registry.npmjs.org/once/-/once-1.3.3.tgz",
+                      "resolved": "https://registry.npmjs.org/once/-/once-1.3.3.tgz",
+                      "dependencies": {
+                        "wrappy": {
+                          "version": "1.0.1",
+                          "from": "https://registry.npmjs.org/wrappy/-/wrappy-1.0.1.tgz",
+                          "resolved": "https://registry.npmjs.org/wrappy/-/wrappy-1.0.1.tgz"
+                        }
+                      }
+                    },
+                    "path-is-absolute": {
+                      "version": "1.0.0",
+                      "from": "https://registry.npmjs.org/path-is-absolute/-/path-is-absolute-1.0.0.tgz",
+                      "resolved": "https://registry.npmjs.org/path-is-absolute/-/path-is-absolute-1.0.0.tgz"
+                    }
+                  }
+                }
+              }
+            },
+            "flagged-respawn": {
+              "version": "0.3.2",
+              "from": "https://registry.npmjs.org/flagged-respawn/-/flagged-respawn-0.3.2.tgz",
+              "resolved": "https://registry.npmjs.org/flagged-respawn/-/flagged-respawn-0.3.2.tgz"
+            },
+            "rechoir": {
+              "version": "0.6.2",
+              "from": "https://registry.npmjs.org/rechoir/-/rechoir-0.6.2.tgz",
+              "resolved": "https://registry.npmjs.org/rechoir/-/rechoir-0.6.2.tgz"
+            },
+            "resolve": {
+              "version": "1.1.7",
+              "from": "https://registry.npmjs.org/resolve/-/resolve-1.1.7.tgz",
+              "resolved": "https://registry.npmjs.org/resolve/-/resolve-1.1.7.tgz"
+            }
+          }
+        },
+        "minimist": {
+          "version": "1.2.0",
+          "from": "https://registry.npmjs.org/minimist/-/minimist-1.2.0.tgz",
+          "resolved": "https://registry.npmjs.org/minimist/-/minimist-1.2.0.tgz"
+        },
+        "orchestrator": {
+          "version": "0.3.7",
+          "from": "https://registry.npmjs.org/orchestrator/-/orchestrator-0.3.7.tgz",
+          "resolved": "https://registry.npmjs.org/orchestrator/-/orchestrator-0.3.7.tgz",
+          "dependencies": {
+            "end-of-stream": {
+              "version": "0.1.5",
+              "from": "https://registry.npmjs.org/end-of-stream/-/end-of-stream-0.1.5.tgz",
+              "resolved": "https://registry.npmjs.org/end-of-stream/-/end-of-stream-0.1.5.tgz",
+              "dependencies": {
+                "once": {
+                  "version": "1.3.3",
+                  "from": "https://registry.npmjs.org/once/-/once-1.3.3.tgz",
+                  "resolved": "https://registry.npmjs.org/once/-/once-1.3.3.tgz",
+                  "dependencies": {
+                    "wrappy": {
+                      "version": "1.0.1",
+                      "from": "https://registry.npmjs.org/wrappy/-/wrappy-1.0.1.tgz",
+                      "resolved": "https://registry.npmjs.org/wrappy/-/wrappy-1.0.1.tgz"
+                    }
+                  }
+                }
+              }
+            },
+            "sequencify": {
+              "version": "0.0.7",
+              "from": "https://registry.npmjs.org/sequencify/-/sequencify-0.0.7.tgz",
+              "resolved": "https://registry.npmjs.org/sequencify/-/sequencify-0.0.7.tgz"
+            },
+            "stream-consume": {
+              "version": "0.1.0",
+              "from": "https://registry.npmjs.org/stream-consume/-/stream-consume-0.1.0.tgz",
+              "resolved": "https://registry.npmjs.org/stream-consume/-/stream-consume-0.1.0.tgz"
+            }
+          }
+        },
+        "pretty-hrtime": {
+          "version": "0.2.2",
+          "from": "https://registry.npmjs.org/pretty-hrtime/-/pretty-hrtime-0.2.2.tgz",
+          "resolved": "https://registry.npmjs.org/pretty-hrtime/-/pretty-hrtime-0.2.2.tgz"
+        },
+        "semver": {
+          "version": "4.3.6",
+          "from": "https://registry.npmjs.org/semver/-/semver-4.3.6.tgz",
+          "resolved": "https://registry.npmjs.org/semver/-/semver-4.3.6.tgz"
+        },
+        "tildify": {
+          "version": "1.2.0",
+          "from": "https://registry.npmjs.org/tildify/-/tildify-1.2.0.tgz",
+          "resolved": "https://registry.npmjs.org/tildify/-/tildify-1.2.0.tgz",
+          "dependencies": {
+            "os-homedir": {
+              "version": "1.0.1",
+              "from": "https://registry.npmjs.org/os-homedir/-/os-homedir-1.0.1.tgz",
+              "resolved": "https://registry.npmjs.org/os-homedir/-/os-homedir-1.0.1.tgz"
+            }
+          }
+        },
+        "v8flags": {
+          "version": "2.0.11",
+          "from": "https://registry.npmjs.org/v8flags/-/v8flags-2.0.11.tgz",
+          "resolved": "https://registry.npmjs.org/v8flags/-/v8flags-2.0.11.tgz",
+          "dependencies": {
+            "user-home": {
+              "version": "1.1.1",
+              "from": "https://registry.npmjs.org/user-home/-/user-home-1.1.1.tgz",
+              "resolved": "https://registry.npmjs.org/user-home/-/user-home-1.1.1.tgz"
+            }
+          }
+        },
+        "vinyl-fs": {
+          "version": "0.3.14",
+          "from": "https://registry.npmjs.org/vinyl-fs/-/vinyl-fs-0.3.14.tgz",
+          "resolved": "https://registry.npmjs.org/vinyl-fs/-/vinyl-fs-0.3.14.tgz",
+          "dependencies": {
+            "defaults": {
+              "version": "1.0.3",
+              "from": "https://registry.npmjs.org/defaults/-/defaults-1.0.3.tgz",
+              "resolved": "https://registry.npmjs.org/defaults/-/defaults-1.0.3.tgz",
+              "dependencies": {
+                "clone": {
+                  "version": "1.0.2",
+                  "from": "https://registry.npmjs.org/clone/-/clone-1.0.2.tgz",
+                  "resolved": "https://registry.npmjs.org/clone/-/clone-1.0.2.tgz"
+                }
+              }
+            },
+            "glob-stream": {
+              "version": "3.1.18",
+              "from": "https://registry.npmjs.org/glob-stream/-/glob-stream-3.1.18.tgz",
+              "resolved": "https://registry.npmjs.org/glob-stream/-/glob-stream-3.1.18.tgz",
+              "dependencies": {
+                "glob": {
+                  "version": "4.5.3",
+                  "from": "https://registry.npmjs.org/glob/-/glob-4.5.3.tgz",
+                  "resolved": "https://registry.npmjs.org/glob/-/glob-4.5.3.tgz",
+                  "dependencies": {
+                    "inflight": {
+                      "version": "1.0.4",
+                      "from": "https://registry.npmjs.org/inflight/-/inflight-1.0.4.tgz",
+                      "resolved": "https://registry.npmjs.org/inflight/-/inflight-1.0.4.tgz",
+                      "dependencies": {
+                        "wrappy": {
+                          "version": "1.0.1",
+                          "from": "https://registry.npmjs.org/wrappy/-/wrappy-1.0.1.tgz",
+                          "resolved": "https://registry.npmjs.org/wrappy/-/wrappy-1.0.1.tgz"
+                        }
+                      }
+                    },
+                    "inherits": {
+                      "version": "2.0.1",
+                      "from": "https://registry.npmjs.org/inherits/-/inherits-2.0.1.tgz",
+                      "resolved": "https://registry.npmjs.org/inherits/-/inherits-2.0.1.tgz"
+                    },
+                    "once": {
+                      "version": "1.3.3",
+                      "from": "https://registry.npmjs.org/once/-/once-1.3.3.tgz",
+                      "resolved": "https://registry.npmjs.org/once/-/once-1.3.3.tgz",
+                      "dependencies": {
+                        "wrappy": {
+                          "version": "1.0.1",
+                          "from": "https://registry.npmjs.org/wrappy/-/wrappy-1.0.1.tgz",
+                          "resolved": "https://registry.npmjs.org/wrappy/-/wrappy-1.0.1.tgz"
+                        }
+                      }
+                    }
+                  }
+                },
+                "minimatch": {
+                  "version": "2.0.10",
+                  "from": "https://registry.npmjs.org/minimatch/-/minimatch-2.0.10.tgz",
+                  "resolved": "https://registry.npmjs.org/minimatch/-/minimatch-2.0.10.tgz",
+                  "dependencies": {
+                    "brace-expansion": {
+                      "version": "1.1.4",
+                      "from": "https://registry.npmjs.org/brace-expansion/-/brace-expansion-1.1.4.tgz",
+                      "resolved": "https://registry.npmjs.org/brace-expansion/-/brace-expansion-1.1.4.tgz",
+                      "dependencies": {
+                        "balanced-match": {
+                          "version": "0.4.1",
+                          "from": "https://registry.npmjs.org/balanced-match/-/balanced-match-0.4.1.tgz",
+                          "resolved": "https://registry.npmjs.org/balanced-match/-/balanced-match-0.4.1.tgz"
+                        },
+                        "concat-map": {
+                          "version": "0.0.1",
+                          "from": "https://registry.npmjs.org/concat-map/-/concat-map-0.0.1.tgz",
+                          "resolved": "https://registry.npmjs.org/concat-map/-/concat-map-0.0.1.tgz"
+                        }
+                      }
+                    }
+                  }
+                },
+                "ordered-read-streams": {
+                  "version": "0.1.0",
+                  "from": "https://registry.npmjs.org/ordered-read-streams/-/ordered-read-streams-0.1.0.tgz",
+                  "resolved": "https://registry.npmjs.org/ordered-read-streams/-/ordered-read-streams-0.1.0.tgz"
+                },
+                "glob2base": {
+                  "version": "0.0.12",
+                  "from": "https://registry.npmjs.org/glob2base/-/glob2base-0.0.12.tgz",
+                  "resolved": "https://registry.npmjs.org/glob2base/-/glob2base-0.0.12.tgz",
+                  "dependencies": {
+                    "find-index": {
+                      "version": "0.1.1",
+                      "from": "https://registry.npmjs.org/find-index/-/find-index-0.1.1.tgz",
+                      "resolved": "https://registry.npmjs.org/find-index/-/find-index-0.1.1.tgz"
+                    }
+                  }
+                },
+                "unique-stream": {
+                  "version": "1.0.0",
+                  "from": "https://registry.npmjs.org/unique-stream/-/unique-stream-1.0.0.tgz",
+                  "resolved": "https://registry.npmjs.org/unique-stream/-/unique-stream-1.0.0.tgz"
+                }
+              }
+            },
+            "glob-watcher": {
+              "version": "0.0.6",
+              "from": "https://registry.npmjs.org/glob-watcher/-/glob-watcher-0.0.6.tgz",
+              "resolved": "https://registry.npmjs.org/glob-watcher/-/glob-watcher-0.0.6.tgz",
+              "dependencies": {
+                "gaze": {
+                  "version": "0.5.2",
+                  "from": "https://registry.npmjs.org/gaze/-/gaze-0.5.2.tgz",
+                  "resolved": "https://registry.npmjs.org/gaze/-/gaze-0.5.2.tgz",
+                  "dependencies": {
+                    "globule": {
+                      "version": "0.1.0",
+                      "from": "https://registry.npmjs.org/globule/-/globule-0.1.0.tgz",
+                      "resolved": "https://registry.npmjs.org/globule/-/globule-0.1.0.tgz",
+                      "dependencies": {
+                        "lodash": {
+                          "version": "1.0.2",
+                          "from": "https://registry.npmjs.org/lodash/-/lodash-1.0.2.tgz",
+                          "resolved": "https://registry.npmjs.org/lodash/-/lodash-1.0.2.tgz"
+                        },
+                        "glob": {
+                          "version": "3.1.21",
+                          "from": "https://registry.npmjs.org/glob/-/glob-3.1.21.tgz",
+                          "resolved": "https://registry.npmjs.org/glob/-/glob-3.1.21.tgz",
+                          "dependencies": {
+                            "graceful-fs": {
+                              "version": "1.2.3",
+                              "from": "https://registry.npmjs.org/graceful-fs/-/graceful-fs-1.2.3.tgz",
+                              "resolved": "https://registry.npmjs.org/graceful-fs/-/graceful-fs-1.2.3.tgz"
+                            },
+                            "inherits": {
+                              "version": "1.0.2",
+                              "from": "https://registry.npmjs.org/inherits/-/inherits-1.0.2.tgz",
+                              "resolved": "https://registry.npmjs.org/inherits/-/inherits-1.0.2.tgz"
+                            }
+                          }
+                        },
+                        "minimatch": {
+                          "version": "0.2.14",
+                          "from": "https://registry.npmjs.org/minimatch/-/minimatch-0.2.14.tgz",
+                          "resolved": "https://registry.npmjs.org/minimatch/-/minimatch-0.2.14.tgz",
+                          "dependencies": {
+                            "lru-cache": {
+                              "version": "2.7.3",
+                              "from": "https://registry.npmjs.org/lru-cache/-/lru-cache-2.7.3.tgz",
+                              "resolved": "https://registry.npmjs.org/lru-cache/-/lru-cache-2.7.3.tgz"
+                            },
+                            "sigmund": {
+                              "version": "1.0.1",
+                              "from": "https://registry.npmjs.org/sigmund/-/sigmund-1.0.1.tgz",
+                              "resolved": "https://registry.npmjs.org/sigmund/-/sigmund-1.0.1.tgz"
+                            }
+                          }
+                        }
+                      }
+                    }
+                  }
+                }
+              }
+            },
+            "graceful-fs": {
+              "version": "3.0.8",
+              "from": "https://registry.npmjs.org/graceful-fs/-/graceful-fs-3.0.8.tgz",
+              "resolved": "https://registry.npmjs.org/graceful-fs/-/graceful-fs-3.0.8.tgz"
+            },
+            "mkdirp": {
+              "version": "0.5.1",
+              "from": "https://registry.npmjs.org/mkdirp/-/mkdirp-0.5.1.tgz",
+              "resolved": "https://registry.npmjs.org/mkdirp/-/mkdirp-0.5.1.tgz",
+              "dependencies": {
+                "minimist": {
+                  "version": "0.0.8",
+                  "from": "https://registry.npmjs.org/minimist/-/minimist-0.0.8.tgz",
+                  "resolved": "https://registry.npmjs.org/minimist/-/minimist-0.0.8.tgz"
+                }
+              }
+            },
+            "strip-bom": {
+              "version": "1.0.0",
+              "from": "https://registry.npmjs.org/strip-bom/-/strip-bom-1.0.0.tgz",
+              "resolved": "https://registry.npmjs.org/strip-bom/-/strip-bom-1.0.0.tgz",
+              "dependencies": {
+                "first-chunk-stream": {
+                  "version": "1.0.0",
+                  "from": "https://registry.npmjs.org/first-chunk-stream/-/first-chunk-stream-1.0.0.tgz",
+                  "resolved": "https://registry.npmjs.org/first-chunk-stream/-/first-chunk-stream-1.0.0.tgz"
+                },
+                "is-utf8": {
+                  "version": "0.2.1",
+                  "from": "https://registry.npmjs.org/is-utf8/-/is-utf8-0.2.1.tgz",
+                  "resolved": "https://registry.npmjs.org/is-utf8/-/is-utf8-0.2.1.tgz"
+                }
+              }
+            },
+            "through2": {
+              "version": "0.6.5",
+              "from": "https://registry.npmjs.org/through2/-/through2-0.6.5.tgz",
+              "resolved": "https://registry.npmjs.org/through2/-/through2-0.6.5.tgz",
+              "dependencies": {
+                "readable-stream": {
+                  "version": "1.0.34",
+                  "from": "https://registry.npmjs.org/readable-stream/-/readable-stream-1.0.34.tgz",
+                  "resolved": "https://registry.npmjs.org/readable-stream/-/readable-stream-1.0.34.tgz",
+                  "dependencies": {
+                    "core-util-is": {
+                      "version": "1.0.2",
+                      "from": "https://registry.npmjs.org/core-util-is/-/core-util-is-1.0.2.tgz",
+                      "resolved": "https://registry.npmjs.org/core-util-is/-/core-util-is-1.0.2.tgz"
+                    },
+                    "isarray": {
+                      "version": "0.0.1",
+                      "from": "https://registry.npmjs.org/isarray/-/isarray-0.0.1.tgz",
+                      "resolved": "https://registry.npmjs.org/isarray/-/isarray-0.0.1.tgz"
+                    },
+                    "string_decoder": {
+                      "version": "0.10.31",
+                      "from": "https://registry.npmjs.org/string_decoder/-/string_decoder-0.10.31.tgz",
+                      "resolved": "https://registry.npmjs.org/string_decoder/-/string_decoder-0.10.31.tgz"
+                    },
+                    "inherits": {
+                      "version": "2.0.1",
+                      "from": "https://registry.npmjs.org/inherits/-/inherits-2.0.1.tgz",
+                      "resolved": "https://registry.npmjs.org/inherits/-/inherits-2.0.1.tgz"
+                    }
+                  }
+                },
+                "xtend": {
+                  "version": "4.0.1",
+                  "from": "https://registry.npmjs.org/xtend/-/xtend-4.0.1.tgz",
+                  "resolved": "https://registry.npmjs.org/xtend/-/xtend-4.0.1.tgz"
+                }
+              }
+            },
+            "vinyl": {
+              "version": "0.4.6",
+              "from": "https://registry.npmjs.org/vinyl/-/vinyl-0.4.6.tgz",
+              "resolved": "https://registry.npmjs.org/vinyl/-/vinyl-0.4.6.tgz",
+              "dependencies": {
+                "clone": {
+                  "version": "0.2.0",
+                  "from": "https://registry.npmjs.org/clone/-/clone-0.2.0.tgz",
+                  "resolved": "https://registry.npmjs.org/clone/-/clone-0.2.0.tgz"
+                },
+                "clone-stats": {
+                  "version": "0.0.1",
+                  "from": "https://registry.npmjs.org/clone-stats/-/clone-stats-0.0.1.tgz",
+                  "resolved": "https://registry.npmjs.org/clone-stats/-/clone-stats-0.0.1.tgz"
+                }
+              }
+            }
+          }
+        }
+      }
+    },
+    "gulp-concat": {
+      "version": "2.6.0",
+      "from": "https://registry.npmjs.org/gulp-concat/-/gulp-concat-2.6.0.tgz",
+      "resolved": "https://registry.npmjs.org/gulp-concat/-/gulp-concat-2.6.0.tgz",
+      "dependencies": {
+        "concat-with-sourcemaps": {
+          "version": "1.0.4",
+          "from": "https://registry.npmjs.org/concat-with-sourcemaps/-/concat-with-sourcemaps-1.0.4.tgz",
+          "resolved": "https://registry.npmjs.org/concat-with-sourcemaps/-/concat-with-sourcemaps-1.0.4.tgz",
+          "dependencies": {
+            "source-map": {
+              "version": "0.5.6",
+              "from": "https://registry.npmjs.org/source-map/-/source-map-0.5.6.tgz",
+              "resolved": "https://registry.npmjs.org/source-map/-/source-map-0.5.6.tgz"
+            }
+          }
+        },
+        "through2": {
+          "version": "0.6.5",
+          "from": "https://registry.npmjs.org/through2/-/through2-0.6.5.tgz",
+          "resolved": "https://registry.npmjs.org/through2/-/through2-0.6.5.tgz",
+          "dependencies": {
+            "readable-stream": {
+              "version": "1.0.34",
+              "from": "https://registry.npmjs.org/readable-stream/-/readable-stream-1.0.34.tgz",
+              "resolved": "https://registry.npmjs.org/readable-stream/-/readable-stream-1.0.34.tgz",
+              "dependencies": {
+                "core-util-is": {
+                  "version": "1.0.2",
+                  "from": "https://registry.npmjs.org/core-util-is/-/core-util-is-1.0.2.tgz",
+                  "resolved": "https://registry.npmjs.org/core-util-is/-/core-util-is-1.0.2.tgz"
+                },
+                "isarray": {
+                  "version": "0.0.1",
+                  "from": "https://registry.npmjs.org/isarray/-/isarray-0.0.1.tgz",
+                  "resolved": "https://registry.npmjs.org/isarray/-/isarray-0.0.1.tgz"
+                },
+                "string_decoder": {
+                  "version": "0.10.31",
+                  "from": "https://registry.npmjs.org/string_decoder/-/string_decoder-0.10.31.tgz",
+                  "resolved": "https://registry.npmjs.org/string_decoder/-/string_decoder-0.10.31.tgz"
+                },
+                "inherits": {
+                  "version": "2.0.1",
+                  "from": "https://registry.npmjs.org/inherits/-/inherits-2.0.1.tgz",
+                  "resolved": "https://registry.npmjs.org/inherits/-/inherits-2.0.1.tgz"
+                }
+              }
+            },
+            "xtend": {
+              "version": "4.0.1",
+              "from": "https://registry.npmjs.org/xtend/-/xtend-4.0.1.tgz",
+              "resolved": "https://registry.npmjs.org/xtend/-/xtend-4.0.1.tgz"
+            }
+          }
+        }
+      }
+    },
+    "gulp-eslint": {
+      "version": "3.0.1",
+      "from": "gulp-eslint@latest",
+      "resolved": "https://registry.npmjs.org/gulp-eslint/-/gulp-eslint-3.0.1.tgz",
+      "dependencies": {
+        "bufferstreams": {
+          "version": "1.1.1",
+          "from": "bufferstreams@>=1.1.1 <2.0.0",
+          "resolved": "https://registry.npmjs.org/bufferstreams/-/bufferstreams-1.1.1.tgz",
+          "dependencies": {
+            "readable-stream": {
+              "version": "2.1.4",
+              "from": "readable-stream@>=2.0.2 <3.0.0",
+              "resolved": "https://registry.npmjs.org/readable-stream/-/readable-stream-2.1.4.tgz",
+              "dependencies": {
+                "buffer-shims": {
+                  "version": "1.0.0",
+                  "from": "buffer-shims@>=1.0.0 <2.0.0",
+                  "resolved": "https://registry.npmjs.org/buffer-shims/-/buffer-shims-1.0.0.tgz"
+                },
+                "core-util-is": {
+                  "version": "1.0.2",
+                  "from": "core-util-is@>=1.0.0 <1.1.0",
+                  "resolved": "https://registry.npmjs.org/core-util-is/-/core-util-is-1.0.2.tgz"
+                },
+                "inherits": {
+                  "version": "2.0.1",
+                  "from": "inherits@>=2.0.1 <2.1.0",
+                  "resolved": "https://registry.npmjs.org/inherits/-/inherits-2.0.1.tgz"
+                },
+                "isarray": {
+                  "version": "1.0.0",
+                  "from": "isarray@>=1.0.0 <1.1.0",
+                  "resolved": "https://registry.npmjs.org/isarray/-/isarray-1.0.0.tgz"
+                },
+                "process-nextick-args": {
+                  "version": "1.0.7",
+                  "from": "process-nextick-args@>=1.0.6 <1.1.0",
+                  "resolved": "https://registry.npmjs.org/process-nextick-args/-/process-nextick-args-1.0.7.tgz"
+                },
+                "string_decoder": {
+                  "version": "0.10.31",
+                  "from": "string_decoder@>=0.10.0 <0.11.0",
+                  "resolved": "https://registry.npmjs.org/string_decoder/-/string_decoder-0.10.31.tgz"
+                },
+                "util-deprecate": {
+                  "version": "1.0.2",
+                  "from": "util-deprecate@>=1.0.1 <1.1.0",
+                  "resolved": "https://registry.npmjs.org/util-deprecate/-/util-deprecate-1.0.2.tgz"
+                }
+              }
+            }
+          }
+        },
+        "eslint": {
+          "version": "3.2.2",
+          "from": "eslint@>=3.0.0 <4.0.0",
+          "resolved": "https://registry.npmjs.org/eslint/-/eslint-3.2.2.tgz",
+          "dependencies": {
+            "chalk": {
+              "version": "1.1.3",
+              "from": "chalk@>=1.1.3 <2.0.0",
+              "resolved": "https://registry.npmjs.org/chalk/-/chalk-1.1.3.tgz",
+              "dependencies": {
+                "ansi-styles": {
+                  "version": "2.2.1",
+                  "from": "ansi-styles@>=2.2.1 <3.0.0",
+                  "resolved": "https://registry.npmjs.org/ansi-styles/-/ansi-styles-2.2.1.tgz"
+                },
+                "escape-string-regexp": {
+                  "version": "1.0.5",
+                  "from": "escape-string-regexp@>=1.0.2 <2.0.0",
+                  "resolved": "https://registry.npmjs.org/escape-string-regexp/-/escape-string-regexp-1.0.5.tgz"
+                },
+                "has-ansi": {
+                  "version": "2.0.0",
+                  "from": "has-ansi@>=2.0.0 <3.0.0",
+                  "resolved": "https://registry.npmjs.org/has-ansi/-/has-ansi-2.0.0.tgz",
+                  "dependencies": {
+                    "ansi-regex": {
+                      "version": "2.0.0",
+                      "from": "ansi-regex@>=2.0.0 <3.0.0",
+                      "resolved": "https://registry.npmjs.org/ansi-regex/-/ansi-regex-2.0.0.tgz"
+                    }
+                  }
+                },
+                "strip-ansi": {
+                  "version": "3.0.1",
+                  "from": "strip-ansi@>=3.0.0 <4.0.0",
+                  "resolved": "https://registry.npmjs.org/strip-ansi/-/strip-ansi-3.0.1.tgz",
+                  "dependencies": {
+                    "ansi-regex": {
+                      "version": "2.0.0",
+                      "from": "ansi-regex@>=2.0.0 <3.0.0",
+                      "resolved": "https://registry.npmjs.org/ansi-regex/-/ansi-regex-2.0.0.tgz"
+                    }
+                  }
+                },
+                "supports-color": {
+                  "version": "2.0.0",
+                  "from": "supports-color@>=2.0.0 <3.0.0",
+                  "resolved": "https://registry.npmjs.org/supports-color/-/supports-color-2.0.0.tgz"
+                }
+              }
+            },
+            "concat-stream": {
+              "version": "1.5.1",
+              "from": "concat-stream@>=1.4.6 <2.0.0",
+              "resolved": "https://registry.npmjs.org/concat-stream/-/concat-stream-1.5.1.tgz",
+              "dependencies": {
+                "inherits": {
+                  "version": "2.0.1",
+                  "from": "inherits@>=2.0.1 <2.1.0",
+                  "resolved": "https://registry.npmjs.org/inherits/-/inherits-2.0.1.tgz"
+                },
+                "typedarray": {
+                  "version": "0.0.6",
+                  "from": "typedarray@>=0.0.5 <0.1.0",
+                  "resolved": "https://registry.npmjs.org/typedarray/-/typedarray-0.0.6.tgz"
+                },
+                "readable-stream": {
+                  "version": "2.0.6",
+                  "from": "readable-stream@>=2.0.0 <2.1.0",
+                  "resolved": "https://registry.npmjs.org/readable-stream/-/readable-stream-2.0.6.tgz",
+                  "dependencies": {
+                    "core-util-is": {
+                      "version": "1.0.2",
+                      "from": "core-util-is@>=1.0.0 <1.1.0",
+                      "resolved": "https://registry.npmjs.org/core-util-is/-/core-util-is-1.0.2.tgz"
+                    },
+                    "isarray": {
+                      "version": "1.0.0",
+                      "from": "isarray@>=1.0.0 <1.1.0",
+                      "resolved": "https://registry.npmjs.org/isarray/-/isarray-1.0.0.tgz"
+                    },
+                    "process-nextick-args": {
+                      "version": "1.0.7",
+                      "from": "process-nextick-args@>=1.0.6 <1.1.0",
+                      "resolved": "https://registry.npmjs.org/process-nextick-args/-/process-nextick-args-1.0.7.tgz"
+                    },
+                    "string_decoder": {
+                      "version": "0.10.31",
+                      "from": "string_decoder@>=0.10.0 <0.11.0",
+                      "resolved": "https://registry.npmjs.org/string_decoder/-/string_decoder-0.10.31.tgz"
+                    },
+                    "util-deprecate": {
+                      "version": "1.0.2",
+                      "from": "util-deprecate@>=1.0.1 <1.1.0",
+                      "resolved": "https://registry.npmjs.org/util-deprecate/-/util-deprecate-1.0.2.tgz"
+                    }
+                  }
+                }
+              }
+            },
+            "debug": {
+              "version": "2.2.0",
+              "from": "debug@>=2.1.1 <3.0.0",
+              "resolved": "https://registry.npmjs.org/debug/-/debug-2.2.0.tgz",
+              "dependencies": {
+                "ms": {
+                  "version": "0.7.1",
+                  "from": "ms@0.7.1",
+                  "resolved": "https://registry.npmjs.org/ms/-/ms-0.7.1.tgz"
+                }
+              }
+            },
+            "doctrine": {
+              "version": "1.2.2",
+              "from": "doctrine@>=1.2.2 <2.0.0",
+              "resolved": "https://registry.npmjs.org/doctrine/-/doctrine-1.2.2.tgz",
+              "dependencies": {
+                "esutils": {
+                  "version": "1.1.6",
+                  "from": "esutils@>=1.1.6 <2.0.0",
+                  "resolved": "https://registry.npmjs.org/esutils/-/esutils-1.1.6.tgz"
+                },
+                "isarray": {
+                  "version": "1.0.0",
+                  "from": "isarray@>=1.0.0 <2.0.0",
+                  "resolved": "https://registry.npmjs.org/isarray/-/isarray-1.0.0.tgz"
+                }
+              }
+            },
+            "escope": {
+              "version": "3.6.0",
+              "from": "escope@>=3.6.0 <4.0.0",
+              "resolved": "https://registry.npmjs.org/escope/-/escope-3.6.0.tgz",
+              "dependencies": {
+                "es6-map": {
+                  "version": "0.1.4",
+                  "from": "es6-map@>=0.1.3 <0.2.0",
+                  "resolved": "https://registry.npmjs.org/es6-map/-/es6-map-0.1.4.tgz",
+                  "dependencies": {
+                    "d": {
+                      "version": "0.1.1",
+                      "from": "d@>=0.1.1 <0.2.0",
+                      "resolved": "https://registry.npmjs.org/d/-/d-0.1.1.tgz"
+                    },
+                    "es5-ext": {
+                      "version": "0.10.12",
+                      "from": "es5-ext@>=0.10.8 <0.11.0",
+                      "resolved": "https://registry.npmjs.org/es5-ext/-/es5-ext-0.10.12.tgz"
+                    },
+                    "es6-iterator": {
+                      "version": "2.0.0",
+                      "from": "es6-iterator@>=2.0.0 <3.0.0",
+                      "resolved": "https://registry.npmjs.org/es6-iterator/-/es6-iterator-2.0.0.tgz"
+                    },
+                    "es6-set": {
+                      "version": "0.1.4",
+                      "from": "es6-set@>=0.1.3 <0.2.0",
+                      "resolved": "https://registry.npmjs.org/es6-set/-/es6-set-0.1.4.tgz"
+                    },
+                    "es6-symbol": {
+                      "version": "3.1.0",
+                      "from": "es6-symbol@>=3.1.0 <3.2.0",
+                      "resolved": "https://registry.npmjs.org/es6-symbol/-/es6-symbol-3.1.0.tgz"
+                    },
+                    "event-emitter": {
+                      "version": "0.3.4",
+                      "from": "event-emitter@>=0.3.4 <0.4.0",
+                      "resolved": "https://registry.npmjs.org/event-emitter/-/event-emitter-0.3.4.tgz"
+                    }
+                  }
+                },
+                "es6-weak-map": {
+                  "version": "2.0.1",
+                  "from": "es6-weak-map@>=2.0.1 <3.0.0",
+                  "resolved": "https://registry.npmjs.org/es6-weak-map/-/es6-weak-map-2.0.1.tgz",
+                  "dependencies": {
+                    "d": {
+                      "version": "0.1.1",
+                      "from": "d@>=0.1.1 <0.2.0",
+                      "resolved": "https://registry.npmjs.org/d/-/d-0.1.1.tgz"
+                    },
+                    "es5-ext": {
+                      "version": "0.10.12",
+                      "from": "es5-ext@>=0.10.8 <0.11.0",
+                      "resolved": "https://registry.npmjs.org/es5-ext/-/es5-ext-0.10.12.tgz"
+                    },
+                    "es6-iterator": {
+                      "version": "2.0.0",
+                      "from": "es6-iterator@>=2.0.0 <3.0.0",
+                      "resolved": "https://registry.npmjs.org/es6-iterator/-/es6-iterator-2.0.0.tgz"
+                    },
+                    "es6-symbol": {
+                      "version": "3.1.0",
+                      "from": "es6-symbol@>=3.1.0 <3.2.0",
+                      "resolved": "https://registry.npmjs.org/es6-symbol/-/es6-symbol-3.1.0.tgz"
+                    }
+                  }
+                },
+                "esrecurse": {
+                  "version": "4.1.0",
+                  "from": "esrecurse@>=4.1.0 <5.0.0",
+                  "resolved": "https://registry.npmjs.org/esrecurse/-/esrecurse-4.1.0.tgz",
+                  "dependencies": {
+                    "estraverse": {
+                      "version": "4.1.1",
+                      "from": "estraverse@>=4.1.0 <4.2.0",
+                      "resolved": "https://registry.npmjs.org/estraverse/-/estraverse-4.1.1.tgz"
+                    },
+                    "object-assign": {
+                      "version": "4.1.0",
+                      "from": "object-assign@>=4.0.1 <5.0.0",
+                      "resolved": "https://registry.npmjs.org/object-assign/-/object-assign-4.1.0.tgz"
+                    }
+                  }
+                }
+              }
+            },
+            "espree": {
+              "version": "3.1.7",
+              "from": "espree@>=3.1.6 <4.0.0",
+              "resolved": "https://registry.npmjs.org/espree/-/espree-3.1.7.tgz",
               "dependencies": {
-                "glob": {
-                  "version": "5.0.15",
-                  "from": "https://registry.npmjs.org/glob/-/glob-5.0.15.tgz",
-                  "resolved": "https://registry.npmjs.org/glob/-/glob-5.0.15.tgz",
+                "acorn": {
+                  "version": "3.3.0",
+                  "from": "acorn@>=3.3.0 <4.0.0",
+                  "resolved": "https://registry.npmjs.org/acorn/-/acorn-3.3.0.tgz"
+                },
+                "acorn-jsx": {
+                  "version": "3.0.1",
+                  "from": "acorn-jsx@>=3.0.0 <4.0.0",
+                  "resolved": "https://registry.npmjs.org/acorn-jsx/-/acorn-jsx-3.0.1.tgz"
+                }
+              }
+            },
+            "estraverse": {
+              "version": "4.2.0",
+              "from": "estraverse@>=4.2.0 <5.0.0",
+              "resolved": "https://registry.npmjs.org/estraverse/-/estraverse-4.2.0.tgz"
+            },
+            "esutils": {
+              "version": "2.0.2",
+              "from": "esutils@>=2.0.2 <3.0.0",
+              "resolved": "https://registry.npmjs.org/esutils/-/esutils-2.0.2.tgz"
+            },
+            "file-entry-cache": {
+              "version": "1.3.1",
+              "from": "file-entry-cache@>=1.3.1 <2.0.0",
+              "resolved": "https://registry.npmjs.org/file-entry-cache/-/file-entry-cache-1.3.1.tgz",
+              "dependencies": {
+                "flat-cache": {
+                  "version": "1.2.1",
+                  "from": "flat-cache@>=1.2.1 <2.0.0",
+                  "resolved": "https://registry.npmjs.org/flat-cache/-/flat-cache-1.2.1.tgz",
                   "dependencies": {
-                    "inflight": {
-                      "version": "1.0.4",
-                      "from": "https://registry.npmjs.org/inflight/-/inflight-1.0.4.tgz",
-                      "resolved": "https://registry.npmjs.org/inflight/-/inflight-1.0.4.tgz",
-                      "dependencies": {
-                        "wrappy": {
-                          "version": "1.0.1",
-                          "from": "https://registry.npmjs.org/wrappy/-/wrappy-1.0.1.tgz",
-                          "resolved": "https://registry.npmjs.org/wrappy/-/wrappy-1.0.1.tgz"
-                        }
-                      }
-                    },
-                    "inherits": {
-                      "version": "2.0.1",
-                      "from": "https://registry.npmjs.org/inherits/-/inherits-2.0.1.tgz",
-                      "resolved": "https://registry.npmjs.org/inherits/-/inherits-2.0.1.tgz"
+                    "circular-json": {
+                      "version": "0.3.1",
+                      "from": "circular-json@>=0.3.0 <0.4.0",
+                      "resolved": "https://registry.npmjs.org/circular-json/-/circular-json-0.3.1.tgz"
                     },
-                    "minimatch": {
-                      "version": "3.0.0",
-                      "from": "https://registry.npmjs.org/minimatch/-/minimatch-3.0.0.tgz",
-                      "resolved": "https://registry.npmjs.org/minimatch/-/minimatch-3.0.0.tgz",
+                    "del": {
+                      "version": "2.2.1",
+                      "from": "del@>=2.0.2 <3.0.0",
+                      "resolved": "https://registry.npmjs.org/del/-/del-2.2.1.tgz",
                       "dependencies": {
-                        "brace-expansion": {
-                          "version": "1.1.4",
-                          "from": "https://registry.npmjs.org/brace-expansion/-/brace-expansion-1.1.4.tgz",
-                          "resolved": "https://registry.npmjs.org/brace-expansion/-/brace-expansion-1.1.4.tgz",
+                        "globby": {
+                          "version": "5.0.0",
+                          "from": "globby@>=5.0.0 <6.0.0",
+                          "resolved": "https://registry.npmjs.org/globby/-/globby-5.0.0.tgz",
                           "dependencies": {
-                            "balanced-match": {
-                              "version": "0.4.1",
-                              "from": "https://registry.npmjs.org/balanced-match/-/balanced-match-0.4.1.tgz",
-                              "resolved": "https://registry.npmjs.org/balanced-match/-/balanced-match-0.4.1.tgz"
+                            "array-union": {
+                              "version": "1.0.2",
+                              "from": "array-union@>=1.0.1 <2.0.0",
+                              "resolved": "https://registry.npmjs.org/array-union/-/array-union-1.0.2.tgz",
+                              "dependencies": {
+                                "array-uniq": {
+                                  "version": "1.0.3",
+                                  "from": "array-uniq@>=1.0.1 <2.0.0",
+                                  "resolved": "https://registry.npmjs.org/array-uniq/-/array-uniq-1.0.3.tgz"
+                                }
+                              }
                             },
-                            "concat-map": {
-                              "version": "0.0.1",
-                              "from": "https://registry.npmjs.org/concat-map/-/concat-map-0.0.1.tgz",
-                              "resolved": "https://registry.npmjs.org/concat-map/-/concat-map-0.0.1.tgz"
+                            "arrify": {
+                              "version": "1.0.1",
+                              "from": "arrify@>=1.0.0 <2.0.0",
+                              "resolved": "https://registry.npmjs.org/arrify/-/arrify-1.0.1.tgz"
+                            }
+                          }
+                        },
+                        "is-path-cwd": {
+                          "version": "1.0.0",
+                          "from": "is-path-cwd@>=1.0.0 <2.0.0",
+                          "resolved": "https://registry.npmjs.org/is-path-cwd/-/is-path-cwd-1.0.0.tgz"
+                        },
+                        "is-path-in-cwd": {
+                          "version": "1.0.0",
+                          "from": "is-path-in-cwd@>=1.0.0 <2.0.0",
+                          "resolved": "https://registry.npmjs.org/is-path-in-cwd/-/is-path-in-cwd-1.0.0.tgz",
+                          "dependencies": {
+                            "is-path-inside": {
+                              "version": "1.0.0",
+                              "from": "is-path-inside@>=1.0.0 <2.0.0",
+                              "resolved": "https://registry.npmjs.org/is-path-inside/-/is-path-inside-1.0.0.tgz"
+                            }
+                          }
+                        },
+                        "pify": {
+                          "version": "2.3.0",
+                          "from": "pify@>=2.0.0 <3.0.0",
+                          "resolved": "https://registry.npmjs.org/pify/-/pify-2.3.0.tgz"
+                        },
+                        "pinkie-promise": {
+                          "version": "2.0.1",
+                          "from": "pinkie-promise@>=2.0.0 <3.0.0",
+                          "resolved": "https://registry.npmjs.org/pinkie-promise/-/pinkie-promise-2.0.1.tgz",
+                          "dependencies": {
+                            "pinkie": {
+                              "version": "2.0.4",
+                              "from": "pinkie@>=2.0.0 <3.0.0",
+                              "resolved": "https://registry.npmjs.org/pinkie/-/pinkie-2.0.4.tgz"
                             }
                           }
+                        },
+                        "rimraf": {
+                          "version": "2.5.4",
+                          "from": "rimraf@>=2.2.8 <3.0.0",
+                          "resolved": "https://registry.npmjs.org/rimraf/-/rimraf-2.5.4.tgz"
                         }
                       }
                     },
-                    "once": {
-                      "version": "1.3.3",
-                      "from": "https://registry.npmjs.org/once/-/once-1.3.3.tgz",
-                      "resolved": "https://registry.npmjs.org/once/-/once-1.3.3.tgz",
-                      "dependencies": {
-                        "wrappy": {
-                          "version": "1.0.1",
-                          "from": "https://registry.npmjs.org/wrappy/-/wrappy-1.0.1.tgz",
-                          "resolved": "https://registry.npmjs.org/wrappy/-/wrappy-1.0.1.tgz"
-                        }
-                      }
+                    "graceful-fs": {
+                      "version": "4.1.5",
+                      "from": "graceful-fs@>=4.1.2 <5.0.0",
+                      "resolved": "https://registry.npmjs.org/graceful-fs/-/graceful-fs-4.1.5.tgz"
                     },
-                    "path-is-absolute": {
-                      "version": "1.0.0",
-                      "from": "https://registry.npmjs.org/path-is-absolute/-/path-is-absolute-1.0.0.tgz",
-                      "resolved": "https://registry.npmjs.org/path-is-absolute/-/path-is-absolute-1.0.0.tgz"
+                    "write": {
+                      "version": "0.2.1",
+                      "from": "write@>=0.2.1 <0.3.0",
+                      "resolved": "https://registry.npmjs.org/write/-/write-0.2.1.tgz"
                     }
                   }
+                },
+                "object-assign": {
+                  "version": "4.1.0",
+                  "from": "object-assign@>=4.0.1 <5.0.0",
+                  "resolved": "https://registry.npmjs.org/object-assign/-/object-assign-4.1.0.tgz"
                 }
               }
             },
-            "flagged-respawn": {
-              "version": "0.3.2",
-              "from": "https://registry.npmjs.org/flagged-respawn/-/flagged-respawn-0.3.2.tgz",
-              "resolved": "https://registry.npmjs.org/flagged-respawn/-/flagged-respawn-0.3.2.tgz"
-            },
-            "rechoir": {
-              "version": "0.6.2",
-              "from": "https://registry.npmjs.org/rechoir/-/rechoir-0.6.2.tgz",
-              "resolved": "https://registry.npmjs.org/rechoir/-/rechoir-0.6.2.tgz"
-            },
-            "resolve": {
-              "version": "1.1.7",
-              "from": "https://registry.npmjs.org/resolve/-/resolve-1.1.7.tgz",
-              "resolved": "https://registry.npmjs.org/resolve/-/resolve-1.1.7.tgz"
-            }
-          }
-        },
-        "minimist": {
-          "version": "1.2.0",
-          "from": "https://registry.npmjs.org/minimist/-/minimist-1.2.0.tgz",
-          "resolved": "https://registry.npmjs.org/minimist/-/minimist-1.2.0.tgz"
-        },
-        "orchestrator": {
-          "version": "0.3.7",
-          "from": "https://registry.npmjs.org/orchestrator/-/orchestrator-0.3.7.tgz",
-          "resolved": "https://registry.npmjs.org/orchestrator/-/orchestrator-0.3.7.tgz",
-          "dependencies": {
-            "end-of-stream": {
-              "version": "0.1.5",
-              "from": "https://registry.npmjs.org/end-of-stream/-/end-of-stream-0.1.5.tgz",
-              "resolved": "https://registry.npmjs.org/end-of-stream/-/end-of-stream-0.1.5.tgz",
+            "glob": {
+              "version": "7.0.5",
+              "from": "glob@>=7.0.3 <8.0.0",
+              "resolved": "https://registry.npmjs.org/glob/-/glob-7.0.5.tgz",
               "dependencies": {
+                "fs.realpath": {
+                  "version": "1.0.0",
+                  "from": "fs.realpath@>=1.0.0 <2.0.0",
+                  "resolved": "https://registry.npmjs.org/fs.realpath/-/fs.realpath-1.0.0.tgz"
+                },
+                "inflight": {
+                  "version": "1.0.5",
+                  "from": "inflight@>=1.0.4 <2.0.0",
+                  "resolved": "https://registry.npmjs.org/inflight/-/inflight-1.0.5.tgz",
+                  "dependencies": {
+                    "wrappy": {
+                      "version": "1.0.2",
+                      "from": "wrappy@>=1.0.0 <2.0.0",
+                      "resolved": "https://registry.npmjs.org/wrappy/-/wrappy-1.0.2.tgz"
+                    }
+                  }
+                },
+                "inherits": {
+                  "version": "2.0.1",
+                  "from": "inherits@>=2.0.0 <3.0.0",
+                  "resolved": "https://registry.npmjs.org/inherits/-/inherits-2.0.1.tgz"
+                },
+                "minimatch": {
+                  "version": "3.0.2",
+                  "from": "minimatch@>=3.0.2 <4.0.0",
+                  "resolved": "https://registry.npmjs.org/minimatch/-/minimatch-3.0.2.tgz",
+                  "dependencies": {
+                    "brace-expansion": {
+                      "version": "1.1.6",
+                      "from": "brace-expansion@>=1.0.0 <2.0.0",
+                      "resolved": "https://registry.npmjs.org/brace-expansion/-/brace-expansion-1.1.6.tgz",
+                      "dependencies": {
+                        "balanced-match": {
+                          "version": "0.4.2",
+                          "from": "balanced-match@>=0.4.1 <0.5.0",
+                          "resolved": "https://registry.npmjs.org/balanced-match/-/balanced-match-0.4.2.tgz"
+                        },
+                        "concat-map": {
+                          "version": "0.0.1",
+                          "from": "concat-map@0.0.1",
+                          "resolved": "https://registry.npmjs.org/concat-map/-/concat-map-0.0.1.tgz"
+                        }
+                      }
+                    }
+                  }
+                },
                 "once": {
                   "version": "1.3.3",
-                  "from": "https://registry.npmjs.org/once/-/once-1.3.3.tgz",
+                  "from": "once@>=1.3.0 <2.0.0",
                   "resolved": "https://registry.npmjs.org/once/-/once-1.3.3.tgz",
                   "dependencies": {
                     "wrappy": {
-                      "version": "1.0.1",
-                      "from": "https://registry.npmjs.org/wrappy/-/wrappy-1.0.1.tgz",
-                      "resolved": "https://registry.npmjs.org/wrappy/-/wrappy-1.0.1.tgz"
+                      "version": "1.0.2",
+                      "from": "wrappy@>=1.0.0 <2.0.0",
+                      "resolved": "https://registry.npmjs.org/wrappy/-/wrappy-1.0.2.tgz"
                     }
                   }
+                },
+                "path-is-absolute": {
+                  "version": "1.0.0",
+                  "from": "path-is-absolute@>=1.0.0 <2.0.0",
+                  "resolved": "https://registry.npmjs.org/path-is-absolute/-/path-is-absolute-1.0.0.tgz"
                 }
               }
             },
-            "sequencify": {
-              "version": "0.0.7",
-              "from": "https://registry.npmjs.org/sequencify/-/sequencify-0.0.7.tgz",
-              "resolved": "https://registry.npmjs.org/sequencify/-/sequencify-0.0.7.tgz"
+            "globals": {
+              "version": "9.9.0",
+              "from": "globals@>=9.2.0 <10.0.0",
+              "resolved": "https://registry.npmjs.org/globals/-/globals-9.9.0.tgz"
             },
-            "stream-consume": {
-              "version": "0.1.0",
-              "from": "https://registry.npmjs.org/stream-consume/-/stream-consume-0.1.0.tgz",
-              "resolved": "https://registry.npmjs.org/stream-consume/-/stream-consume-0.1.0.tgz"
-            }
-          }
-        },
-        "pretty-hrtime": {
-          "version": "0.2.2",
-          "from": "https://registry.npmjs.org/pretty-hrtime/-/pretty-hrtime-0.2.2.tgz",
-          "resolved": "https://registry.npmjs.org/pretty-hrtime/-/pretty-hrtime-0.2.2.tgz"
-        },
-        "semver": {
-          "version": "4.3.6",
-          "from": "https://registry.npmjs.org/semver/-/semver-4.3.6.tgz",
-          "resolved": "https://registry.npmjs.org/semver/-/semver-4.3.6.tgz"
-        },
-        "tildify": {
-          "version": "1.2.0",
-          "from": "https://registry.npmjs.org/tildify/-/tildify-1.2.0.tgz",
-          "resolved": "https://registry.npmjs.org/tildify/-/tildify-1.2.0.tgz",
-          "dependencies": {
-            "os-homedir": {
-              "version": "1.0.1",
-              "from": "https://registry.npmjs.org/os-homedir/-/os-homedir-1.0.1.tgz",
-              "resolved": "https://registry.npmjs.org/os-homedir/-/os-homedir-1.0.1.tgz"
-            }
-          }
-        },
-        "v8flags": {
-          "version": "2.0.11",
-          "from": "https://registry.npmjs.org/v8flags/-/v8flags-2.0.11.tgz",
-          "resolved": "https://registry.npmjs.org/v8flags/-/v8flags-2.0.11.tgz",
-          "dependencies": {
-            "user-home": {
-              "version": "1.1.1",
-              "from": "https://registry.npmjs.org/user-home/-/user-home-1.1.1.tgz",
-              "resolved": "https://registry.npmjs.org/user-home/-/user-home-1.1.1.tgz"
-            }
-          }
-        },
-        "vinyl-fs": {
-          "version": "0.3.14",
-          "from": "https://registry.npmjs.org/vinyl-fs/-/vinyl-fs-0.3.14.tgz",
-          "resolved": "https://registry.npmjs.org/vinyl-fs/-/vinyl-fs-0.3.14.tgz",
-          "dependencies": {
-            "defaults": {
-              "version": "1.0.3",
-              "from": "https://registry.npmjs.org/defaults/-/defaults-1.0.3.tgz",
-              "resolved": "https://registry.npmjs.org/defaults/-/defaults-1.0.3.tgz",
-              "dependencies": {
-                "clone": {
-                  "version": "1.0.2",
-                  "from": "https://registry.npmjs.org/clone/-/clone-1.0.2.tgz",
-                  "resolved": "https://registry.npmjs.org/clone/-/clone-1.0.2.tgz"
-                }
-              }
+            "ignore": {
+              "version": "3.1.3",
+              "from": "ignore@>=3.1.2 <4.0.0",
+              "resolved": "https://registry.npmjs.org/ignore/-/ignore-3.1.3.tgz"
+            },
+            "imurmurhash": {
+              "version": "0.1.4",
+              "from": "imurmurhash@>=0.1.4 <0.2.0",
+              "resolved": "https://registry.npmjs.org/imurmurhash/-/imurmurhash-0.1.4.tgz"
             },
-            "glob-stream": {
-              "version": "3.1.18",
-              "from": "https://registry.npmjs.org/glob-stream/-/glob-stream-3.1.18.tgz",
-              "resolved": "https://registry.npmjs.org/glob-stream/-/glob-stream-3.1.18.tgz",
+            "inquirer": {
+              "version": "0.12.0",
+              "from": "inquirer@>=0.12.0 <0.13.0",
+              "resolved": "https://registry.npmjs.org/inquirer/-/inquirer-0.12.0.tgz",
               "dependencies": {
-                "glob": {
-                  "version": "4.5.3",
-                  "from": "https://registry.npmjs.org/glob/-/glob-4.5.3.tgz",
-                  "resolved": "https://registry.npmjs.org/glob/-/glob-4.5.3.tgz",
+                "ansi-escapes": {
+                  "version": "1.4.0",
+                  "from": "ansi-escapes@>=1.1.0 <2.0.0",
+                  "resolved": "https://registry.npmjs.org/ansi-escapes/-/ansi-escapes-1.4.0.tgz"
+                },
+                "ansi-regex": {
+                  "version": "2.0.0",
+                  "from": "ansi-regex@>=2.0.0 <3.0.0",
+                  "resolved": "https://registry.npmjs.org/ansi-regex/-/ansi-regex-2.0.0.tgz"
+                },
+                "cli-cursor": {
+                  "version": "1.0.2",
+                  "from": "cli-cursor@>=1.0.1 <2.0.0",
+                  "resolved": "https://registry.npmjs.org/cli-cursor/-/cli-cursor-1.0.2.tgz",
                   "dependencies": {
-                    "inflight": {
-                      "version": "1.0.4",
-                      "from": "https://registry.npmjs.org/inflight/-/inflight-1.0.4.tgz",
-                      "resolved": "https://registry.npmjs.org/inflight/-/inflight-1.0.4.tgz",
+                    "restore-cursor": {
+                      "version": "1.0.1",
+                      "from": "restore-cursor@>=1.0.1 <2.0.0",
+                      "resolved": "https://registry.npmjs.org/restore-cursor/-/restore-cursor-1.0.1.tgz",
                       "dependencies": {
-                        "wrappy": {
-                          "version": "1.0.1",
-                          "from": "https://registry.npmjs.org/wrappy/-/wrappy-1.0.1.tgz",
-                          "resolved": "https://registry.npmjs.org/wrappy/-/wrappy-1.0.1.tgz"
+                        "exit-hook": {
+                          "version": "1.1.1",
+                          "from": "exit-hook@>=1.0.0 <2.0.0",
+                          "resolved": "https://registry.npmjs.org/exit-hook/-/exit-hook-1.1.1.tgz"
+                        },
+                        "onetime": {
+                          "version": "1.1.0",
+                          "from": "onetime@>=1.0.0 <2.0.0",
+                          "resolved": "https://registry.npmjs.org/onetime/-/onetime-1.1.0.tgz"
+                        }
+                      }
+                    }
+                  }
+                },
+                "cli-width": {
+                  "version": "2.1.0",
+                  "from": "cli-width@>=2.0.0 <3.0.0",
+                  "resolved": "https://registry.npmjs.org/cli-width/-/cli-width-2.1.0.tgz"
+                },
+                "figures": {
+                  "version": "1.7.0",
+                  "from": "figures@>=1.3.5 <2.0.0",
+                  "resolved": "https://registry.npmjs.org/figures/-/figures-1.7.0.tgz",
+                  "dependencies": {
+                    "escape-string-regexp": {
+                      "version": "1.0.5",
+                      "from": "escape-string-regexp@>=1.0.5 <2.0.0",
+                      "resolved": "https://registry.npmjs.org/escape-string-regexp/-/escape-string-regexp-1.0.5.tgz"
+                    },
+                    "object-assign": {
+                      "version": "4.1.0",
+                      "from": "object-assign@>=4.1.0 <5.0.0",
+                      "resolved": "https://registry.npmjs.org/object-assign/-/object-assign-4.1.0.tgz"
+                    }
+                  }
+                },
+                "readline2": {
+                  "version": "1.0.1",
+                  "from": "readline2@>=1.0.1 <2.0.0",
+                  "resolved": "https://registry.npmjs.org/readline2/-/readline2-1.0.1.tgz",
+                  "dependencies": {
+                    "code-point-at": {
+                      "version": "1.0.0",
+                      "from": "code-point-at@>=1.0.0 <2.0.0",
+                      "resolved": "https://registry.npmjs.org/code-point-at/-/code-point-at-1.0.0.tgz",
+                      "dependencies": {
+                        "number-is-nan": {
+                          "version": "1.0.0",
+                          "from": "number-is-nan@>=1.0.0 <2.0.0",
+                          "resolved": "https://registry.npmjs.org/number-is-nan/-/number-is-nan-1.0.0.tgz"
                         }
                       }
                     },
-                    "inherits": {
-                      "version": "2.0.1",
-                      "from": "https://registry.npmjs.org/inherits/-/inherits-2.0.1.tgz",
-                      "resolved": "https://registry.npmjs.org/inherits/-/inherits-2.0.1.tgz"
+                    "is-fullwidth-code-point": {
+                      "version": "1.0.0",
+                      "from": "is-fullwidth-code-point@>=1.0.0 <2.0.0",
+                      "resolved": "https://registry.npmjs.org/is-fullwidth-code-point/-/is-fullwidth-code-point-1.0.0.tgz",
+                      "dependencies": {
+                        "number-is-nan": {
+                          "version": "1.0.0",
+                          "from": "number-is-nan@>=1.0.0 <2.0.0",
+                          "resolved": "https://registry.npmjs.org/number-is-nan/-/number-is-nan-1.0.0.tgz"
+                        }
+                      }
                     },
+                    "mute-stream": {
+                      "version": "0.0.5",
+                      "from": "mute-stream@0.0.5",
+                      "resolved": "https://registry.npmjs.org/mute-stream/-/mute-stream-0.0.5.tgz"
+                    }
+                  }
+                },
+                "run-async": {
+                  "version": "0.1.0",
+                  "from": "run-async@>=0.1.0 <0.2.0",
+                  "resolved": "https://registry.npmjs.org/run-async/-/run-async-0.1.0.tgz",
+                  "dependencies": {
                     "once": {
                       "version": "1.3.3",
-                      "from": "https://registry.npmjs.org/once/-/once-1.3.3.tgz",
+                      "from": "once@>=1.3.0 <2.0.0",
                       "resolved": "https://registry.npmjs.org/once/-/once-1.3.3.tgz",
                       "dependencies": {
                         "wrappy": {
-                          "version": "1.0.1",
-                          "from": "https://registry.npmjs.org/wrappy/-/wrappy-1.0.1.tgz",
-                          "resolved": "https://registry.npmjs.org/wrappy/-/wrappy-1.0.1.tgz"
+                          "version": "1.0.2",
+                          "from": "wrappy@>=1.0.0 <2.0.0",
+                          "resolved": "https://registry.npmjs.org/wrappy/-/wrappy-1.0.2.tgz"
                         }
                       }
                     }
                   }
                 },
-                "minimatch": {
-                  "version": "2.0.10",
-                  "from": "https://registry.npmjs.org/minimatch/-/minimatch-2.0.10.tgz",
-                  "resolved": "https://registry.npmjs.org/minimatch/-/minimatch-2.0.10.tgz",
+                "rx-lite": {
+                  "version": "3.1.2",
+                  "from": "rx-lite@>=3.1.2 <4.0.0",
+                  "resolved": "https://registry.npmjs.org/rx-lite/-/rx-lite-3.1.2.tgz"
+                },
+                "string-width": {
+                  "version": "1.0.1",
+                  "from": "string-width@>=1.0.1 <2.0.0",
+                  "resolved": "https://registry.npmjs.org/string-width/-/string-width-1.0.1.tgz",
                   "dependencies": {
-                    "brace-expansion": {
-                      "version": "1.1.4",
-                      "from": "https://registry.npmjs.org/brace-expansion/-/brace-expansion-1.1.4.tgz",
-                      "resolved": "https://registry.npmjs.org/brace-expansion/-/brace-expansion-1.1.4.tgz",
+                    "code-point-at": {
+                      "version": "1.0.0",
+                      "from": "code-point-at@>=1.0.0 <2.0.0",
+                      "resolved": "https://registry.npmjs.org/code-point-at/-/code-point-at-1.0.0.tgz",
                       "dependencies": {
-                        "balanced-match": {
-                          "version": "0.4.1",
-                          "from": "https://registry.npmjs.org/balanced-match/-/balanced-match-0.4.1.tgz",
-                          "resolved": "https://registry.npmjs.org/balanced-match/-/balanced-match-0.4.1.tgz"
-                        },
-                        "concat-map": {
-                          "version": "0.0.1",
-                          "from": "https://registry.npmjs.org/concat-map/-/concat-map-0.0.1.tgz",
-                          "resolved": "https://registry.npmjs.org/concat-map/-/concat-map-0.0.1.tgz"
+                        "number-is-nan": {
+                          "version": "1.0.0",
+                          "from": "number-is-nan@>=1.0.0 <2.0.0",
+                          "resolved": "https://registry.npmjs.org/number-is-nan/-/number-is-nan-1.0.0.tgz"
+                        }
+                      }
+                    },
+                    "is-fullwidth-code-point": {
+                      "version": "1.0.0",
+                      "from": "is-fullwidth-code-point@>=1.0.0 <2.0.0",
+                      "resolved": "https://registry.npmjs.org/is-fullwidth-code-point/-/is-fullwidth-code-point-1.0.0.tgz",
+                      "dependencies": {
+                        "number-is-nan": {
+                          "version": "1.0.0",
+                          "from": "number-is-nan@>=1.0.0 <2.0.0",
+                          "resolved": "https://registry.npmjs.org/number-is-nan/-/number-is-nan-1.0.0.tgz"
                         }
                       }
                     }
                   }
                 },
-                "ordered-read-streams": {
-                  "version": "0.1.0",
-                  "from": "https://registry.npmjs.org/ordered-read-streams/-/ordered-read-streams-0.1.0.tgz",
-                  "resolved": "https://registry.npmjs.org/ordered-read-streams/-/ordered-read-streams-0.1.0.tgz"
+                "strip-ansi": {
+                  "version": "3.0.1",
+                  "from": "strip-ansi@>=3.0.0 <4.0.0",
+                  "resolved": "https://registry.npmjs.org/strip-ansi/-/strip-ansi-3.0.1.tgz"
                 },
-                "glob2base": {
-                  "version": "0.0.12",
-                  "from": "https://registry.npmjs.org/glob2base/-/glob2base-0.0.12.tgz",
-                  "resolved": "https://registry.npmjs.org/glob2base/-/glob2base-0.0.12.tgz",
+                "through": {
+                  "version": "2.3.8",
+                  "from": "through@>=2.3.6 <3.0.0",
+                  "resolved": "https://registry.npmjs.org/through/-/through-2.3.8.tgz"
+                }
+              }
+            },
+            "is-my-json-valid": {
+              "version": "2.13.1",
+              "from": "is-my-json-valid@>=2.10.0 <3.0.0",
+              "resolved": "https://registry.npmjs.org/is-my-json-valid/-/is-my-json-valid-2.13.1.tgz",
+              "dependencies": {
+                "generate-function": {
+                  "version": "2.0.0",
+                  "from": "generate-function@>=2.0.0 <3.0.0",
+                  "resolved": "https://registry.npmjs.org/generate-function/-/generate-function-2.0.0.tgz"
+                },
+                "generate-object-property": {
+                  "version": "1.2.0",
+                  "from": "generate-object-property@>=1.1.0 <2.0.0",
+                  "resolved": "https://registry.npmjs.org/generate-object-property/-/generate-object-property-1.2.0.tgz",
                   "dependencies": {
-                    "find-index": {
-                      "version": "0.1.1",
-                      "from": "https://registry.npmjs.org/find-index/-/find-index-0.1.1.tgz",
-                      "resolved": "https://registry.npmjs.org/find-index/-/find-index-0.1.1.tgz"
+                    "is-property": {
+                      "version": "1.0.2",
+                      "from": "is-property@>=1.0.0 <2.0.0",
+                      "resolved": "https://registry.npmjs.org/is-property/-/is-property-1.0.2.tgz"
                     }
                   }
                 },
-                "unique-stream": {
-                  "version": "1.0.0",
-                  "from": "https://registry.npmjs.org/unique-stream/-/unique-stream-1.0.0.tgz",
-                  "resolved": "https://registry.npmjs.org/unique-stream/-/unique-stream-1.0.0.tgz"
+                "jsonpointer": {
+                  "version": "2.0.0",
+                  "from": "jsonpointer@2.0.0",
+                  "resolved": "https://registry.npmjs.org/jsonpointer/-/jsonpointer-2.0.0.tgz"
+                },
+                "xtend": {
+                  "version": "4.0.1",
+                  "from": "xtend@>=4.0.0 <5.0.0",
+                  "resolved": "https://registry.npmjs.org/xtend/-/xtend-4.0.1.tgz"
                 }
               }
             },
-            "glob-watcher": {
-              "version": "0.0.6",
-              "from": "https://registry.npmjs.org/glob-watcher/-/glob-watcher-0.0.6.tgz",
-              "resolved": "https://registry.npmjs.org/glob-watcher/-/glob-watcher-0.0.6.tgz",
+            "is-resolvable": {
+              "version": "1.0.0",
+              "from": "is-resolvable@>=1.0.0 <2.0.0",
+              "resolved": "https://registry.npmjs.org/is-resolvable/-/is-resolvable-1.0.0.tgz",
               "dependencies": {
-                "gaze": {
-                  "version": "0.5.2",
-                  "from": "https://registry.npmjs.org/gaze/-/gaze-0.5.2.tgz",
-                  "resolved": "https://registry.npmjs.org/gaze/-/gaze-0.5.2.tgz",
+                "tryit": {
+                  "version": "1.0.2",
+                  "from": "tryit@>=1.0.1 <2.0.0",
+                  "resolved": "https://registry.npmjs.org/tryit/-/tryit-1.0.2.tgz"
+                }
+              }
+            },
+            "js-yaml": {
+              "version": "3.6.1",
+              "from": "js-yaml@>=3.5.1 <4.0.0",
+              "resolved": "https://registry.npmjs.org/js-yaml/-/js-yaml-3.6.1.tgz",
+              "dependencies": {
+                "argparse": {
+                  "version": "1.0.7",
+                  "from": "argparse@>=1.0.7 <2.0.0",
+                  "resolved": "https://registry.npmjs.org/argparse/-/argparse-1.0.7.tgz",
                   "dependencies": {
-                    "globule": {
-                      "version": "0.1.0",
-                      "from": "https://registry.npmjs.org/globule/-/globule-0.1.0.tgz",
-                      "resolved": "https://registry.npmjs.org/globule/-/globule-0.1.0.tgz",
-                      "dependencies": {
-                        "lodash": {
-                          "version": "1.0.2",
-                          "from": "https://registry.npmjs.org/lodash/-/lodash-1.0.2.tgz",
-                          "resolved": "https://registry.npmjs.org/lodash/-/lodash-1.0.2.tgz"
-                        },
-                        "glob": {
-                          "version": "3.1.21",
-                          "from": "https://registry.npmjs.org/glob/-/glob-3.1.21.tgz",
-                          "resolved": "https://registry.npmjs.org/glob/-/glob-3.1.21.tgz",
-                          "dependencies": {
-                            "graceful-fs": {
-                              "version": "1.2.3",
-                              "from": "https://registry.npmjs.org/graceful-fs/-/graceful-fs-1.2.3.tgz",
-                              "resolved": "https://registry.npmjs.org/graceful-fs/-/graceful-fs-1.2.3.tgz"
-                            },
-                            "inherits": {
-                              "version": "1.0.2",
-                              "from": "https://registry.npmjs.org/inherits/-/inherits-1.0.2.tgz",
-                              "resolved": "https://registry.npmjs.org/inherits/-/inherits-1.0.2.tgz"
-                            }
-                          }
-                        },
-                        "minimatch": {
-                          "version": "0.2.14",
-                          "from": "https://registry.npmjs.org/minimatch/-/minimatch-0.2.14.tgz",
-                          "resolved": "https://registry.npmjs.org/minimatch/-/minimatch-0.2.14.tgz",
-                          "dependencies": {
-                            "lru-cache": {
-                              "version": "2.7.3",
-                              "from": "https://registry.npmjs.org/lru-cache/-/lru-cache-2.7.3.tgz",
-                              "resolved": "https://registry.npmjs.org/lru-cache/-/lru-cache-2.7.3.tgz"
-                            },
-                            "sigmund": {
-                              "version": "1.0.1",
-                              "from": "https://registry.npmjs.org/sigmund/-/sigmund-1.0.1.tgz",
-                              "resolved": "https://registry.npmjs.org/sigmund/-/sigmund-1.0.1.tgz"
-                            }
-                          }
-                        }
-                      }
+                    "sprintf-js": {
+                      "version": "1.0.3",
+                      "from": "sprintf-js@>=1.0.2 <1.1.0",
+                      "resolved": "https://registry.npmjs.org/sprintf-js/-/sprintf-js-1.0.3.tgz"
                     }
                   }
+                },
+                "esprima": {
+                  "version": "2.7.2",
+                  "from": "esprima@>=2.6.0 <3.0.0",
+                  "resolved": "https://registry.npmjs.org/esprima/-/esprima-2.7.2.tgz"
                 }
               }
             },
-            "graceful-fs": {
-              "version": "3.0.8",
-              "from": "https://registry.npmjs.org/graceful-fs/-/graceful-fs-3.0.8.tgz",
-              "resolved": "https://registry.npmjs.org/graceful-fs/-/graceful-fs-3.0.8.tgz"
+            "json-stable-stringify": {
+              "version": "1.0.1",
+              "from": "json-stable-stringify@>=1.0.0 <2.0.0",
+              "resolved": "https://registry.npmjs.org/json-stable-stringify/-/json-stable-stringify-1.0.1.tgz",
+              "dependencies": {
+                "jsonify": {
+                  "version": "0.0.0",
+                  "from": "jsonify@>=0.0.0 <0.1.0",
+                  "resolved": "https://registry.npmjs.org/jsonify/-/jsonify-0.0.0.tgz"
+                }
+              }
+            },
+            "levn": {
+              "version": "0.3.0",
+              "from": "levn@>=0.3.0 <0.4.0",
+              "resolved": "https://registry.npmjs.org/levn/-/levn-0.3.0.tgz",
+              "dependencies": {
+                "prelude-ls": {
+                  "version": "1.1.2",
+                  "from": "prelude-ls@>=1.1.2 <1.2.0",
+                  "resolved": "https://registry.npmjs.org/prelude-ls/-/prelude-ls-1.1.2.tgz"
+                },
+                "type-check": {
+                  "version": "0.3.2",
+                  "from": "type-check@>=0.3.2 <0.4.0",
+                  "resolved": "https://registry.npmjs.org/type-check/-/type-check-0.3.2.tgz"
+                }
+              }
+            },
+            "lodash": {
+              "version": "4.14.1",
+              "from": "lodash@>=4.0.0 <5.0.0",
+              "resolved": "https://registry.npmjs.org/lodash/-/lodash-4.14.1.tgz"
             },
             "mkdirp": {
               "version": "0.5.1",
-              "from": "https://registry.npmjs.org/mkdirp/-/mkdirp-0.5.1.tgz",
+              "from": "mkdirp@>=0.5.0 <0.6.0",
               "resolved": "https://registry.npmjs.org/mkdirp/-/mkdirp-0.5.1.tgz",
               "dependencies": {
                 "minimist": {
                   "version": "0.0.8",
-                  "from": "https://registry.npmjs.org/minimist/-/minimist-0.0.8.tgz",
+                  "from": "minimist@0.0.8",
                   "resolved": "https://registry.npmjs.org/minimist/-/minimist-0.0.8.tgz"
                 }
               }
             },
-            "strip-bom": {
-              "version": "1.0.0",
-              "from": "https://registry.npmjs.org/strip-bom/-/strip-bom-1.0.0.tgz",
-              "resolved": "https://registry.npmjs.org/strip-bom/-/strip-bom-1.0.0.tgz",
+            "optionator": {
+              "version": "0.8.1",
+              "from": "optionator@>=0.8.1 <0.9.0",
+              "resolved": "https://registry.npmjs.org/optionator/-/optionator-0.8.1.tgz",
               "dependencies": {
-                "first-chunk-stream": {
-                  "version": "1.0.0",
-                  "from": "https://registry.npmjs.org/first-chunk-stream/-/first-chunk-stream-1.0.0.tgz",
-                  "resolved": "https://registry.npmjs.org/first-chunk-stream/-/first-chunk-stream-1.0.0.tgz"
+                "prelude-ls": {
+                  "version": "1.1.2",
+                  "from": "prelude-ls@>=1.1.2 <1.2.0",
+                  "resolved": "https://registry.npmjs.org/prelude-ls/-/prelude-ls-1.1.2.tgz"
+                },
+                "deep-is": {
+                  "version": "0.1.3",
+                  "from": "deep-is@>=0.1.3 <0.2.0",
+                  "resolved": "https://registry.npmjs.org/deep-is/-/deep-is-0.1.3.tgz"
+                },
+                "wordwrap": {
+                  "version": "1.0.0",
+                  "from": "wordwrap@>=1.0.0 <1.1.0",
+                  "resolved": "https://registry.npmjs.org/wordwrap/-/wordwrap-1.0.0.tgz"
                 },
-                "is-utf8": {
-                  "version": "0.2.1",
-                  "from": "https://registry.npmjs.org/is-utf8/-/is-utf8-0.2.1.tgz",
-                  "resolved": "https://registry.npmjs.org/is-utf8/-/is-utf8-0.2.1.tgz"
+                "type-check": {
+                  "version": "0.3.2",
+                  "from": "type-check@>=0.3.2 <0.4.0",
+                  "resolved": "https://registry.npmjs.org/type-check/-/type-check-0.3.2.tgz"
+                },
+                "fast-levenshtein": {
+                  "version": "1.1.4",
+                  "from": "fast-levenshtein@>=1.1.0 <2.0.0",
+                  "resolved": "https://registry.npmjs.org/fast-levenshtein/-/fast-levenshtein-1.1.4.tgz"
                 }
               }
             },
-            "through2": {
-              "version": "0.6.5",
-              "from": "https://registry.npmjs.org/through2/-/through2-0.6.5.tgz",
-              "resolved": "https://registry.npmjs.org/through2/-/through2-0.6.5.tgz",
+            "path-is-inside": {
+              "version": "1.0.1",
+              "from": "path-is-inside@>=1.0.1 <2.0.0",
+              "resolved": "https://registry.npmjs.org/path-is-inside/-/path-is-inside-1.0.1.tgz"
+            },
+            "pluralize": {
+              "version": "1.2.1",
+              "from": "pluralize@>=1.2.1 <2.0.0",
+              "resolved": "https://registry.npmjs.org/pluralize/-/pluralize-1.2.1.tgz"
+            },
+            "progress": {
+              "version": "1.1.8",
+              "from": "progress@>=1.1.8 <2.0.0",
+              "resolved": "https://registry.npmjs.org/progress/-/progress-1.1.8.tgz"
+            },
+            "require-uncached": {
+              "version": "1.0.2",
+              "from": "require-uncached@>=1.0.2 <2.0.0",
+              "resolved": "https://registry.npmjs.org/require-uncached/-/require-uncached-1.0.2.tgz",
               "dependencies": {
-                "readable-stream": {
-                  "version": "1.0.34",
-                  "from": "https://registry.npmjs.org/readable-stream/-/readable-stream-1.0.34.tgz",
-                  "resolved": "https://registry.npmjs.org/readable-stream/-/readable-stream-1.0.34.tgz",
+                "caller-path": {
+                  "version": "0.1.0",
+                  "from": "caller-path@>=0.1.0 <0.2.0",
+                  "resolved": "https://registry.npmjs.org/caller-path/-/caller-path-0.1.0.tgz",
                   "dependencies": {
-                    "core-util-is": {
-                      "version": "1.0.2",
-                      "from": "https://registry.npmjs.org/core-util-is/-/core-util-is-1.0.2.tgz",
-                      "resolved": "https://registry.npmjs.org/core-util-is/-/core-util-is-1.0.2.tgz"
-                    },
-                    "isarray": {
-                      "version": "0.0.1",
-                      "from": "https://registry.npmjs.org/isarray/-/isarray-0.0.1.tgz",
-                      "resolved": "https://registry.npmjs.org/isarray/-/isarray-0.0.1.tgz"
-                    },
-                    "string_decoder": {
-                      "version": "0.10.31",
-                      "from": "https://registry.npmjs.org/string_decoder/-/string_decoder-0.10.31.tgz",
-                      "resolved": "https://registry.npmjs.org/string_decoder/-/string_decoder-0.10.31.tgz"
-                    },
-                    "inherits": {
-                      "version": "2.0.1",
-                      "from": "https://registry.npmjs.org/inherits/-/inherits-2.0.1.tgz",
-                      "resolved": "https://registry.npmjs.org/inherits/-/inherits-2.0.1.tgz"
+                    "callsites": {
+                      "version": "0.2.0",
+                      "from": "callsites@>=0.2.0 <0.3.0",
+                      "resolved": "https://registry.npmjs.org/callsites/-/callsites-0.2.0.tgz"
                     }
                   }
                 },
-                "xtend": {
-                  "version": "4.0.1",
-                  "from": "https://registry.npmjs.org/xtend/-/xtend-4.0.1.tgz",
-                  "resolved": "https://registry.npmjs.org/xtend/-/xtend-4.0.1.tgz"
+                "resolve-from": {
+                  "version": "1.0.1",
+                  "from": "resolve-from@>=1.0.0 <2.0.0",
+                  "resolved": "https://registry.npmjs.org/resolve-from/-/resolve-from-1.0.1.tgz"
                 }
               }
             },
-            "vinyl": {
-              "version": "0.4.6",
-              "from": "https://registry.npmjs.org/vinyl/-/vinyl-0.4.6.tgz",
-              "resolved": "https://registry.npmjs.org/vinyl/-/vinyl-0.4.6.tgz",
+            "shelljs": {
+              "version": "0.6.0",
+              "from": "shelljs@>=0.6.0 <0.7.0",
+              "resolved": "https://registry.npmjs.org/shelljs/-/shelljs-0.6.0.tgz"
+            },
+            "strip-bom": {
+              "version": "3.0.0",
+              "from": "strip-bom@>=3.0.0 <4.0.0",
+              "resolved": "https://registry.npmjs.org/strip-bom/-/strip-bom-3.0.0.tgz"
+            },
+            "strip-json-comments": {
+              "version": "1.0.4",
+              "from": "strip-json-comments@>=1.0.1 <1.1.0",
+              "resolved": "https://registry.npmjs.org/strip-json-comments/-/strip-json-comments-1.0.4.tgz"
+            },
+            "table": {
+              "version": "3.7.8",
+              "from": "table@>=3.7.8 <4.0.0",
+              "resolved": "https://registry.npmjs.org/table/-/table-3.7.8.tgz",
               "dependencies": {
-                "clone": {
-                  "version": "0.2.0",
-                  "from": "https://registry.npmjs.org/clone/-/clone-0.2.0.tgz",
-                  "resolved": "https://registry.npmjs.org/clone/-/clone-0.2.0.tgz"
+                "bluebird": {
+                  "version": "3.4.1",
+                  "from": "bluebird@>=3.1.1 <4.0.0",
+                  "resolved": "https://registry.npmjs.org/bluebird/-/bluebird-3.4.1.tgz"
                 },
-                "clone-stats": {
-                  "version": "0.0.1",
-                  "from": "https://registry.npmjs.org/clone-stats/-/clone-stats-0.0.1.tgz",
-                  "resolved": "https://registry.npmjs.org/clone-stats/-/clone-stats-0.0.1.tgz"
-                }
-              }
-            }
-          }
-        }
-      }
-    },
-    "gulp-concat": {
-      "version": "2.6.0",
-      "from": "https://registry.npmjs.org/gulp-concat/-/gulp-concat-2.6.0.tgz",
-      "resolved": "https://registry.npmjs.org/gulp-concat/-/gulp-concat-2.6.0.tgz",
-      "dependencies": {
-        "concat-with-sourcemaps": {
-          "version": "1.0.4",
-          "from": "https://registry.npmjs.org/concat-with-sourcemaps/-/concat-with-sourcemaps-1.0.4.tgz",
-          "resolved": "https://registry.npmjs.org/concat-with-sourcemaps/-/concat-with-sourcemaps-1.0.4.tgz",
-          "dependencies": {
-            "source-map": {
-              "version": "0.5.6",
-              "from": "https://registry.npmjs.org/source-map/-/source-map-0.5.6.tgz",
-              "resolved": "https://registry.npmjs.org/source-map/-/source-map-0.5.6.tgz"
-            }
-          }
-        },
-        "through2": {
-          "version": "0.6.5",
-          "from": "https://registry.npmjs.org/through2/-/through2-0.6.5.tgz",
-          "resolved": "https://registry.npmjs.org/through2/-/through2-0.6.5.tgz",
-          "dependencies": {
-            "readable-stream": {
-              "version": "1.0.34",
-              "from": "https://registry.npmjs.org/readable-stream/-/readable-stream-1.0.34.tgz",
-              "resolved": "https://registry.npmjs.org/readable-stream/-/readable-stream-1.0.34.tgz",
-              "dependencies": {
-                "core-util-is": {
-                  "version": "1.0.2",
-                  "from": "https://registry.npmjs.org/core-util-is/-/core-util-is-1.0.2.tgz",
-                  "resolved": "https://registry.npmjs.org/core-util-is/-/core-util-is-1.0.2.tgz"
+                "slice-ansi": {
+                  "version": "0.0.4",
+                  "from": "slice-ansi@0.0.4",
+                  "resolved": "https://registry.npmjs.org/slice-ansi/-/slice-ansi-0.0.4.tgz"
                 },
-                "isarray": {
-                  "version": "0.0.1",
-                  "from": "https://registry.npmjs.org/isarray/-/isarray-0.0.1.tgz",
-                  "resolved": "https://registry.npmjs.org/isarray/-/isarray-0.0.1.tgz"
+                "string-width": {
+                  "version": "1.0.1",
+                  "from": "string-width@>=1.0.1 <2.0.0",
+                  "resolved": "https://registry.npmjs.org/string-width/-/string-width-1.0.1.tgz",
+                  "dependencies": {
+                    "code-point-at": {
+                      "version": "1.0.0",
+                      "from": "code-point-at@>=1.0.0 <2.0.0",
+                      "resolved": "https://registry.npmjs.org/code-point-at/-/code-point-at-1.0.0.tgz",
+                      "dependencies": {
+                        "number-is-nan": {
+                          "version": "1.0.0",
+                          "from": "number-is-nan@>=1.0.0 <2.0.0",
+                          "resolved": "https://registry.npmjs.org/number-is-nan/-/number-is-nan-1.0.0.tgz"
+                        }
+                      }
+                    },
+                    "is-fullwidth-code-point": {
+                      "version": "1.0.0",
+                      "from": "is-fullwidth-code-point@>=1.0.0 <2.0.0",
+                      "resolved": "https://registry.npmjs.org/is-fullwidth-code-point/-/is-fullwidth-code-point-1.0.0.tgz",
+                      "dependencies": {
+                        "number-is-nan": {
+                          "version": "1.0.0",
+                          "from": "number-is-nan@>=1.0.0 <2.0.0",
+                          "resolved": "https://registry.npmjs.org/number-is-nan/-/number-is-nan-1.0.0.tgz"
+                        }
+                      }
+                    }
+                  }
                 },
-                "string_decoder": {
-                  "version": "0.10.31",
-                  "from": "https://registry.npmjs.org/string_decoder/-/string_decoder-0.10.31.tgz",
-                  "resolved": "https://registry.npmjs.org/string_decoder/-/string_decoder-0.10.31.tgz"
+                "strip-ansi": {
+                  "version": "3.0.1",
+                  "from": "strip-ansi@>=3.0.0 <4.0.0",
+                  "resolved": "https://registry.npmjs.org/strip-ansi/-/strip-ansi-3.0.1.tgz",
+                  "dependencies": {
+                    "ansi-regex": {
+                      "version": "2.0.0",
+                      "from": "ansi-regex@>=2.0.0 <3.0.0",
+                      "resolved": "https://registry.npmjs.org/ansi-regex/-/ansi-regex-2.0.0.tgz"
+                    }
+                  }
                 },
-                "inherits": {
-                  "version": "2.0.1",
-                  "from": "https://registry.npmjs.org/inherits/-/inherits-2.0.1.tgz",
-                  "resolved": "https://registry.npmjs.org/inherits/-/inherits-2.0.1.tgz"
+                "tv4": {
+                  "version": "1.2.7",
+                  "from": "tv4@>=1.2.7 <2.0.0",
+                  "resolved": "https://registry.npmjs.org/tv4/-/tv4-1.2.7.tgz"
+                },
+                "xregexp": {
+                  "version": "3.1.1",
+                  "from": "xregexp@>=3.0.0 <4.0.0",
+                  "resolved": "https://registry.npmjs.org/xregexp/-/xregexp-3.1.1.tgz"
                 }
               }
             },
-            "xtend": {
-              "version": "4.0.1",
-              "from": "https://registry.npmjs.org/xtend/-/xtend-4.0.1.tgz",
-              "resolved": "https://registry.npmjs.org/xtend/-/xtend-4.0.1.tgz"
+            "text-table": {
+              "version": "0.2.0",
+              "from": "text-table@>=0.2.0 <0.3.0",
+              "resolved": "https://registry.npmjs.org/text-table/-/text-table-0.2.0.tgz"
+            },
+            "user-home": {
+              "version": "2.0.0",
+              "from": "user-home@>=2.0.0 <3.0.0",
+              "resolved": "https://registry.npmjs.org/user-home/-/user-home-2.0.0.tgz",
+              "dependencies": {
+                "os-homedir": {
+                  "version": "1.0.1",
+                  "from": "os-homedir@>=1.0.0 <2.0.0",
+                  "resolved": "https://registry.npmjs.org/os-homedir/-/os-homedir-1.0.1.tgz"
+                }
+              }
             }
           }
         }
@@ -8475,144 +9081,38 @@
                       "from": "https://registry.npmjs.org/string_decoder/-/string_decoder-0.10.31.tgz",
                       "resolved": "https://registry.npmjs.org/string_decoder/-/string_decoder-0.10.31.tgz"
                     },
-                    "inherits": {
-                      "version": "2.0.1",
-                      "from": "https://registry.npmjs.org/inherits/-/inherits-2.0.1.tgz",
-                      "resolved": "https://registry.npmjs.org/inherits/-/inherits-2.0.1.tgz"
-                    }
-                  }
-                },
-                "xtend": {
-                  "version": "3.0.0",
-                  "from": "https://registry.npmjs.org/xtend/-/xtend-3.0.0.tgz",
-                  "resolved": "https://registry.npmjs.org/xtend/-/xtend-3.0.0.tgz"
-                }
-              }
-            },
-            "vinyl": {
-              "version": "0.2.3",
-              "from": "https://registry.npmjs.org/vinyl/-/vinyl-0.2.3.tgz",
-              "resolved": "https://registry.npmjs.org/vinyl/-/vinyl-0.2.3.tgz",
-              "dependencies": {
-                "clone-stats": {
-                  "version": "0.0.1",
-                  "from": "https://registry.npmjs.org/clone-stats/-/clone-stats-0.0.1.tgz",
-                  "resolved": "https://registry.npmjs.org/clone-stats/-/clone-stats-0.0.1.tgz"
-                }
-              }
-            }
-          }
-        },
-        "through": {
-          "version": "2.3.8",
-          "from": "https://registry.npmjs.org/through/-/through-2.3.8.tgz",
-          "resolved": "https://registry.npmjs.org/through/-/through-2.3.8.tgz"
-        }
-      }
-    },
-    "gulp-jshint": {
-      "version": "2.0.1",
-      "from": "https://registry.npmjs.org/gulp-jshint/-/gulp-jshint-2.0.1.tgz",
-      "resolved": "https://registry.npmjs.org/gulp-jshint/-/gulp-jshint-2.0.1.tgz",
-      "dependencies": {
-        "lodash": {
-          "version": "4.12.0",
-          "from": "https://registry.npmjs.org/lodash/-/lodash-4.12.0.tgz",
-          "resolved": "https://registry.npmjs.org/lodash/-/lodash-4.12.0.tgz"
-        },
-        "minimatch": {
-          "version": "2.0.10",
-          "from": "https://registry.npmjs.org/minimatch/-/minimatch-2.0.10.tgz",
-          "resolved": "https://registry.npmjs.org/minimatch/-/minimatch-2.0.10.tgz",
-          "dependencies": {
-            "brace-expansion": {
-              "version": "1.1.4",
-              "from": "https://registry.npmjs.org/brace-expansion/-/brace-expansion-1.1.4.tgz",
-              "resolved": "https://registry.npmjs.org/brace-expansion/-/brace-expansion-1.1.4.tgz",
-              "dependencies": {
-                "balanced-match": {
-                  "version": "0.4.1",
-                  "from": "https://registry.npmjs.org/balanced-match/-/balanced-match-0.4.1.tgz",
-                  "resolved": "https://registry.npmjs.org/balanced-match/-/balanced-match-0.4.1.tgz"
-                },
-                "concat-map": {
-                  "version": "0.0.1",
-                  "from": "https://registry.npmjs.org/concat-map/-/concat-map-0.0.1.tgz",
-                  "resolved": "https://registry.npmjs.org/concat-map/-/concat-map-0.0.1.tgz"
-                }
-              }
-            }
-          }
-        },
-        "rcloader": {
-          "version": "0.1.2",
-          "from": "https://registry.npmjs.org/rcloader/-/rcloader-0.1.2.tgz",
-          "resolved": "https://registry.npmjs.org/rcloader/-/rcloader-0.1.2.tgz",
-          "dependencies": {
-            "rcfinder": {
-              "version": "0.1.9",
-              "from": "https://registry.npmjs.org/rcfinder/-/rcfinder-0.1.9.tgz",
-              "resolved": "https://registry.npmjs.org/rcfinder/-/rcfinder-0.1.9.tgz",
-              "dependencies": {
-                "lodash.clonedeep": {
-                  "version": "4.3.2",
-                  "from": "https://registry.npmjs.org/lodash.clonedeep/-/lodash.clonedeep-4.3.2.tgz",
-                  "resolved": "https://registry.npmjs.org/lodash.clonedeep/-/lodash.clonedeep-4.3.2.tgz",
-                  "dependencies": {
-                    "lodash._baseclone": {
-                      "version": "4.5.6",
-                      "from": "https://registry.npmjs.org/lodash._baseclone/-/lodash._baseclone-4.5.6.tgz",
-                      "resolved": "https://registry.npmjs.org/lodash._baseclone/-/lodash._baseclone-4.5.6.tgz"
-                    }
-                  }
-                }
-              }
-            },
-            "lodash": {
-              "version": "2.4.2",
-              "from": "https://registry.npmjs.org/lodash/-/lodash-2.4.2.tgz",
-              "resolved": "https://registry.npmjs.org/lodash/-/lodash-2.4.2.tgz"
-            }
-          }
-        },
-        "through2": {
-          "version": "0.6.5",
-          "from": "https://registry.npmjs.org/through2/-/through2-0.6.5.tgz",
-          "resolved": "https://registry.npmjs.org/through2/-/through2-0.6.5.tgz",
-          "dependencies": {
-            "readable-stream": {
-              "version": "1.0.34",
-              "from": "https://registry.npmjs.org/readable-stream/-/readable-stream-1.0.34.tgz",
-              "resolved": "https://registry.npmjs.org/readable-stream/-/readable-stream-1.0.34.tgz",
-              "dependencies": {
-                "core-util-is": {
-                  "version": "1.0.2",
-                  "from": "https://registry.npmjs.org/core-util-is/-/core-util-is-1.0.2.tgz",
-                  "resolved": "https://registry.npmjs.org/core-util-is/-/core-util-is-1.0.2.tgz"
-                },
-                "isarray": {
-                  "version": "0.0.1",
-                  "from": "https://registry.npmjs.org/isarray/-/isarray-0.0.1.tgz",
-                  "resolved": "https://registry.npmjs.org/isarray/-/isarray-0.0.1.tgz"
-                },
-                "string_decoder": {
-                  "version": "0.10.31",
-                  "from": "https://registry.npmjs.org/string_decoder/-/string_decoder-0.10.31.tgz",
-                  "resolved": "https://registry.npmjs.org/string_decoder/-/string_decoder-0.10.31.tgz"
+                    "inherits": {
+                      "version": "2.0.1",
+                      "from": "https://registry.npmjs.org/inherits/-/inherits-2.0.1.tgz",
+                      "resolved": "https://registry.npmjs.org/inherits/-/inherits-2.0.1.tgz"
+                    }
+                  }
                 },
-                "inherits": {
-                  "version": "2.0.1",
-                  "from": "https://registry.npmjs.org/inherits/-/inherits-2.0.1.tgz",
-                  "resolved": "https://registry.npmjs.org/inherits/-/inherits-2.0.1.tgz"
+                "xtend": {
+                  "version": "3.0.0",
+                  "from": "https://registry.npmjs.org/xtend/-/xtend-3.0.0.tgz",
+                  "resolved": "https://registry.npmjs.org/xtend/-/xtend-3.0.0.tgz"
                 }
               }
             },
-            "xtend": {
-              "version": "4.0.1",
-              "from": "https://registry.npmjs.org/xtend/-/xtend-4.0.1.tgz",
-              "resolved": "https://registry.npmjs.org/xtend/-/xtend-4.0.1.tgz"
+            "vinyl": {
+              "version": "0.2.3",
+              "from": "https://registry.npmjs.org/vinyl/-/vinyl-0.2.3.tgz",
+              "resolved": "https://registry.npmjs.org/vinyl/-/vinyl-0.2.3.tgz",
+              "dependencies": {
+                "clone-stats": {
+                  "version": "0.0.1",
+                  "from": "https://registry.npmjs.org/clone-stats/-/clone-stats-0.0.1.tgz",
+                  "resolved": "https://registry.npmjs.org/clone-stats/-/clone-stats-0.0.1.tgz"
+                }
+              }
             }
           }
+        },
+        "through": {
+          "version": "2.3.8",
+          "from": "https://registry.npmjs.org/through/-/through-2.3.8.tgz",
+          "resolved": "https://registry.npmjs.org/through/-/through-2.3.8.tgz"
         }
       }
     },
@@ -9781,388 +10281,122 @@
         }
       }
     },
-    "jshint": {
-      "version": "2.9.2",
-      "from": "https://registry.npmjs.org/jshint/-/jshint-2.9.2.tgz",
-      "resolved": "https://registry.npmjs.org/jshint/-/jshint-2.9.2.tgz",
-      "dependencies": {
-        "cli": {
-          "version": "0.6.6",
-          "from": "https://registry.npmjs.org/cli/-/cli-0.6.6.tgz",
-          "resolved": "https://registry.npmjs.org/cli/-/cli-0.6.6.tgz",
-          "dependencies": {
-            "glob": {
-              "version": "3.2.11",
-              "from": "https://registry.npmjs.org/glob/-/glob-3.2.11.tgz",
-              "resolved": "https://registry.npmjs.org/glob/-/glob-3.2.11.tgz",
-              "dependencies": {
-                "inherits": {
-                  "version": "2.0.1",
-                  "from": "https://registry.npmjs.org/inherits/-/inherits-2.0.1.tgz",
-                  "resolved": "https://registry.npmjs.org/inherits/-/inherits-2.0.1.tgz"
-                },
-                "minimatch": {
-                  "version": "0.3.0",
-                  "from": "https://registry.npmjs.org/minimatch/-/minimatch-0.3.0.tgz",
-                  "resolved": "https://registry.npmjs.org/minimatch/-/minimatch-0.3.0.tgz",
-                  "dependencies": {
-                    "lru-cache": {
-                      "version": "2.7.3",
-                      "from": "https://registry.npmjs.org/lru-cache/-/lru-cache-2.7.3.tgz",
-                      "resolved": "https://registry.npmjs.org/lru-cache/-/lru-cache-2.7.3.tgz"
-                    },
-                    "sigmund": {
-                      "version": "1.0.1",
-                      "from": "https://registry.npmjs.org/sigmund/-/sigmund-1.0.1.tgz",
-                      "resolved": "https://registry.npmjs.org/sigmund/-/sigmund-1.0.1.tgz"
-                    }
-                  }
-                }
-              }
-            }
-          }
-        },
-        "console-browserify": {
-          "version": "1.1.0",
-          "from": "https://registry.npmjs.org/console-browserify/-/console-browserify-1.1.0.tgz",
-          "resolved": "https://registry.npmjs.org/console-browserify/-/console-browserify-1.1.0.tgz",
-          "dependencies": {
-            "date-now": {
-              "version": "0.1.4",
-              "from": "https://registry.npmjs.org/date-now/-/date-now-0.1.4.tgz",
-              "resolved": "https://registry.npmjs.org/date-now/-/date-now-0.1.4.tgz"
-            }
-          }
-        },
-        "exit": {
-          "version": "0.1.2",
-          "from": "https://registry.npmjs.org/exit/-/exit-0.1.2.tgz",
-          "resolved": "https://registry.npmjs.org/exit/-/exit-0.1.2.tgz"
-        },
-        "htmlparser2": {
-          "version": "3.8.3",
-          "from": "https://registry.npmjs.org/htmlparser2/-/htmlparser2-3.8.3.tgz",
-          "resolved": "https://registry.npmjs.org/htmlparser2/-/htmlparser2-3.8.3.tgz",
-          "dependencies": {
-            "domhandler": {
-              "version": "2.3.0",
-              "from": "https://registry.npmjs.org/domhandler/-/domhandler-2.3.0.tgz",
-              "resolved": "https://registry.npmjs.org/domhandler/-/domhandler-2.3.0.tgz"
-            },
-            "domutils": {
-              "version": "1.5.1",
-              "from": "https://registry.npmjs.org/domutils/-/domutils-1.5.1.tgz",
-              "resolved": "https://registry.npmjs.org/domutils/-/domutils-1.5.1.tgz",
-              "dependencies": {
-                "dom-serializer": {
-                  "version": "0.1.0",
-                  "from": "https://registry.npmjs.org/dom-serializer/-/dom-serializer-0.1.0.tgz",
-                  "resolved": "https://registry.npmjs.org/dom-serializer/-/dom-serializer-0.1.0.tgz",
-                  "dependencies": {
-                    "domelementtype": {
-                      "version": "1.1.3",
-                      "from": "https://registry.npmjs.org/domelementtype/-/domelementtype-1.1.3.tgz",
-                      "resolved": "https://registry.npmjs.org/domelementtype/-/domelementtype-1.1.3.tgz"
-                    },
-                    "entities": {
-                      "version": "1.1.1",
-                      "from": "https://registry.npmjs.org/entities/-/entities-1.1.1.tgz",
-                      "resolved": "https://registry.npmjs.org/entities/-/entities-1.1.1.tgz"
-                    }
-                  }
-                }
-              }
-            },
-            "domelementtype": {
-              "version": "1.3.0",
-              "from": "https://registry.npmjs.org/domelementtype/-/domelementtype-1.3.0.tgz",
-              "resolved": "https://registry.npmjs.org/domelementtype/-/domelementtype-1.3.0.tgz"
-            },
-            "readable-stream": {
-              "version": "1.1.14",
-              "from": "https://registry.npmjs.org/readable-stream/-/readable-stream-1.1.14.tgz",
-              "resolved": "https://registry.npmjs.org/readable-stream/-/readable-stream-1.1.14.tgz",
-              "dependencies": {
-                "core-util-is": {
-                  "version": "1.0.2",
-                  "from": "https://registry.npmjs.org/core-util-is/-/core-util-is-1.0.2.tgz",
-                  "resolved": "https://registry.npmjs.org/core-util-is/-/core-util-is-1.0.2.tgz"
-                },
-                "isarray": {
-                  "version": "0.0.1",
-                  "from": "https://registry.npmjs.org/isarray/-/isarray-0.0.1.tgz",
-                  "resolved": "https://registry.npmjs.org/isarray/-/isarray-0.0.1.tgz"
-                },
-                "string_decoder": {
-                  "version": "0.10.31",
-                  "from": "https://registry.npmjs.org/string_decoder/-/string_decoder-0.10.31.tgz",
-                  "resolved": "https://registry.npmjs.org/string_decoder/-/string_decoder-0.10.31.tgz"
-                },
-                "inherits": {
-                  "version": "2.0.1",
-                  "from": "https://registry.npmjs.org/inherits/-/inherits-2.0.1.tgz",
-                  "resolved": "https://registry.npmjs.org/inherits/-/inherits-2.0.1.tgz"
-                }
-              }
-            },
-            "entities": {
-              "version": "1.0.0",
-              "from": "https://registry.npmjs.org/entities/-/entities-1.0.0.tgz",
-              "resolved": "https://registry.npmjs.org/entities/-/entities-1.0.0.tgz"
-            }
-          }
-        },
-        "minimatch": {
-          "version": "2.0.10",
-          "from": "https://registry.npmjs.org/minimatch/-/minimatch-2.0.10.tgz",
-          "resolved": "https://registry.npmjs.org/minimatch/-/minimatch-2.0.10.tgz",
-          "dependencies": {
-            "brace-expansion": {
-              "version": "1.1.4",
-              "from": "https://registry.npmjs.org/brace-expansion/-/brace-expansion-1.1.4.tgz",
-              "resolved": "https://registry.npmjs.org/brace-expansion/-/brace-expansion-1.1.4.tgz",
-              "dependencies": {
-                "balanced-match": {
-                  "version": "0.4.1",
-                  "from": "https://registry.npmjs.org/balanced-match/-/balanced-match-0.4.1.tgz",
-                  "resolved": "https://registry.npmjs.org/balanced-match/-/balanced-match-0.4.1.tgz"
-                },
-                "concat-map": {
-                  "version": "0.0.1",
-                  "from": "https://registry.npmjs.org/concat-map/-/concat-map-0.0.1.tgz",
-                  "resolved": "https://registry.npmjs.org/concat-map/-/concat-map-0.0.1.tgz"
-                }
-              }
-            }
-          }
-        },
-        "strip-json-comments": {
-          "version": "1.0.4",
-          "from": "https://registry.npmjs.org/strip-json-comments/-/strip-json-comments-1.0.4.tgz",
-          "resolved": "https://registry.npmjs.org/strip-json-comments/-/strip-json-comments-1.0.4.tgz"
-        },
-        "lodash": {
-          "version": "3.7.0",
-          "from": "https://registry.npmjs.org/lodash/-/lodash-3.7.0.tgz",
-          "resolved": "https://registry.npmjs.org/lodash/-/lodash-3.7.0.tgz"
-        }
-      }
-    },
-    "jshint-stylish": {
-      "version": "2.2.0",
-      "from": "https://registry.npmjs.org/jshint-stylish/-/jshint-stylish-2.2.0.tgz",
-      "resolved": "https://registry.npmjs.org/jshint-stylish/-/jshint-stylish-2.2.0.tgz",
-      "dependencies": {
-        "chalk": {
-          "version": "1.1.3",
-          "from": "https://registry.npmjs.org/chalk/-/chalk-1.1.3.tgz",
-          "resolved": "https://registry.npmjs.org/chalk/-/chalk-1.1.3.tgz",
-          "dependencies": {
-            "ansi-styles": {
-              "version": "2.2.1",
-              "from": "https://registry.npmjs.org/ansi-styles/-/ansi-styles-2.2.1.tgz",
-              "resolved": "https://registry.npmjs.org/ansi-styles/-/ansi-styles-2.2.1.tgz"
-            },
-            "escape-string-regexp": {
-              "version": "1.0.5",
-              "from": "https://registry.npmjs.org/escape-string-regexp/-/escape-string-regexp-1.0.5.tgz",
-              "resolved": "https://registry.npmjs.org/escape-string-regexp/-/escape-string-regexp-1.0.5.tgz"
-            },
-            "has-ansi": {
-              "version": "2.0.0",
-              "from": "https://registry.npmjs.org/has-ansi/-/has-ansi-2.0.0.tgz",
-              "resolved": "https://registry.npmjs.org/has-ansi/-/has-ansi-2.0.0.tgz",
-              "dependencies": {
-                "ansi-regex": {
-                  "version": "2.0.0",
-                  "from": "https://registry.npmjs.org/ansi-regex/-/ansi-regex-2.0.0.tgz",
-                  "resolved": "https://registry.npmjs.org/ansi-regex/-/ansi-regex-2.0.0.tgz"
-                }
-              }
-            },
-            "strip-ansi": {
-              "version": "3.0.1",
-              "from": "https://registry.npmjs.org/strip-ansi/-/strip-ansi-3.0.1.tgz",
-              "resolved": "https://registry.npmjs.org/strip-ansi/-/strip-ansi-3.0.1.tgz",
-              "dependencies": {
-                "ansi-regex": {
-                  "version": "2.0.0",
-                  "from": "https://registry.npmjs.org/ansi-regex/-/ansi-regex-2.0.0.tgz",
-                  "resolved": "https://registry.npmjs.org/ansi-regex/-/ansi-regex-2.0.0.tgz"
-                }
-              }
-            },
-            "supports-color": {
-              "version": "2.0.0",
-              "from": "https://registry.npmjs.org/supports-color/-/supports-color-2.0.0.tgz",
-              "resolved": "https://registry.npmjs.org/supports-color/-/supports-color-2.0.0.tgz"
-            }
-          }
-        },
-        "log-symbols": {
-          "version": "1.0.2",
-          "from": "https://registry.npmjs.org/log-symbols/-/log-symbols-1.0.2.tgz",
-          "resolved": "https://registry.npmjs.org/log-symbols/-/log-symbols-1.0.2.tgz"
-        },
-        "plur": {
-          "version": "2.1.2",
-          "from": "https://registry.npmjs.org/plur/-/plur-2.1.2.tgz",
-          "resolved": "https://registry.npmjs.org/plur/-/plur-2.1.2.tgz",
-          "dependencies": {
-            "irregular-plurals": {
-              "version": "1.1.0",
-              "from": "https://registry.npmjs.org/irregular-plurals/-/irregular-plurals-1.1.0.tgz",
-              "resolved": "https://registry.npmjs.org/irregular-plurals/-/irregular-plurals-1.1.0.tgz"
-            }
-          }
-        },
-        "string-length": {
-          "version": "1.0.1",
-          "from": "https://registry.npmjs.org/string-length/-/string-length-1.0.1.tgz",
-          "resolved": "https://registry.npmjs.org/string-length/-/string-length-1.0.1.tgz",
-          "dependencies": {
-            "strip-ansi": {
-              "version": "3.0.1",
-              "from": "https://registry.npmjs.org/strip-ansi/-/strip-ansi-3.0.1.tgz",
-              "resolved": "https://registry.npmjs.org/strip-ansi/-/strip-ansi-3.0.1.tgz",
-              "dependencies": {
-                "ansi-regex": {
-                  "version": "2.0.0",
-                  "from": "https://registry.npmjs.org/ansi-regex/-/ansi-regex-2.0.0.tgz",
-                  "resolved": "https://registry.npmjs.org/ansi-regex/-/ansi-regex-2.0.0.tgz"
-                }
-              }
-            }
-          }
-        },
-        "text-table": {
-          "version": "0.2.0",
-          "from": "https://registry.npmjs.org/text-table/-/text-table-0.2.0.tgz",
-          "resolved": "https://registry.npmjs.org/text-table/-/text-table-0.2.0.tgz"
-        },
-        "beeper": {
-          "version": "1.1.0",
-          "from": "https://registry.npmjs.org/beeper/-/beeper-1.1.0.tgz",
-          "resolved": "https://registry.npmjs.org/beeper/-/beeper-1.1.0.tgz"
-        }
-      }
-    },
     "karma": {
       "version": "1.1.2",
-      "from": "karma@1.1.2",
+      "from": "https://registry.npmjs.org/karma/-/karma-1.1.2.tgz",
       "resolved": "https://registry.npmjs.org/karma/-/karma-1.1.2.tgz",
       "dependencies": {
         "bluebird": {
           "version": "3.4.1",
-          "from": "bluebird@>=3.3.0 <4.0.0",
+          "from": "https://registry.npmjs.org/bluebird/-/bluebird-3.4.1.tgz",
           "resolved": "https://registry.npmjs.org/bluebird/-/bluebird-3.4.1.tgz"
         },
         "body-parser": {
           "version": "1.15.2",
-          "from": "body-parser@>=1.12.4 <2.0.0",
+          "from": "https://registry.npmjs.org/body-parser/-/body-parser-1.15.2.tgz",
           "resolved": "https://registry.npmjs.org/body-parser/-/body-parser-1.15.2.tgz",
           "dependencies": {
             "bytes": {
               "version": "2.4.0",
-              "from": "bytes@2.4.0",
+              "from": "https://registry.npmjs.org/bytes/-/bytes-2.4.0.tgz",
               "resolved": "https://registry.npmjs.org/bytes/-/bytes-2.4.0.tgz"
             },
             "content-type": {
               "version": "1.0.2",
-              "from": "content-type@>=1.0.2 <1.1.0",
+              "from": "https://registry.npmjs.org/content-type/-/content-type-1.0.2.tgz",
               "resolved": "https://registry.npmjs.org/content-type/-/content-type-1.0.2.tgz"
             },
             "debug": {
               "version": "2.2.0",
-              "from": "debug@>=2.2.0 <2.3.0",
+              "from": "https://registry.npmjs.org/debug/-/debug-2.2.0.tgz",
               "resolved": "https://registry.npmjs.org/debug/-/debug-2.2.0.tgz",
               "dependencies": {
                 "ms": {
                   "version": "0.7.1",
-                  "from": "ms@0.7.1",
+                  "from": "https://registry.npmjs.org/ms/-/ms-0.7.1.tgz",
                   "resolved": "https://registry.npmjs.org/ms/-/ms-0.7.1.tgz"
                 }
               }
             },
             "depd": {
               "version": "1.1.0",
-              "from": "depd@>=1.1.0 <1.2.0",
+              "from": "https://registry.npmjs.org/depd/-/depd-1.1.0.tgz",
               "resolved": "https://registry.npmjs.org/depd/-/depd-1.1.0.tgz"
             },
             "http-errors": {
               "version": "1.5.0",
-              "from": "http-errors@>=1.5.0 <1.6.0",
+              "from": "https://registry.npmjs.org/http-errors/-/http-errors-1.5.0.tgz",
               "resolved": "https://registry.npmjs.org/http-errors/-/http-errors-1.5.0.tgz",
               "dependencies": {
                 "inherits": {
                   "version": "2.0.1",
-                  "from": "inherits@2.0.1",
+                  "from": "https://registry.npmjs.org/inherits/-/inherits-2.0.1.tgz",
                   "resolved": "https://registry.npmjs.org/inherits/-/inherits-2.0.1.tgz"
                 },
                 "setprototypeof": {
                   "version": "1.0.1",
-                  "from": "setprototypeof@1.0.1",
+                  "from": "https://registry.npmjs.org/setprototypeof/-/setprototypeof-1.0.1.tgz",
                   "resolved": "https://registry.npmjs.org/setprototypeof/-/setprototypeof-1.0.1.tgz"
                 },
                 "statuses": {
                   "version": "1.3.0",
-                  "from": "statuses@>=1.3.0 <2.0.0",
+                  "from": "https://registry.npmjs.org/statuses/-/statuses-1.3.0.tgz",
                   "resolved": "https://registry.npmjs.org/statuses/-/statuses-1.3.0.tgz"
                 }
               }
             },
             "iconv-lite": {
               "version": "0.4.13",
-              "from": "iconv-lite@0.4.13",
+              "from": "https://registry.npmjs.org/iconv-lite/-/iconv-lite-0.4.13.tgz",
               "resolved": "https://registry.npmjs.org/iconv-lite/-/iconv-lite-0.4.13.tgz"
             },
             "on-finished": {
               "version": "2.3.0",
-              "from": "on-finished@>=2.3.0 <2.4.0",
+              "from": "https://registry.npmjs.org/on-finished/-/on-finished-2.3.0.tgz",
               "resolved": "https://registry.npmjs.org/on-finished/-/on-finished-2.3.0.tgz",
               "dependencies": {
                 "ee-first": {
                   "version": "1.1.1",
-                  "from": "ee-first@1.1.1",
+                  "from": "https://registry.npmjs.org/ee-first/-/ee-first-1.1.1.tgz",
                   "resolved": "https://registry.npmjs.org/ee-first/-/ee-first-1.1.1.tgz"
                 }
               }
             },
             "qs": {
               "version": "6.2.0",
-              "from": "qs@6.2.0",
+              "from": "https://registry.npmjs.org/qs/-/qs-6.2.0.tgz",
               "resolved": "https://registry.npmjs.org/qs/-/qs-6.2.0.tgz"
             },
             "raw-body": {
               "version": "2.1.7",
-              "from": "raw-body@>=2.1.7 <2.2.0",
+              "from": "https://registry.npmjs.org/raw-body/-/raw-body-2.1.7.tgz",
               "resolved": "https://registry.npmjs.org/raw-body/-/raw-body-2.1.7.tgz",
               "dependencies": {
                 "unpipe": {
                   "version": "1.0.0",
-                  "from": "unpipe@1.0.0",
+                  "from": "https://registry.npmjs.org/unpipe/-/unpipe-1.0.0.tgz",
                   "resolved": "https://registry.npmjs.org/unpipe/-/unpipe-1.0.0.tgz"
                 }
               }
             },
             "type-is": {
               "version": "1.6.13",
-              "from": "type-is@>=1.6.13 <1.7.0",
+              "from": "https://registry.npmjs.org/type-is/-/type-is-1.6.13.tgz",
               "resolved": "https://registry.npmjs.org/type-is/-/type-is-1.6.13.tgz",
               "dependencies": {
                 "media-typer": {
                   "version": "0.3.0",
-                  "from": "media-typer@0.3.0",
+                  "from": "https://registry.npmjs.org/media-typer/-/media-typer-0.3.0.tgz",
                   "resolved": "https://registry.npmjs.org/media-typer/-/media-typer-0.3.0.tgz"
                 },
                 "mime-types": {
                   "version": "2.1.11",
-                  "from": "mime-types@>=2.1.11 <2.2.0",
+                  "from": "https://registry.npmjs.org/mime-types/-/mime-types-2.1.11.tgz",
                   "resolved": "https://registry.npmjs.org/mime-types/-/mime-types-2.1.11.tgz",
                   "dependencies": {
                     "mime-db": {
                       "version": "1.23.0",
-                      "from": "mime-db@>=1.23.0 <1.24.0",
+                      "from": "https://registry.npmjs.org/mime-db/-/mime-db-1.23.0.tgz",
                       "resolved": "https://registry.npmjs.org/mime-db/-/mime-db-1.23.0.tgz"
                     }
                   }
@@ -10173,81 +10407,81 @@
         },
         "chokidar": {
           "version": "1.6.0",
-          "from": "chokidar@>=1.4.1 <2.0.0",
+          "from": "https://registry.npmjs.org/chokidar/-/chokidar-1.6.0.tgz",
           "resolved": "https://registry.npmjs.org/chokidar/-/chokidar-1.6.0.tgz",
           "dependencies": {
             "anymatch": {
               "version": "1.3.0",
-              "from": "anymatch@>=1.3.0 <2.0.0",
+              "from": "https://registry.npmjs.org/anymatch/-/anymatch-1.3.0.tgz",
               "resolved": "https://registry.npmjs.org/anymatch/-/anymatch-1.3.0.tgz",
               "dependencies": {
                 "arrify": {
                   "version": "1.0.1",
-                  "from": "arrify@>=1.0.0 <2.0.0",
+                  "from": "https://registry.npmjs.org/arrify/-/arrify-1.0.1.tgz",
                   "resolved": "https://registry.npmjs.org/arrify/-/arrify-1.0.1.tgz"
                 },
                 "micromatch": {
                   "version": "2.3.11",
-                  "from": "micromatch@>=2.1.5 <3.0.0",
+                  "from": "https://registry.npmjs.org/micromatch/-/micromatch-2.3.11.tgz",
                   "resolved": "https://registry.npmjs.org/micromatch/-/micromatch-2.3.11.tgz",
                   "dependencies": {
                     "arr-diff": {
                       "version": "2.0.0",
-                      "from": "arr-diff@>=2.0.0 <3.0.0",
+                      "from": "https://registry.npmjs.org/arr-diff/-/arr-diff-2.0.0.tgz",
                       "resolved": "https://registry.npmjs.org/arr-diff/-/arr-diff-2.0.0.tgz",
                       "dependencies": {
                         "arr-flatten": {
                           "version": "1.0.1",
-                          "from": "arr-flatten@>=1.0.1 <2.0.0",
+                          "from": "https://registry.npmjs.org/arr-flatten/-/arr-flatten-1.0.1.tgz",
                           "resolved": "https://registry.npmjs.org/arr-flatten/-/arr-flatten-1.0.1.tgz"
                         }
                       }
                     },
                     "array-unique": {
                       "version": "0.2.1",
-                      "from": "array-unique@>=0.2.1 <0.3.0",
+                      "from": "https://registry.npmjs.org/array-unique/-/array-unique-0.2.1.tgz",
                       "resolved": "https://registry.npmjs.org/array-unique/-/array-unique-0.2.1.tgz"
                     },
                     "braces": {
                       "version": "1.8.5",
-                      "from": "braces@>=1.8.2 <2.0.0",
+                      "from": "https://registry.npmjs.org/braces/-/braces-1.8.5.tgz",
                       "resolved": "https://registry.npmjs.org/braces/-/braces-1.8.5.tgz",
                       "dependencies": {
                         "expand-range": {
                           "version": "1.8.2",
-                          "from": "expand-range@>=1.8.1 <2.0.0",
+                          "from": "https://registry.npmjs.org/expand-range/-/expand-range-1.8.2.tgz",
                           "resolved": "https://registry.npmjs.org/expand-range/-/expand-range-1.8.2.tgz",
                           "dependencies": {
                             "fill-range": {
                               "version": "2.2.3",
-                              "from": "fill-range@>=2.1.0 <3.0.0",
+                              "from": "https://registry.npmjs.org/fill-range/-/fill-range-2.2.3.tgz",
                               "resolved": "https://registry.npmjs.org/fill-range/-/fill-range-2.2.3.tgz",
                               "dependencies": {
                                 "is-number": {
                                   "version": "2.1.0",
-                                  "from": "is-number@>=2.1.0 <3.0.0",
+                                  "from": "https://registry.npmjs.org/is-number/-/is-number-2.1.0.tgz",
                                   "resolved": "https://registry.npmjs.org/is-number/-/is-number-2.1.0.tgz"
                                 },
                                 "isobject": {
                                   "version": "2.1.0",
-                                  "from": "isobject@>=2.0.0 <3.0.0",
+                                  "from": "https://registry.npmjs.org/isobject/-/isobject-2.1.0.tgz",
                                   "resolved": "https://registry.npmjs.org/isobject/-/isobject-2.1.0.tgz",
                                   "dependencies": {
                                     "isarray": {
                                       "version": "1.0.0",
-                                      "from": "isarray@1.0.0",
+                                      "from": "https://registry.npmjs.org/isarray/-/isarray-1.0.0.tgz",
                                       "resolved": "https://registry.npmjs.org/isarray/-/isarray-1.0.0.tgz"
                                     }
                                   }
                                 },
                                 "randomatic": {
                                   "version": "1.1.5",
-                                  "from": "randomatic@>=1.1.3 <2.0.0",
+                                  "from": "https://registry.npmjs.org/randomatic/-/randomatic-1.1.5.tgz",
                                   "resolved": "https://registry.npmjs.org/randomatic/-/randomatic-1.1.5.tgz"
                                 },
                                 "repeat-string": {
                                   "version": "1.5.4",
-                                  "from": "repeat-string@>=1.5.2 <2.0.0",
+                                  "from": "https://registry.npmjs.org/repeat-string/-/repeat-string-1.5.4.tgz",
                                   "resolved": "https://registry.npmjs.org/repeat-string/-/repeat-string-1.5.4.tgz"
                                 }
                               }
@@ -10256,114 +10490,114 @@
                         },
                         "preserve": {
                           "version": "0.2.0",
-                          "from": "preserve@>=0.2.0 <0.3.0",
+                          "from": "https://registry.npmjs.org/preserve/-/preserve-0.2.0.tgz",
                           "resolved": "https://registry.npmjs.org/preserve/-/preserve-0.2.0.tgz"
                         },
                         "repeat-element": {
                           "version": "1.1.2",
-                          "from": "repeat-element@>=1.1.2 <2.0.0",
+                          "from": "https://registry.npmjs.org/repeat-element/-/repeat-element-1.1.2.tgz",
                           "resolved": "https://registry.npmjs.org/repeat-element/-/repeat-element-1.1.2.tgz"
                         }
                       }
                     },
                     "expand-brackets": {
                       "version": "0.1.5",
-                      "from": "expand-brackets@>=0.1.4 <0.2.0",
+                      "from": "https://registry.npmjs.org/expand-brackets/-/expand-brackets-0.1.5.tgz",
                       "resolved": "https://registry.npmjs.org/expand-brackets/-/expand-brackets-0.1.5.tgz",
                       "dependencies": {
                         "is-posix-bracket": {
                           "version": "0.1.1",
-                          "from": "is-posix-bracket@>=0.1.0 <0.2.0",
+                          "from": "https://registry.npmjs.org/is-posix-bracket/-/is-posix-bracket-0.1.1.tgz",
                           "resolved": "https://registry.npmjs.org/is-posix-bracket/-/is-posix-bracket-0.1.1.tgz"
                         }
                       }
                     },
                     "extglob": {
                       "version": "0.3.2",
-                      "from": "extglob@>=0.3.1 <0.4.0",
+                      "from": "https://registry.npmjs.org/extglob/-/extglob-0.3.2.tgz",
                       "resolved": "https://registry.npmjs.org/extglob/-/extglob-0.3.2.tgz"
                     },
                     "filename-regex": {
                       "version": "2.0.0",
-                      "from": "filename-regex@>=2.0.0 <3.0.0",
+                      "from": "https://registry.npmjs.org/filename-regex/-/filename-regex-2.0.0.tgz",
                       "resolved": "https://registry.npmjs.org/filename-regex/-/filename-regex-2.0.0.tgz"
                     },
                     "is-extglob": {
                       "version": "1.0.0",
-                      "from": "is-extglob@>=1.0.0 <2.0.0",
+                      "from": "https://registry.npmjs.org/is-extglob/-/is-extglob-1.0.0.tgz",
                       "resolved": "https://registry.npmjs.org/is-extglob/-/is-extglob-1.0.0.tgz"
                     },
                     "kind-of": {
                       "version": "3.0.4",
-                      "from": "kind-of@>=3.0.2 <4.0.0",
+                      "from": "https://registry.npmjs.org/kind-of/-/kind-of-3.0.4.tgz",
                       "resolved": "https://registry.npmjs.org/kind-of/-/kind-of-3.0.4.tgz",
                       "dependencies": {
                         "is-buffer": {
                           "version": "1.1.4",
-                          "from": "is-buffer@>=1.0.2 <2.0.0",
+                          "from": "https://registry.npmjs.org/is-buffer/-/is-buffer-1.1.4.tgz",
                           "resolved": "https://registry.npmjs.org/is-buffer/-/is-buffer-1.1.4.tgz"
                         }
                       }
                     },
                     "normalize-path": {
                       "version": "2.0.1",
-                      "from": "normalize-path@>=2.0.1 <3.0.0",
+                      "from": "https://registry.npmjs.org/normalize-path/-/normalize-path-2.0.1.tgz",
                       "resolved": "https://registry.npmjs.org/normalize-path/-/normalize-path-2.0.1.tgz"
                     },
                     "object.omit": {
                       "version": "2.0.0",
-                      "from": "object.omit@>=2.0.0 <3.0.0",
+                      "from": "https://registry.npmjs.org/object.omit/-/object.omit-2.0.0.tgz",
                       "resolved": "https://registry.npmjs.org/object.omit/-/object.omit-2.0.0.tgz",
                       "dependencies": {
                         "for-own": {
                           "version": "0.1.4",
-                          "from": "for-own@>=0.1.3 <0.2.0",
+                          "from": "https://registry.npmjs.org/for-own/-/for-own-0.1.4.tgz",
                           "resolved": "https://registry.npmjs.org/for-own/-/for-own-0.1.4.tgz",
                           "dependencies": {
                             "for-in": {
                               "version": "0.1.5",
-                              "from": "for-in@>=0.1.5 <0.2.0",
+                              "from": "https://registry.npmjs.org/for-in/-/for-in-0.1.5.tgz",
                               "resolved": "https://registry.npmjs.org/for-in/-/for-in-0.1.5.tgz"
                             }
                           }
                         },
                         "is-extendable": {
                           "version": "0.1.1",
-                          "from": "is-extendable@>=0.1.1 <0.2.0",
+                          "from": "https://registry.npmjs.org/is-extendable/-/is-extendable-0.1.1.tgz",
                           "resolved": "https://registry.npmjs.org/is-extendable/-/is-extendable-0.1.1.tgz"
                         }
                       }
                     },
                     "parse-glob": {
                       "version": "3.0.4",
-                      "from": "parse-glob@>=3.0.4 <4.0.0",
+                      "from": "https://registry.npmjs.org/parse-glob/-/parse-glob-3.0.4.tgz",
                       "resolved": "https://registry.npmjs.org/parse-glob/-/parse-glob-3.0.4.tgz",
                       "dependencies": {
                         "glob-base": {
                           "version": "0.3.0",
-                          "from": "glob-base@>=0.3.0 <0.4.0",
+                          "from": "https://registry.npmjs.org/glob-base/-/glob-base-0.3.0.tgz",
                           "resolved": "https://registry.npmjs.org/glob-base/-/glob-base-0.3.0.tgz"
                         },
                         "is-dotfile": {
                           "version": "1.0.2",
-                          "from": "is-dotfile@>=1.0.0 <2.0.0",
+                          "from": "https://registry.npmjs.org/is-dotfile/-/is-dotfile-1.0.2.tgz",
                           "resolved": "https://registry.npmjs.org/is-dotfile/-/is-dotfile-1.0.2.tgz"
                         }
                       }
                     },
                     "regex-cache": {
                       "version": "0.4.3",
-                      "from": "regex-cache@>=0.4.2 <0.5.0",
+                      "from": "https://registry.npmjs.org/regex-cache/-/regex-cache-0.4.3.tgz",
                       "resolved": "https://registry.npmjs.org/regex-cache/-/regex-cache-0.4.3.tgz",
                       "dependencies": {
                         "is-equal-shallow": {
                           "version": "0.1.3",
-                          "from": "is-equal-shallow@>=0.1.3 <0.2.0",
+                          "from": "https://registry.npmjs.org/is-equal-shallow/-/is-equal-shallow-0.1.3.tgz",
                           "resolved": "https://registry.npmjs.org/is-equal-shallow/-/is-equal-shallow-0.1.3.tgz"
                         },
                         "is-primitive": {
                           "version": "2.0.0",
-                          "from": "is-primitive@>=2.0.0 <3.0.0",
+                          "from": "https://registry.npmjs.org/is-primitive/-/is-primitive-2.0.0.tgz",
                           "resolved": "https://registry.npmjs.org/is-primitive/-/is-primitive-2.0.0.tgz"
                         }
                       }
@@ -10374,105 +10608,105 @@
             },
             "async-each": {
               "version": "1.0.0",
-              "from": "async-each@>=1.0.0 <2.0.0",
+              "from": "https://registry.npmjs.org/async-each/-/async-each-1.0.0.tgz",
               "resolved": "https://registry.npmjs.org/async-each/-/async-each-1.0.0.tgz"
             },
             "glob-parent": {
               "version": "2.0.0",
-              "from": "glob-parent@>=2.0.0 <3.0.0",
+              "from": "https://registry.npmjs.org/glob-parent/-/glob-parent-2.0.0.tgz",
               "resolved": "https://registry.npmjs.org/glob-parent/-/glob-parent-2.0.0.tgz"
             },
             "inherits": {
               "version": "2.0.1",
-              "from": "inherits@>=2.0.1 <2.1.0",
+              "from": "https://registry.npmjs.org/inherits/-/inherits-2.0.1.tgz",
               "resolved": "https://registry.npmjs.org/inherits/-/inherits-2.0.1.tgz"
             },
             "is-binary-path": {
               "version": "1.0.1",
-              "from": "is-binary-path@>=1.0.0 <2.0.0",
+              "from": "https://registry.npmjs.org/is-binary-path/-/is-binary-path-1.0.1.tgz",
               "resolved": "https://registry.npmjs.org/is-binary-path/-/is-binary-path-1.0.1.tgz",
               "dependencies": {
                 "binary-extensions": {
                   "version": "1.5.0",
-                  "from": "binary-extensions@>=1.0.0 <2.0.0",
+                  "from": "https://registry.npmjs.org/binary-extensions/-/binary-extensions-1.5.0.tgz",
                   "resolved": "https://registry.npmjs.org/binary-extensions/-/binary-extensions-1.5.0.tgz"
                 }
               }
             },
             "is-glob": {
               "version": "2.0.1",
-              "from": "is-glob@>=2.0.0 <3.0.0",
+              "from": "https://registry.npmjs.org/is-glob/-/is-glob-2.0.1.tgz",
               "resolved": "https://registry.npmjs.org/is-glob/-/is-glob-2.0.1.tgz",
               "dependencies": {
                 "is-extglob": {
                   "version": "1.0.0",
-                  "from": "is-extglob@>=1.0.0 <2.0.0",
+                  "from": "https://registry.npmjs.org/is-extglob/-/is-extglob-1.0.0.tgz",
                   "resolved": "https://registry.npmjs.org/is-extglob/-/is-extglob-1.0.0.tgz"
                 }
               }
             },
             "path-is-absolute": {
               "version": "1.0.0",
-              "from": "path-is-absolute@>=1.0.0 <2.0.0",
+              "from": "https://registry.npmjs.org/path-is-absolute/-/path-is-absolute-1.0.0.tgz",
               "resolved": "https://registry.npmjs.org/path-is-absolute/-/path-is-absolute-1.0.0.tgz"
             },
             "readdirp": {
               "version": "2.1.0",
-              "from": "readdirp@>=2.0.0 <3.0.0",
+              "from": "https://registry.npmjs.org/readdirp/-/readdirp-2.1.0.tgz",
               "resolved": "https://registry.npmjs.org/readdirp/-/readdirp-2.1.0.tgz",
               "dependencies": {
                 "readable-stream": {
                   "version": "2.1.4",
-                  "from": "readable-stream@>=2.0.2 <3.0.0",
+                  "from": "https://registry.npmjs.org/readable-stream/-/readable-stream-2.1.4.tgz",
                   "resolved": "https://registry.npmjs.org/readable-stream/-/readable-stream-2.1.4.tgz",
                   "dependencies": {
                     "buffer-shims": {
                       "version": "1.0.0",
-                      "from": "buffer-shims@>=1.0.0 <2.0.0",
+                      "from": "https://registry.npmjs.org/buffer-shims/-/buffer-shims-1.0.0.tgz",
                       "resolved": "https://registry.npmjs.org/buffer-shims/-/buffer-shims-1.0.0.tgz"
                     },
                     "core-util-is": {
                       "version": "1.0.2",
-                      "from": "core-util-is@>=1.0.0 <1.1.0",
+                      "from": "https://registry.npmjs.org/core-util-is/-/core-util-is-1.0.2.tgz",
                       "resolved": "https://registry.npmjs.org/core-util-is/-/core-util-is-1.0.2.tgz"
                     },
                     "isarray": {
                       "version": "1.0.0",
-                      "from": "isarray@>=1.0.0 <1.1.0",
+                      "from": "https://registry.npmjs.org/isarray/-/isarray-1.0.0.tgz",
                       "resolved": "https://registry.npmjs.org/isarray/-/isarray-1.0.0.tgz"
                     },
                     "process-nextick-args": {
                       "version": "1.0.7",
-                      "from": "process-nextick-args@>=1.0.6 <1.1.0",
+                      "from": "https://registry.npmjs.org/process-nextick-args/-/process-nextick-args-1.0.7.tgz",
                       "resolved": "https://registry.npmjs.org/process-nextick-args/-/process-nextick-args-1.0.7.tgz"
                     },
                     "string_decoder": {
                       "version": "0.10.31",
-                      "from": "string_decoder@>=0.10.0 <0.11.0",
+                      "from": "https://registry.npmjs.org/string_decoder/-/string_decoder-0.10.31.tgz",
                       "resolved": "https://registry.npmjs.org/string_decoder/-/string_decoder-0.10.31.tgz"
                     },
                     "util-deprecate": {
                       "version": "1.0.2",
-                      "from": "util-deprecate@>=1.0.1 <1.1.0",
+                      "from": "https://registry.npmjs.org/util-deprecate/-/util-deprecate-1.0.2.tgz",
                       "resolved": "https://registry.npmjs.org/util-deprecate/-/util-deprecate-1.0.2.tgz"
                     }
                   }
                 },
                 "set-immediate-shim": {
                   "version": "1.0.1",
-                  "from": "set-immediate-shim@>=1.0.1 <2.0.0",
+                  "from": "https://registry.npmjs.org/set-immediate-shim/-/set-immediate-shim-1.0.1.tgz",
                   "resolved": "https://registry.npmjs.org/set-immediate-shim/-/set-immediate-shim-1.0.1.tgz"
                 }
               }
             },
             "fsevents": {
               "version": "1.0.14",
-              "from": "fsevents@>=1.0.0 <2.0.0",
+              "from": "https://registry.npmjs.org/fsevents/-/fsevents-1.0.14.tgz",
               "resolved": "https://registry.npmjs.org/fsevents/-/fsevents-1.0.14.tgz",
               "dependencies": {
                 "nan": {
                   "version": "2.4.0",
-                  "from": "nan@>=2.3.0 <3.0.0",
+                  "from": "https://registry.npmjs.org/nan/-/nan-2.4.0.tgz",
                   "resolved": "https://registry.npmjs.org/nan/-/nan-2.4.0.tgz"
                 },
                 "node-pre-gyp": {
@@ -11081,149 +11315,149 @@
         },
         "colors": {
           "version": "1.1.2",
-          "from": "colors@>=1.1.0 <2.0.0",
+          "from": "https://registry.npmjs.org/colors/-/colors-1.1.2.tgz",
           "resolved": "https://registry.npmjs.org/colors/-/colors-1.1.2.tgz"
         },
         "combine-lists": {
           "version": "1.0.0",
-          "from": "combine-lists@>=1.0.0 <2.0.0",
+          "from": "https://registry.npmjs.org/combine-lists/-/combine-lists-1.0.0.tgz",
           "resolved": "https://registry.npmjs.org/combine-lists/-/combine-lists-1.0.0.tgz",
           "dependencies": {
             "lodash": {
               "version": "4.14.1",
-              "from": "lodash@>=4.5.0 <5.0.0",
+              "from": "https://registry.npmjs.org/lodash/-/lodash-4.14.1.tgz",
               "resolved": "https://registry.npmjs.org/lodash/-/lodash-4.14.1.tgz"
             }
           }
         },
         "connect": {
           "version": "3.4.1",
-          "from": "connect@>=3.3.5 <4.0.0",
+          "from": "https://registry.npmjs.org/connect/-/connect-3.4.1.tgz",
           "resolved": "https://registry.npmjs.org/connect/-/connect-3.4.1.tgz",
           "dependencies": {
             "debug": {
               "version": "2.2.0",
-              "from": "debug@>=2.2.0 <2.3.0",
+              "from": "https://registry.npmjs.org/debug/-/debug-2.2.0.tgz",
               "resolved": "https://registry.npmjs.org/debug/-/debug-2.2.0.tgz",
               "dependencies": {
                 "ms": {
                   "version": "0.7.1",
-                  "from": "ms@0.7.1",
+                  "from": "https://registry.npmjs.org/ms/-/ms-0.7.1.tgz",
                   "resolved": "https://registry.npmjs.org/ms/-/ms-0.7.1.tgz"
                 }
               }
             },
             "finalhandler": {
               "version": "0.4.1",
-              "from": "finalhandler@0.4.1",
+              "from": "https://registry.npmjs.org/finalhandler/-/finalhandler-0.4.1.tgz",
               "resolved": "https://registry.npmjs.org/finalhandler/-/finalhandler-0.4.1.tgz",
               "dependencies": {
                 "escape-html": {
                   "version": "1.0.3",
-                  "from": "escape-html@>=1.0.3 <1.1.0",
+                  "from": "https://registry.npmjs.org/escape-html/-/escape-html-1.0.3.tgz",
                   "resolved": "https://registry.npmjs.org/escape-html/-/escape-html-1.0.3.tgz"
                 },
                 "on-finished": {
                   "version": "2.3.0",
-                  "from": "on-finished@>=2.3.0 <2.4.0",
+                  "from": "https://registry.npmjs.org/on-finished/-/on-finished-2.3.0.tgz",
                   "resolved": "https://registry.npmjs.org/on-finished/-/on-finished-2.3.0.tgz",
                   "dependencies": {
                     "ee-first": {
                       "version": "1.1.1",
-                      "from": "ee-first@1.1.1",
+                      "from": "https://registry.npmjs.org/ee-first/-/ee-first-1.1.1.tgz",
                       "resolved": "https://registry.npmjs.org/ee-first/-/ee-first-1.1.1.tgz"
                     }
                   }
                 },
                 "unpipe": {
                   "version": "1.0.0",
-                  "from": "unpipe@>=1.0.0 <1.1.0",
+                  "from": "https://registry.npmjs.org/unpipe/-/unpipe-1.0.0.tgz",
                   "resolved": "https://registry.npmjs.org/unpipe/-/unpipe-1.0.0.tgz"
                 }
               }
             },
             "parseurl": {
               "version": "1.3.1",
-              "from": "parseurl@>=1.3.1 <1.4.0",
+              "from": "https://registry.npmjs.org/parseurl/-/parseurl-1.3.1.tgz",
               "resolved": "https://registry.npmjs.org/parseurl/-/parseurl-1.3.1.tgz"
             },
             "utils-merge": {
               "version": "1.0.0",
-              "from": "utils-merge@1.0.0",
+              "from": "https://registry.npmjs.org/utils-merge/-/utils-merge-1.0.0.tgz",
               "resolved": "https://registry.npmjs.org/utils-merge/-/utils-merge-1.0.0.tgz"
             }
           }
         },
         "core-js": {
           "version": "2.4.1",
-          "from": "core-js@>=2.2.0 <3.0.0",
+          "from": "https://registry.npmjs.org/core-js/-/core-js-2.4.1.tgz",
           "resolved": "https://registry.npmjs.org/core-js/-/core-js-2.4.1.tgz"
         },
         "di": {
           "version": "0.0.1",
-          "from": "di@>=0.0.1 <0.0.2",
+          "from": "https://registry.npmjs.org/di/-/di-0.0.1.tgz",
           "resolved": "https://registry.npmjs.org/di/-/di-0.0.1.tgz"
         },
         "dom-serialize": {
           "version": "2.2.1",
-          "from": "dom-serialize@>=2.2.0 <3.0.0",
+          "from": "https://registry.npmjs.org/dom-serialize/-/dom-serialize-2.2.1.tgz",
           "resolved": "https://registry.npmjs.org/dom-serialize/-/dom-serialize-2.2.1.tgz",
           "dependencies": {
             "custom-event": {
               "version": "1.0.0",
-              "from": "custom-event@>=1.0.0 <1.1.0",
+              "from": "https://registry.npmjs.org/custom-event/-/custom-event-1.0.0.tgz",
               "resolved": "https://registry.npmjs.org/custom-event/-/custom-event-1.0.0.tgz"
             },
             "ent": {
               "version": "2.2.0",
-              "from": "ent@>=2.2.0 <2.3.0",
+              "from": "https://registry.npmjs.org/ent/-/ent-2.2.0.tgz",
               "resolved": "https://registry.npmjs.org/ent/-/ent-2.2.0.tgz"
             },
             "extend": {
               "version": "3.0.0",
-              "from": "extend@>=3.0.0 <4.0.0",
+              "from": "https://registry.npmjs.org/extend/-/extend-3.0.0.tgz",
               "resolved": "https://registry.npmjs.org/extend/-/extend-3.0.0.tgz"
             },
             "void-elements": {
               "version": "2.0.1",
-              "from": "void-elements@>=2.0.0 <3.0.0",
+              "from": "https://registry.npmjs.org/void-elements/-/void-elements-2.0.1.tgz",
               "resolved": "https://registry.npmjs.org/void-elements/-/void-elements-2.0.1.tgz"
             }
           }
         },
         "expand-braces": {
           "version": "0.1.2",
-          "from": "expand-braces@>=0.1.1 <0.2.0",
+          "from": "https://registry.npmjs.org/expand-braces/-/expand-braces-0.1.2.tgz",
           "resolved": "https://registry.npmjs.org/expand-braces/-/expand-braces-0.1.2.tgz",
           "dependencies": {
             "array-slice": {
               "version": "0.2.3",
-              "from": "array-slice@>=0.2.3 <0.3.0",
+              "from": "https://registry.npmjs.org/array-slice/-/array-slice-0.2.3.tgz",
               "resolved": "https://registry.npmjs.org/array-slice/-/array-slice-0.2.3.tgz"
             },
             "array-unique": {
               "version": "0.2.1",
-              "from": "array-unique@>=0.2.1 <0.3.0",
+              "from": "https://registry.npmjs.org/array-unique/-/array-unique-0.2.1.tgz",
               "resolved": "https://registry.npmjs.org/array-unique/-/array-unique-0.2.1.tgz"
             },
             "braces": {
               "version": "0.1.5",
-              "from": "braces@>=0.1.2 <0.2.0",
+              "from": "https://registry.npmjs.org/braces/-/braces-0.1.5.tgz",
               "resolved": "https://registry.npmjs.org/braces/-/braces-0.1.5.tgz",
               "dependencies": {
                 "expand-range": {
                   "version": "0.1.1",
-                  "from": "expand-range@>=0.1.0 <0.2.0",
+                  "from": "https://registry.npmjs.org/expand-range/-/expand-range-0.1.1.tgz",
                   "resolved": "https://registry.npmjs.org/expand-range/-/expand-range-0.1.1.tgz",
                   "dependencies": {
                     "is-number": {
                       "version": "0.1.1",
-                      "from": "is-number@>=0.1.1 <0.2.0",
+                      "from": "https://registry.npmjs.org/is-number/-/is-number-0.1.1.tgz",
                       "resolved": "https://registry.npmjs.org/is-number/-/is-number-0.1.1.tgz"
                     },
                     "repeat-string": {
                       "version": "0.2.2",
-                      "from": "repeat-string@>=0.2.2 <0.3.0",
+                      "from": "https://registry.npmjs.org/repeat-string/-/repeat-string-0.2.2.tgz",
                       "resolved": "https://registry.npmjs.org/repeat-string/-/repeat-string-0.2.2.tgz"
                     }
                   }
@@ -11234,144 +11468,144 @@
         },
         "glob": {
           "version": "7.0.5",
-          "from": "glob@>=7.0.3 <8.0.0",
+          "from": "https://registry.npmjs.org/glob/-/glob-7.0.5.tgz",
           "resolved": "https://registry.npmjs.org/glob/-/glob-7.0.5.tgz",
           "dependencies": {
             "fs.realpath": {
               "version": "1.0.0",
-              "from": "fs.realpath@>=1.0.0 <2.0.0",
+              "from": "https://registry.npmjs.org/fs.realpath/-/fs.realpath-1.0.0.tgz",
               "resolved": "https://registry.npmjs.org/fs.realpath/-/fs.realpath-1.0.0.tgz"
             },
             "inflight": {
               "version": "1.0.5",
-              "from": "inflight@>=1.0.4 <2.0.0",
+              "from": "https://registry.npmjs.org/inflight/-/inflight-1.0.5.tgz",
               "resolved": "https://registry.npmjs.org/inflight/-/inflight-1.0.5.tgz",
               "dependencies": {
                 "wrappy": {
                   "version": "1.0.2",
-                  "from": "wrappy@>=1.0.0 <2.0.0",
+                  "from": "https://registry.npmjs.org/wrappy/-/wrappy-1.0.2.tgz",
                   "resolved": "https://registry.npmjs.org/wrappy/-/wrappy-1.0.2.tgz"
                 }
               }
             },
             "inherits": {
               "version": "2.0.1",
-              "from": "inherits@>=2.0.1 <2.1.0",
+              "from": "https://registry.npmjs.org/inherits/-/inherits-2.0.1.tgz",
               "resolved": "https://registry.npmjs.org/inherits/-/inherits-2.0.1.tgz"
             },
             "once": {
               "version": "1.3.3",
-              "from": "once@>=1.3.0 <2.0.0",
+              "from": "https://registry.npmjs.org/once/-/once-1.3.3.tgz",
               "resolved": "https://registry.npmjs.org/once/-/once-1.3.3.tgz",
               "dependencies": {
                 "wrappy": {
                   "version": "1.0.2",
-                  "from": "wrappy@>=1.0.0 <2.0.0",
+                  "from": "https://registry.npmjs.org/wrappy/-/wrappy-1.0.2.tgz",
                   "resolved": "https://registry.npmjs.org/wrappy/-/wrappy-1.0.2.tgz"
                 }
               }
             },
             "path-is-absolute": {
               "version": "1.0.0",
-              "from": "path-is-absolute@>=1.0.0 <2.0.0",
+              "from": "https://registry.npmjs.org/path-is-absolute/-/path-is-absolute-1.0.0.tgz",
               "resolved": "https://registry.npmjs.org/path-is-absolute/-/path-is-absolute-1.0.0.tgz"
             }
           }
         },
         "graceful-fs": {
           "version": "4.1.5",
-          "from": "graceful-fs@>=4.1.2 <5.0.0",
+          "from": "https://registry.npmjs.org/graceful-fs/-/graceful-fs-4.1.5.tgz",
           "resolved": "https://registry.npmjs.org/graceful-fs/-/graceful-fs-4.1.5.tgz"
         },
         "http-proxy": {
           "version": "1.14.0",
-          "from": "http-proxy@>=1.13.0 <2.0.0",
+          "from": "https://registry.npmjs.org/http-proxy/-/http-proxy-1.14.0.tgz",
           "resolved": "https://registry.npmjs.org/http-proxy/-/http-proxy-1.14.0.tgz",
           "dependencies": {
             "eventemitter3": {
               "version": "1.2.0",
-              "from": "eventemitter3@>=1.0.0 <2.0.0",
+              "from": "https://registry.npmjs.org/eventemitter3/-/eventemitter3-1.2.0.tgz",
               "resolved": "https://registry.npmjs.org/eventemitter3/-/eventemitter3-1.2.0.tgz"
             },
             "requires-port": {
               "version": "1.0.0",
-              "from": "requires-port@>=1.0.0 <2.0.0",
+              "from": "https://registry.npmjs.org/requires-port/-/requires-port-1.0.0.tgz",
               "resolved": "https://registry.npmjs.org/requires-port/-/requires-port-1.0.0.tgz"
             }
           }
         },
         "isbinaryfile": {
           "version": "3.0.0",
-          "from": "isbinaryfile@>=3.0.0 <4.0.0",
+          "from": "https://registry.npmjs.org/isbinaryfile/-/isbinaryfile-3.0.0.tgz",
           "resolved": "https://registry.npmjs.org/isbinaryfile/-/isbinaryfile-3.0.0.tgz"
         },
         "lodash": {
           "version": "3.10.1",
-          "from": "lodash@>=3.8.0 <4.0.0",
+          "from": "https://registry.npmjs.org/lodash/-/lodash-3.10.1.tgz",
           "resolved": "https://registry.npmjs.org/lodash/-/lodash-3.10.1.tgz"
         },
         "log4js": {
           "version": "0.6.38",
-          "from": "log4js@>=0.6.31 <0.7.0",
+          "from": "https://registry.npmjs.com/log4js/-/log4js-0.6.38.tgz",
           "resolved": "https://registry.npmjs.com/log4js/-/log4js-0.6.38.tgz",
           "dependencies": {
             "readable-stream": {
               "version": "1.0.34",
-              "from": "readable-stream@>=1.0.2 <1.1.0",
+              "from": "https://registry.npmjs.org/readable-stream/-/readable-stream-1.0.34.tgz",
               "resolved": "https://registry.npmjs.org/readable-stream/-/readable-stream-1.0.34.tgz",
               "dependencies": {
                 "core-util-is": {
                   "version": "1.0.2",
-                  "from": "core-util-is@>=1.0.0 <1.1.0",
+                  "from": "https://registry.npmjs.org/core-util-is/-/core-util-is-1.0.2.tgz",
                   "resolved": "https://registry.npmjs.org/core-util-is/-/core-util-is-1.0.2.tgz"
                 },
                 "isarray": {
                   "version": "0.0.1",
-                  "from": "isarray@0.0.1",
+                  "from": "https://registry.npmjs.org/isarray/-/isarray-0.0.1.tgz",
                   "resolved": "https://registry.npmjs.org/isarray/-/isarray-0.0.1.tgz"
                 },
                 "string_decoder": {
                   "version": "0.10.31",
-                  "from": "string_decoder@>=0.10.0 <0.11.0",
+                  "from": "https://registry.npmjs.org/string_decoder/-/string_decoder-0.10.31.tgz",
                   "resolved": "https://registry.npmjs.org/string_decoder/-/string_decoder-0.10.31.tgz"
                 },
                 "inherits": {
                   "version": "2.0.1",
-                  "from": "inherits@>=2.0.1 <2.1.0",
+                  "from": "https://registry.npmjs.org/inherits/-/inherits-2.0.1.tgz",
                   "resolved": "https://registry.npmjs.org/inherits/-/inherits-2.0.1.tgz"
                 }
               }
             },
             "semver": {
               "version": "4.3.6",
-              "from": "semver@>=4.3.3 <4.4.0",
+              "from": "https://registry.npmjs.org/semver/-/semver-4.3.6.tgz",
               "resolved": "https://registry.npmjs.org/semver/-/semver-4.3.6.tgz"
             }
           }
         },
         "mime": {
           "version": "1.3.4",
-          "from": "mime@>=1.3.4 <2.0.0",
+          "from": "https://registry.npmjs.org/mime/-/mime-1.3.4.tgz",
           "resolved": "https://registry.npmjs.org/mime/-/mime-1.3.4.tgz"
         },
         "minimatch": {
           "version": "3.0.2",
-          "from": "minimatch@>=3.0.0 <4.0.0",
+          "from": "https://registry.npmjs.org/minimatch/-/minimatch-3.0.2.tgz",
           "resolved": "https://registry.npmjs.org/minimatch/-/minimatch-3.0.2.tgz",
           "dependencies": {
             "brace-expansion": {
               "version": "1.1.6",
-              "from": "brace-expansion@>=1.0.0 <2.0.0",
+              "from": "https://registry.npmjs.org/brace-expansion/-/brace-expansion-1.1.6.tgz",
               "resolved": "https://registry.npmjs.org/brace-expansion/-/brace-expansion-1.1.6.tgz",
               "dependencies": {
                 "balanced-match": {
                   "version": "0.4.2",
-                  "from": "balanced-match@>=0.4.1 <0.5.0",
+                  "from": "https://registry.npmjs.org/balanced-match/-/balanced-match-0.4.2.tgz",
                   "resolved": "https://registry.npmjs.org/balanced-match/-/balanced-match-0.4.2.tgz"
                 },
                 "concat-map": {
                   "version": "0.0.1",
-                  "from": "concat-map@0.0.1",
+                  "from": "https://registry.npmjs.org/concat-map/-/concat-map-0.0.1.tgz",
                   "resolved": "https://registry.npmjs.org/concat-map/-/concat-map-0.0.1.tgz"
                 }
               }
@@ -11380,127 +11614,127 @@
         },
         "optimist": {
           "version": "0.6.1",
-          "from": "optimist@>=0.6.1 <0.7.0",
+          "from": "https://registry.npmjs.org/optimist/-/optimist-0.6.1.tgz",
           "resolved": "https://registry.npmjs.org/optimist/-/optimist-0.6.1.tgz",
           "dependencies": {
             "wordwrap": {
               "version": "0.0.3",
-              "from": "wordwrap@>=0.0.2 <0.1.0",
+              "from": "https://registry.npmjs.org/wordwrap/-/wordwrap-0.0.3.tgz",
               "resolved": "https://registry.npmjs.org/wordwrap/-/wordwrap-0.0.3.tgz"
             },
             "minimist": {
               "version": "0.0.10",
-              "from": "minimist@>=0.0.1 <0.1.0",
+              "from": "https://registry.npmjs.org/minimist/-/minimist-0.0.10.tgz",
               "resolved": "https://registry.npmjs.org/minimist/-/minimist-0.0.10.tgz"
             }
           }
         },
         "qjobs": {
           "version": "1.1.4",
-          "from": "qjobs@>=1.1.4 <2.0.0",
+          "from": "https://registry.npmjs.org/qjobs/-/qjobs-1.1.4.tgz",
           "resolved": "https://registry.npmjs.org/qjobs/-/qjobs-1.1.4.tgz"
         },
         "rimraf": {
           "version": "2.5.4",
-          "from": "rimraf@>=2.3.3 <3.0.0",
+          "from": "https://registry.npmjs.org/rimraf/-/rimraf-2.5.4.tgz",
           "resolved": "https://registry.npmjs.org/rimraf/-/rimraf-2.5.4.tgz"
         },
         "socket.io": {
           "version": "1.4.7",
-          "from": "socket.io@1.4.7",
+          "from": "https://registry.npmjs.org/socket.io/-/socket.io-1.4.7.tgz",
           "resolved": "https://registry.npmjs.org/socket.io/-/socket.io-1.4.7.tgz",
           "dependencies": {
             "engine.io": {
               "version": "1.6.10",
-              "from": "engine.io@1.6.10",
+              "from": "https://registry.npmjs.org/engine.io/-/engine.io-1.6.10.tgz",
               "resolved": "https://registry.npmjs.org/engine.io/-/engine.io-1.6.10.tgz",
               "dependencies": {
                 "base64id": {
                   "version": "0.1.0",
-                  "from": "base64id@0.1.0",
+                  "from": "https://registry.npmjs.org/base64id/-/base64id-0.1.0.tgz",
                   "resolved": "https://registry.npmjs.org/base64id/-/base64id-0.1.0.tgz"
                 },
                 "ws": {
                   "version": "1.0.1",
-                  "from": "ws@1.0.1",
+                  "from": "https://registry.npmjs.org/ws/-/ws-1.0.1.tgz",
                   "resolved": "https://registry.npmjs.org/ws/-/ws-1.0.1.tgz",
                   "dependencies": {
                     "options": {
                       "version": "0.0.6",
-                      "from": "options@>=0.0.5",
+                      "from": "https://registry.npmjs.org/options/-/options-0.0.6.tgz",
                       "resolved": "https://registry.npmjs.org/options/-/options-0.0.6.tgz"
                     },
                     "ultron": {
                       "version": "1.0.2",
-                      "from": "ultron@>=1.0.0 <1.1.0",
+                      "from": "https://registry.npmjs.org/ultron/-/ultron-1.0.2.tgz",
                       "resolved": "https://registry.npmjs.org/ultron/-/ultron-1.0.2.tgz"
                     }
                   }
                 },
                 "engine.io-parser": {
                   "version": "1.2.4",
-                  "from": "engine.io-parser@1.2.4",
+                  "from": "https://registry.npmjs.org/engine.io-parser/-/engine.io-parser-1.2.4.tgz",
                   "resolved": "https://registry.npmjs.org/engine.io-parser/-/engine.io-parser-1.2.4.tgz",
                   "dependencies": {
                     "after": {
                       "version": "0.8.1",
-                      "from": "after@0.8.1",
+                      "from": "https://registry.npmjs.org/after/-/after-0.8.1.tgz",
                       "resolved": "https://registry.npmjs.org/after/-/after-0.8.1.tgz"
                     },
                     "arraybuffer.slice": {
                       "version": "0.0.6",
-                      "from": "arraybuffer.slice@0.0.6",
+                      "from": "https://registry.npmjs.org/arraybuffer.slice/-/arraybuffer.slice-0.0.6.tgz",
                       "resolved": "https://registry.npmjs.org/arraybuffer.slice/-/arraybuffer.slice-0.0.6.tgz"
                     },
                     "base64-arraybuffer": {
                       "version": "0.1.2",
-                      "from": "base64-arraybuffer@0.1.2",
+                      "from": "https://registry.npmjs.org/base64-arraybuffer/-/base64-arraybuffer-0.1.2.tgz",
                       "resolved": "https://registry.npmjs.org/base64-arraybuffer/-/base64-arraybuffer-0.1.2.tgz"
                     },
                     "blob": {
                       "version": "0.0.4",
-                      "from": "blob@0.0.4",
+                      "from": "https://registry.npmjs.org/blob/-/blob-0.0.4.tgz",
                       "resolved": "https://registry.npmjs.org/blob/-/blob-0.0.4.tgz"
                     },
                     "has-binary": {
                       "version": "0.1.6",
-                      "from": "has-binary@0.1.6",
+                      "from": "https://registry.npmjs.org/has-binary/-/has-binary-0.1.6.tgz",
                       "resolved": "https://registry.npmjs.org/has-binary/-/has-binary-0.1.6.tgz",
                       "dependencies": {
                         "isarray": {
                           "version": "0.0.1",
-                          "from": "isarray@0.0.1",
+                          "from": "https://registry.npmjs.org/isarray/-/isarray-0.0.1.tgz",
                           "resolved": "https://registry.npmjs.org/isarray/-/isarray-0.0.1.tgz"
                         }
                       }
                     },
                     "utf8": {
                       "version": "2.1.0",
-                      "from": "utf8@2.1.0",
+                      "from": "https://registry.npmjs.org/utf8/-/utf8-2.1.0.tgz",
                       "resolved": "https://registry.npmjs.org/utf8/-/utf8-2.1.0.tgz"
                     }
                   }
                 },
                 "accepts": {
                   "version": "1.1.4",
-                  "from": "accepts@1.1.4",
+                  "from": "https://registry.npmjs.org/accepts/-/accepts-1.1.4.tgz",
                   "resolved": "https://registry.npmjs.org/accepts/-/accepts-1.1.4.tgz",
                   "dependencies": {
                     "mime-types": {
                       "version": "2.0.14",
-                      "from": "mime-types@>=2.0.4 <2.1.0",
+                      "from": "https://registry.npmjs.org/mime-types/-/mime-types-2.0.14.tgz",
                       "resolved": "https://registry.npmjs.org/mime-types/-/mime-types-2.0.14.tgz",
                       "dependencies": {
                         "mime-db": {
                           "version": "1.12.0",
-                          "from": "mime-db@>=1.12.0 <1.13.0",
+                          "from": "https://registry.npmjs.org/mime-db/-/mime-db-1.12.0.tgz",
                           "resolved": "https://registry.npmjs.org/mime-db/-/mime-db-1.12.0.tgz"
                         }
                       }
                     },
                     "negotiator": {
                       "version": "0.4.9",
-                      "from": "negotiator@0.4.9",
+                      "from": "https://registry.npmjs.org/negotiator/-/negotiator-0.4.9.tgz",
                       "resolved": "https://registry.npmjs.org/negotiator/-/negotiator-0.4.9.tgz"
                     }
                   }
@@ -11509,125 +11743,125 @@
             },
             "socket.io-parser": {
               "version": "2.2.6",
-              "from": "socket.io-parser@2.2.6",
+              "from": "https://registry.npmjs.org/socket.io-parser/-/socket.io-parser-2.2.6.tgz",
               "resolved": "https://registry.npmjs.org/socket.io-parser/-/socket.io-parser-2.2.6.tgz",
               "dependencies": {
                 "json3": {
                   "version": "3.3.2",
-                  "from": "json3@3.3.2",
+                  "from": "https://registry.npmjs.org/json3/-/json3-3.3.2.tgz",
                   "resolved": "https://registry.npmjs.org/json3/-/json3-3.3.2.tgz"
                 },
                 "component-emitter": {
                   "version": "1.1.2",
-                  "from": "component-emitter@1.1.2",
+                  "from": "https://registry.npmjs.org/component-emitter/-/component-emitter-1.1.2.tgz",
                   "resolved": "https://registry.npmjs.org/component-emitter/-/component-emitter-1.1.2.tgz"
                 },
                 "isarray": {
                   "version": "0.0.1",
-                  "from": "isarray@0.0.1",
+                  "from": "https://registry.npmjs.org/isarray/-/isarray-0.0.1.tgz",
                   "resolved": "https://registry.npmjs.org/isarray/-/isarray-0.0.1.tgz"
                 }
               }
             },
             "socket.io-client": {
               "version": "1.4.6",
-              "from": "socket.io-client@1.4.6",
+              "from": "https://registry.npmjs.org/socket.io-client/-/socket.io-client-1.4.6.tgz",
               "resolved": "https://registry.npmjs.org/socket.io-client/-/socket.io-client-1.4.6.tgz",
               "dependencies": {
                 "engine.io-client": {
                   "version": "1.6.9",
-                  "from": "engine.io-client@1.6.9",
+                  "from": "https://registry.npmjs.org/engine.io-client/-/engine.io-client-1.6.9.tgz",
                   "resolved": "https://registry.npmjs.org/engine.io-client/-/engine.io-client-1.6.9.tgz",
                   "dependencies": {
                     "has-cors": {
                       "version": "1.1.0",
-                      "from": "has-cors@1.1.0",
+                      "from": "https://registry.npmjs.org/has-cors/-/has-cors-1.1.0.tgz",
                       "resolved": "https://registry.npmjs.org/has-cors/-/has-cors-1.1.0.tgz"
                     },
                     "ws": {
                       "version": "1.0.1",
-                      "from": "ws@1.0.1",
+                      "from": "https://registry.npmjs.org/ws/-/ws-1.0.1.tgz",
                       "resolved": "https://registry.npmjs.org/ws/-/ws-1.0.1.tgz",
                       "dependencies": {
                         "options": {
                           "version": "0.0.6",
-                          "from": "options@>=0.0.5",
+                          "from": "https://registry.npmjs.org/options/-/options-0.0.6.tgz",
                           "resolved": "https://registry.npmjs.org/options/-/options-0.0.6.tgz"
                         },
                         "ultron": {
                           "version": "1.0.2",
-                          "from": "ultron@>=1.0.0 <1.1.0",
+                          "from": "https://registry.npmjs.org/ultron/-/ultron-1.0.2.tgz",
                           "resolved": "https://registry.npmjs.org/ultron/-/ultron-1.0.2.tgz"
                         }
                       }
                     },
                     "xmlhttprequest-ssl": {
                       "version": "1.5.1",
-                      "from": "xmlhttprequest-ssl@1.5.1",
+                      "from": "https://registry.npmjs.org/xmlhttprequest-ssl/-/xmlhttprequest-ssl-1.5.1.tgz",
                       "resolved": "https://registry.npmjs.org/xmlhttprequest-ssl/-/xmlhttprequest-ssl-1.5.1.tgz"
                     },
                     "component-emitter": {
                       "version": "1.1.2",
-                      "from": "component-emitter@1.1.2",
+                      "from": "https://registry.npmjs.org/component-emitter/-/component-emitter-1.1.2.tgz",
                       "resolved": "https://registry.npmjs.org/component-emitter/-/component-emitter-1.1.2.tgz"
                     },
                     "engine.io-parser": {
                       "version": "1.2.4",
-                      "from": "engine.io-parser@1.2.4",
+                      "from": "https://registry.npmjs.org/engine.io-parser/-/engine.io-parser-1.2.4.tgz",
                       "resolved": "https://registry.npmjs.org/engine.io-parser/-/engine.io-parser-1.2.4.tgz",
                       "dependencies": {
                         "after": {
                           "version": "0.8.1",
-                          "from": "after@0.8.1",
+                          "from": "https://registry.npmjs.org/after/-/after-0.8.1.tgz",
                           "resolved": "https://registry.npmjs.org/after/-/after-0.8.1.tgz"
                         },
                         "arraybuffer.slice": {
                           "version": "0.0.6",
-                          "from": "arraybuffer.slice@0.0.6",
+                          "from": "https://registry.npmjs.org/arraybuffer.slice/-/arraybuffer.slice-0.0.6.tgz",
                           "resolved": "https://registry.npmjs.org/arraybuffer.slice/-/arraybuffer.slice-0.0.6.tgz"
                         },
                         "base64-arraybuffer": {
                           "version": "0.1.2",
-                          "from": "base64-arraybuffer@0.1.2",
+                          "from": "https://registry.npmjs.org/base64-arraybuffer/-/base64-arraybuffer-0.1.2.tgz",
                           "resolved": "https://registry.npmjs.org/base64-arraybuffer/-/base64-arraybuffer-0.1.2.tgz"
                         },
                         "blob": {
                           "version": "0.0.4",
-                          "from": "blob@0.0.4",
+                          "from": "https://registry.npmjs.org/blob/-/blob-0.0.4.tgz",
                           "resolved": "https://registry.npmjs.org/blob/-/blob-0.0.4.tgz"
                         },
                         "has-binary": {
                           "version": "0.1.6",
-                          "from": "has-binary@0.1.6",
+                          "from": "https://registry.npmjs.org/has-binary/-/has-binary-0.1.6.tgz",
                           "resolved": "https://registry.npmjs.org/has-binary/-/has-binary-0.1.6.tgz",
                           "dependencies": {
                             "isarray": {
                               "version": "0.0.1",
-                              "from": "isarray@0.0.1",
+                              "from": "https://registry.npmjs.org/isarray/-/isarray-0.0.1.tgz",
                               "resolved": "https://registry.npmjs.org/isarray/-/isarray-0.0.1.tgz"
                             }
                           }
                         },
                         "utf8": {
                           "version": "2.1.0",
-                          "from": "utf8@2.1.0",
+                          "from": "https://registry.npmjs.org/utf8/-/utf8-2.1.0.tgz",
                           "resolved": "https://registry.npmjs.org/utf8/-/utf8-2.1.0.tgz"
                         }
                       }
                     },
                     "parsejson": {
                       "version": "0.0.1",
-                      "from": "parsejson@0.0.1",
+                      "from": "https://registry.npmjs.org/parsejson/-/parsejson-0.0.1.tgz",
                       "resolved": "https://registry.npmjs.org/parsejson/-/parsejson-0.0.1.tgz",
                       "dependencies": {
                         "better-assert": {
                           "version": "1.0.2",
-                          "from": "better-assert@>=1.0.0 <1.1.0",
+                          "from": "https://registry.npmjs.org/better-assert/-/better-assert-1.0.2.tgz",
                           "resolved": "https://registry.npmjs.org/better-assert/-/better-assert-1.0.2.tgz",
                           "dependencies": {
                             "callsite": {
                               "version": "1.0.0",
-                              "from": "callsite@1.0.0",
+                              "from": "https://registry.npmjs.org/callsite/-/callsite-1.0.0.tgz",
                               "resolved": "https://registry.npmjs.org/callsite/-/callsite-1.0.0.tgz"
                             }
                           }
@@ -11636,17 +11870,17 @@
                     },
                     "parseqs": {
                       "version": "0.0.2",
-                      "from": "parseqs@0.0.2",
+                      "from": "https://registry.npmjs.org/parseqs/-/parseqs-0.0.2.tgz",
                       "resolved": "https://registry.npmjs.org/parseqs/-/parseqs-0.0.2.tgz",
                       "dependencies": {
                         "better-assert": {
                           "version": "1.0.2",
-                          "from": "better-assert@>=1.0.0 <1.1.0",
+                          "from": "https://registry.npmjs.org/better-assert/-/better-assert-1.0.2.tgz",
                           "resolved": "https://registry.npmjs.org/better-assert/-/better-assert-1.0.2.tgz",
                           "dependencies": {
                             "callsite": {
                               "version": "1.0.0",
-                              "from": "callsite@1.0.0",
+                              "from": "https://registry.npmjs.org/callsite/-/callsite-1.0.0.tgz",
                               "resolved": "https://registry.npmjs.org/callsite/-/callsite-1.0.0.tgz"
                             }
                           }
@@ -11655,49 +11889,49 @@
                     },
                     "component-inherit": {
                       "version": "0.0.3",
-                      "from": "component-inherit@0.0.3",
+                      "from": "https://registry.npmjs.org/component-inherit/-/component-inherit-0.0.3.tgz",
                       "resolved": "https://registry.npmjs.org/component-inherit/-/component-inherit-0.0.3.tgz"
                     },
                     "yeast": {
                       "version": "0.1.2",
-                      "from": "yeast@0.1.2",
+                      "from": "https://registry.npmjs.org/yeast/-/yeast-0.1.2.tgz",
                       "resolved": "https://registry.npmjs.org/yeast/-/yeast-0.1.2.tgz"
                     }
                   }
                 },
                 "component-bind": {
                   "version": "1.0.0",
-                  "from": "component-bind@1.0.0",
+                  "from": "https://registry.npmjs.org/component-bind/-/component-bind-1.0.0.tgz",
                   "resolved": "https://registry.npmjs.org/component-bind/-/component-bind-1.0.0.tgz"
                 },
                 "component-emitter": {
                   "version": "1.2.0",
-                  "from": "component-emitter@1.2.0",
+                  "from": "https://registry.npmjs.org/component-emitter/-/component-emitter-1.2.0.tgz",
                   "resolved": "https://registry.npmjs.org/component-emitter/-/component-emitter-1.2.0.tgz"
                 },
                 "object-component": {
                   "version": "0.0.3",
-                  "from": "object-component@0.0.3",
+                  "from": "https://registry.npmjs.org/object-component/-/object-component-0.0.3.tgz",
                   "resolved": "https://registry.npmjs.org/object-component/-/object-component-0.0.3.tgz"
                 },
                 "indexof": {
                   "version": "0.0.1",
-                  "from": "indexof@0.0.1",
+                  "from": "https://registry.npmjs.org/indexof/-/indexof-0.0.1.tgz",
                   "resolved": "https://registry.npmjs.org/indexof/-/indexof-0.0.1.tgz"
                 },
                 "parseuri": {
                   "version": "0.0.4",
-                  "from": "parseuri@0.0.4",
+                  "from": "https://registry.npmjs.org/parseuri/-/parseuri-0.0.4.tgz",
                   "resolved": "https://registry.npmjs.org/parseuri/-/parseuri-0.0.4.tgz",
                   "dependencies": {
                     "better-assert": {
                       "version": "1.0.2",
-                      "from": "better-assert@>=1.0.0 <1.1.0",
+                      "from": "https://registry.npmjs.org/better-assert/-/better-assert-1.0.2.tgz",
                       "resolved": "https://registry.npmjs.org/better-assert/-/better-assert-1.0.2.tgz",
                       "dependencies": {
                         "callsite": {
                           "version": "1.0.0",
-                          "from": "callsite@1.0.0",
+                          "from": "https://registry.npmjs.org/callsite/-/callsite-1.0.0.tgz",
                           "resolved": "https://registry.npmjs.org/callsite/-/callsite-1.0.0.tgz"
                         }
                       }
@@ -11706,44 +11940,44 @@
                 },
                 "to-array": {
                   "version": "0.1.4",
-                  "from": "to-array@0.1.4",
+                  "from": "https://registry.npmjs.org/to-array/-/to-array-0.1.4.tgz",
                   "resolved": "https://registry.npmjs.org/to-array/-/to-array-0.1.4.tgz"
                 },
                 "backo2": {
                   "version": "1.0.2",
-                  "from": "backo2@1.0.2",
+                  "from": "https://registry.npmjs.org/backo2/-/backo2-1.0.2.tgz",
                   "resolved": "https://registry.npmjs.org/backo2/-/backo2-1.0.2.tgz"
                 }
               }
             },
             "socket.io-adapter": {
               "version": "0.4.0",
-              "from": "socket.io-adapter@0.4.0",
+              "from": "https://registry.npmjs.org/socket.io-adapter/-/socket.io-adapter-0.4.0.tgz",
               "resolved": "https://registry.npmjs.org/socket.io-adapter/-/socket.io-adapter-0.4.0.tgz",
               "dependencies": {
                 "socket.io-parser": {
                   "version": "2.2.2",
-                  "from": "socket.io-parser@2.2.2",
+                  "from": "https://registry.npmjs.org/socket.io-parser/-/socket.io-parser-2.2.2.tgz",
                   "resolved": "https://registry.npmjs.org/socket.io-parser/-/socket.io-parser-2.2.2.tgz",
                   "dependencies": {
                     "debug": {
                       "version": "0.7.4",
-                      "from": "debug@0.7.4",
+                      "from": "https://registry.npmjs.org/debug/-/debug-0.7.4.tgz",
                       "resolved": "https://registry.npmjs.org/debug/-/debug-0.7.4.tgz"
                     },
                     "json3": {
                       "version": "3.2.6",
-                      "from": "json3@3.2.6",
+                      "from": "https://registry.npmjs.org/json3/-/json3-3.2.6.tgz",
                       "resolved": "https://registry.npmjs.org/json3/-/json3-3.2.6.tgz"
                     },
                     "component-emitter": {
                       "version": "1.1.2",
-                      "from": "component-emitter@1.1.2",
+                      "from": "https://registry.npmjs.org/component-emitter/-/component-emitter-1.1.2.tgz",
                       "resolved": "https://registry.npmjs.org/component-emitter/-/component-emitter-1.1.2.tgz"
                     },
                     "isarray": {
                       "version": "0.0.1",
-                      "from": "isarray@0.0.1",
+                      "from": "https://registry.npmjs.org/isarray/-/isarray-0.0.1.tgz",
                       "resolved": "https://registry.npmjs.org/isarray/-/isarray-0.0.1.tgz"
                     }
                   }
@@ -11752,24 +11986,24 @@
             },
             "has-binary": {
               "version": "0.1.7",
-              "from": "has-binary@0.1.7",
+              "from": "https://registry.npmjs.org/has-binary/-/has-binary-0.1.7.tgz",
               "resolved": "https://registry.npmjs.org/has-binary/-/has-binary-0.1.7.tgz",
               "dependencies": {
                 "isarray": {
                   "version": "0.0.1",
-                  "from": "isarray@0.0.1",
+                  "from": "https://registry.npmjs.org/isarray/-/isarray-0.0.1.tgz",
                   "resolved": "https://registry.npmjs.org/isarray/-/isarray-0.0.1.tgz"
                 }
               }
             },
             "debug": {
               "version": "2.2.0",
-              "from": "debug@>=2.2.0 <2.3.0",
+              "from": "https://registry.npmjs.org/debug/-/debug-2.2.0.tgz",
               "resolved": "https://registry.npmjs.org/debug/-/debug-2.2.0.tgz",
               "dependencies": {
                 "ms": {
                   "version": "0.7.1",
-                  "from": "ms@0.7.1",
+                  "from": "https://registry.npmjs.org/ms/-/ms-0.7.1.tgz",
                   "resolved": "https://registry.npmjs.org/ms/-/ms-0.7.1.tgz"
                 }
               }
@@ -11778,29 +12012,29 @@
         },
         "source-map": {
           "version": "0.5.6",
-          "from": "source-map@>=0.5.3 <0.6.0",
+          "from": "https://registry.npmjs.org/source-map/-/source-map-0.5.6.tgz",
           "resolved": "https://registry.npmjs.org/source-map/-/source-map-0.5.6.tgz"
         },
         "tmp": {
           "version": "0.0.28",
-          "from": "tmp@0.0.28",
+          "from": "https://registry.npmjs.org/tmp/-/tmp-0.0.28.tgz",
           "resolved": "https://registry.npmjs.org/tmp/-/tmp-0.0.28.tgz",
           "dependencies": {
             "os-tmpdir": {
               "version": "1.0.1",
-              "from": "os-tmpdir@>=1.0.1 <1.1.0",
+              "from": "https://registry.npmjs.org/os-tmpdir/-/os-tmpdir-1.0.1.tgz",
               "resolved": "https://registry.npmjs.org/os-tmpdir/-/os-tmpdir-1.0.1.tgz"
             }
           }
         },
         "useragent": {
           "version": "2.1.9",
-          "from": "useragent@>=2.1.9 <3.0.0",
+          "from": "https://registry.npmjs.org/useragent/-/useragent-2.1.9.tgz",
           "resolved": "https://registry.npmjs.org/useragent/-/useragent-2.1.9.tgz",
           "dependencies": {
             "lru-cache": {
               "version": "2.2.4",
-              "from": "lru-cache@>=2.2.0 <2.3.0",
+              "from": "https://registry.npmjs.org/lru-cache/-/lru-cache-2.2.4.tgz",
               "resolved": "https://registry.npmjs.org/lru-cache/-/lru-cache-2.2.4.tgz"
             }
           }
@@ -11809,46 +12043,46 @@
     },
     "karma-browserstack-launcher": {
       "version": "1.0.1",
-      "from": "karma-browserstack-launcher@1.0.1",
+      "from": "https://registry.npmjs.org/karma-browserstack-launcher/-/karma-browserstack-launcher-1.0.1.tgz",
       "resolved": "https://registry.npmjs.org/karma-browserstack-launcher/-/karma-browserstack-launcher-1.0.1.tgz",
       "dependencies": {
         "browserstack": {
           "version": "1.5.0",
-          "from": "browserstack@1.5.0",
+          "from": "https://registry.npmjs.org/browserstack/-/browserstack-1.5.0.tgz",
           "resolved": "https://registry.npmjs.org/browserstack/-/browserstack-1.5.0.tgz",
           "dependencies": {
             "https-proxy-agent": {
               "version": "1.0.0",
-              "from": "https-proxy-agent@1.0.0",
+              "from": "https://registry.npmjs.org/https-proxy-agent/-/https-proxy-agent-1.0.0.tgz",
               "resolved": "https://registry.npmjs.org/https-proxy-agent/-/https-proxy-agent-1.0.0.tgz",
               "dependencies": {
                 "agent-base": {
                   "version": "2.0.1",
-                  "from": "agent-base@>=2.0.0 <3.0.0",
+                  "from": "https://registry.npmjs.org/agent-base/-/agent-base-2.0.1.tgz",
                   "resolved": "https://registry.npmjs.org/agent-base/-/agent-base-2.0.1.tgz",
                   "dependencies": {
                     "semver": {
                       "version": "5.0.3",
-                      "from": "semver@>=5.0.1 <5.1.0",
+                      "from": "https://registry.npmjs.org/semver/-/semver-5.0.3.tgz",
                       "resolved": "https://registry.npmjs.org/semver/-/semver-5.0.3.tgz"
                     }
                   }
                 },
                 "debug": {
                   "version": "2.2.0",
-                  "from": "debug@>=2.2.0 <2.3.0",
+                  "from": "https://registry.npmjs.org/debug/-/debug-2.2.0.tgz",
                   "resolved": "https://registry.npmjs.org/debug/-/debug-2.2.0.tgz",
                   "dependencies": {
                     "ms": {
                       "version": "0.7.1",
-                      "from": "ms@0.7.1",
+                      "from": "https://registry.npmjs.org/ms/-/ms-0.7.1.tgz",
                       "resolved": "https://registry.npmjs.org/ms/-/ms-0.7.1.tgz"
                     }
                   }
                 },
                 "extend": {
                   "version": "3.0.0",
-                  "from": "extend@>=3.0.0 <4.0.0",
+                  "from": "https://registry.npmjs.org/extend/-/extend-3.0.0.tgz",
                   "resolved": "https://registry.npmjs.org/extend/-/extend-3.0.0.tgz"
                 }
               }
@@ -11857,36 +12091,36 @@
         },
         "q": {
           "version": "1.4.1",
-          "from": "q@>=1.4.1 <1.5.0",
+          "from": "https://registry.npmjs.org/q/-/q-1.4.1.tgz",
           "resolved": "https://registry.npmjs.org/q/-/q-1.4.1.tgz"
         }
       }
     },
     "karma-chrome-launcher": {
       "version": "1.0.1",
-      "from": "karma-chrome-launcher@1.0.1",
+      "from": "https://registry.npmjs.org/karma-chrome-launcher/-/karma-chrome-launcher-1.0.1.tgz",
       "resolved": "https://registry.npmjs.org/karma-chrome-launcher/-/karma-chrome-launcher-1.0.1.tgz",
       "dependencies": {
         "fs-access": {
           "version": "1.0.0",
-          "from": "fs-access@>=1.0.0 <2.0.0",
+          "from": "https://registry.npmjs.org/fs-access/-/fs-access-1.0.0.tgz",
           "resolved": "https://registry.npmjs.org/fs-access/-/fs-access-1.0.0.tgz",
           "dependencies": {
             "null-check": {
               "version": "1.0.0",
-              "from": "null-check@>=1.0.0 <2.0.0",
+              "from": "https://registry.npmjs.org/null-check/-/null-check-1.0.0.tgz",
               "resolved": "https://registry.npmjs.org/null-check/-/null-check-1.0.0.tgz"
             }
           }
         },
         "which": {
           "version": "1.2.10",
-          "from": "which@>=1.2.1 <2.0.0",
+          "from": "https://registry.npmjs.org/which/-/which-1.2.10.tgz",
           "resolved": "https://registry.npmjs.org/which/-/which-1.2.10.tgz",
           "dependencies": {
             "isexe": {
               "version": "1.1.2",
-              "from": "isexe@>=1.1.1 <2.0.0",
+              "from": "https://registry.npmjs.org/isexe/-/isexe-1.1.2.tgz",
               "resolved": "https://registry.npmjs.org/isexe/-/isexe-1.1.2.tgz"
             }
           }
@@ -11895,111 +12129,111 @@
     },
     "karma-firefox-launcher": {
       "version": "1.0.0",
-      "from": "karma-firefox-launcher@1.0.0",
+      "from": "https://registry.npmjs.org/karma-firefox-launcher/-/karma-firefox-launcher-1.0.0.tgz",
       "resolved": "https://registry.npmjs.org/karma-firefox-launcher/-/karma-firefox-launcher-1.0.0.tgz"
     },
     "karma-jasmine": {
       "version": "1.0.2",
-      "from": "karma-jasmine@1.0.2",
+      "from": "https://registry.npmjs.org/karma-jasmine/-/karma-jasmine-1.0.2.tgz",
       "resolved": "https://registry.npmjs.org/karma-jasmine/-/karma-jasmine-1.0.2.tgz"
     },
     "karma-junit-reporter": {
       "version": "1.1.0",
-      "from": "karma-junit-reporter@1.1.0",
+      "from": "https://registry.npmjs.org/karma-junit-reporter/-/karma-junit-reporter-1.1.0.tgz",
       "resolved": "https://registry.npmjs.org/karma-junit-reporter/-/karma-junit-reporter-1.1.0.tgz",
       "dependencies": {
         "path-is-absolute": {
           "version": "1.0.0",
-          "from": "path-is-absolute@>=1.0.0 <2.0.0",
+          "from": "https://registry.npmjs.org/path-is-absolute/-/path-is-absolute-1.0.0.tgz",
           "resolved": "https://registry.npmjs.org/path-is-absolute/-/path-is-absolute-1.0.0.tgz"
         },
         "xmlbuilder": {
           "version": "8.2.2",
-          "from": "xmlbuilder@8.2.2",
+          "from": "https://registry.npmjs.org/xmlbuilder/-/xmlbuilder-8.2.2.tgz",
           "resolved": "https://registry.npmjs.org/xmlbuilder/-/xmlbuilder-8.2.2.tgz"
         }
       }
     },
     "karma-ng-scenario": {
       "version": "1.0.0",
-      "from": "karma-ng-scenario@1.0.0",
+      "from": "https://registry.npmjs.org/karma-ng-scenario/-/karma-ng-scenario-1.0.0.tgz",
       "resolved": "https://registry.npmjs.org/karma-ng-scenario/-/karma-ng-scenario-1.0.0.tgz"
     },
     "karma-sauce-launcher": {
       "version": "1.0.0",
-      "from": "karma-sauce-launcher@1.0.0",
+      "from": "https://registry.npmjs.org/karma-sauce-launcher/-/karma-sauce-launcher-1.0.0.tgz",
       "resolved": "https://registry.npmjs.org/karma-sauce-launcher/-/karma-sauce-launcher-1.0.0.tgz",
       "dependencies": {
         "q": {
           "version": "1.4.1",
-          "from": "q@>=1.4.1 <1.5.0",
+          "from": "https://registry.npmjs.org/q/-/q-1.4.1.tgz",
           "resolved": "https://registry.npmjs.org/q/-/q-1.4.1.tgz"
         },
         "sauce-connect-launcher": {
           "version": "0.13.0",
-          "from": "sauce-connect-launcher@>=0.13.0 <0.14.0",
+          "from": "https://registry.npmjs.org/sauce-connect-launcher/-/sauce-connect-launcher-0.13.0.tgz",
           "resolved": "https://registry.npmjs.org/sauce-connect-launcher/-/sauce-connect-launcher-0.13.0.tgz",
           "dependencies": {
             "lodash": {
               "version": "3.10.1",
-              "from": "lodash@3.10.1",
+              "from": "https://registry.npmjs.org/lodash/-/lodash-3.10.1.tgz",
               "resolved": "https://registry.npmjs.org/lodash/-/lodash-3.10.1.tgz"
             },
             "async": {
               "version": "1.4.0",
-              "from": "async@1.4.0",
+              "from": "https://registry.npmjs.org/async/-/async-1.4.0.tgz",
               "resolved": "https://registry.npmjs.org/async/-/async-1.4.0.tgz"
             },
             "adm-zip": {
               "version": "0.4.7",
-              "from": "adm-zip@>=0.4.3 <0.5.0",
+              "from": "https://registry.npmjs.org/adm-zip/-/adm-zip-0.4.7.tgz",
               "resolved": "https://registry.npmjs.org/adm-zip/-/adm-zip-0.4.7.tgz"
             },
             "rimraf": {
               "version": "2.4.3",
-              "from": "rimraf@2.4.3",
+              "from": "https://registry.npmjs.org/rimraf/-/rimraf-2.4.3.tgz",
               "resolved": "https://registry.npmjs.org/rimraf/-/rimraf-2.4.3.tgz",
               "dependencies": {
                 "glob": {
                   "version": "5.0.15",
-                  "from": "glob@>=5.0.14 <6.0.0",
+                  "from": "https://registry.npmjs.org/glob/-/glob-5.0.15.tgz",
                   "resolved": "https://registry.npmjs.org/glob/-/glob-5.0.15.tgz",
                   "dependencies": {
                     "inflight": {
                       "version": "1.0.5",
-                      "from": "inflight@>=1.0.4 <2.0.0",
+                      "from": "https://registry.npmjs.org/inflight/-/inflight-1.0.5.tgz",
                       "resolved": "https://registry.npmjs.org/inflight/-/inflight-1.0.5.tgz",
                       "dependencies": {
                         "wrappy": {
                           "version": "1.0.2",
-                          "from": "wrappy@>=1.0.0 <2.0.0",
+                          "from": "https://registry.npmjs.org/wrappy/-/wrappy-1.0.2.tgz",
                           "resolved": "https://registry.npmjs.org/wrappy/-/wrappy-1.0.2.tgz"
                         }
                       }
                     },
                     "inherits": {
                       "version": "2.0.1",
-                      "from": "inherits@>=2.0.0 <3.0.0",
+                      "from": "https://registry.npmjs.org/inherits/-/inherits-2.0.1.tgz",
                       "resolved": "https://registry.npmjs.org/inherits/-/inherits-2.0.1.tgz"
                     },
                     "minimatch": {
                       "version": "3.0.2",
-                      "from": "minimatch@>=2.0.0 <3.0.0||>=3.0.0 <4.0.0",
+                      "from": "https://registry.npmjs.org/minimatch/-/minimatch-3.0.2.tgz",
                       "resolved": "https://registry.npmjs.org/minimatch/-/minimatch-3.0.2.tgz",
                       "dependencies": {
                         "brace-expansion": {
                           "version": "1.1.6",
-                          "from": "brace-expansion@>=1.0.0 <2.0.0",
+                          "from": "https://registry.npmjs.org/brace-expansion/-/brace-expansion-1.1.6.tgz",
                           "resolved": "https://registry.npmjs.org/brace-expansion/-/brace-expansion-1.1.6.tgz",
                           "dependencies": {
                             "balanced-match": {
                               "version": "0.4.2",
-                              "from": "balanced-match@>=0.4.1 <0.5.0",
+                              "from": "https://registry.npmjs.org/balanced-match/-/balanced-match-0.4.2.tgz",
                               "resolved": "https://registry.npmjs.org/balanced-match/-/balanced-match-0.4.2.tgz"
                             },
                             "concat-map": {
                               "version": "0.0.1",
-                              "from": "concat-map@0.0.1",
+                              "from": "https://registry.npmjs.org/concat-map/-/concat-map-0.0.1.tgz",
                               "resolved": "https://registry.npmjs.org/concat-map/-/concat-map-0.0.1.tgz"
                             }
                           }
@@ -12008,19 +12242,19 @@
                     },
                     "once": {
                       "version": "1.3.3",
-                      "from": "once@>=1.3.0 <2.0.0",
+                      "from": "https://registry.npmjs.org/once/-/once-1.3.3.tgz",
                       "resolved": "https://registry.npmjs.org/once/-/once-1.3.3.tgz",
                       "dependencies": {
                         "wrappy": {
                           "version": "1.0.2",
-                          "from": "wrappy@>=1.0.0 <2.0.0",
+                          "from": "https://registry.npmjs.org/wrappy/-/wrappy-1.0.2.tgz",
                           "resolved": "https://registry.npmjs.org/wrappy/-/wrappy-1.0.2.tgz"
                         }
                       }
                     },
                     "path-is-absolute": {
                       "version": "1.0.0",
-                      "from": "path-is-absolute@>=1.0.0 <2.0.0",
+                      "from": "https://registry.npmjs.org/path-is-absolute/-/path-is-absolute-1.0.0.tgz",
                       "resolved": "https://registry.npmjs.org/path-is-absolute/-/path-is-absolute-1.0.0.tgz"
                     }
                   }
@@ -12031,41 +12265,41 @@
         },
         "saucelabs": {
           "version": "1.2.0",
-          "from": "saucelabs@>=1.0.1 <2.0.0",
+          "from": "https://registry.npmjs.org/saucelabs/-/saucelabs-1.2.0.tgz",
           "resolved": "https://registry.npmjs.org/saucelabs/-/saucelabs-1.2.0.tgz",
           "dependencies": {
             "https-proxy-agent": {
               "version": "1.0.0",
-              "from": "https-proxy-agent@1.0.0",
+              "from": "https://registry.npmjs.org/https-proxy-agent/-/https-proxy-agent-1.0.0.tgz",
               "resolved": "https://registry.npmjs.org/https-proxy-agent/-/https-proxy-agent-1.0.0.tgz",
               "dependencies": {
                 "agent-base": {
                   "version": "2.0.1",
-                  "from": "agent-base@>=2.0.0 <3.0.0",
+                  "from": "https://registry.npmjs.org/agent-base/-/agent-base-2.0.1.tgz",
                   "resolved": "https://registry.npmjs.org/agent-base/-/agent-base-2.0.1.tgz",
                   "dependencies": {
                     "semver": {
                       "version": "5.0.3",
-                      "from": "semver@>=5.0.1 <5.1.0",
+                      "from": "https://registry.npmjs.org/semver/-/semver-5.0.3.tgz",
                       "resolved": "https://registry.npmjs.org/semver/-/semver-5.0.3.tgz"
                     }
                   }
                 },
                 "debug": {
                   "version": "2.2.0",
-                  "from": "debug@>=2.2.0 <2.3.0",
+                  "from": "https://registry.npmjs.org/debug/-/debug-2.2.0.tgz",
                   "resolved": "https://registry.npmjs.org/debug/-/debug-2.2.0.tgz",
                   "dependencies": {
                     "ms": {
                       "version": "0.7.1",
-                      "from": "ms@0.7.1",
+                      "from": "https://registry.npmjs.org/ms/-/ms-0.7.1.tgz",
                       "resolved": "https://registry.npmjs.org/ms/-/ms-0.7.1.tgz"
                     }
                   }
                 },
                 "extend": {
                   "version": "3.0.0",
-                  "from": "extend@>=3.0.0 <4.0.0",
+                  "from": "https://registry.npmjs.org/extend/-/extend-3.0.0.tgz",
                   "resolved": "https://registry.npmjs.org/extend/-/extend-3.0.0.tgz"
                 }
               }
@@ -12074,64 +12308,64 @@
         },
         "wd": {
           "version": "0.3.12",
-          "from": "wd@>=0.3.4 <0.4.0",
+          "from": "https://registry.npmjs.org/wd/-/wd-0.3.12.tgz",
           "resolved": "https://registry.npmjs.org/wd/-/wd-0.3.12.tgz",
           "dependencies": {
             "archiver": {
               "version": "0.14.4",
-              "from": "archiver@>=0.14.0 <0.15.0",
+              "from": "https://registry.npmjs.org/archiver/-/archiver-0.14.4.tgz",
               "resolved": "https://registry.npmjs.org/archiver/-/archiver-0.14.4.tgz",
               "dependencies": {
                 "async": {
                   "version": "0.9.2",
-                  "from": "async@>=0.9.0 <0.10.0",
+                  "from": "https://registry.npmjs.org/async/-/async-0.9.2.tgz",
                   "resolved": "https://registry.npmjs.org/async/-/async-0.9.2.tgz"
                 },
                 "buffer-crc32": {
                   "version": "0.2.5",
-                  "from": "buffer-crc32@>=0.2.1 <0.3.0",
+                  "from": "https://registry.npmjs.org/buffer-crc32/-/buffer-crc32-0.2.5.tgz",
                   "resolved": "https://registry.npmjs.org/buffer-crc32/-/buffer-crc32-0.2.5.tgz"
                 },
                 "glob": {
                   "version": "4.3.5",
-                  "from": "glob@>=4.3.0 <4.4.0",
+                  "from": "https://registry.npmjs.org/glob/-/glob-4.3.5.tgz",
                   "resolved": "https://registry.npmjs.org/glob/-/glob-4.3.5.tgz",
                   "dependencies": {
                     "inflight": {
                       "version": "1.0.5",
-                      "from": "inflight@>=1.0.4 <2.0.0",
+                      "from": "https://registry.npmjs.org/inflight/-/inflight-1.0.5.tgz",
                       "resolved": "https://registry.npmjs.org/inflight/-/inflight-1.0.5.tgz",
                       "dependencies": {
                         "wrappy": {
                           "version": "1.0.2",
-                          "from": "wrappy@>=1.0.0 <2.0.0",
+                          "from": "https://registry.npmjs.org/wrappy/-/wrappy-1.0.2.tgz",
                           "resolved": "https://registry.npmjs.org/wrappy/-/wrappy-1.0.2.tgz"
                         }
                       }
                     },
                     "inherits": {
                       "version": "2.0.1",
-                      "from": "inherits@>=2.0.0 <3.0.0",
+                      "from": "https://registry.npmjs.org/inherits/-/inherits-2.0.1.tgz",
                       "resolved": "https://registry.npmjs.org/inherits/-/inherits-2.0.1.tgz"
                     },
                     "minimatch": {
                       "version": "2.0.10",
-                      "from": "minimatch@>=2.0.1 <3.0.0",
+                      "from": "https://registry.npmjs.org/minimatch/-/minimatch-2.0.10.tgz",
                       "resolved": "https://registry.npmjs.org/minimatch/-/minimatch-2.0.10.tgz",
                       "dependencies": {
                         "brace-expansion": {
                           "version": "1.1.6",
-                          "from": "brace-expansion@>=1.0.0 <2.0.0",
+                          "from": "https://registry.npmjs.org/brace-expansion/-/brace-expansion-1.1.6.tgz",
                           "resolved": "https://registry.npmjs.org/brace-expansion/-/brace-expansion-1.1.6.tgz",
                           "dependencies": {
                             "balanced-match": {
                               "version": "0.4.2",
-                              "from": "balanced-match@>=0.4.1 <0.5.0",
+                              "from": "https://registry.npmjs.org/balanced-match/-/balanced-match-0.4.2.tgz",
                               "resolved": "https://registry.npmjs.org/balanced-match/-/balanced-match-0.4.2.tgz"
                             },
                             "concat-map": {
                               "version": "0.0.1",
-                              "from": "concat-map@0.0.1",
+                              "from": "https://registry.npmjs.org/concat-map/-/concat-map-0.0.1.tgz",
                               "resolved": "https://registry.npmjs.org/concat-map/-/concat-map-0.0.1.tgz"
                             }
                           }
@@ -12140,12 +12374,12 @@
                     },
                     "once": {
                       "version": "1.3.3",
-                      "from": "once@>=1.3.0 <2.0.0",
+                      "from": "https://registry.npmjs.org/once/-/once-1.3.3.tgz",
                       "resolved": "https://registry.npmjs.org/once/-/once-1.3.3.tgz",
                       "dependencies": {
                         "wrappy": {
                           "version": "1.0.2",
-                          "from": "wrappy@>=1.0.0 <2.0.0",
+                          "from": "https://registry.npmjs.org/wrappy/-/wrappy-1.0.2.tgz",
                           "resolved": "https://registry.npmjs.org/wrappy/-/wrappy-1.0.2.tgz"
                         }
                       }
@@ -12154,64 +12388,64 @@
                 },
                 "lazystream": {
                   "version": "0.1.0",
-                  "from": "lazystream@>=0.1.0 <0.2.0",
+                  "from": "https://registry.npmjs.org/lazystream/-/lazystream-0.1.0.tgz",
                   "resolved": "https://registry.npmjs.org/lazystream/-/lazystream-0.1.0.tgz"
                 },
                 "lodash": {
                   "version": "3.2.0",
-                  "from": "lodash@>=3.2.0 <3.3.0",
+                  "from": "https://registry.npmjs.org/lodash/-/lodash-3.2.0.tgz",
                   "resolved": "https://registry.npmjs.org/lodash/-/lodash-3.2.0.tgz"
                 },
                 "readable-stream": {
                   "version": "1.0.34",
-                  "from": "readable-stream@>=1.0.26 <1.1.0",
+                  "from": "https://registry.npmjs.org/readable-stream/-/readable-stream-1.0.34.tgz",
                   "resolved": "https://registry.npmjs.org/readable-stream/-/readable-stream-1.0.34.tgz",
                   "dependencies": {
                     "core-util-is": {
                       "version": "1.0.2",
-                      "from": "core-util-is@>=1.0.0 <1.1.0",
+                      "from": "https://registry.npmjs.org/core-util-is/-/core-util-is-1.0.2.tgz",
                       "resolved": "https://registry.npmjs.org/core-util-is/-/core-util-is-1.0.2.tgz"
                     },
                     "isarray": {
                       "version": "0.0.1",
-                      "from": "isarray@0.0.1",
+                      "from": "https://registry.npmjs.org/isarray/-/isarray-0.0.1.tgz",
                       "resolved": "https://registry.npmjs.org/isarray/-/isarray-0.0.1.tgz"
                     },
                     "string_decoder": {
                       "version": "0.10.31",
-                      "from": "string_decoder@>=0.10.0 <0.11.0",
+                      "from": "https://registry.npmjs.org/string_decoder/-/string_decoder-0.10.31.tgz",
                       "resolved": "https://registry.npmjs.org/string_decoder/-/string_decoder-0.10.31.tgz"
                     },
                     "inherits": {
                       "version": "2.0.1",
-                      "from": "inherits@>=2.0.1 <2.1.0",
+                      "from": "https://registry.npmjs.org/inherits/-/inherits-2.0.1.tgz",
                       "resolved": "https://registry.npmjs.org/inherits/-/inherits-2.0.1.tgz"
                     }
                   }
                 },
                 "tar-stream": {
                   "version": "1.1.5",
-                  "from": "tar-stream@>=1.1.0 <1.2.0",
+                  "from": "https://registry.npmjs.org/tar-stream/-/tar-stream-1.1.5.tgz",
                   "resolved": "https://registry.npmjs.org/tar-stream/-/tar-stream-1.1.5.tgz",
                   "dependencies": {
                     "bl": {
                       "version": "0.9.5",
-                      "from": "bl@>=0.9.0 <0.10.0",
+                      "from": "https://registry.npmjs.org/bl/-/bl-0.9.5.tgz",
                       "resolved": "https://registry.npmjs.org/bl/-/bl-0.9.5.tgz"
                     },
                     "end-of-stream": {
                       "version": "1.1.0",
-                      "from": "end-of-stream@>=1.0.0 <2.0.0",
+                      "from": "https://registry.npmjs.org/end-of-stream/-/end-of-stream-1.1.0.tgz",
                       "resolved": "https://registry.npmjs.org/end-of-stream/-/end-of-stream-1.1.0.tgz",
                       "dependencies": {
                         "once": {
                           "version": "1.3.3",
-                          "from": "once@>=1.3.0 <1.4.0",
+                          "from": "https://registry.npmjs.org/once/-/once-1.3.3.tgz",
                           "resolved": "https://registry.npmjs.org/once/-/once-1.3.3.tgz",
                           "dependencies": {
                             "wrappy": {
                               "version": "1.0.2",
-                              "from": "wrappy@>=1.0.0 <2.0.0",
+                              "from": "https://registry.npmjs.org/wrappy/-/wrappy-1.0.2.tgz",
                               "resolved": "https://registry.npmjs.org/wrappy/-/wrappy-1.0.2.tgz"
                             }
                           }
@@ -12220,29 +12454,29 @@
                     },
                     "xtend": {
                       "version": "4.0.1",
-                      "from": "xtend@>=4.0.0 <5.0.0",
+                      "from": "https://registry.npmjs.org/xtend/-/xtend-4.0.1.tgz",
                       "resolved": "https://registry.npmjs.org/xtend/-/xtend-4.0.1.tgz"
                     }
                   }
                 },
                 "zip-stream": {
                   "version": "0.5.2",
-                  "from": "zip-stream@>=0.5.0 <0.6.0",
+                  "from": "https://registry.npmjs.org/zip-stream/-/zip-stream-0.5.2.tgz",
                   "resolved": "https://registry.npmjs.org/zip-stream/-/zip-stream-0.5.2.tgz",
                   "dependencies": {
                     "compress-commons": {
                       "version": "0.2.9",
-                      "from": "compress-commons@>=0.2.0 <0.3.0",
+                      "from": "https://registry.npmjs.org/compress-commons/-/compress-commons-0.2.9.tgz",
                       "resolved": "https://registry.npmjs.org/compress-commons/-/compress-commons-0.2.9.tgz",
                       "dependencies": {
                         "crc32-stream": {
                           "version": "0.3.4",
-                          "from": "crc32-stream@>=0.3.1 <0.4.0",
+                          "from": "https://registry.npmjs.org/crc32-stream/-/crc32-stream-0.3.4.tgz",
                           "resolved": "https://registry.npmjs.org/crc32-stream/-/crc32-stream-0.3.4.tgz"
                         },
                         "node-int64": {
                           "version": "0.3.3",
-                          "from": "node-int64@>=0.3.0 <0.4.0",
+                          "from": "https://registry.npmjs.org/node-int64/-/node-int64-0.3.3.tgz",
                           "resolved": "https://registry.npmjs.org/node-int64/-/node-int64-0.3.3.tgz"
                         }
                       }
@@ -12253,47 +12487,47 @@
             },
             "async": {
               "version": "1.0.0",
-              "from": "async@>=1.0.0 <1.1.0",
+              "from": "https://registry.npmjs.org/async/-/async-1.0.0.tgz",
               "resolved": "https://registry.npmjs.org/async/-/async-1.0.0.tgz"
             },
             "lodash": {
               "version": "3.9.3",
-              "from": "lodash@>=3.9.3 <3.10.0",
+              "from": "https://registry.npmjs.org/lodash/-/lodash-3.9.3.tgz",
               "resolved": "https://registry.npmjs.org/lodash/-/lodash-3.9.3.tgz"
             },
             "request": {
               "version": "2.55.0",
-              "from": "request@>=2.55.0 <2.56.0",
+              "from": "https://registry.npmjs.org/request/-/request-2.55.0.tgz",
               "resolved": "https://registry.npmjs.org/request/-/request-2.55.0.tgz",
               "dependencies": {
                 "bl": {
                   "version": "0.9.5",
-                  "from": "bl@>=0.9.0 <0.10.0",
+                  "from": "https://registry.npmjs.org/bl/-/bl-0.9.5.tgz",
                   "resolved": "https://registry.npmjs.org/bl/-/bl-0.9.5.tgz",
                   "dependencies": {
                     "readable-stream": {
                       "version": "1.0.34",
-                      "from": "readable-stream@>=1.0.26 <1.1.0",
+                      "from": "https://registry.npmjs.org/readable-stream/-/readable-stream-1.0.34.tgz",
                       "resolved": "https://registry.npmjs.org/readable-stream/-/readable-stream-1.0.34.tgz",
                       "dependencies": {
                         "core-util-is": {
                           "version": "1.0.2",
-                          "from": "core-util-is@>=1.0.0 <1.1.0",
+                          "from": "https://registry.npmjs.org/core-util-is/-/core-util-is-1.0.2.tgz",
                           "resolved": "https://registry.npmjs.org/core-util-is/-/core-util-is-1.0.2.tgz"
                         },
                         "isarray": {
                           "version": "0.0.1",
-                          "from": "isarray@0.0.1",
+                          "from": "https://registry.npmjs.org/isarray/-/isarray-0.0.1.tgz",
                           "resolved": "https://registry.npmjs.org/isarray/-/isarray-0.0.1.tgz"
                         },
                         "string_decoder": {
                           "version": "0.10.31",
-                          "from": "string_decoder@>=0.10.0 <0.11.0",
+                          "from": "https://registry.npmjs.org/string_decoder/-/string_decoder-0.10.31.tgz",
                           "resolved": "https://registry.npmjs.org/string_decoder/-/string_decoder-0.10.31.tgz"
                         },
                         "inherits": {
                           "version": "2.0.1",
-                          "from": "inherits@>=2.0.1 <2.1.0",
+                          "from": "https://registry.npmjs.org/inherits/-/inherits-2.0.1.tgz",
                           "resolved": "https://registry.npmjs.org/inherits/-/inherits-2.0.1.tgz"
                         }
                       }
@@ -12302,242 +12536,242 @@
                 },
                 "caseless": {
                   "version": "0.9.0",
-                  "from": "caseless@>=0.9.0 <0.10.0",
+                  "from": "https://registry.npmjs.org/caseless/-/caseless-0.9.0.tgz",
                   "resolved": "https://registry.npmjs.org/caseless/-/caseless-0.9.0.tgz"
                 },
                 "forever-agent": {
                   "version": "0.6.1",
-                  "from": "forever-agent@>=0.6.0 <0.7.0",
+                  "from": "https://registry.npmjs.org/forever-agent/-/forever-agent-0.6.1.tgz",
                   "resolved": "https://registry.npmjs.org/forever-agent/-/forever-agent-0.6.1.tgz"
                 },
                 "form-data": {
                   "version": "0.2.0",
-                  "from": "form-data@>=0.2.0 <0.3.0",
+                  "from": "https://registry.npmjs.org/form-data/-/form-data-0.2.0.tgz",
                   "resolved": "https://registry.npmjs.org/form-data/-/form-data-0.2.0.tgz",
                   "dependencies": {
                     "async": {
                       "version": "0.9.2",
-                      "from": "async@>=0.9.0 <0.10.0",
+                      "from": "https://registry.npmjs.org/async/-/async-0.9.2.tgz",
                       "resolved": "https://registry.npmjs.org/async/-/async-0.9.2.tgz"
                     }
                   }
                 },
                 "json-stringify-safe": {
                   "version": "5.0.1",
-                  "from": "json-stringify-safe@>=5.0.0 <5.1.0",
+                  "from": "https://registry.npmjs.org/json-stringify-safe/-/json-stringify-safe-5.0.1.tgz",
                   "resolved": "https://registry.npmjs.org/json-stringify-safe/-/json-stringify-safe-5.0.1.tgz"
                 },
                 "mime-types": {
                   "version": "2.0.14",
-                  "from": "mime-types@>=2.0.1 <2.1.0",
+                  "from": "https://registry.npmjs.org/mime-types/-/mime-types-2.0.14.tgz",
                   "resolved": "https://registry.npmjs.org/mime-types/-/mime-types-2.0.14.tgz",
                   "dependencies": {
                     "mime-db": {
                       "version": "1.12.0",
-                      "from": "mime-db@>=1.12.0 <1.13.0",
+                      "from": "https://registry.npmjs.org/mime-db/-/mime-db-1.12.0.tgz",
                       "resolved": "https://registry.npmjs.org/mime-db/-/mime-db-1.12.0.tgz"
                     }
                   }
                 },
                 "node-uuid": {
                   "version": "1.4.7",
-                  "from": "node-uuid@>=1.4.0 <1.5.0",
+                  "from": "https://registry.npmjs.org/node-uuid/-/node-uuid-1.4.7.tgz",
                   "resolved": "https://registry.npmjs.org/node-uuid/-/node-uuid-1.4.7.tgz"
                 },
                 "qs": {
                   "version": "2.4.2",
-                  "from": "qs@>=2.4.0 <2.5.0",
+                  "from": "https://registry.npmjs.org/qs/-/qs-2.4.2.tgz",
                   "resolved": "https://registry.npmjs.org/qs/-/qs-2.4.2.tgz"
                 },
                 "tunnel-agent": {
                   "version": "0.4.3",
-                  "from": "tunnel-agent@>=0.4.0 <0.5.0",
+                  "from": "https://registry.npmjs.org/tunnel-agent/-/tunnel-agent-0.4.3.tgz",
                   "resolved": "https://registry.npmjs.org/tunnel-agent/-/tunnel-agent-0.4.3.tgz"
                 },
                 "tough-cookie": {
                   "version": "2.3.1",
-                  "from": "tough-cookie@>=0.12.0",
+                  "from": "https://registry.npmjs.org/tough-cookie/-/tough-cookie-2.3.1.tgz",
                   "resolved": "https://registry.npmjs.org/tough-cookie/-/tough-cookie-2.3.1.tgz"
                 },
                 "http-signature": {
                   "version": "0.10.1",
-                  "from": "http-signature@>=0.10.0 <0.11.0",
+                  "from": "https://registry.npmjs.org/http-signature/-/http-signature-0.10.1.tgz",
                   "resolved": "https://registry.npmjs.org/http-signature/-/http-signature-0.10.1.tgz",
                   "dependencies": {
                     "assert-plus": {
                       "version": "0.1.5",
-                      "from": "assert-plus@>=0.1.5 <0.2.0",
+                      "from": "https://registry.npmjs.org/assert-plus/-/assert-plus-0.1.5.tgz",
                       "resolved": "https://registry.npmjs.org/assert-plus/-/assert-plus-0.1.5.tgz"
                     },
                     "asn1": {
                       "version": "0.1.11",
-                      "from": "asn1@0.1.11",
+                      "from": "https://registry.npmjs.org/asn1/-/asn1-0.1.11.tgz",
                       "resolved": "https://registry.npmjs.org/asn1/-/asn1-0.1.11.tgz"
                     },
                     "ctype": {
                       "version": "0.5.3",
-                      "from": "ctype@0.5.3",
+                      "from": "https://registry.npmjs.org/ctype/-/ctype-0.5.3.tgz",
                       "resolved": "https://registry.npmjs.org/ctype/-/ctype-0.5.3.tgz"
                     }
                   }
                 },
                 "oauth-sign": {
                   "version": "0.6.0",
-                  "from": "oauth-sign@>=0.6.0 <0.7.0",
+                  "from": "https://registry.npmjs.org/oauth-sign/-/oauth-sign-0.6.0.tgz",
                   "resolved": "https://registry.npmjs.org/oauth-sign/-/oauth-sign-0.6.0.tgz"
                 },
                 "hawk": {
                   "version": "2.3.1",
-                  "from": "hawk@>=2.3.0 <2.4.0",
+                  "from": "https://registry.npmjs.org/hawk/-/hawk-2.3.1.tgz",
                   "resolved": "https://registry.npmjs.org/hawk/-/hawk-2.3.1.tgz",
                   "dependencies": {
                     "hoek": {
                       "version": "2.16.3",
-                      "from": "hoek@>=2.0.0 <3.0.0",
+                      "from": "https://registry.npmjs.org/hoek/-/hoek-2.16.3.tgz",
                       "resolved": "https://registry.npmjs.org/hoek/-/hoek-2.16.3.tgz"
                     },
                     "boom": {
                       "version": "2.10.1",
-                      "from": "boom@>=2.0.0 <3.0.0",
+                      "from": "https://registry.npmjs.org/boom/-/boom-2.10.1.tgz",
                       "resolved": "https://registry.npmjs.org/boom/-/boom-2.10.1.tgz"
                     },
                     "cryptiles": {
                       "version": "2.0.5",
-                      "from": "cryptiles@>=2.0.0 <3.0.0",
+                      "from": "https://registry.npmjs.org/cryptiles/-/cryptiles-2.0.5.tgz",
                       "resolved": "https://registry.npmjs.org/cryptiles/-/cryptiles-2.0.5.tgz"
                     },
                     "sntp": {
                       "version": "1.0.9",
-                      "from": "sntp@>=1.0.0 <2.0.0",
+                      "from": "https://registry.npmjs.org/sntp/-/sntp-1.0.9.tgz",
                       "resolved": "https://registry.npmjs.org/sntp/-/sntp-1.0.9.tgz"
                     }
                   }
                 },
                 "aws-sign2": {
                   "version": "0.5.0",
-                  "from": "aws-sign2@>=0.5.0 <0.6.0",
+                  "from": "https://registry.npmjs.org/aws-sign2/-/aws-sign2-0.5.0.tgz",
                   "resolved": "https://registry.npmjs.org/aws-sign2/-/aws-sign2-0.5.0.tgz"
                 },
                 "stringstream": {
                   "version": "0.0.5",
-                  "from": "stringstream@>=0.0.4 <0.1.0",
+                  "from": "https://registry.npmjs.org/stringstream/-/stringstream-0.0.5.tgz",
                   "resolved": "https://registry.npmjs.org/stringstream/-/stringstream-0.0.5.tgz"
                 },
                 "combined-stream": {
                   "version": "0.0.7",
-                  "from": "combined-stream@>=0.0.5 <0.1.0",
+                  "from": "https://registry.npmjs.org/combined-stream/-/combined-stream-0.0.7.tgz",
                   "resolved": "https://registry.npmjs.org/combined-stream/-/combined-stream-0.0.7.tgz",
                   "dependencies": {
                     "delayed-stream": {
                       "version": "0.0.5",
-                      "from": "delayed-stream@0.0.5",
+                      "from": "https://registry.npmjs.org/delayed-stream/-/delayed-stream-0.0.5.tgz",
                       "resolved": "https://registry.npmjs.org/delayed-stream/-/delayed-stream-0.0.5.tgz"
                     }
                   }
                 },
                 "isstream": {
                   "version": "0.1.2",
-                  "from": "isstream@>=0.1.1 <0.2.0",
+                  "from": "https://registry.npmjs.org/isstream/-/isstream-0.1.2.tgz",
                   "resolved": "https://registry.npmjs.org/isstream/-/isstream-0.1.2.tgz"
                 },
                 "har-validator": {
                   "version": "1.8.0",
-                  "from": "har-validator@>=1.4.0 <2.0.0",
+                  "from": "https://registry.npmjs.org/har-validator/-/har-validator-1.8.0.tgz",
                   "resolved": "https://registry.npmjs.org/har-validator/-/har-validator-1.8.0.tgz",
                   "dependencies": {
                     "bluebird": {
                       "version": "2.10.2",
-                      "from": "bluebird@>=2.9.30 <3.0.0",
+                      "from": "https://registry.npmjs.org/bluebird/-/bluebird-2.10.2.tgz",
                       "resolved": "https://registry.npmjs.org/bluebird/-/bluebird-2.10.2.tgz"
                     },
                     "chalk": {
                       "version": "1.1.3",
-                      "from": "chalk@>=1.0.0 <2.0.0",
+                      "from": "https://registry.npmjs.org/chalk/-/chalk-1.1.3.tgz",
                       "resolved": "https://registry.npmjs.org/chalk/-/chalk-1.1.3.tgz",
                       "dependencies": {
                         "ansi-styles": {
                           "version": "2.2.1",
-                          "from": "ansi-styles@>=2.2.1 <3.0.0",
+                          "from": "https://registry.npmjs.org/ansi-styles/-/ansi-styles-2.2.1.tgz",
                           "resolved": "https://registry.npmjs.org/ansi-styles/-/ansi-styles-2.2.1.tgz"
                         },
                         "escape-string-regexp": {
                           "version": "1.0.5",
-                          "from": "escape-string-regexp@>=1.0.2 <2.0.0",
+                          "from": "https://registry.npmjs.org/escape-string-regexp/-/escape-string-regexp-1.0.5.tgz",
                           "resolved": "https://registry.npmjs.org/escape-string-regexp/-/escape-string-regexp-1.0.5.tgz"
                         },
                         "has-ansi": {
                           "version": "2.0.0",
-                          "from": "has-ansi@>=2.0.0 <3.0.0",
+                          "from": "https://registry.npmjs.org/has-ansi/-/has-ansi-2.0.0.tgz",
                           "resolved": "https://registry.npmjs.org/has-ansi/-/has-ansi-2.0.0.tgz",
                           "dependencies": {
                             "ansi-regex": {
                               "version": "2.0.0",
-                              "from": "ansi-regex@>=2.0.0 <3.0.0",
+                              "from": "https://registry.npmjs.org/ansi-regex/-/ansi-regex-2.0.0.tgz",
                               "resolved": "https://registry.npmjs.org/ansi-regex/-/ansi-regex-2.0.0.tgz"
                             }
                           }
                         },
                         "strip-ansi": {
                           "version": "3.0.1",
-                          "from": "strip-ansi@>=3.0.0 <4.0.0",
+                          "from": "https://registry.npmjs.org/strip-ansi/-/strip-ansi-3.0.1.tgz",
                           "resolved": "https://registry.npmjs.org/strip-ansi/-/strip-ansi-3.0.1.tgz",
                           "dependencies": {
                             "ansi-regex": {
                               "version": "2.0.0",
-                              "from": "ansi-regex@>=2.0.0 <3.0.0",
+                              "from": "https://registry.npmjs.org/ansi-regex/-/ansi-regex-2.0.0.tgz",
                               "resolved": "https://registry.npmjs.org/ansi-regex/-/ansi-regex-2.0.0.tgz"
                             }
                           }
                         },
                         "supports-color": {
                           "version": "2.0.0",
-                          "from": "supports-color@>=2.0.0 <3.0.0",
+                          "from": "https://registry.npmjs.org/supports-color/-/supports-color-2.0.0.tgz",
                           "resolved": "https://registry.npmjs.org/supports-color/-/supports-color-2.0.0.tgz"
                         }
                       }
                     },
                     "commander": {
                       "version": "2.9.0",
-                      "from": "commander@>=2.8.1 <3.0.0",
+                      "from": "https://registry.npmjs.org/commander/-/commander-2.9.0.tgz",
                       "resolved": "https://registry.npmjs.org/commander/-/commander-2.9.0.tgz",
                       "dependencies": {
                         "graceful-readlink": {
                           "version": "1.0.1",
-                          "from": "graceful-readlink@>=1.0.0",
+                          "from": "https://registry.npmjs.org/graceful-readlink/-/graceful-readlink-1.0.1.tgz",
                           "resolved": "https://registry.npmjs.org/graceful-readlink/-/graceful-readlink-1.0.1.tgz"
                         }
                       }
                     },
                     "is-my-json-valid": {
                       "version": "2.13.1",
-                      "from": "is-my-json-valid@>=2.12.0 <3.0.0",
+                      "from": "https://registry.npmjs.org/is-my-json-valid/-/is-my-json-valid-2.13.1.tgz",
                       "resolved": "https://registry.npmjs.org/is-my-json-valid/-/is-my-json-valid-2.13.1.tgz",
                       "dependencies": {
                         "generate-function": {
                           "version": "2.0.0",
-                          "from": "generate-function@>=2.0.0 <3.0.0",
+                          "from": "https://registry.npmjs.org/generate-function/-/generate-function-2.0.0.tgz",
                           "resolved": "https://registry.npmjs.org/generate-function/-/generate-function-2.0.0.tgz"
                         },
                         "generate-object-property": {
                           "version": "1.2.0",
-                          "from": "generate-object-property@>=1.1.0 <2.0.0",
+                          "from": "https://registry.npmjs.org/generate-object-property/-/generate-object-property-1.2.0.tgz",
                           "resolved": "https://registry.npmjs.org/generate-object-property/-/generate-object-property-1.2.0.tgz",
                           "dependencies": {
                             "is-property": {
                               "version": "1.0.2",
-                              "from": "is-property@>=1.0.0 <2.0.0",
+                              "from": "https://registry.npmjs.org/is-property/-/is-property-1.0.2.tgz",
                               "resolved": "https://registry.npmjs.org/is-property/-/is-property-1.0.2.tgz"
                             }
                           }
                         },
                         "jsonpointer": {
                           "version": "2.0.0",
-                          "from": "jsonpointer@2.0.0",
+                          "from": "https://registry.npmjs.org/jsonpointer/-/jsonpointer-2.0.0.tgz",
                           "resolved": "https://registry.npmjs.org/jsonpointer/-/jsonpointer-2.0.0.tgz"
                         },
                         "xtend": {
                           "version": "4.0.1",
-                          "from": "xtend@>=4.0.0 <5.0.0",
+                          "from": "https://registry.npmjs.org/xtend/-/xtend-4.0.1.tgz",
                           "resolved": "https://registry.npmjs.org/xtend/-/xtend-4.0.1.tgz"
                         }
                       }
@@ -12548,12 +12782,12 @@
             },
             "underscore.string": {
               "version": "3.0.3",
-              "from": "underscore.string@>=3.0.3 <3.1.0",
+              "from": "https://registry.npmjs.org/underscore.string/-/underscore.string-3.0.3.tgz",
               "resolved": "https://registry.npmjs.org/underscore.string/-/underscore.string-3.0.3.tgz"
             },
             "vargs": {
               "version": "0.1.0",
-              "from": "vargs@>=0.1.0 <0.2.0",
+              "from": "https://registry.npmjs.org/vargs/-/vargs-0.1.0.tgz",
               "resolved": "https://registry.npmjs.org/vargs/-/vargs-0.1.0.tgz"
             }
           }
@@ -12562,7 +12796,7 @@
     },
     "karma-script-launcher": {
       "version": "1.0.0",
-      "from": "karma-script-launcher@1.0.0",
+      "from": "https://registry.npmjs.org/karma-script-launcher/-/karma-script-launcher-1.0.0.tgz",
       "resolved": "https://registry.npmjs.org/karma-script-launcher/-/karma-script-launcher-1.0.0.tgz"
     },
     "load-grunt-tasks": {
@@ -12833,105 +13067,105 @@
     },
     "protractor": {
       "version": "4.0.2",
-      "from": "protractor@4.0.2",
+      "from": "https://registry.npmjs.org/protractor/-/protractor-4.0.2.tgz",
       "resolved": "https://registry.npmjs.org/protractor/-/protractor-4.0.2.tgz",
       "dependencies": {
         "adm-zip": {
           "version": "0.4.7",
-          "from": "adm-zip@0.4.7",
+          "from": "https://registry.npmjs.org/adm-zip/-/adm-zip-0.4.7.tgz",
           "resolved": "https://registry.npmjs.org/adm-zip/-/adm-zip-0.4.7.tgz"
         },
         "chalk": {
           "version": "1.1.3",
-          "from": "chalk@>=1.1.3 <2.0.0",
+          "from": "https://registry.npmjs.org/chalk/-/chalk-1.1.3.tgz",
           "resolved": "https://registry.npmjs.org/chalk/-/chalk-1.1.3.tgz",
           "dependencies": {
             "ansi-styles": {
               "version": "2.2.1",
-              "from": "ansi-styles@>=2.2.1 <3.0.0",
+              "from": "https://registry.npmjs.org/ansi-styles/-/ansi-styles-2.2.1.tgz",
               "resolved": "https://registry.npmjs.org/ansi-styles/-/ansi-styles-2.2.1.tgz"
             },
             "escape-string-regexp": {
               "version": "1.0.5",
-              "from": "escape-string-regexp@>=1.0.2 <2.0.0",
+              "from": "https://registry.npmjs.org/escape-string-regexp/-/escape-string-regexp-1.0.5.tgz",
               "resolved": "https://registry.npmjs.org/escape-string-regexp/-/escape-string-regexp-1.0.5.tgz"
             },
             "has-ansi": {
               "version": "2.0.0",
-              "from": "has-ansi@>=2.0.0 <3.0.0",
+              "from": "https://registry.npmjs.org/has-ansi/-/has-ansi-2.0.0.tgz",
               "resolved": "https://registry.npmjs.org/has-ansi/-/has-ansi-2.0.0.tgz",
               "dependencies": {
                 "ansi-regex": {
                   "version": "2.0.0",
-                  "from": "ansi-regex@>=2.0.0 <3.0.0",
+                  "from": "https://registry.npmjs.org/ansi-regex/-/ansi-regex-2.0.0.tgz",
                   "resolved": "https://registry.npmjs.org/ansi-regex/-/ansi-regex-2.0.0.tgz"
                 }
               }
             },
             "strip-ansi": {
               "version": "3.0.1",
-              "from": "strip-ansi@>=3.0.0 <4.0.0",
+              "from": "https://registry.npmjs.org/strip-ansi/-/strip-ansi-3.0.1.tgz",
               "resolved": "https://registry.npmjs.org/strip-ansi/-/strip-ansi-3.0.1.tgz",
               "dependencies": {
                 "ansi-regex": {
                   "version": "2.0.0",
-                  "from": "ansi-regex@>=2.0.0 <3.0.0",
+                  "from": "https://registry.npmjs.org/ansi-regex/-/ansi-regex-2.0.0.tgz",
                   "resolved": "https://registry.npmjs.org/ansi-regex/-/ansi-regex-2.0.0.tgz"
                 }
               }
             },
             "supports-color": {
               "version": "2.0.0",
-              "from": "supports-color@>=2.0.0 <3.0.0",
+              "from": "https://registry.npmjs.org/supports-color/-/supports-color-2.0.0.tgz",
               "resolved": "https://registry.npmjs.org/supports-color/-/supports-color-2.0.0.tgz"
             }
           }
         },
         "glob": {
           "version": "7.0.5",
-          "from": "glob@>=7.0.3 <8.0.0",
+          "from": "https://registry.npmjs.org/glob/-/glob-7.0.5.tgz",
           "resolved": "https://registry.npmjs.org/glob/-/glob-7.0.5.tgz",
           "dependencies": {
             "fs.realpath": {
               "version": "1.0.0",
-              "from": "fs.realpath@>=1.0.0 <2.0.0",
+              "from": "https://registry.npmjs.org/fs.realpath/-/fs.realpath-1.0.0.tgz",
               "resolved": "https://registry.npmjs.org/fs.realpath/-/fs.realpath-1.0.0.tgz"
             },
             "inflight": {
               "version": "1.0.5",
-              "from": "inflight@>=1.0.4 <2.0.0",
+              "from": "https://registry.npmjs.org/inflight/-/inflight-1.0.5.tgz",
               "resolved": "https://registry.npmjs.org/inflight/-/inflight-1.0.5.tgz",
               "dependencies": {
                 "wrappy": {
                   "version": "1.0.2",
-                  "from": "wrappy@>=1.0.0 <2.0.0",
+                  "from": "https://registry.npmjs.org/wrappy/-/wrappy-1.0.2.tgz",
                   "resolved": "https://registry.npmjs.org/wrappy/-/wrappy-1.0.2.tgz"
                 }
               }
             },
             "inherits": {
               "version": "2.0.1",
-              "from": "inherits@>=2.0.0 <3.0.0",
+              "from": "https://registry.npmjs.org/inherits/-/inherits-2.0.1.tgz",
               "resolved": "https://registry.npmjs.org/inherits/-/inherits-2.0.1.tgz"
             },
             "minimatch": {
               "version": "3.0.2",
-              "from": "minimatch@>=3.0.2 <4.0.0",
+              "from": "https://registry.npmjs.org/minimatch/-/minimatch-3.0.2.tgz",
               "resolved": "https://registry.npmjs.org/minimatch/-/minimatch-3.0.2.tgz",
               "dependencies": {
                 "brace-expansion": {
                   "version": "1.1.6",
-                  "from": "brace-expansion@>=1.0.0 <2.0.0",
+                  "from": "https://registry.npmjs.org/brace-expansion/-/brace-expansion-1.1.6.tgz",
                   "resolved": "https://registry.npmjs.org/brace-expansion/-/brace-expansion-1.1.6.tgz",
                   "dependencies": {
                     "balanced-match": {
                       "version": "0.4.2",
-                      "from": "balanced-match@>=0.4.1 <0.5.0",
+                      "from": "https://registry.npmjs.org/balanced-match/-/balanced-match-0.4.2.tgz",
                       "resolved": "https://registry.npmjs.org/balanced-match/-/balanced-match-0.4.2.tgz"
                     },
                     "concat-map": {
                       "version": "0.0.1",
-                      "from": "concat-map@0.0.1",
+                      "from": "https://registry.npmjs.org/concat-map/-/concat-map-0.0.1.tgz",
                       "resolved": "https://registry.npmjs.org/concat-map/-/concat-map-0.0.1.tgz"
                     }
                   }
@@ -12940,56 +13174,56 @@
             },
             "once": {
               "version": "1.3.3",
-              "from": "once@>=1.3.0 <2.0.0",
+              "from": "https://registry.npmjs.org/once/-/once-1.3.3.tgz",
               "resolved": "https://registry.npmjs.org/once/-/once-1.3.3.tgz",
               "dependencies": {
                 "wrappy": {
                   "version": "1.0.2",
-                  "from": "wrappy@>=1.0.0 <2.0.0",
+                  "from": "https://registry.npmjs.org/wrappy/-/wrappy-1.0.2.tgz",
                   "resolved": "https://registry.npmjs.org/wrappy/-/wrappy-1.0.2.tgz"
                 }
               }
             },
             "path-is-absolute": {
               "version": "1.0.0",
-              "from": "path-is-absolute@>=1.0.0 <2.0.0",
+              "from": "https://registry.npmjs.org/path-is-absolute/-/path-is-absolute-1.0.0.tgz",
               "resolved": "https://registry.npmjs.org/path-is-absolute/-/path-is-absolute-1.0.0.tgz"
             }
           }
         },
         "jasmine": {
           "version": "2.4.1",
-          "from": "jasmine@2.4.1",
+          "from": "https://registry.npmjs.org/jasmine/-/jasmine-2.4.1.tgz",
           "resolved": "https://registry.npmjs.org/jasmine/-/jasmine-2.4.1.tgz",
           "dependencies": {
             "exit": {
               "version": "0.1.2",
-              "from": "exit@>=0.1.2 <0.2.0",
+              "from": "https://registry.npmjs.org/exit/-/exit-0.1.2.tgz",
               "resolved": "https://registry.npmjs.org/exit/-/exit-0.1.2.tgz"
             },
             "glob": {
               "version": "3.2.11",
-              "from": "glob@>=3.2.11 <4.0.0",
+              "from": "https://registry.npmjs.org/glob/-/glob-3.2.11.tgz",
               "resolved": "https://registry.npmjs.org/glob/-/glob-3.2.11.tgz",
               "dependencies": {
                 "inherits": {
                   "version": "2.0.1",
-                  "from": "inherits@>=2.0.0 <3.0.0",
+                  "from": "https://registry.npmjs.org/inherits/-/inherits-2.0.1.tgz",
                   "resolved": "https://registry.npmjs.org/inherits/-/inherits-2.0.1.tgz"
                 },
                 "minimatch": {
                   "version": "0.3.0",
-                  "from": "minimatch@>=0.3.0 <0.4.0",
+                  "from": "https://registry.npmjs.org/minimatch/-/minimatch-0.3.0.tgz",
                   "resolved": "https://registry.npmjs.org/minimatch/-/minimatch-0.3.0.tgz",
                   "dependencies": {
                     "lru-cache": {
                       "version": "2.7.3",
-                      "from": "lru-cache@>=2.0.0 <3.0.0",
+                      "from": "https://registry.npmjs.org/lru-cache/-/lru-cache-2.7.3.tgz",
                       "resolved": "https://registry.npmjs.org/lru-cache/-/lru-cache-2.7.3.tgz"
                     },
                     "sigmund": {
                       "version": "1.0.1",
-                      "from": "sigmund@>=1.0.0 <1.1.0",
+                      "from": "https://registry.npmjs.org/sigmund/-/sigmund-1.0.1.tgz",
                       "resolved": "https://registry.npmjs.org/sigmund/-/sigmund-1.0.1.tgz"
                     }
                   }
@@ -13000,68 +13234,68 @@
         },
         "jasminewd2": {
           "version": "0.0.9",
-          "from": "jasminewd2@0.0.9",
+          "from": "https://registry.npmjs.org/jasminewd2/-/jasminewd2-0.0.9.tgz",
           "resolved": "https://registry.npmjs.org/jasminewd2/-/jasminewd2-0.0.9.tgz"
         },
         "optimist": {
           "version": "0.6.1",
-          "from": "optimist@>=0.6.0 <0.7.0",
+          "from": "https://registry.npmjs.org/optimist/-/optimist-0.6.1.tgz",
           "resolved": "https://registry.npmjs.org/optimist/-/optimist-0.6.1.tgz",
           "dependencies": {
             "wordwrap": {
               "version": "0.0.3",
-              "from": "wordwrap@>=0.0.2 <0.1.0",
+              "from": "https://registry.npmjs.org/wordwrap/-/wordwrap-0.0.3.tgz",
               "resolved": "https://registry.npmjs.org/wordwrap/-/wordwrap-0.0.3.tgz"
             },
             "minimist": {
               "version": "0.0.10",
-              "from": "minimist@>=0.0.1 <0.1.0",
+              "from": "https://registry.npmjs.org/minimist/-/minimist-0.0.10.tgz",
               "resolved": "https://registry.npmjs.org/minimist/-/minimist-0.0.10.tgz"
             }
           }
         },
         "q": {
           "version": "1.4.1",
-          "from": "q@1.4.1",
+          "from": "https://registry.npmjs.org/q/-/q-1.4.1.tgz",
           "resolved": "https://registry.npmjs.org/q/-/q-1.4.1.tgz"
         },
         "saucelabs": {
           "version": "1.2.0",
-          "from": "saucelabs@>=1.2.0 <1.3.0",
+          "from": "https://registry.npmjs.org/saucelabs/-/saucelabs-1.2.0.tgz",
           "resolved": "https://registry.npmjs.org/saucelabs/-/saucelabs-1.2.0.tgz",
           "dependencies": {
             "https-proxy-agent": {
               "version": "1.0.0",
-              "from": "https-proxy-agent@>=1.0.0 <2.0.0",
+              "from": "https://registry.npmjs.org/https-proxy-agent/-/https-proxy-agent-1.0.0.tgz",
               "resolved": "https://registry.npmjs.org/https-proxy-agent/-/https-proxy-agent-1.0.0.tgz",
               "dependencies": {
                 "agent-base": {
                   "version": "2.0.1",
-                  "from": "agent-base@>=2.0.0 <3.0.0",
+                  "from": "https://registry.npmjs.org/agent-base/-/agent-base-2.0.1.tgz",
                   "resolved": "https://registry.npmjs.org/agent-base/-/agent-base-2.0.1.tgz",
                   "dependencies": {
                     "semver": {
                       "version": "5.0.3",
-                      "from": "semver@>=5.0.1 <5.1.0",
+                      "from": "https://registry.npmjs.org/semver/-/semver-5.0.3.tgz",
                       "resolved": "https://registry.npmjs.org/semver/-/semver-5.0.3.tgz"
                     }
                   }
                 },
                 "debug": {
                   "version": "2.2.0",
-                  "from": "debug@>=2.0.0 <3.0.0",
+                  "from": "https://registry.npmjs.org/debug/-/debug-2.2.0.tgz",
                   "resolved": "https://registry.npmjs.org/debug/-/debug-2.2.0.tgz",
                   "dependencies": {
                     "ms": {
                       "version": "0.7.1",
-                      "from": "ms@0.7.1",
+                      "from": "https://registry.npmjs.org/ms/-/ms-0.7.1.tgz",
                       "resolved": "https://registry.npmjs.org/ms/-/ms-0.7.1.tgz"
                     }
                   }
                 },
                 "extend": {
                   "version": "3.0.0",
-                  "from": "extend@>=3.0.0 <4.0.0",
+                  "from": "https://registry.npmjs.org/extend/-/extend-3.0.0.tgz",
                   "resolved": "https://registry.npmjs.org/extend/-/extend-3.0.0.tgz"
                 }
               }
@@ -13070,54 +13304,54 @@
         },
         "selenium-webdriver": {
           "version": "2.53.3",
-          "from": "selenium-webdriver@2.53.3",
+          "from": "https://registry.npmjs.org/selenium-webdriver/-/selenium-webdriver-2.53.3.tgz",
           "resolved": "https://registry.npmjs.org/selenium-webdriver/-/selenium-webdriver-2.53.3.tgz",
           "dependencies": {
             "adm-zip": {
               "version": "0.4.4",
-              "from": "adm-zip@0.4.4",
+              "from": "https://registry.npmjs.org/adm-zip/-/adm-zip-0.4.4.tgz",
               "resolved": "https://registry.npmjs.org/adm-zip/-/adm-zip-0.4.4.tgz"
             },
             "rimraf": {
               "version": "2.5.4",
-              "from": "rimraf@>=2.5.2 <3.0.0",
+              "from": "https://registry.npmjs.org/rimraf/-/rimraf-2.5.4.tgz",
               "resolved": "https://registry.npmjs.org/rimraf/-/rimraf-2.5.4.tgz"
             },
             "tmp": {
               "version": "0.0.24",
-              "from": "tmp@0.0.24",
+              "from": "https://registry.npmjs.org/tmp/-/tmp-0.0.24.tgz",
               "resolved": "https://registry.npmjs.org/tmp/-/tmp-0.0.24.tgz"
             },
             "ws": {
               "version": "1.1.1",
-              "from": "ws@>=1.0.1 <2.0.0",
+              "from": "https://registry.npmjs.org/ws/-/ws-1.1.1.tgz",
               "resolved": "https://registry.npmjs.org/ws/-/ws-1.1.1.tgz",
               "dependencies": {
                 "options": {
                   "version": "0.0.6",
-                  "from": "options@>=0.0.5",
+                  "from": "https://registry.npmjs.org/options/-/options-0.0.6.tgz",
                   "resolved": "https://registry.npmjs.org/options/-/options-0.0.6.tgz"
                 },
                 "ultron": {
                   "version": "1.0.2",
-                  "from": "ultron@>=1.0.0 <1.1.0",
+                  "from": "https://registry.npmjs.org/ultron/-/ultron-1.0.2.tgz",
                   "resolved": "https://registry.npmjs.org/ultron/-/ultron-1.0.2.tgz"
                 }
               }
             },
             "xml2js": {
               "version": "0.4.4",
-              "from": "xml2js@0.4.4",
+              "from": "https://registry.npmjs.org/xml2js/-/xml2js-0.4.4.tgz",
               "resolved": "https://registry.npmjs.org/xml2js/-/xml2js-0.4.4.tgz",
               "dependencies": {
                 "sax": {
                   "version": "0.6.1",
-                  "from": "sax@>=0.6.0 <0.7.0",
+                  "from": "https://registry.npmjs.org/sax/-/sax-0.6.1.tgz",
                   "resolved": "https://registry.npmjs.org/sax/-/sax-0.6.1.tgz"
                 },
                 "xmlbuilder": {
                   "version": "8.2.2",
-                  "from": "xmlbuilder@>=1.0.0",
+                  "from": "https://registry.npmjs.org/xmlbuilder/-/xmlbuilder-8.2.2.tgz",
                   "resolved": "https://registry.npmjs.org/xmlbuilder/-/xmlbuilder-8.2.2.tgz"
                 }
               }
@@ -13126,17 +13360,17 @@
         },
         "source-map-support": {
           "version": "0.4.2",
-          "from": "source-map-support@>=0.4.0 <0.5.0",
+          "from": "https://registry.npmjs.org/source-map-support/-/source-map-support-0.4.2.tgz",
           "resolved": "https://registry.npmjs.org/source-map-support/-/source-map-support-0.4.2.tgz",
           "dependencies": {
             "source-map": {
               "version": "0.1.32",
-              "from": "source-map@0.1.32",
+              "from": "https://registry.npmjs.org/source-map/-/source-map-0.1.32.tgz",
               "resolved": "https://registry.npmjs.org/source-map/-/source-map-0.1.32.tgz",
               "dependencies": {
                 "amdefine": {
                   "version": "1.0.0",
-                  "from": "amdefine@>=0.0.4",
+                  "from": "https://registry.npmjs.org/amdefine/-/amdefine-1.0.0.tgz",
                   "resolved": "https://registry.npmjs.org/amdefine/-/amdefine-1.0.0.tgz"
                 }
               }
@@ -13145,56 +13379,56 @@
         },
         "webdriver-manager": {
           "version": "10.2.1",
-          "from": "webdriver-manager@>=10.2.1 <11.0.0",
+          "from": "https://registry.npmjs.org/webdriver-manager/-/webdriver-manager-10.2.1.tgz",
           "resolved": "https://registry.npmjs.org/webdriver-manager/-/webdriver-manager-10.2.1.tgz",
           "dependencies": {
             "del": {
               "version": "2.2.1",
-              "from": "del@>=2.2.0 <3.0.0",
+              "from": "https://registry.npmjs.org/del/-/del-2.2.1.tgz",
               "resolved": "https://registry.npmjs.org/del/-/del-2.2.1.tgz",
               "dependencies": {
                 "globby": {
                   "version": "5.0.0",
-                  "from": "globby@>=5.0.0 <6.0.0",
+                  "from": "https://registry.npmjs.org/globby/-/globby-5.0.0.tgz",
                   "resolved": "https://registry.npmjs.org/globby/-/globby-5.0.0.tgz",
                   "dependencies": {
                     "array-union": {
                       "version": "1.0.2",
-                      "from": "array-union@>=1.0.1 <2.0.0",
+                      "from": "https://registry.npmjs.org/array-union/-/array-union-1.0.2.tgz",
                       "resolved": "https://registry.npmjs.org/array-union/-/array-union-1.0.2.tgz",
                       "dependencies": {
                         "array-uniq": {
                           "version": "1.0.3",
-                          "from": "array-uniq@>=1.0.1 <2.0.0",
+                          "from": "https://registry.npmjs.org/array-uniq/-/array-uniq-1.0.3.tgz",
                           "resolved": "https://registry.npmjs.org/array-uniq/-/array-uniq-1.0.3.tgz"
                         }
                       }
                     },
                     "arrify": {
                       "version": "1.0.1",
-                      "from": "arrify@>=1.0.0 <2.0.0",
+                      "from": "https://registry.npmjs.org/arrify/-/arrify-1.0.1.tgz",
                       "resolved": "https://registry.npmjs.org/arrify/-/arrify-1.0.1.tgz"
                     }
                   }
                 },
                 "is-path-cwd": {
                   "version": "1.0.0",
-                  "from": "is-path-cwd@>=1.0.0 <2.0.0",
+                  "from": "https://registry.npmjs.org/is-path-cwd/-/is-path-cwd-1.0.0.tgz",
                   "resolved": "https://registry.npmjs.org/is-path-cwd/-/is-path-cwd-1.0.0.tgz"
                 },
                 "is-path-in-cwd": {
                   "version": "1.0.0",
-                  "from": "is-path-in-cwd@>=1.0.0 <2.0.0",
+                  "from": "https://registry.npmjs.org/is-path-in-cwd/-/is-path-in-cwd-1.0.0.tgz",
                   "resolved": "https://registry.npmjs.org/is-path-in-cwd/-/is-path-in-cwd-1.0.0.tgz",
                   "dependencies": {
                     "is-path-inside": {
                       "version": "1.0.0",
-                      "from": "is-path-inside@>=1.0.0 <2.0.0",
+                      "from": "https://registry.npmjs.org/is-path-inside/-/is-path-inside-1.0.0.tgz",
                       "resolved": "https://registry.npmjs.org/is-path-inside/-/is-path-inside-1.0.0.tgz",
                       "dependencies": {
                         "path-is-inside": {
                           "version": "1.0.1",
-                          "from": "path-is-inside@>=1.0.1 <2.0.0",
+                          "from": "https://registry.npmjs.org/path-is-inside/-/path-is-inside-1.0.1.tgz",
                           "resolved": "https://registry.npmjs.org/path-is-inside/-/path-is-inside-1.0.1.tgz"
                         }
                       }
@@ -13203,22 +13437,22 @@
                 },
                 "object-assign": {
                   "version": "4.1.0",
-                  "from": "object-assign@>=4.0.1 <5.0.0",
+                  "from": "https://registry.npmjs.org/object-assign/-/object-assign-4.1.0.tgz",
                   "resolved": "https://registry.npmjs.org/object-assign/-/object-assign-4.1.0.tgz"
                 },
                 "pify": {
                   "version": "2.3.0",
-                  "from": "pify@>=2.0.0 <3.0.0",
+                  "from": "https://registry.npmjs.org/pify/-/pify-2.3.0.tgz",
                   "resolved": "https://registry.npmjs.org/pify/-/pify-2.3.0.tgz"
                 },
                 "pinkie-promise": {
                   "version": "2.0.1",
-                  "from": "pinkie-promise@>=2.0.0 <3.0.0",
+                  "from": "https://registry.npmjs.org/pinkie-promise/-/pinkie-promise-2.0.1.tgz",
                   "resolved": "https://registry.npmjs.org/pinkie-promise/-/pinkie-promise-2.0.1.tgz",
                   "dependencies": {
                     "pinkie": {
                       "version": "2.0.4",
-                      "from": "pinkie@>=2.0.0 <3.0.0",
+                      "from": "https://registry.npmjs.org/pinkie/-/pinkie-2.0.4.tgz",
                       "resolved": "https://registry.npmjs.org/pinkie/-/pinkie-2.0.4.tgz"
                     }
                   }
@@ -13227,67 +13461,67 @@
             },
             "ini": {
               "version": "1.3.4",
-              "from": "ini@>=1.3.4 <2.0.0",
+              "from": "https://registry.npmjs.org/ini/-/ini-1.3.4.tgz",
               "resolved": "https://registry.npmjs.org/ini/-/ini-1.3.4.tgz"
             },
             "minimist": {
               "version": "1.2.0",
-              "from": "minimist@>=1.2.0 <2.0.0",
+              "from": "https://registry.npmjs.org/minimist/-/minimist-1.2.0.tgz",
               "resolved": "https://registry.npmjs.org/minimist/-/minimist-1.2.0.tgz"
             },
             "request": {
               "version": "2.74.0",
-              "from": "request@>=2.69.0 <3.0.0",
+              "from": "https://registry.npmjs.org/request/-/request-2.74.0.tgz",
               "resolved": "https://registry.npmjs.org/request/-/request-2.74.0.tgz",
               "dependencies": {
                 "aws-sign2": {
                   "version": "0.6.0",
-                  "from": "aws-sign2@>=0.6.0 <0.7.0",
+                  "from": "https://registry.npmjs.org/aws-sign2/-/aws-sign2-0.6.0.tgz",
                   "resolved": "https://registry.npmjs.org/aws-sign2/-/aws-sign2-0.6.0.tgz"
                 },
                 "aws4": {
                   "version": "1.4.1",
-                  "from": "aws4@>=1.2.1 <2.0.0",
+                  "from": "https://registry.npmjs.org/aws4/-/aws4-1.4.1.tgz",
                   "resolved": "https://registry.npmjs.org/aws4/-/aws4-1.4.1.tgz"
                 },
                 "bl": {
                   "version": "1.1.2",
-                  "from": "bl@>=1.1.2 <1.2.0",
+                  "from": "https://registry.npmjs.org/bl/-/bl-1.1.2.tgz",
                   "resolved": "https://registry.npmjs.org/bl/-/bl-1.1.2.tgz",
                   "dependencies": {
                     "readable-stream": {
                       "version": "2.0.6",
-                      "from": "readable-stream@>=2.0.5 <2.1.0",
+                      "from": "https://registry.npmjs.org/readable-stream/-/readable-stream-2.0.6.tgz",
                       "resolved": "https://registry.npmjs.org/readable-stream/-/readable-stream-2.0.6.tgz",
                       "dependencies": {
                         "core-util-is": {
                           "version": "1.0.2",
-                          "from": "core-util-is@>=1.0.0 <1.1.0",
+                          "from": "https://registry.npmjs.org/core-util-is/-/core-util-is-1.0.2.tgz",
                           "resolved": "https://registry.npmjs.org/core-util-is/-/core-util-is-1.0.2.tgz"
                         },
                         "inherits": {
                           "version": "2.0.1",
-                          "from": "inherits@>=2.0.1 <2.1.0",
+                          "from": "https://registry.npmjs.org/inherits/-/inherits-2.0.1.tgz",
                           "resolved": "https://registry.npmjs.org/inherits/-/inherits-2.0.1.tgz"
                         },
                         "isarray": {
                           "version": "1.0.0",
-                          "from": "isarray@>=1.0.0 <1.1.0",
+                          "from": "https://registry.npmjs.org/isarray/-/isarray-1.0.0.tgz",
                           "resolved": "https://registry.npmjs.org/isarray/-/isarray-1.0.0.tgz"
                         },
                         "process-nextick-args": {
                           "version": "1.0.7",
-                          "from": "process-nextick-args@>=1.0.6 <1.1.0",
+                          "from": "https://registry.npmjs.org/process-nextick-args/-/process-nextick-args-1.0.7.tgz",
                           "resolved": "https://registry.npmjs.org/process-nextick-args/-/process-nextick-args-1.0.7.tgz"
                         },
                         "string_decoder": {
                           "version": "0.10.31",
-                          "from": "string_decoder@>=0.10.0 <0.11.0",
+                          "from": "https://registry.npmjs.org/string_decoder/-/string_decoder-0.10.31.tgz",
                           "resolved": "https://registry.npmjs.org/string_decoder/-/string_decoder-0.10.31.tgz"
                         },
                         "util-deprecate": {
                           "version": "1.0.2",
-                          "from": "util-deprecate@>=1.0.1 <1.1.0",
+                          "from": "https://registry.npmjs.org/util-deprecate/-/util-deprecate-1.0.2.tgz",
                           "resolved": "https://registry.npmjs.org/util-deprecate/-/util-deprecate-1.0.2.tgz"
                         }
                       }
@@ -13296,102 +13530,102 @@
                 },
                 "caseless": {
                   "version": "0.11.0",
-                  "from": "caseless@>=0.11.0 <0.12.0",
+                  "from": "https://registry.npmjs.org/caseless/-/caseless-0.11.0.tgz",
                   "resolved": "https://registry.npmjs.org/caseless/-/caseless-0.11.0.tgz"
                 },
                 "combined-stream": {
                   "version": "1.0.5",
-                  "from": "combined-stream@>=1.0.5 <1.1.0",
+                  "from": "https://registry.npmjs.org/combined-stream/-/combined-stream-1.0.5.tgz",
                   "resolved": "https://registry.npmjs.org/combined-stream/-/combined-stream-1.0.5.tgz",
                   "dependencies": {
                     "delayed-stream": {
                       "version": "1.0.0",
-                      "from": "delayed-stream@>=1.0.0 <1.1.0",
+                      "from": "https://registry.npmjs.org/delayed-stream/-/delayed-stream-1.0.0.tgz",
                       "resolved": "https://registry.npmjs.org/delayed-stream/-/delayed-stream-1.0.0.tgz"
                     }
                   }
                 },
                 "extend": {
                   "version": "3.0.0",
-                  "from": "extend@>=3.0.0 <3.1.0",
+                  "from": "https://registry.npmjs.org/extend/-/extend-3.0.0.tgz",
                   "resolved": "https://registry.npmjs.org/extend/-/extend-3.0.0.tgz"
                 },
                 "forever-agent": {
                   "version": "0.6.1",
-                  "from": "forever-agent@>=0.6.1 <0.7.0",
+                  "from": "https://registry.npmjs.org/forever-agent/-/forever-agent-0.6.1.tgz",
                   "resolved": "https://registry.npmjs.org/forever-agent/-/forever-agent-0.6.1.tgz"
                 },
                 "form-data": {
                   "version": "1.0.0-rc4",
-                  "from": "form-data@>=1.0.0-rc4 <1.1.0",
+                  "from": "https://registry.npmjs.org/form-data/-/form-data-1.0.0-rc4.tgz",
                   "resolved": "https://registry.npmjs.org/form-data/-/form-data-1.0.0-rc4.tgz",
                   "dependencies": {
                     "async": {
                       "version": "1.5.2",
-                      "from": "async@>=1.5.2 <2.0.0",
+                      "from": "https://registry.npmjs.org/async/-/async-1.5.2.tgz",
                       "resolved": "https://registry.npmjs.org/async/-/async-1.5.2.tgz"
                     }
                   }
                 },
                 "har-validator": {
                   "version": "2.0.6",
-                  "from": "har-validator@>=2.0.6 <2.1.0",
+                  "from": "https://registry.npmjs.org/har-validator/-/har-validator-2.0.6.tgz",
                   "resolved": "https://registry.npmjs.org/har-validator/-/har-validator-2.0.6.tgz",
                   "dependencies": {
                     "commander": {
                       "version": "2.9.0",
-                      "from": "commander@>=2.9.0 <3.0.0",
+                      "from": "https://registry.npmjs.org/commander/-/commander-2.9.0.tgz",
                       "resolved": "https://registry.npmjs.org/commander/-/commander-2.9.0.tgz",
                       "dependencies": {
                         "graceful-readlink": {
                           "version": "1.0.1",
-                          "from": "graceful-readlink@>=1.0.0",
+                          "from": "https://registry.npmjs.org/graceful-readlink/-/graceful-readlink-1.0.1.tgz",
                           "resolved": "https://registry.npmjs.org/graceful-readlink/-/graceful-readlink-1.0.1.tgz"
                         }
                       }
                     },
                     "is-my-json-valid": {
                       "version": "2.13.1",
-                      "from": "is-my-json-valid@>=2.12.4 <3.0.0",
+                      "from": "https://registry.npmjs.org/is-my-json-valid/-/is-my-json-valid-2.13.1.tgz",
                       "resolved": "https://registry.npmjs.org/is-my-json-valid/-/is-my-json-valid-2.13.1.tgz",
                       "dependencies": {
                         "generate-function": {
                           "version": "2.0.0",
-                          "from": "generate-function@>=2.0.0 <3.0.0",
+                          "from": "https://registry.npmjs.org/generate-function/-/generate-function-2.0.0.tgz",
                           "resolved": "https://registry.npmjs.org/generate-function/-/generate-function-2.0.0.tgz"
                         },
                         "generate-object-property": {
                           "version": "1.2.0",
-                          "from": "generate-object-property@>=1.1.0 <2.0.0",
+                          "from": "https://registry.npmjs.org/generate-object-property/-/generate-object-property-1.2.0.tgz",
                           "resolved": "https://registry.npmjs.org/generate-object-property/-/generate-object-property-1.2.0.tgz",
                           "dependencies": {
                             "is-property": {
                               "version": "1.0.2",
-                              "from": "is-property@>=1.0.0 <2.0.0",
+                              "from": "https://registry.npmjs.org/is-property/-/is-property-1.0.2.tgz",
                               "resolved": "https://registry.npmjs.org/is-property/-/is-property-1.0.2.tgz"
                             }
                           }
                         },
                         "jsonpointer": {
                           "version": "2.0.0",
-                          "from": "jsonpointer@2.0.0",
+                          "from": "https://registry.npmjs.org/jsonpointer/-/jsonpointer-2.0.0.tgz",
                           "resolved": "https://registry.npmjs.org/jsonpointer/-/jsonpointer-2.0.0.tgz"
                         },
                         "xtend": {
                           "version": "4.0.1",
-                          "from": "xtend@>=4.0.0 <5.0.0",
+                          "from": "https://registry.npmjs.org/xtend/-/xtend-4.0.1.tgz",
                           "resolved": "https://registry.npmjs.org/xtend/-/xtend-4.0.1.tgz"
                         }
                       }
                     },
                     "pinkie-promise": {
                       "version": "2.0.1",
-                      "from": "pinkie-promise@>=2.0.0 <3.0.0",
+                      "from": "https://registry.npmjs.org/pinkie-promise/-/pinkie-promise-2.0.1.tgz",
                       "resolved": "https://registry.npmjs.org/pinkie-promise/-/pinkie-promise-2.0.1.tgz",
                       "dependencies": {
                         "pinkie": {
                           "version": "2.0.4",
-                          "from": "pinkie@>=2.0.0 <3.0.0",
+                          "from": "https://registry.npmjs.org/pinkie/-/pinkie-2.0.4.tgz",
                           "resolved": "https://registry.npmjs.org/pinkie/-/pinkie-2.0.4.tgz"
                         }
                       }
@@ -13400,106 +13634,106 @@
                 },
                 "hawk": {
                   "version": "3.1.3",
-                  "from": "hawk@>=3.1.3 <3.2.0",
+                  "from": "https://registry.npmjs.org/hawk/-/hawk-3.1.3.tgz",
                   "resolved": "https://registry.npmjs.org/hawk/-/hawk-3.1.3.tgz",
                   "dependencies": {
                     "hoek": {
                       "version": "2.16.3",
-                      "from": "hoek@>=2.0.0 <3.0.0",
+                      "from": "https://registry.npmjs.org/hoek/-/hoek-2.16.3.tgz",
                       "resolved": "https://registry.npmjs.org/hoek/-/hoek-2.16.3.tgz"
                     },
                     "boom": {
                       "version": "2.10.1",
-                      "from": "boom@>=2.0.0 <3.0.0",
+                      "from": "https://registry.npmjs.org/boom/-/boom-2.10.1.tgz",
                       "resolved": "https://registry.npmjs.org/boom/-/boom-2.10.1.tgz"
                     },
                     "cryptiles": {
                       "version": "2.0.5",
-                      "from": "cryptiles@>=2.0.0 <3.0.0",
+                      "from": "https://registry.npmjs.org/cryptiles/-/cryptiles-2.0.5.tgz",
                       "resolved": "https://registry.npmjs.org/cryptiles/-/cryptiles-2.0.5.tgz"
                     },
                     "sntp": {
                       "version": "1.0.9",
-                      "from": "sntp@>=1.0.0 <2.0.0",
+                      "from": "https://registry.npmjs.org/sntp/-/sntp-1.0.9.tgz",
                       "resolved": "https://registry.npmjs.org/sntp/-/sntp-1.0.9.tgz"
                     }
                   }
                 },
                 "http-signature": {
                   "version": "1.1.1",
-                  "from": "http-signature@>=1.1.0 <1.2.0",
+                  "from": "https://registry.npmjs.org/http-signature/-/http-signature-1.1.1.tgz",
                   "resolved": "https://registry.npmjs.org/http-signature/-/http-signature-1.1.1.tgz",
                   "dependencies": {
                     "assert-plus": {
                       "version": "0.2.0",
-                      "from": "assert-plus@>=0.2.0 <0.3.0",
+                      "from": "https://registry.npmjs.org/assert-plus/-/assert-plus-0.2.0.tgz",
                       "resolved": "https://registry.npmjs.org/assert-plus/-/assert-plus-0.2.0.tgz"
                     },
                     "jsprim": {
                       "version": "1.3.0",
-                      "from": "jsprim@>=1.2.2 <2.0.0",
+                      "from": "https://registry.npmjs.org/jsprim/-/jsprim-1.3.0.tgz",
                       "resolved": "https://registry.npmjs.org/jsprim/-/jsprim-1.3.0.tgz",
                       "dependencies": {
                         "extsprintf": {
                           "version": "1.0.2",
-                          "from": "extsprintf@1.0.2",
+                          "from": "https://registry.npmjs.org/extsprintf/-/extsprintf-1.0.2.tgz",
                           "resolved": "https://registry.npmjs.org/extsprintf/-/extsprintf-1.0.2.tgz"
                         },
                         "json-schema": {
                           "version": "0.2.2",
-                          "from": "json-schema@0.2.2",
+                          "from": "https://registry.npmjs.org/json-schema/-/json-schema-0.2.2.tgz",
                           "resolved": "https://registry.npmjs.org/json-schema/-/json-schema-0.2.2.tgz"
                         },
                         "verror": {
                           "version": "1.3.6",
-                          "from": "verror@1.3.6",
+                          "from": "https://registry.npmjs.org/verror/-/verror-1.3.6.tgz",
                           "resolved": "https://registry.npmjs.org/verror/-/verror-1.3.6.tgz"
                         }
                       }
                     },
                     "sshpk": {
                       "version": "1.9.2",
-                      "from": "sshpk@>=1.7.0 <2.0.0",
+                      "from": "https://registry.npmjs.org/sshpk/-/sshpk-1.9.2.tgz",
                       "resolved": "https://registry.npmjs.org/sshpk/-/sshpk-1.9.2.tgz",
                       "dependencies": {
                         "asn1": {
                           "version": "0.2.3",
-                          "from": "asn1@>=0.2.3 <0.3.0",
+                          "from": "https://registry.npmjs.org/asn1/-/asn1-0.2.3.tgz",
                           "resolved": "https://registry.npmjs.org/asn1/-/asn1-0.2.3.tgz"
                         },
                         "assert-plus": {
                           "version": "1.0.0",
-                          "from": "assert-plus@>=1.0.0 <2.0.0",
+                          "from": "https://registry.npmjs.org/assert-plus/-/assert-plus-1.0.0.tgz",
                           "resolved": "https://registry.npmjs.org/assert-plus/-/assert-plus-1.0.0.tgz"
                         },
                         "dashdash": {
                           "version": "1.14.0",
-                          "from": "dashdash@>=1.12.0 <2.0.0",
+                          "from": "https://registry.npmjs.org/dashdash/-/dashdash-1.14.0.tgz",
                           "resolved": "https://registry.npmjs.org/dashdash/-/dashdash-1.14.0.tgz"
                         },
                         "getpass": {
                           "version": "0.1.6",
-                          "from": "getpass@>=0.1.1 <0.2.0",
+                          "from": "https://registry.npmjs.org/getpass/-/getpass-0.1.6.tgz",
                           "resolved": "https://registry.npmjs.org/getpass/-/getpass-0.1.6.tgz"
                         },
                         "jsbn": {
                           "version": "0.1.0",
-                          "from": "jsbn@>=0.1.0 <0.2.0",
+                          "from": "https://registry.npmjs.org/jsbn/-/jsbn-0.1.0.tgz",
                           "resolved": "https://registry.npmjs.org/jsbn/-/jsbn-0.1.0.tgz"
                         },
                         "tweetnacl": {
                           "version": "0.13.3",
-                          "from": "tweetnacl@>=0.13.0 <0.14.0",
+                          "from": "https://registry.npmjs.org/tweetnacl/-/tweetnacl-0.13.3.tgz",
                           "resolved": "https://registry.npmjs.org/tweetnacl/-/tweetnacl-0.13.3.tgz"
                         },
                         "jodid25519": {
                           "version": "1.0.2",
-                          "from": "jodid25519@>=1.0.0 <2.0.0",
+                          "from": "https://registry.npmjs.org/jodid25519/-/jodid25519-1.0.2.tgz",
                           "resolved": "https://registry.npmjs.org/jodid25519/-/jodid25519-1.0.2.tgz"
                         },
                         "ecc-jsbn": {
                           "version": "0.1.1",
-                          "from": "ecc-jsbn@>=0.1.1 <0.2.0",
+                          "from": "https://registry.npmjs.org/ecc-jsbn/-/ecc-jsbn-0.1.1.tgz",
                           "resolved": "https://registry.npmjs.org/ecc-jsbn/-/ecc-jsbn-0.1.1.tgz"
                         }
                       }
@@ -13508,66 +13742,66 @@
                 },
                 "is-typedarray": {
                   "version": "1.0.0",
-                  "from": "is-typedarray@>=1.0.0 <1.1.0",
+                  "from": "https://registry.npmjs.org/is-typedarray/-/is-typedarray-1.0.0.tgz",
                   "resolved": "https://registry.npmjs.org/is-typedarray/-/is-typedarray-1.0.0.tgz"
                 },
                 "isstream": {
                   "version": "0.1.2",
-                  "from": "isstream@>=0.1.2 <0.2.0",
+                  "from": "https://registry.npmjs.org/isstream/-/isstream-0.1.2.tgz",
                   "resolved": "https://registry.npmjs.org/isstream/-/isstream-0.1.2.tgz"
                 },
                 "json-stringify-safe": {
                   "version": "5.0.1",
-                  "from": "json-stringify-safe@>=5.0.1 <5.1.0",
+                  "from": "https://registry.npmjs.org/json-stringify-safe/-/json-stringify-safe-5.0.1.tgz",
                   "resolved": "https://registry.npmjs.org/json-stringify-safe/-/json-stringify-safe-5.0.1.tgz"
                 },
                 "mime-types": {
                   "version": "2.1.11",
-                  "from": "mime-types@>=2.1.7 <2.2.0",
+                  "from": "https://registry.npmjs.org/mime-types/-/mime-types-2.1.11.tgz",
                   "resolved": "https://registry.npmjs.org/mime-types/-/mime-types-2.1.11.tgz",
                   "dependencies": {
                     "mime-db": {
                       "version": "1.23.0",
-                      "from": "mime-db@>=1.23.0 <1.24.0",
+                      "from": "https://registry.npmjs.org/mime-db/-/mime-db-1.23.0.tgz",
                       "resolved": "https://registry.npmjs.org/mime-db/-/mime-db-1.23.0.tgz"
                     }
                   }
                 },
                 "node-uuid": {
                   "version": "1.4.7",
-                  "from": "node-uuid@>=1.4.7 <1.5.0",
+                  "from": "https://registry.npmjs.org/node-uuid/-/node-uuid-1.4.7.tgz",
                   "resolved": "https://registry.npmjs.org/node-uuid/-/node-uuid-1.4.7.tgz"
                 },
                 "oauth-sign": {
                   "version": "0.8.2",
-                  "from": "oauth-sign@>=0.8.1 <0.9.0",
+                  "from": "https://registry.npmjs.org/oauth-sign/-/oauth-sign-0.8.2.tgz",
                   "resolved": "https://registry.npmjs.org/oauth-sign/-/oauth-sign-0.8.2.tgz"
                 },
                 "qs": {
                   "version": "6.2.1",
-                  "from": "qs@>=6.2.0 <6.3.0",
+                  "from": "https://registry.npmjs.org/qs/-/qs-6.2.1.tgz",
                   "resolved": "https://registry.npmjs.org/qs/-/qs-6.2.1.tgz"
                 },
                 "stringstream": {
                   "version": "0.0.5",
-                  "from": "stringstream@>=0.0.4 <0.1.0",
+                  "from": "https://registry.npmjs.org/stringstream/-/stringstream-0.0.5.tgz",
                   "resolved": "https://registry.npmjs.org/stringstream/-/stringstream-0.0.5.tgz"
                 },
                 "tough-cookie": {
                   "version": "2.3.1",
-                  "from": "tough-cookie@>=2.3.0 <2.4.0",
+                  "from": "https://registry.npmjs.org/tough-cookie/-/tough-cookie-2.3.1.tgz",
                   "resolved": "https://registry.npmjs.org/tough-cookie/-/tough-cookie-2.3.1.tgz"
                 },
                 "tunnel-agent": {
                   "version": "0.4.3",
-                  "from": "tunnel-agent@>=0.4.1 <0.5.0",
+                  "from": "https://registry.npmjs.org/tunnel-agent/-/tunnel-agent-0.4.3.tgz",
                   "resolved": "https://registry.npmjs.org/tunnel-agent/-/tunnel-agent-0.4.3.tgz"
                 }
               }
             },
             "rimraf": {
               "version": "2.5.4",
-              "from": "rimraf@>=2.5.2 <3.0.0",
+              "from": "https://registry.npmjs.org/rimraf/-/rimraf-2.5.4.tgz",
               "resolved": "https://registry.npmjs.org/rimraf/-/rimraf-2.5.4.tgz"
             }
           }
@@ -13869,11 +14103,6 @@
       "version": "0.2.2",
       "from": "https://registry.npmjs.org/stringmap/-/stringmap-0.2.2.tgz",
       "resolved": "https://registry.npmjs.org/stringmap/-/stringmap-0.2.2.tgz"
-    },
-    "strip-json-comments": {
-      "version": "2.0.1",
-      "from": "https://registry.npmjs.org/strip-json-comments/-/strip-json-comments-2.0.1.tgz",
-      "resolved": "https://registry.npmjs.org/strip-json-comments/-/strip-json-comments-2.0.1.tgz"
     }
   }
 }
diff --git a/package.json b/package.json
index 2140e7387f88..9889ac229eb1 100644
--- a/package.json
+++ b/package.json
@@ -39,15 +39,14 @@
     "grunt-contrib-compress": "^1.3.0",
     "grunt-contrib-connect": "^1.0.2",
     "grunt-contrib-copy": "^1.0.0",
-    "grunt-contrib-jshint": "^1.0.0",
     "grunt-ddescribe-iit": "~0.0.1",
-    "grunt-jscs": "^3.0.1",
+    "grunt-eslint": "^19.0.0",
     "grunt-merge-conflict": "~0.0.1",
     "grunt-shell": "^1.3.0",
     "gulp": "~3.8.0",
     "gulp-concat": "^2.4.1",
+    "gulp-eslint": "^3.0.1",
     "gulp-foreach": "0.0.1",
-    "gulp-jshint": "^2.0.0",
     "gulp-rename": "^1.2.0",
     "gulp-sourcemaps": "^1.2.2",
     "gulp-uglify": "^1.0.1",
@@ -55,8 +54,6 @@
     "jasmine-core": "^2.4.0",
     "jasmine-node": "^2.0.0",
     "jasmine-reporters": "^2.2.0",
-    "jshint": "^2.9.1",
-    "jshint-stylish": "^2.1.0",
     "karma": "^1.1.2",
     "karma-browserstack-launcher": "^1.0.1",
     "karma-chrome-launcher": "^1.0.1",
@@ -83,8 +80,7 @@
     "serve-static": "^1.11.1",
     "shelljs": "~0.3.0",
     "sorted-object": "^1.0.0",
-    "stringmap": "^0.2.2",
-    "strip-json-comments": "^2.0.1"
+    "stringmap": "^0.2.2"
   },
   "dependencies": {},
   "config": {
diff --git a/scripts/npm/clean-shrinkwrap.js b/scripts/npm/clean-shrinkwrap.js
index 953b126031f2..a5a5421c0863 100755
--- a/scripts/npm/clean-shrinkwrap.js
+++ b/scripts/npm/clean-shrinkwrap.js
@@ -1,5 +1,7 @@
 #!/usr/bin/env node
 
+'use strict';
+
 /**
  * this script is just a temporary solution to deal with the issue of npm outputting the npm
  * shrinkwrap file in an unstable manner.
diff --git a/src/.jshintrc b/src/.eslintrc.json
similarity index 97%
rename from src/.jshintrc
rename to src/.eslintrc.json
index b77462c5b0d9..caa332ff8bf7 100644
--- a/src/.jshintrc
+++ b/src/.eslintrc.json
@@ -1,10 +1,8 @@
 {
-  "extends": "../.jshintrc-base",
-  "eqeqeq": true,
-  "eqnull": true,
-  "globals": {
-    "window": false,
+  "root": true,
+  "extends": "../.eslintrc-browser.json",
 
+  "globals": {
     /* auto/injector.js */
     "createInjector": false,
 
diff --git a/src/Angular.js b/src/Angular.js
index 45d4273dbb15..252582517e65 100644
--- a/src/Angular.js
+++ b/src/Angular.js
@@ -1,99 +1,100 @@
 'use strict';
 
-/* We need to tell jshint what variables are being exported */
-/* global angular: true,
-  msie: true,
-  jqLite: true,
-  jQuery: true,
-  slice: true,
-  splice: true,
-  push: true,
-  toString: true,
-  ngMinErr: true,
-  angularModule: true,
-  uid: true,
-  REGEX_STRING_REGEXP: true,
-  VALIDITY_STATE_PROPERTY: true,
-
-  lowercase: true,
-  uppercase: true,
-  manualLowercase: true,
-  manualUppercase: true,
-  nodeName_: true,
-  isArrayLike: true,
-  forEach: true,
-  forEachSorted: true,
-  reverseParams: true,
-  nextUid: true,
-  setHashKey: true,
-  extend: true,
-  toInt: true,
-  inherit: true,
-  merge: true,
-  noop: true,
-  identity: true,
-  valueFn: true,
-  isUndefined: true,
-  isDefined: true,
-  isObject: true,
-  isBlankObject: true,
-  isString: true,
-  isNumber: true,
-  isDate: true,
-  isArray: true,
-  isFunction: true,
-  isRegExp: true,
-  isWindow: true,
-  isScope: true,
-  isFile: true,
-  isFormData: true,
-  isBlob: true,
-  isBoolean: true,
-  isPromiseLike: true,
-  trim: true,
-  escapeForRegexp: true,
-  isElement: true,
-  makeMap: true,
-  includes: true,
-  arrayRemove: true,
-  copy: true,
-  equals: true,
-  csp: true,
-  jq: true,
-  concat: true,
-  sliceArgs: true,
-  bind: true,
-  toJsonReplacer: true,
-  toJson: true,
-  fromJson: true,
-  convertTimezoneToLocal: true,
-  timezoneToOffset: true,
-  startingTag: true,
-  tryDecodeURIComponent: true,
-  parseKeyValue: true,
-  toKeyValue: true,
-  encodeUriSegment: true,
-  encodeUriQuery: true,
-  angularInit: true,
-  bootstrap: true,
-  getTestability: true,
-  snake_case: true,
-  bindJQuery: true,
-  assertArg: true,
-  assertArgFn: true,
-  assertNotHasOwnProperty: true,
-  getter: true,
-  getBlockNodes: true,
-  hasOwnProperty: true,
-  createMap: true,
-  stringify: true,
-
-  NODE_TYPE_ELEMENT: true,
-  NODE_TYPE_ATTRIBUTE: true,
-  NODE_TYPE_TEXT: true,
-  NODE_TYPE_COMMENT: true,
-  NODE_TYPE_DOCUMENT: true,
-  NODE_TYPE_DOCUMENT_FRAGMENT: true,
+/* We need to tell ESLint what variables are being exported */
+/* exported
+  angular,
+  msie,
+  jqLite,
+  jQuery,
+  slice,
+  splice,
+  push,
+  toString,
+  ngMinErr,
+  angularModule,
+  uid,
+  REGEX_STRING_REGEXP,
+  VALIDITY_STATE_PROPERTY,
+
+  lowercase,
+  uppercase,
+  manualLowercase,
+  manualUppercase,
+  nodeName_,
+  isArrayLike,
+  forEach,
+  forEachSorted,
+  reverseParams,
+  nextUid,
+  setHashKey,
+  extend,
+  toInt,
+  inherit,
+  merge,
+  noop,
+  identity,
+  valueFn,
+  isUndefined,
+  isDefined,
+  isObject,
+  isBlankObject,
+  isString,
+  isNumber,
+  isDate,
+  isArray,
+  isFunction,
+  isRegExp,
+  isWindow,
+  isScope,
+  isFile,
+  isFormData,
+  isBlob,
+  isBoolean,
+  isPromiseLike,
+  trim,
+  escapeForRegexp,
+  isElement,
+  makeMap,
+  includes,
+  arrayRemove,
+  copy,
+  equals,
+  csp,
+  jq,
+  concat,
+  sliceArgs,
+  bind,
+  toJsonReplacer,
+  toJson,
+  fromJson,
+  convertTimezoneToLocal,
+  timezoneToOffset,
+  startingTag,
+  tryDecodeURIComponent,
+  parseKeyValue,
+  toKeyValue,
+  encodeUriSegment,
+  encodeUriQuery,
+  angularInit,
+  bootstrap,
+  getTestability,
+  snake_case,
+  bindJQuery,
+  assertArg,
+  assertArgFn,
+  assertNotHasOwnProperty,
+  getter,
+  getBlockNodes,
+  hasOwnProperty,
+  createMap,
+  stringify,
+
+  NODE_TYPE_ELEMENT,
+  NODE_TYPE_ATTRIBUTE,
+  NODE_TYPE_TEXT,
+  NODE_TYPE_COMMENT,
+  NODE_TYPE_DOCUMENT,
+  NODE_TYPE_DOCUMENT_FRAGMENT
 */
 
 ////////////////////////////////////
@@ -127,16 +128,18 @@ var uppercase = function(string) {return isString(string) ? string.toUpperCase()
 
 
 var manualLowercase = function(s) {
-  /* jshint bitwise: false */
+  /* eslint-disable no-bitwise */
   return isString(s)
       ? s.replace(/[A-Z]/g, function(ch) {return String.fromCharCode(ch.charCodeAt(0) | 32);})
       : s;
+  /* eslint-enable */
 };
 var manualUppercase = function(s) {
-  /* jshint bitwise: false */
+  /* eslint-disable no-bitwise */
   return isString(s)
       ? s.replace(/[a-z]/g, function(ch) {return String.fromCharCode(ch.charCodeAt(0) & ~32);})
       : s;
+  /* eslint-enable */
 };
 
 
@@ -686,8 +689,10 @@ var trim = function(value) {
 // http://docs.closure-library.googlecode.com/git/local_closure_goog_string_string.js.source.html#line1021
 // Prereq: s is a string.
 var escapeForRegexp = function(s) {
-  return s.replace(/([-()\[\]{}+?*.$\^|,:#<!\\])/g, '\\$1').
-           replace(/\x08/g, '\\x08');
+  return s
+    .replace(/([-()\[\]{}+?*.$\^|,:#<!\\])/g, '\\$1')
+    // eslint-disable-next-line no-control-regex
+    .replace(/\x08/g, '\\x08');
 };
 
 
@@ -911,10 +916,13 @@ function copy(source, destination) {
         return new source.constructor(copyElement(source.buffer), source.byteOffset, source.length);
 
       case '[object ArrayBuffer]':
-        //Support: IE10
+        // Support: IE10
         if (!source.slice) {
+          // If we're in this case we know the environment supports ArrayBuffer
+          /* eslint-disable no-undef */
           var copied = new ArrayBuffer(source.byteLength);
           new Uint8Array(copied).set(new Uint8Array(source));
+          /* eslint-enable */
           return copied;
         }
         return source.slice(0);
@@ -997,7 +1005,6 @@ function copy(source, destination) {
         angular.module('equalsExample', []).controller('ExampleController', ['$scope', function($scope) {
           $scope.user1 = {};
           $scope.user2 = {};
-          $scope.result;
           $scope.compare = function() {
             $scope.result = angular.equals($scope.user1, $scope.user2);
           };
@@ -1008,6 +1015,7 @@ function copy(source, destination) {
 function equals(o1, o2) {
   if (o1 === o2) return true;
   if (o1 === null || o2 === null) return false;
+  // eslint-disable-next-line no-self-compare
   if (o1 !== o1 && o2 !== o2) return true; // NaN === NaN
   var t1 = typeof o1, t2 = typeof o2, length, key, keySet;
   if (t1 === t2 && t1 === 'object') {
@@ -1072,9 +1080,8 @@ var csp = function() {
 
   function noUnsafeEval() {
     try {
-      /* jshint -W031, -W054 */
+      // eslint-disable-next-line no-new, no-new-func
       new Function('');
-      /* jshint +W031, +W054 */
       return false;
     } catch (e) {
       return true;
@@ -1126,7 +1133,8 @@ var jq = function() {
   var i, ii = ngAttrPrefixes.length, prefix, name;
   for (i = 0; i < ii; ++i) {
     prefix = ngAttrPrefixes[i];
-    if (el = window.document.querySelector('[' + prefix.replace(':', '\\:') + 'jq]')) {
+    el = window.document.querySelector('[' + prefix.replace(':', '\\:') + 'jq]');
+    if (el) {
       name = el.getAttribute(prefix + 'jq');
       break;
     }
@@ -1144,7 +1152,6 @@ function sliceArgs(args, startIndex) {
 }
 
 
-/* jshint -W101 */
 /**
  * @ngdoc function
  * @name angular.bind
@@ -1162,7 +1169,6 @@ function sliceArgs(args, startIndex) {
  * @param {...*} args Optional arguments to be prebound to the `fn` function call.
  * @returns {function()} Function that wraps the `fn` with all the specified bindings.
  */
-/* jshint +W101 */
 function bind(self, fn) {
   var curryArgs = arguments.length > 2 ? sliceArgs(arguments, 2) : [];
   if (isFunction(fn) && !(fn instanceof RegExp)) {
@@ -1298,7 +1304,7 @@ function startingTag(element) {
     // turns out IE does not let you set .html() on elements which
     // are not allowed to have children. So we just ignore it.
     element.empty();
-  } catch (e) {}
+  } catch (e) { /* empty */ }
   var elemHtml = jqLite('<div>').append(element).html();
   try {
     return element[0].nodeType === NODE_TYPE_TEXT ? lowercase(elemHtml) :
diff --git a/src/apis.js b/src/apis.js
index f8a29da9a45b..d9bd34f90de5 100644
--- a/src/apis.js
+++ b/src/apis.js
@@ -74,7 +74,7 @@ HashMap.prototype = {
   }
 };
 
-var $$HashMapProvider = [function() {
+var $$HashMapProvider = [/* @this */function() {
   this.$get = [function() {
     return HashMap;
   }];
diff --git a/src/auto/injector.js b/src/auto/injector.js
index 7eda310abc07..352561afa4d9 100644
--- a/src/auto/injector.js
+++ b/src/auto/injector.js
@@ -322,7 +322,6 @@ function annotate(fn, strictDi, name) {
 
 
 
-
 /**
  * @ngdoc service
  * @name $provide
@@ -707,11 +706,11 @@ function createInjector(modulesToLoad, strictDi) {
     if (!provider_.$get) {
       throw $injectorMinErr('pget', "Provider '{0}' must define $get factory method.", name);
     }
-    return providerCache[name + providerSuffix] = provider_;
+    return (providerCache[name + providerSuffix] = provider_);
   }
 
   function enforceReturnValue(name, factory) {
-    return function enforcedReturnValue() {
+    return /* @this */ function enforcedReturnValue() {
       var result = instanceInjector.invoke(factory, this);
       if (isUndefined(result)) {
         throw $injectorMinErr('undef', "Provider '{0}' must return a value from $get factory method.", name);
@@ -792,7 +791,7 @@ function createInjector(modulesToLoad, strictDi) {
           // unlike those of Chrome and IE
           // So if stack doesn't contain message, we create a new string that contains both.
           // Since error.stack is read-only in Safari, I'm overriding e and not e.stack here.
-          /* jshint -W022 */
+          // eslint-disable-next-line no-ex-assign
           e = e.message + '\n' + e.stack;
         }
         throw $injectorMinErr('modulerr', "Failed to instantiate module {0} due to:\n{1}",
@@ -819,7 +818,8 @@ function createInjector(modulesToLoad, strictDi) {
         try {
           path.unshift(serviceName);
           cache[serviceName] = INSTANTIATING;
-          return cache[serviceName] = factory(serviceName, caller);
+          cache[serviceName] = factory(serviceName, caller);
+          return cache[serviceName];
         } catch (err) {
           if (cache[serviceName] === INSTANTIATING) {
             delete cache[serviceName];
diff --git a/src/jqLite.js b/src/jqLite.js
index fe3ad25e84ae..f3ae97e6be38 100644
--- a/src/jqLite.js
+++ b/src/jqLite.js
@@ -11,9 +11,10 @@
  *     Or gives undesired access to variables likes document or window?    *
  * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * */
 
-/* global JQLitePrototype: true,
+/* global
+  JQLitePrototype: true,
   BOOLEAN_ATTR: true,
-  ALIASED_ATTR: true,
+  ALIASED_ATTR: true
 */
 
 //////////////////////////////////
@@ -135,9 +136,9 @@ JQLite._data = function(node) {
 function jqNextId() { return ++jqId; }
 
 
-var SPECIAL_CHARS_REGEXP = /([\:\-\_]+(.))/g;
+var SPECIAL_CHARS_REGEXP = /([:\-_]+(.))/g;
 var MOZ_HACK_REGEXP = /^moz([A-Z])/;
-var MOUSE_EVENT_MAP= { mouseleave: "mouseout", mouseenter: "mouseover"};
+var MOUSE_EVENT_MAP = { mouseleave: 'mouseout', mouseenter: 'mouseover' };
 var jqLiteMinErr = minErr('jqLite');
 
 /**
@@ -261,10 +262,9 @@ function jqLiteWrapNode(node, wrapper) {
 
 
 // IE9-11 has no method "contains" in SVG element and in Node.prototype. Bug #10259.
-var jqLiteContains = window.Node.prototype.contains || function(arg) {
-  // jshint bitwise: false
+var jqLiteContains = window.Node.prototype.contains || /* @this */ function(arg) {
+  // eslint-disable-next-line no-bitwise
   return !!(this.compareDocumentPosition(arg) & 16);
-  // jshint bitwise: true
 };
 
 /////////////////////////////////////////////
@@ -538,9 +538,8 @@ var JQLitePrototype = JQLite.prototype = {
     } else {
       this.on('DOMContentLoaded', trigger); // works for modern browsers and IE9
       // we can not use jqLite since we are not done loading and jQuery could be loaded later.
-      // jshint -W064
+      // eslint-disable-next-line new-cap
       JQLite(window).on('load', trigger); // fallback to window.onload for others
-      // jshint +W064
     }
   },
   toString: function() {
@@ -645,7 +644,7 @@ forEach({
     var lowercasedName = lowercase(name);
     if (BOOLEAN_ATTR[lowercasedName]) {
       if (isDefined(value)) {
-        if (!!value) {
+        if (value) {
           element[name] = true;
           element.setAttribute(name, lowercasedName);
         } else {
@@ -1069,6 +1068,7 @@ forEach({
 
 
 // Provider for private $$jqLite service
+/* @this */
 function $$jqLiteProvider() {
   this.$get = function $$jqLite() {
     return extend(JQLite, {
diff --git a/src/ng/anchorScroll.js b/src/ng/anchorScroll.js
index 3c739c142f22..50512b173253 100644
--- a/src/ng/anchorScroll.js
+++ b/src/ng/anchorScroll.js
@@ -3,6 +3,7 @@
 /**
  * @ngdoc provider
  * @name $anchorScrollProvider
+ * @this
  *
  * @description
  * Use `$anchorScrollProvider` to disable automatic scrolling whenever
@@ -84,7 +85,7 @@ function $AnchorScrollProvider() {
        <file name="script.js">
          angular.module('anchorScrollExample', [])
            .controller('ScrollController', ['$scope', '$location', '$anchorScroll',
-             function ($scope, $location, $anchorScroll) {
+             function($scope, $location, $anchorScroll) {
                $scope.gotoBottom = function() {
                  // set the location.hash to the id of
                  // the element you wish to scroll to.
@@ -130,7 +131,7 @@ function $AnchorScrollProvider() {
              $anchorScroll.yOffset = 50;   // always scroll by 50 extra pixels
            }])
            .controller('headerCtrl', ['$anchorScroll', '$location', '$scope',
-             function ($anchorScroll, $location, $scope) {
+             function($anchorScroll, $location, $scope) {
                $scope.gotoAnchor = function(x) {
                  var newHash = 'anchor' + x;
                  if ($location.hash() !== newHash) {
@@ -249,7 +250,7 @@ function $AnchorScrollProvider() {
       // first anchor with given name :-D
       else if ((elm = getFirstAnchor(document.getElementsByName(hash)))) scrollTo(elm);
 
-      // no element and hash == 'top', scroll to the top of the page
+      // no element and hash === 'top', scroll to the top of the page
       else if (hash === 'top') scrollTo(null);
     }
 
diff --git a/src/ng/animate.js b/src/ng/animate.js
index dec1c101d646..207933928c6d 100644
--- a/src/ng/animate.js
+++ b/src/ng/animate.js
@@ -53,13 +53,13 @@ function prepareAnimateOptions(options) {
       : {};
 }
 
-var $$CoreAnimateJsProvider = function() {
+var $$CoreAnimateJsProvider = /* @this */ function() {
   this.$get = noop;
 };
 
 // this is prefixed with Core since it conflicts with
 // the animateQueueProvider defined in ngAnimate/animateQueue.js
-var $$CoreAnimateQueueProvider = function() {
+var $$CoreAnimateQueueProvider = /* @this */ function() {
   var postDigestQueue = new HashMap();
   var postDigestElements = [];
 
@@ -72,17 +72,23 @@ var $$CoreAnimateQueueProvider = function() {
       pin: noop,
 
       push: function(element, event, options, domOperation) {
-        domOperation        && domOperation();
+        if (domOperation) {
+          domOperation();
+        }
 
         options = options || {};
-        options.from        && element.css(options.from);
-        options.to          && element.css(options.to);
+        if (options.from) {
+          element.css(options.from);
+        }
+        if (options.to) {
+          element.css(options.to);
+        }
 
         if (options.addClass || options.removeClass) {
           addRemoveClassesPostDigest(element, options.addClass, options.removeClass);
         }
 
-        var runner = new $$AnimateRunner(); // jshint ignore:line
+        var runner = new $$AnimateRunner();
 
         // since there are no animations to run the runner needs to be
         // notified that the animation call is complete.
@@ -126,8 +132,12 @@ var $$CoreAnimateQueueProvider = function() {
           });
 
           forEach(element, function(elm) {
-            toAdd    && jqLiteAddClass(elm, toAdd);
-            toRemove && jqLiteRemoveClass(elm, toRemove);
+            if (toAdd) {
+              jqLiteAddClass(elm, toAdd);
+            }
+            if (toRemove) {
+              jqLiteRemoveClass(elm, toRemove);
+            }
           });
           postDigestQueue.remove(element);
         }
@@ -167,7 +177,7 @@ var $$CoreAnimateQueueProvider = function() {
  *
  * To see the functional implementation check out `src/ngAnimate/animate.js`.
  */
-var $AnimateProvider = ['$provide', function($provide) {
+var $AnimateProvider = ['$provide', /* @this */ function($provide) {
   var provider = this;
 
   this.$$registeredAnimations = Object.create(null);
@@ -260,7 +270,11 @@ var $AnimateProvider = ['$provide', function($provide) {
           afterElement = null;
         }
       }
-      afterElement ? afterElement.after(element) : parentElement.prepend(element);
+      if (afterElement) {
+        afterElement.after(element);
+      } else {
+        parentElement.prepend(element);
+      }
     }
 
     /**
@@ -403,7 +417,9 @@ var $AnimateProvider = ['$provide', function($provide) {
        * @param {Promise} animationPromise The animation promise that is returned when an animation is started.
        */
       cancel: function(runner) {
-        runner.end && runner.end();
+        if (runner.end) {
+          runner.end();
+        }
       },
 
       /**
diff --git a/src/ng/animateCss.js b/src/ng/animateCss.js
index 2e133167a6c3..6611c49ea2ee 100644
--- a/src/ng/animateCss.js
+++ b/src/ng/animateCss.js
@@ -1,9 +1,12 @@
 'use strict';
 
+/* exported $CoreAnimateCssProvider */
+
 /**
  * @ngdoc service
  * @name $animateCss
  * @kind object
+ * @this
  *
  * @description
  * This is the core version of `$animateCss`. By default, only when the `ngAnimate` is included,
@@ -36,7 +39,6 @@ var $CoreAnimateCssProvider = function() {
         options.from = null;
       }
 
-      /* jshint newcap: false */
       var closed, runner = new $$AnimateRunner();
       return {
         start: run,
diff --git a/src/ng/animateRunner.js b/src/ng/animateRunner.js
index adc052775501..5b0d6615cdec 100644
--- a/src/ng/animateRunner.js
+++ b/src/ng/animateRunner.js
@@ -1,6 +1,6 @@
 'use strict';
 
-var $$AnimateAsyncRunFactoryProvider = function() {
+var $$AnimateAsyncRunFactoryProvider = /* @this */ function() {
   this.$get = ['$$rAF', function($$rAF) {
     var waitQueue = [];
 
@@ -21,13 +21,17 @@ var $$AnimateAsyncRunFactoryProvider = function() {
         passed = true;
       });
       return function(callback) {
-        passed ? callback() : waitForTick(callback);
+        if (passed) {
+          callback();
+        } else {
+          waitForTick(callback);
+        }
       };
     };
   }];
 };
 
-var $$AnimateRunnerFactoryProvider = function() {
+var $$AnimateRunnerFactoryProvider = /* @this */ function() {
   this.$get = ['$q', '$sniffer', '$$animateAsyncRun', '$$isDocumentHidden', '$timeout',
        function($q,   $sniffer,   $$animateAsyncRun,   $$isDocumentHidden,   $timeout) {
 
@@ -110,7 +114,11 @@ var $$AnimateRunnerFactoryProvider = function() {
           var self = this;
           this.promise = $q(function(resolve, reject) {
             self.done(function(status) {
-              status === false ? reject() : resolve();
+              if (status === false) {
+                reject();
+              } else {
+                resolve();
+              }
             });
           });
         }
diff --git a/src/ng/browser.js b/src/ng/browser.js
index 4a1d21bcc69e..c5102fd28a8a 100644
--- a/src/ng/browser.js
+++ b/src/ng/browser.js
@@ -302,7 +302,7 @@ function Browser(window, document, $log, $sniffer) {
    */
   self.baseHref = function() {
     var href = baseElement.attr('href');
-    return href ? href.replace(/^(https?\:)?\/\/[^\/]*/, '') : '';
+    return href ? href.replace(/^(https?:)?\/\/[^\/]*/, '') : '';
   };
 
   /**
@@ -353,6 +353,7 @@ function Browser(window, document, $log, $sniffer) {
 
 }
 
+/* @this */
 function $BrowserProvider() {
   this.$get = ['$window', '$log', '$sniffer', '$document',
       function($window, $log, $sniffer, $document) {
diff --git a/src/ng/cacheFactory.js b/src/ng/cacheFactory.js
index 53d3acaa8688..ae121d3bfacb 100644
--- a/src/ng/cacheFactory.js
+++ b/src/ng/cacheFactory.js
@@ -3,6 +3,7 @@
 /**
  * @ngdoc service
  * @name $cacheFactory
+ * @this
  *
  * @description
  * Factory that constructs {@link $cacheFactory.Cache Cache} objects and gives access to
@@ -138,7 +139,7 @@ function $CacheFactoryProvider() {
        *  }));
        * ```
        */
-      return caches[cacheId] = {
+      return (caches[cacheId] = {
 
         /**
          * @ngdoc method
@@ -282,7 +283,7 @@ function $CacheFactoryProvider() {
         info: function() {
           return extend({}, stats, {size: size});
         }
-      };
+      });
 
 
       /**
@@ -356,6 +357,7 @@ function $CacheFactoryProvider() {
 /**
  * @ngdoc service
  * @name $templateCache
+ * @this
  *
  * @description
  * The first time a template is used, it is loaded in the template cache for quick retrieval. You
diff --git a/src/ng/compile.js b/src/ng/compile.js
index dbaeba81f9b6..f5b0d450edea 100644
--- a/src/ng/compile.js
+++ b/src/ng/compile.js
@@ -958,11 +958,12 @@ var _UNINITIALIZED_VALUE = new UNINITIALIZED_VALUE();
  * @description
  */
 $CompileProvider.$inject = ['$provide', '$$sanitizeUriProvider'];
+/* @this */
 function $CompileProvider($provide, $$sanitizeUriProvider) {
   var hasDirectives = {},
       Suffix = 'Directive',
-      COMMENT_DIRECTIVE_REGEXP = /^\s*directive\:\s*([\w\-]+)\s+(.*)$/,
-      CLASS_DIRECTIVE_REGEXP = /(([\w\-]+)(?:\:([^;]+))?;?)/,
+      COMMENT_DIRECTIVE_REGEXP = /^\s*directive:\s*([\w\-]+)\s+(.*)$/,
+      CLASS_DIRECTIVE_REGEXP = /(([\w\-]+)(?::([^;]+))?;?)/,
       ALL_OR_NOTHING_ATTRS = makeMap('ngSrc,ngSrcset,src,srcset'),
       REQUIRE_PREFIX_REGEXP = /^(?:(\^\^?)?(\?)?(\^\^?)?)?/;
 
@@ -1216,7 +1217,7 @@ function $CompileProvider($provide, $$sanitizeUriProvider) {
     function factory($injector) {
       function makeInjectable(fn) {
         if (isFunction(fn) || isArray(fn)) {
-          return function(tElement, tAttrs) {
+          return /* @this */ function(tElement, tAttrs) {
             return $injector.invoke(fn, this, {$element: tElement, $attrs: tAttrs});
           };
         } else {
@@ -1621,13 +1622,15 @@ function $CompileProvider($provide, $$sanitizeUriProvider) {
 
         // fire observers
         var $$observers = this.$$observers;
-        $$observers && forEach($$observers[observer], function(fn) {
-          try {
-            fn(value);
-          } catch (e) {
-            $exceptionHandler(e);
-          }
-        });
+        if ($$observers) {
+          forEach($$observers[observer], function(fn) {
+            try {
+              fn(value);
+            } catch (e) {
+              $exceptionHandler(e);
+            }
+          });
+        }
       },
 
 
@@ -1891,7 +1894,7 @@ function $CompileProvider($provide, $$sanitizeUriProvider) {
           stableNodeList = new Array(nodeListLength);
 
           // create a sparse array by only copying the elements which have a linkFn
-          for (i = 0; i < linkFns.length; i+=3) {
+          for (i = 0; i < linkFns.length; i += 3) {
             idx = linkFns[i];
             stableNodeList[idx] = nodeList[idx];
           }
@@ -1998,7 +2001,8 @@ function $CompileProvider($provide, $$sanitizeUriProvider) {
 
             // support ngAttr attribute binding
             ngAttrName = directiveNormalize(name);
-            if (isNgAttr = NG_ATTR_BINDING.test(ngAttrName)) {
+            isNgAttr = NG_ATTR_BINDING.test(ngAttrName);
+            if (isNgAttr) {
               name = name.replace(PREFIX_REGEXP, '')
                 .substr(8).replace(/_(.)/g, function(match, letter) {
                   return letter.toUpperCase();
@@ -2032,7 +2036,7 @@ function $CompileProvider($provide, $$sanitizeUriProvider) {
               className = className.animVal;
           }
           if (isString(className) && className !== '') {
-            while (match = CLASS_DIRECTIVE_REGEXP.exec(className)) {
+            while ((match = CLASS_DIRECTIVE_REGEXP.exec(className))) {
               nName = directiveNormalize(match[2]);
               if (addDirective(directives, nName, 'C', maxPriority, ignoreDirective)) {
                 attrs[nName] = trim(match[3]);
@@ -2142,7 +2146,7 @@ function $CompileProvider($provide, $$sanitizeUriProvider) {
       if (eager) {
         return compile($compileNodes, transcludeFn, maxPriority, ignoreDirective, previousCompileContext);
       }
-      return function lazyCompilation() {
+      return /* @this */ function lazyCompilation() {
         if (!compiled) {
           compiled = compile($compileNodes, transcludeFn, maxPriority, ignoreDirective, previousCompileContext);
 
@@ -2218,7 +2222,9 @@ function $CompileProvider($provide, $$sanitizeUriProvider) {
           break; // prevent further processing of directives
         }
 
-        if (directiveValue = directive.scope) {
+        directiveValue = directive.scope;
+
+        if (directiveValue) {
 
           // skip the check for directives with async templates, we'll check the derived sync
           // directive when the template arrives
@@ -2252,7 +2258,7 @@ function $CompileProvider($provide, $$sanitizeUriProvider) {
             || (directive.transclude && !directive.$$tlb))) {
                 var candidateDirective;
 
-                for (var scanningIndex = i + 1; candidateDirective = directives[scanningIndex++];) {
+                for (var scanningIndex = i + 1; (candidateDirective = directives[scanningIndex++]);) {
                     if ((candidateDirective.transclude && !candidateDirective.$$tlb)
                         || (candidateDirective.replace && (candidateDirective.templateUrl || candidateDirective.template))) {
                         mightHaveMultipleTransclusionError = true;
@@ -2271,7 +2277,9 @@ function $CompileProvider($provide, $$sanitizeUriProvider) {
           controllerDirectives[directiveName] = directive;
         }
 
-        if (directiveValue = directive.transclude) {
+        directiveValue = directive.transclude;
+
+        if (directiveValue) {
           hasTranscludeDirective = true;
 
           // Special case ngIf and ngRepeat so that we don't complain about duplicate transclusion.
@@ -2442,9 +2450,8 @@ function $CompileProvider($provide, $$sanitizeUriProvider) {
             replaceDirective = directive;
           }
 
-          /* jshint -W021 */
+          // eslint-disable-next-line no-func-assign
           nodeLinkFn = compileTemplateUrl(directives.splice(i, directives.length - i), $compileNode,
-          /* jshint +W021 */
               templateAttrs, jqCollection, hasTranscludeDirective && childTranscludeFn, preLinkFns, postLinkFns, {
                 controllerDirectives: controllerDirectives,
                 newScopeDirective: (newScopeDirective !== directive) && newScopeDirective,
@@ -2575,7 +2582,9 @@ function $CompileProvider($provide, $$sanitizeUriProvider) {
             // from setupControllers
             controller.instance = controllerResult;
             $element.data('$' + controllerDirective.name + 'Controller', controllerResult);
-            controller.bindingInfo.removeWatches && controller.bindingInfo.removeWatches();
+            if (controller.bindingInfo.removeWatches) {
+              controller.bindingInfo.removeWatches();
+            }
             controller.bindingInfo =
               initializeDirectiveBindings(controllerScope, attrs, controller.instance, bindings, controllerDirective);
           }
@@ -2636,7 +2645,9 @@ function $CompileProvider($provide, $$sanitizeUriProvider) {
         if (newIsolateScopeDirective && (newIsolateScopeDirective.template || newIsolateScopeDirective.templateUrl === null)) {
           scopeToChild = isolateScope;
         }
-        childLinkFn && childLinkFn(scopeToChild, linkNode.childNodes, undefined, boundTranscludeFn);
+        if (childLinkFn) {
+          childLinkFn(scopeToChild, linkNode.childNodes, undefined, boundTranscludeFn);
+        }
 
         // POSTLINKING
         for (i = postLinkFns.length - 1; i >= 0; i--) {
@@ -2857,8 +2868,7 @@ function $CompileProvider($provide, $$sanitizeUriProvider) {
      */
     function mergeTemplateAttributes(dst, src) {
       var srcAttr = src.$attr,
-          dstAttr = dst.$attr,
-          $element = dst.$$element;
+          dstAttr = dst.$attr;
 
       // reapply the old attributes to the new element
       forEach(dst, function(value, key) {
@@ -3270,7 +3280,7 @@ function $CompileProvider($provide, $$sanitizeUriProvider) {
 
           case '@':
             if (!optional && !hasOwnProperty.call(attrs, attrName)) {
-              destination[scopeName] = attrs[attrName] = void 0;
+              destination[scopeName] = attrs[attrName] = undefined;
             }
             attrs.$observe(attrName, function(value) {
               if (isString(value) || isBoolean(value)) {
@@ -3296,7 +3306,7 @@ function $CompileProvider($provide, $$sanitizeUriProvider) {
           case '=':
             if (!hasOwnProperty.call(attrs, attrName)) {
               if (optional) break;
-              attrs[attrName] = void 0;
+              attrs[attrName] = undefined;
             }
             if (optional && !attrs[attrName]) break;
 
@@ -3304,6 +3314,7 @@ function $CompileProvider($provide, $$sanitizeUriProvider) {
             if (parentGet.literal) {
               compare = equals;
             } else {
+              // eslint-disable-next-line no-self-compare
               compare = function simpleCompare(a, b) { return a === b || (a !== a && b !== b); };
             }
             parentSet = parentGet.assign || function() {
@@ -3325,7 +3336,8 @@ function $CompileProvider($provide, $$sanitizeUriProvider) {
                   parentSet(scope, parentValue = destination[scopeName]);
                 }
               }
-              return lastValue = parentValue;
+              lastValue = parentValue;
+              return lastValue;
             };
             parentValueWatch.$stateful = true;
             if (definition.collection) {
@@ -3339,7 +3351,7 @@ function $CompileProvider($provide, $$sanitizeUriProvider) {
           case '<':
             if (!hasOwnProperty.call(attrs, attrName)) {
               if (optional) break;
-              attrs[attrName] = void 0;
+              attrs[attrName] = undefined;
             }
             if (optional && !attrs[attrName]) break;
 
@@ -3420,7 +3432,7 @@ function SimpleChange(previous, current) {
 SimpleChange.prototype.isFirstChange = function() { return this.previousValue === _UNINITIALIZED_VALUE; };
 
 
-var PREFIX_REGEXP = /^((?:x|data)[\:\-_])/i;
+var PREFIX_REGEXP = /^((?:x|data)[:\-_])/i;
 /**
  * Converts all accepted directives format into proper directive name.
  * @param name Name to normalize
diff --git a/src/ng/controller.js b/src/ng/controller.js
index b240d4554b07..39f5c319e820 100644
--- a/src/ng/controller.js
+++ b/src/ng/controller.js
@@ -16,6 +16,8 @@ function identifierForController(controller, ident) {
 /**
  * @ngdoc provider
  * @name $controllerProvider
+ * @this
+ *
  * @description
  * The {@link ng.$controller $controller service} is used by Angular to create new
  * controllers.
@@ -113,7 +115,7 @@ function $ControllerProvider() {
             "Badly formed controller string '{0}'. " +
             "Must match `__name__ as __id__` or `__name__`.", expression);
         }
-        constructor = match[1],
+        constructor = match[1];
         identifier = identifier || match[3];
         expression = controllers.hasOwnProperty(constructor)
             ? controllers[constructor]
@@ -142,8 +144,7 @@ function $ControllerProvider() {
           addIdentifier(locals, identifier, instance, constructor || expression.name);
         }
 
-        var instantiate;
-        return instantiate = extend(function $controllerInit() {
+        return extend(function $controllerInit() {
           var result = $injector.invoke(expression, instance, locals, constructor);
           if (result !== instance && (isObject(result) || isFunction(result))) {
             instance = result;
diff --git a/src/ng/cookieReader.js b/src/ng/cookieReader.js
index 1a7e52071246..85bc165d1f6c 100644
--- a/src/ng/cookieReader.js
+++ b/src/ng/cookieReader.js
@@ -51,6 +51,7 @@ function $$CookieReader($document) {
 
 $$CookieReader.$inject = ['$document'];
 
+/* @this */
 function $$CookieReaderProvider() {
   this.$get = $$CookieReader;
 }
diff --git a/src/ng/directive/input.js b/src/ng/directive/input.js
index eb41a9c16caa..1658dc5580e6 100644
--- a/src/ng/directive/input.js
+++ b/src/ng/directive/input.js
@@ -1,12 +1,11 @@
 'use strict';
 
-/* global VALID_CLASS: false,
+/* global
+  VALID_CLASS: false,
   INVALID_CLASS: false,
   PRISTINE_CLASS: false,
   DIRTY_CLASS: false,
-  UNTOUCHED_CLASS: false,
-  TOUCHED_CLASS: false,
-  ngModelMinErr: false,
+  ngModelMinErr: false
 */
 
 // Regex code was initially obtained from SO prior to modification: https://stackoverflow.com/questions/3143070/javascript-regex-iso-datetime#answer-3143231
@@ -24,9 +23,8 @@ var ISO_DATE_REGEXP = /^\d{4,}-[01]\d-[0-3]\dT[0-2]\d:[0-5]\d:[0-5]\d\.\d+(?:[+-
 //   9. Fragment
 //                 1111111111111111 222   333333    44444        555555555555555555555555    666     77777777     8888888     999
 var URL_REGEXP = /^[a-z][a-z\d.+-]*:\/*(?:[^:@]+(?::[^@]+)?@)?(?:[^\s:/?#]+|\[[a-f\d:]+\])(?::\d+)?(?:\/[^?#]*)?(?:\?[^#]*)?(?:#.*)?$/i;
-/* jshint maxlen:220 */
+// eslint-disable-next-line max-len
 var EMAIL_REGEXP = /^(?=.{1,254}$)(?=.{1,64}@)[-!#$%&'*+\/0-9=?A-Z^_`a-z{|}~]+(\.[-!#$%&'*+\/0-9=?A-Z^_`a-z{|}~]+)*@[A-Za-z0-9]([A-Za-z0-9-]{0,61}[A-Za-z0-9])?(\.[A-Za-z0-9]([A-Za-z0-9-]{0,61}[A-Za-z0-9])?)*$/;
-/* jshint maxlen:200 */
 var NUMBER_REGEXP = /^\s*(\-|\+)?(\d+|(\d*(\.\d*)))([eE][+-]?\d+)?\s*$/;
 var DATE_REGEXP = /^(\d{4,})-(\d{2})-(\d{2})$/;
 var DATETIMELOCAL_REGEXP = /^(\d{4,})-(\d\d)-(\d\d)T(\d\d):(\d\d)(?::(\d\d)(\.\d{1,3})?)?$/;
@@ -207,7 +205,6 @@ var inputType = {
      <file name="protractor.js" type="protractor">
         var value = element(by.binding('example.value | date: "yyyy-MM-dd"'));
         var valid = element(by.binding('myForm.input.$valid'));
-        var input = element(by.model('example.value'));
 
         // currently protractor/webdriver does not support
         // sending keys to all known HTML5 input controls
@@ -310,7 +307,6 @@ var inputType = {
     <file name="protractor.js" type="protractor">
       var value = element(by.binding('example.value | date: "yyyy-MM-ddTHH:mm:ss"'));
       var valid = element(by.binding('myForm.input.$valid'));
-      var input = element(by.model('example.value'));
 
       // currently protractor/webdriver does not support
       // sending keys to all known HTML5 input controls
@@ -414,7 +410,6 @@ var inputType = {
    <file name="protractor.js" type="protractor">
       var value = element(by.binding('example.value | date: "HH:mm:ss"'));
       var valid = element(by.binding('myForm.input.$valid'));
-      var input = element(by.model('example.value'));
 
       // currently protractor/webdriver does not support
       // sending keys to all known HTML5 input controls
@@ -519,7 +514,6 @@ var inputType = {
     <file name="protractor.js" type="protractor">
       var value = element(by.binding('example.value | date: "yyyy-Www"'));
       var valid = element(by.binding('myForm.input.$valid'));
-      var input = element(by.model('example.value'));
 
       // currently protractor/webdriver does not support
       // sending keys to all known HTML5 input controls
@@ -623,7 +617,6 @@ var inputType = {
    <file name="protractor.js" type="protractor">
       var value = element(by.binding('example.value | date: "yyyy-MM"'));
       var valid = element(by.binding('myForm.input.$valid'));
-      var input = element(by.model('example.value'));
 
       // currently protractor/webdriver does not support
       // sending keys to all known HTML5 input controls
@@ -1278,7 +1271,7 @@ function baseInputType(scope, element, attr, ctrl, $sniffer, $browser) {
       }
     };
 
-    element.on('keydown', function(event) {
+    element.on('keydown', /* @this */ function(event) {
       var key = event.keyCode;
 
       // ignore
@@ -1303,7 +1296,7 @@ function baseInputType(scope, element, attr, ctrl, $sniffer, $browser) {
   // For these event types, when native validators are present and the browser supports the type,
   // check for validity changes on various DOM events.
   if (PARTIAL_VALIDATION_TYPES[type] && ctrl.$$hasNativeValidators && type === attr.type) {
-    element.on(PARTIAL_VALIDATION_EVENTS, function(ev) {
+    element.on(PARTIAL_VALIDATION_EVENTS, /* @this */ function(ev) {
       if (!timeout) {
         var validity = this[VALIDITY_STATE_PROPERTY];
         var origBadInput = validity.badInput;
@@ -1705,7 +1698,7 @@ function radioInputType(scope, element, attr, ctrl) {
       value = trim(value);
     }
     // Strict comparison would cause a BC
-    /* jshint eqeqeq:false */
+    // eslint-disable-next-line eqeqeq
     element[0].checked = (value == ctrl.$viewValue);
   };
 
@@ -2037,5 +2030,3 @@ var ngValueDirective = function() {
   };
 };
 
-
-
diff --git a/src/ng/directive/ngClass.js b/src/ng/directive/ngClass.js
index 3e377bfc1bf6..7e138b065dc2 100644
--- a/src/ng/directive/ngClass.js
+++ b/src/ng/directive/ngClass.js
@@ -1,5 +1,11 @@
 'use strict';
 
+/* exported
+  ngClassDirective,
+  ngClassEvenDirective,
+  ngClassOddDirective
+*/
+
 function classDirective(name, selector) {
   name = 'ngClass' + name;
   return ['$animate', function($animate) {
@@ -17,14 +23,17 @@ function classDirective(name, selector) {
 
         if (name !== 'ngClass') {
           scope.$watch('$index', function($index, old$index) {
-            // jshint bitwise: false
+            /* eslint-disable no-bitwise */
             var mod = $index & 1;
             if (mod !== (old$index & 1)) {
               var classes = arrayClasses(scope.$eval(attr[name]));
-              mod === selector ?
-                addClasses(classes) :
+              if (mod === selector) {
+                addClasses(classes);
+              } else {
                 removeClasses(classes);
+              }
             }
+            /* eslint-enable */
           });
         }
 
@@ -69,9 +78,8 @@ function classDirective(name, selector) {
         }
 
         function ngClassWatchAction(newVal) {
-          // jshint bitwise: false
+          // eslint-disable-next-line no-bitwise
           if (selector === true || (scope.$index & 1) === selector) {
-          // jshint bitwise: true
             var newClasses = arrayClasses(newVal || []);
             if (!oldVal) {
               addClasses(newClasses);
diff --git a/src/ng/directive/ngController.js b/src/ng/directive/ngController.js
index fe742d7d6ca7..565d81c7c6e4 100644
--- a/src/ng/directive/ngController.js
+++ b/src/ng/directive/ngController.js
@@ -89,7 +89,8 @@
  *      this.name = "John Smith";
  *      this.contacts = [
  *        {type: 'phone', value: '408 555 1212'},
- *        {type: 'email', value: 'john.smith@example.org'} ];
+ *        {type: 'email', value: 'john.smith@example.org'}
+ *      ];
  *    }
  *
  *    SettingsController1.prototype.greet = function() {
@@ -172,7 +173,8 @@
  *     $scope.name = "John Smith";
  *     $scope.contacts = [
  *       {type:'phone', value:'408 555 1212'},
- *       {type:'email', value:'john.smith@example.org'} ];
+ *       {type:'email', value:'john.smith@example.org'}
+ *     ];
  *
  *     $scope.greet = function() {
  *       alert($scope.name);
diff --git a/src/ng/directive/ngCsp.js b/src/ng/directive/ngCsp.js
index da0c93430949..a2866dc1ea59 100644
--- a/src/ng/directive/ngCsp.js
+++ b/src/ng/directive/ngCsp.js
@@ -102,15 +102,14 @@
         </file>
         <file name="script.js">
            angular.module('cspExample', [])
-             .controller('MainController', function() {
+             .controller('MainController', function MainController() {
                 this.counter = 0;
                 this.inc = function() {
                   this.counter++;
                 };
                 this.evil = function() {
-                  // jshint evil:true
                   try {
-                    eval('1+2');
+                    eval('1+2'); // eslint-disable-line no-eval
                   } catch (e) {
                     this.evilError = e.message;
                   }
diff --git a/src/ng/directive/ngInclude.js b/src/ng/directive/ngInclude.js
index bc87af195a62..4409c7dee9da 100644
--- a/src/ng/directive/ngInclude.js
+++ b/src/ng/directive/ngInclude.js
@@ -68,8 +68,8 @@
       angular.module('includeExample', ['ngAnimate'])
         .controller('ExampleController', ['$scope', function($scope) {
           $scope.templates =
-            [ { name: 'template1.html', url: 'template1.html'},
-              { name: 'template2.html', url: 'template2.html'} ];
+            [{ name: 'template1.html', url: 'template1.html'},
+             { name: 'template2.html', url: 'template2.html'}];
           $scope.template = $scope.templates[0];
         }]);
      </file>
@@ -127,7 +127,7 @@
       });
 
       it('should load template2.html', function() {
-        if (browser.params.browser == 'firefox') {
+        if (browser.params.browser === 'firefox') {
           // Firefox can't handle using selects
           // See https://github.com/angular/protractor/issues/480
           return;
@@ -138,7 +138,7 @@
       });
 
       it('should change to blank', function() {
-        if (browser.params.browser == 'firefox') {
+        if (browser.params.browser === 'firefox') {
           // Firefox can't handle using selects
           return;
         }
diff --git a/src/ng/directive/ngModel.js b/src/ng/directive/ngModel.js
index d6ac476aa350..d559d45cd05c 100644
--- a/src/ng/directive/ngModel.js
+++ b/src/ng/directive/ngModel.js
@@ -5,7 +5,7 @@
   PRISTINE_CLASS: true,
   DIRTY_CLASS: true,
   UNTOUCHED_CLASS: true,
-  TOUCHED_CLASS: true,
+  TOUCHED_CLASS: true
 */
 
 var VALID_CLASS = 'ng-valid',
@@ -178,7 +178,7 @@ is set to `true`. The parse error is stored in `ngModel.$error.parse`.
                 var html = element.html();
                 // When we clear the content editable the browser leaves a <br> behind
                 // If strip-br attribute is provided then we strip this out
-                if ( attrs.stripBr && html == '<br>' ) {
+                if (attrs.stripBr && html === '<br>') {
                   html = '';
                 }
                 ngModel.$setViewValue(html);
@@ -200,7 +200,7 @@ is set to `true`. The parse error is stored in `ngModel.$error.parse`.
     </file>
     <file name="protractor.js" type="protractor">
     it('should data-bind and become invalid', function() {
-      if (browser.params.browser == 'safari' || browser.params.browser == 'firefox') {
+      if (browser.params.browser === 'safari' || browser.params.browser === 'firefox') {
         // SafariDriver can't handle contenteditable
         // and Firefox driver can't clear contenteditables very well
         return;
@@ -221,7 +221,7 @@ is set to `true`. The parse error is stored in `ngModel.$error.parse`.
  *
  */
 var NgModelController = ['$scope', '$exceptionHandler', '$attrs', '$element', '$parse', '$animate', '$timeout', '$rootScope', '$q', '$interpolate',
-    function($scope, $exceptionHandler, $attr, $element, $parse, $animate, $timeout, $rootScope, $q, $interpolate) {
+    /* @this */ function($scope, $exceptionHandler, $attr, $element, $parse, $animate, $timeout, $rootScope, $q, $interpolate) {
   this.$viewValue = Number.NaN;
   this.$modelValue = Number.NaN;
   this.$$rawModelValue = undefined; // stores the parsed modelValue / model set from scope regardless of validity.
@@ -317,6 +317,7 @@ var NgModelController = ['$scope', '$exceptionHandler', '$attrs', '$element', '$
    * @returns {boolean} True if `value` is "empty".
    */
   this.$isEmpty = function(value) {
+    // eslint-disable-next-line no-self-compare
     return isUndefined(value) || value === '' || value === null || value !== value;
   };
 
@@ -471,7 +472,7 @@ var NgModelController = ['$scope', '$exceptionHandler', '$attrs', '$element', '$
    *       $scope.model = {};
    *
    *       $scope.setEmpty = function(e, value, rollback) {
-   *         if (e.keyCode == 27) {
+   *         if (e.keyCode === 27) {
    *           e.preventDefault();
    *           if (rollback) {
    *             $scope.myForm[value].$rollbackViewValue();
@@ -864,6 +865,7 @@ var NgModelController = ['$scope', '$exceptionHandler', '$attrs', '$element', '$
     // TODO(perf): why not move this to the action fn?
     if (modelValue !== ctrl.$modelValue &&
        // checks for NaN is needed to allow setting the model to NaN when there's an asyncValidator
+        // eslint-disable-next-line no-self-compare
        (ctrl.$modelValue === ctrl.$modelValue || modelValue === modelValue)
     ) {
       ctrl.$modelValue = ctrl.$$rawModelValue = modelValue;
@@ -1136,8 +1138,6 @@ var ngModelDirective = ['$rootScope', function($rootScope) {
 
 
 
-'use strict';
-
 var DEFAULT_REGEXP = /(\s+|^)default(\s+|$)/;
 
 /**
@@ -1213,7 +1213,7 @@ var DEFAULT_REGEXP = /(\s+|^)default(\s+|$)/;
           $scope.user = { name: 'John', data: '' };
 
           $scope.cancel = function(e) {
-            if (e.keyCode == 27) {
+            if (e.keyCode === 27) {
               $scope.userForm.userName.$rollbackViewValue();
             }
           };
@@ -1304,7 +1304,7 @@ var DEFAULT_REGEXP = /(\s+|^)default(\s+|$)/;
 var ngModelOptionsDirective = function() {
   return {
     restrict: 'A',
-    controller: ['$scope', '$attrs', function($scope, $attrs) {
+    controller: ['$scope', '$attrs', function NgModelOptionsController($scope, $attrs) {
       var that = this;
       this.$options = copy($scope.$eval($attrs.ngModelOptions));
       // Allow adding/overriding bound events
diff --git a/src/ng/directive/ngOptions.js b/src/ng/directive/ngOptions.js
index 5f25db40e2f0..8a1d6739d260 100644
--- a/src/ng/directive/ngOptions.js
+++ b/src/ng/directive/ngOptions.js
@@ -1,5 +1,7 @@
 'use strict';
 
+/* exported ngOptionsDirective */
+
 /* global jqLiteRemove */
 
 var ngOptionsMinErr = minErr('ngOptions');
@@ -229,7 +231,7 @@ var ngOptionsMinErr = minErr('ngOptions');
     </example>
  */
 
-// jshint maxlen: false
+/* eslint-disable max-len */
 //                     //00001111111111000000000002222222222000000000000000000000333333333300000000000000000000000004444444444400000000000005555555555555550000000006666666666666660000000777777777777777000000000000000888888888800000000000000000009999999999
 var NG_OPTIONS_REGEXP = /^\s*([\s\S]+?)(?:\s+as\s+([\s\S]+?))?(?:\s+group\s+by\s+([\s\S]+?))?(?:\s+disable\s+when\s+([\s\S]+?))?\s+for\s+(?:([\$\w][\$\w]*)|(?:\(\s*([\$\w][\$\w]*)\s*,\s*([\$\w][\$\w]*)\s*\)))\s+in\s+([\s\S]+?)(?:\s+track\s+by\s+([\s\S]+?))?$/;
                         // 1: value expression (valueFn)
@@ -241,7 +243,7 @@ var NG_OPTIONS_REGEXP = /^\s*([\s\S]+?)(?:\s+as\s+([\s\S]+?))?(?:\s+group\s+by\s
                         // 7: object item value variable name
                         // 8: collection expression
                         // 9: track by expression
-// jshint maxlen: 100
+/* eslint-enable */
 
 
 var ngOptionsDirective = ['$compile', '$document', '$parse', function($compile, $document, $parse) {
diff --git a/src/ng/directive/ngRepeat.js b/src/ng/directive/ngRepeat.js
index 53d950f2d5c7..26d357b9487a 100644
--- a/src/ng/directive/ngRepeat.js
+++ b/src/ng/directive/ngRepeat.js
@@ -1,5 +1,7 @@
 'use strict';
 
+/* exported ngRepeatDirective */
+
 /**
  * @ngdoc directive
  * @name ngRepeat
@@ -241,7 +243,7 @@
           <li class="animate-repeat" ng-repeat="friend in friends | filter:q as results">
             [{{$index + 1}}] {{friend.name}} who is {{friend.age}} years old.
           </li>
-          <li class="animate-repeat" ng-if="results.length == 0">
+          <li class="animate-repeat" ng-if="results.length === 0">
             <strong>No results found...</strong>
           </li>
         </ul>
@@ -334,9 +336,8 @@ var ngRepeatDirective = ['$parse', '$animate', '$compile', function($parse, $ani
     scope.$first = (index === 0);
     scope.$last = (index === (arrayLength - 1));
     scope.$middle = !(scope.$first || scope.$last);
-    // jshint bitwise: false
-    scope.$odd = !(scope.$even = (index&1) === 0);
-    // jshint bitwise: true
+    // eslint-disable-next-line no-bitwise
+    scope.$odd = !(scope.$even = (index & 1) === 0);
   };
 
   var getBlockStart = function(block) {
diff --git a/src/ng/directive/ngSwitch.js b/src/ng/directive/ngSwitch.js
index 4d2831e485a0..1cfbdd7c730c 100644
--- a/src/ng/directive/ngSwitch.js
+++ b/src/ng/directive/ngSwitch.js
@@ -134,7 +134,7 @@ var ngSwitchDirective = ['$animate', '$compile', function($animate, $compile) {
     require: 'ngSwitch',
 
     // asks for $scope to fool the BC controller module
-    controller: ['$scope', function ngSwitchController() {
+    controller: ['$scope', function NgSwitchController() {
      this.cases = {};
     }],
     link: function(scope, element, attr, ngSwitchController) {
diff --git a/src/ng/directive/ngTransclude.js b/src/ng/directive/ngTransclude.js
index d9406f727f0e..ea21eb155ad0 100644
--- a/src/ng/directive/ngTransclude.js
+++ b/src/ng/directive/ngTransclude.js
@@ -122,7 +122,7 @@
  *   </file>
  *   <file name="app.js">
  *    angular.module('multiSlotTranscludeExample', [])
- *     .directive('pane', function(){
+ *     .directive('pane', function() {
  *        return {
  *          restrict: 'E',
  *          transclude: {
diff --git a/src/ng/directive/select.js b/src/ng/directive/select.js
index 59b505323d91..dc0621de60b0 100644
--- a/src/ng/directive/select.js
+++ b/src/ng/directive/select.js
@@ -1,5 +1,7 @@
 'use strict';
 
+/* exported selectDirective, optionDirective */
+
 var noopNgModelController = { $setViewValue: noop, $render: noop };
 
 /**
@@ -11,7 +13,7 @@ var noopNgModelController = { $setViewValue: noop, $render: noop };
  * added `<option>` elements, perhaps by an `ngRepeat` directive.
  */
 var SelectController =
-        ['$element', '$scope', function($element, $scope) {
+        ['$element', '$scope', /* @this */ function($element, $scope) {
 
   var self = this,
       optionsMap = new HashMap();
@@ -183,15 +185,15 @@ var SelectController =
     } else if (interpolateValueFn) {
       // The value attribute is interpolated
       optionAttrs.$observe('value', function valueAttributeObserveAction(newVal) {
-        var currentVal = self.readValue();
+        // This method is overwritten in ngOptions and has side-effects!
+        self.readValue();
+
         var removal;
         var previouslySelected = optionElement.prop('selected');
-        var removedVal;
 
         if (isDefined(oldVal)) {
           self.removeOption(oldVal);
           removal = true;
-          removedVal = oldVal;
         }
         oldVal = newVal;
         self.addOption(newVal, optionElement);
@@ -220,7 +222,6 @@ var SelectController =
     }
 
 
-    var oldDisabled;
     optionAttrs.$observe('disabled', function(newVal) {
 
       // Since model updates will also select disabled options (like ngOptions),
@@ -233,7 +234,6 @@ var SelectController =
           self.ngModelCtrl.$setViewValue(null);
           self.ngModelCtrl.$render();
         }
-        oldDisabled = newVal;
       }
     });
 
@@ -362,7 +362,7 @@ var SelectController =
  *      $scope.data = {
  *       singleSelect: null,
  *       multipleSelect: [],
- *       option1: 'option-1',
+ *       option1: 'option-1'
  *      };
  *
  *      $scope.forceUnknownOption = function() {
@@ -395,7 +395,7 @@ var SelectController =
  *         {id: '1', name: 'Option A'},
  *         {id: '2', name: 'Option B'},
  *         {id: '3', name: 'Option C'}
- *       ],
+ *       ]
  *      };
  *   }]);
  * </file>
@@ -497,7 +497,6 @@ var SelectController =
  *   </file>
  *   <file name="protractor.js" type="protractor">
  *     it('should initialize to model', function() {
- *       var select = element(by.css('select'));
  *       expect(element(by.model('model.id')).$('option:checked').getText()).toEqual('Two');
  *     });
  *   </file>
@@ -619,7 +618,6 @@ var optionDirective = ['$interpolate', function($interpolate) {
       var interpolateValueFn, interpolateTextFn;
 
       if (isDefined(attr.ngValue)) {
-        // jshint noempty: false
         // Will be handled by registerOption
       } else if (isDefined(attr.value)) {
         // If the value attribute is defined, check if it contains an interpolation
diff --git a/src/ng/document.js b/src/ng/document.js
index 4842804105c4..2f2b12ae65e8 100644
--- a/src/ng/document.js
+++ b/src/ng/document.js
@@ -4,6 +4,7 @@
  * @ngdoc service
  * @name $document
  * @requires $window
+ * @this
  *
  * @description
  * A {@link angular.element jQuery or jqLite} wrapper for the browser's `window.document` object.
@@ -34,6 +35,7 @@ function $DocumentProvider() {
 
 /**
  * @private
+ * @this
  * Listens for document visibility change and makes the current status accessible.
  */
 function $$IsDocumentHiddenProvider() {
diff --git a/src/ng/exceptionHandler.js b/src/ng/exceptionHandler.js
index 70af6d051d61..a3763c5870ef 100644
--- a/src/ng/exceptionHandler.js
+++ b/src/ng/exceptionHandler.js
@@ -4,6 +4,7 @@
  * @ngdoc service
  * @name $exceptionHandler
  * @requires ng.$log
+ * @this
  *
  * @description
  * Any uncaught exception in angular expressions is delegated to this service.
diff --git a/src/ng/filter.js b/src/ng/filter.js
index 2226a390fab7..0e2eeb0783e2 100644
--- a/src/ng/filter.js
+++ b/src/ng/filter.js
@@ -106,6 +106,7 @@
    </example>
   */
 $FilterProvider.$inject = ['$provide'];
+/* @this */
 function $FilterProvider($provide) {
   var suffix = 'Filter';
 
@@ -155,7 +156,7 @@ function $FilterProvider($provide) {
     lowercaseFilter: false,
     numberFilter: false,
     orderByFilter: false,
-    uppercaseFilter: false,
+    uppercaseFilter: false
   */
 
   register('currency', currencyFilter);
diff --git a/src/ng/filter/filter.js b/src/ng/filter/filter.js
index 3c346ae07fbe..fe163d33e64f 100644
--- a/src/ng/filter/filter.js
+++ b/src/ng/filter/filter.js
@@ -156,9 +156,8 @@ function filterFilter() {
       case 'number':
       case 'string':
         matchAgainstAnyProp = true;
-        //jshint -W086
+        // falls through
       case 'object':
-        //jshint +W086
         predicateFn = createPredicateFn(expression, comparator, anyPropertyKey, matchAgainstAnyProp);
         break;
       default:
@@ -248,7 +247,6 @@ function deepCompare(actual, expected, comparator, anyPropertyKey, matchAgainstA
       } else {
         return comparator(actual, expected);
       }
-      break;
     case 'function':
       return false;
     default:
diff --git a/src/ng/filter/filters.js b/src/ng/filter/filters.js
index 66e764d2d641..f35911d0965d 100644
--- a/src/ng/filter/filters.js
+++ b/src/ng/filter/filters.js
@@ -42,7 +42,7 @@ var ZERO_CHAR = '0';
          expect(element(by.id('currency-no-fractions')).getText()).toBe('USD$1,235');
        });
        it('should update', function() {
-         if (browser.params.browser == 'safari') {
+         if (browser.params.browser === 'safari') {
            // Safari does not understand the minus key. See
            // https://github.com/angular/protractor/issues/481
            return;
@@ -177,7 +177,7 @@ function parse(numStr) {
   }
 
   // Count the number of leading zeros.
-  for (i = 0; numStr.charAt(i) === ZERO_CHAR; i++) {/* jshint noempty: false */}
+  for (i = 0; numStr.charAt(i) === ZERO_CHAR; i++) { /* empty */ }
 
   if (i === (zeros = numStr.length)) {
     // The digits are all zero.
@@ -580,7 +580,7 @@ function dateFilter($locale) {
                      // 1        2       3         4          5          6          7          8  9     10      11
   function jsonStringToDate(string) {
     var match;
-    if (match = string.match(R_ISO8601_STR)) {
+    if ((match = string.match(R_ISO8601_STR))) {
       var date = new Date(0),
           tzHour = 0,
           tzMin  = 0,
@@ -673,8 +673,8 @@ function dateFilter($locale) {
      </file>
      <file name="protractor.js" type="protractor">
        it('should jsonify filtered objects', function() {
-         expect(element(by.id('default-spacing')).getText()).toMatch(/\{\n  "name": ?"value"\n}/);
-         expect(element(by.id('custom-spacing')).getText()).toMatch(/\{\n    "name": ?"value"\n}/);
+         expect(element(by.id('default-spacing')).getText()).toMatch(/\{\n {2}"name": ?"value"\n}/);
+         expect(element(by.id('custom-spacing')).getText()).toMatch(/\{\n {4}"name": ?"value"\n}/);
        });
      </file>
    </example>
diff --git a/src/ng/forceReflow.js b/src/ng/forceReflow.js
index deca55f76a2f..db84d8bb8d9e 100644
--- a/src/ng/forceReflow.js
+++ b/src/ng/forceReflow.js
@@ -1,6 +1,6 @@
 'use strict';
 
-var $$ForceReflowProvider = function() {
+var $$ForceReflowProvider = /* @this */ function() {
   this.$get = ['$document', function($document) {
     return function(domNode) {
       //the line below will force the browser to perform a repaint so
diff --git a/src/ng/http.js b/src/ng/http.js
index 59cfb112ca61..995a70ec8abb 100644
--- a/src/ng/http.js
+++ b/src/ng/http.js
@@ -23,6 +23,7 @@ function serializeValue(v) {
 }
 
 
+/* @this */
 function $HttpParamSerializerProvider() {
   /**
    * @ngdoc service
@@ -60,10 +61,12 @@ function $HttpParamSerializerProvider() {
   };
 }
 
+/* @this */
 function $HttpParamSerializerJQLikeProvider() {
   /**
    * @ngdoc service
    * @name $httpParamSerializerJQLike
+   *
    * @description
    *
    * Alternative {@link $http `$http`} params serializer that follows
@@ -203,7 +206,7 @@ function headersGetter(headers) {
 
     if (name) {
       var value = headersObj[lowercase(name)];
-      if (value === void 0) {
+      if (value === undefined) {
         value = null;
       }
       return value;
@@ -246,6 +249,8 @@ function isSuccess(status) {
 /**
  * @ngdoc provider
  * @name $httpProvider
+ * @this
+ *
  * @description
  * Use `$httpProvider` to change the default behavior of the {@link ng.$http $http} service.
  * */
@@ -909,7 +914,6 @@ function $HttpProvider() {
   var data = element(by.binding('data'));
   var fetchBtn = element(by.id('fetchbtn'));
   var sampleGetBtn = element(by.id('samplegetbtn'));
-  var sampleJsonpBtn = element(by.id('samplejsonpbtn'));
   var invalidJsonpBtn = element(by.id('invalidjsonpbtn'));
 
   it('should make an xhr GET request', function() {
@@ -921,6 +925,7 @@ function $HttpProvider() {
 
 // Commented out due to flakes. See https://github.com/angular/angular.js/issues/9185
 // it('should make a JSONP request to angularjs.org', function() {
+//   var sampleJsonpBtn = element(by.id('samplejsonpbtn'));
 //   sampleJsonpBtn.click();
 //   fetchBtn.click();
 //   expect(status.getText()).toMatch('200');
diff --git a/src/ng/httpBackend.js b/src/ng/httpBackend.js
index 51c87ab57ed1..79cf27e91023 100644
--- a/src/ng/httpBackend.js
+++ b/src/ng/httpBackend.js
@@ -3,6 +3,7 @@
 /**
  * @ngdoc service
  * @name $xhrFactory
+ * @this
  *
  * @description
  * Factory function used to create XMLHttpRequest objects.
@@ -35,6 +36,7 @@ function $xhrFactoryProvider() {
  * @requires $jsonpCallbacks
  * @requires $document
  * @requires $xhrFactory
+ * @this
  *
  * @description
  * HTTP backend used by the {@link ng.$http service} that delegates to
@@ -149,8 +151,12 @@ function createHttpBackend($browser, createXhr, $browserDefer, callbacks, rawDoc
 
 
     function timeoutRequest() {
-      jsonpDone && jsonpDone();
-      xhr && xhr.abort();
+      if (jsonpDone) {
+        jsonpDone();
+      }
+      if (xhr) {
+        xhr.abort();
+      }
     }
 
     function completeRequest(callback, status, response, headersString, statusText) {
diff --git a/src/ng/interpolate.js b/src/ng/interpolate.js
index 972b1b89c21c..8b38b755beed 100644
--- a/src/ng/interpolate.js
+++ b/src/ng/interpolate.js
@@ -15,6 +15,7 @@ $interpolateMinErr.interr = function(text, err) {
 /**
  * @ngdoc provider
  * @name $interpolateProvider
+ * @this
  *
  * @description
  *
@@ -111,13 +112,13 @@ function $InterpolateProvider() {
         replace(escapedEndRegexp, endSymbol);
     }
 
-    //TODO: this is the same as the constantWatchDelegate in parse.js
+    // TODO: this is the same as the constantWatchDelegate in parse.js
     function constantWatchDelegate(scope, listener, objectEquality, constantInterp) {
-      var unwatch;
-      return unwatch = scope.$watch(function constantInterpolateWatch(scope) {
+      var unwatch = scope.$watch(function constantInterpolateWatch(scope) {
         unwatch();
         return constantInterp(scope);
       }, listener, objectEquality);
+      return unwatch;
     }
 
     /**
@@ -330,7 +331,7 @@ function $InterpolateProvider() {
           expressions: expressions,
           $$watchDelegate: function(scope, listener) {
             var lastValue;
-            return scope.$watchGroup(parseFns, function interpolateFnWatcher(values, oldValues) {
+            return scope.$watchGroup(parseFns, /* @this */ function interpolateFnWatcher(values, oldValues) {
               var currValue = compute(values);
               if (isFunction(listener)) {
                 listener.call(this, currValue, values !== oldValues ? lastValue : currValue, scope);
@@ -387,4 +388,3 @@ function $InterpolateProvider() {
   }];
 }
 
-
diff --git a/src/ng/interval.js b/src/ng/interval.js
index 4346c3fea46a..12d1f98dfe51 100644
--- a/src/ng/interval.js
+++ b/src/ng/interval.js
@@ -1,6 +1,6 @@
 'use strict';
 
-
+/* @this */
 function $IntervalProvider() {
   this.$get = ['$rootScope', '$window', '$q', '$$q', '$browser',
        function($rootScope,   $window,   $q,   $$q,   $browser) {
diff --git a/src/ng/jsonpCallbacks.js b/src/ng/jsonpCallbacks.js
index 654b2c327331..4eb206f2ba7c 100644
--- a/src/ng/jsonpCallbacks.js
+++ b/src/ng/jsonpCallbacks.js
@@ -9,7 +9,7 @@
  * Override this service if you wish to customise where the callbacks are stored and
  * how they vary compared to the requested url.
  */
-var $jsonpCallbacksProvider = function() {
+var $jsonpCallbacksProvider = /* @this */ function() {
   this.$get = ['$window', function($window) {
     var callbacks = $window.angular.callbacks;
     var callbackMap = {};
diff --git a/src/ng/location.js b/src/ng/location.js
index 712813c54b94..a9d04002dfb4 100644
--- a/src/ng/location.js
+++ b/src/ng/location.js
@@ -657,14 +657,14 @@ forEach([LocationHashbangInHtml5Url, LocationHashbangUrl, LocationHtml5Url], fun
 
 
 function locationGetter(property) {
-  return function() {
+  return /* @this */ function() {
     return this[property];
   };
 }
 
 
 function locationGetterSetter(property, preprocess) {
-  return function(value) {
+  return /* @this */ function(value) {
     if (isUndefined(value)) {
       return this[property];
     }
@@ -706,6 +706,8 @@ function locationGetterSetter(property, preprocess) {
 /**
  * @ngdoc provider
  * @name $locationProvider
+ * @this
+ *
  * @description
  * Use the `$locationProvider` to configure how the application deep linking paths are stored.
  */
diff --git a/src/ng/log.js b/src/ng/log.js
index 8f3ebd55489f..c85ee67168d1 100644
--- a/src/ng/log.js
+++ b/src/ng/log.js
@@ -41,6 +41,8 @@
 /**
  * @ngdoc provider
  * @name $logProvider
+ * @this
+ *
  * @description
  * Use the `$logProvider` to configure how the application logs messages
  */
@@ -117,7 +119,7 @@ function $LogProvider() {
             fn.apply(self, arguments);
           }
         };
-      }())
+      })()
     };
 
     function formatError(arg) {
@@ -142,7 +144,7 @@ function $LogProvider() {
       // The reason behind this is that console.log has type "object" in IE8...
       try {
         hasApply = !!logFn.apply;
-      } catch (e) {}
+      } catch (e) { /* empty */ }
 
       if (hasApply) {
         return function() {
diff --git a/src/ng/parse.js b/src/ng/parse.js
index 27f436e567cb..8c19d9e0d003 100644
--- a/src/ng/parse.js
+++ b/src/ng/parse.js
@@ -150,7 +150,7 @@ var ESCAPE = {"n":"\n", "f":"\f", "r":"\r", "t":"\t", "v":"\v", "'":"'", '"':'"'
 /**
  * @constructor
  */
-var Lexer = function(options) {
+var Lexer = function Lexer(options) {
   this.options = options;
 };
 
@@ -236,9 +236,8 @@ Lexer.prototype = {
 
   codePointAt: function(ch) {
     if (ch.length === 1) return ch.charCodeAt(0);
-    /*jshint bitwise: false*/
+    // eslint-disable-next-line no-bitwise
     return (ch.charCodeAt(0) << 10) + ch.charCodeAt(1) - 0x35FDC00;
-    /*jshint bitwise: true*/
   },
 
   peekMultichar: function() {
@@ -360,7 +359,7 @@ Lexer.prototype = {
   }
 };
 
-var AST = function(lexer, options) {
+var AST = function AST(lexer, options) {
   this.lexer = lexer;
   this.options = options;
 };
@@ -902,7 +901,7 @@ ASTCompiler.prototype = {
       this.watchFns() +
       'return fn;';
 
-    /* jshint -W054 */
+    // eslint-disable-next-line no-new-func
     var fn = (new Function('$filter',
         'ensureSafeMemberName',
         'ensureSafeObject',
@@ -922,7 +921,6 @@ ASTCompiler.prototype = {
           ifDefined,
           plusFn,
           expression);
-    /* jshint +W054 */
     this.state = this.stage = undefined;
     fn.literal = isLiteral(ast);
     fn.constant = isConstant(ast);
@@ -1433,7 +1431,7 @@ ASTInterpreter.prototype = {
   },
 
   recurse: function(ast, context, create) {
-    var left, right, self = this, args, expression;
+    var left, right, self = this, args;
     if (ast.input) {
       return this.inputs(ast.input, ast.watchId);
     }
@@ -1645,14 +1643,14 @@ ASTInterpreter.prototype = {
   },
   'binary==': function(left, right, context) {
     return function(scope, locals, assign, inputs) {
-      /* jshint eqeqeq:false */
+      // eslint-disable-next-line eqeqeq
       var arg = left(scope, locals, assign, inputs) == right(scope, locals, assign, inputs);
       return context ? {value: arg} : arg;
     };
   },
   'binary!=': function(left, right, context) {
     return function(scope, locals, assign, inputs) {
-      /* jshint eqeqeq:false */
+      // eslint-disable-next-line eqeqeq
       var arg = left(scope, locals, assign, inputs) != right(scope, locals, assign, inputs);
       return context ? {value: arg} : arg;
     };
@@ -1775,7 +1773,7 @@ ASTInterpreter.prototype = {
 /**
  * @constructor
  */
-var Parser = function(lexer, $filter, options) {
+var Parser = function Parser(lexer, $filter, options) {
   this.lexer = lexer;
   this.$filter = $filter;
   this.options = options;
@@ -1848,6 +1846,7 @@ function getValueOf(value) {
 /**
  * @ngdoc provider
  * @name $parseProvider
+ * @this
  *
  * @description
  * `$parseProvider` can be used for configuring the default behavior of the {@link ng.$parse $parse}
@@ -1882,6 +1881,7 @@ function $ParseProvider() {
  /**
   * @ngdoc method
   * @name $parseProvider#setIdentifierFns
+  *
   * @description
   *
   * Allows defining the set of characters that are allowed in Angular expressions. The function
@@ -2023,6 +2023,7 @@ function $ParseProvider() {
       }
 
       //Primitive or NaN
+      // eslint-disable-next-line no-self-compare
       return newValue === oldValueOfValue || (newValue !== newValue && oldValueOfValue !== oldValueOfValue);
     }
 
@@ -2072,10 +2073,12 @@ function $ParseProvider() {
     function oneTimeWatchDelegate(scope, listener, objectEquality, parsedExpression, prettyPrintExpression) {
       var unwatch, lastValue;
       if (parsedExpression.inputs) {
-        return unwatch = inputsWatchDelegate(scope, oneTimeListener, objectEquality, parsedExpression, prettyPrintExpression);
+        unwatch = inputsWatchDelegate(scope, oneTimeListener, objectEquality, parsedExpression, prettyPrintExpression);
       } else {
-        return unwatch = scope.$watch(oneTimeWatch, oneTimeListener, objectEquality);
+        unwatch = scope.$watch(oneTimeWatch, oneTimeListener, objectEquality);
       }
+      return unwatch;
+
       function oneTimeWatch(scope) {
         return parsedExpression(scope);
       }
@@ -2096,7 +2099,7 @@ function $ParseProvider() {
 
     function oneTimeLiteralWatchDelegate(scope, listener, objectEquality, parsedExpression) {
       var unwatch, lastValue;
-      return unwatch = scope.$watch(function oneTimeWatch(scope) {
+      unwatch = scope.$watch(function oneTimeWatch(scope) {
         return parsedExpression(scope);
       }, function oneTimeListener(value, old, scope) {
         lastValue = value;
@@ -2110,6 +2113,8 @@ function $ParseProvider() {
         }
       }, objectEquality);
 
+      return unwatch;
+
       function isAllDefined(value) {
         var allDefined = true;
         forEach(value, function(val) {
@@ -2120,11 +2125,11 @@ function $ParseProvider() {
     }
 
     function constantWatchDelegate(scope, listener, objectEquality, parsedExpression) {
-      var unwatch;
-      return unwatch = scope.$watch(function constantWatch(scope) {
+      var unwatch = scope.$watch(function constantWatch(scope) {
         unwatch();
         return parsedExpression(scope);
       }, listener, objectEquality);
+      return unwatch;
     }
 
     function addInterceptor(parsedExpression, interceptorFn) {
diff --git a/src/ng/q.js b/src/ng/q.js
index 38962a988a35..def62ee9bdf1 100644
--- a/src/ng/q.js
+++ b/src/ng/q.js
@@ -220,6 +220,7 @@
 /**
  * @ngdoc provider
  * @name $qProvider
+ * @this
  *
  * @description
  */
@@ -253,6 +254,7 @@ function $QProvider() {
   };
 }
 
+/* @this */
 function $$QProvider() {
   var errorOnUnhandledRejections = true;
   this.$get = ['$browser', '$exceptionHandler', function($browser, $exceptionHandler) {
@@ -376,6 +378,7 @@ function qFactory(nextTick, exceptionHandler, errorOnUnhandledRejections) {
   }
 
   function processChecks() {
+    // eslint-disable-next-line no-unmodified-loop-condition
     while (!queueSize && checkQueue.length) {
       var toCheck = checkQueue.shift();
       if (!toCheck.pur) {
diff --git a/src/ng/raf.js b/src/ng/raf.js
index f8bf0839b908..9dd8a5dfd77d 100644
--- a/src/ng/raf.js
+++ b/src/ng/raf.js
@@ -1,5 +1,6 @@
 'use strict';
 
+/* @this */
 function $$RAFProvider() { //rAF
   this.$get = ['$window', '$timeout', function($window, $timeout) {
     var requestAnimationFrame = $window.requestAnimationFrame ||
diff --git a/src/ng/rootScope.js b/src/ng/rootScope.js
index eddcf61da4d6..afefa45e8058 100644
--- a/src/ng/rootScope.js
+++ b/src/ng/rootScope.js
@@ -59,6 +59,8 @@
 /**
  * @ngdoc service
  * @name $rootScope
+ * @this
+ *
  * @description
  *
  * Every application has a single root {@link ng.$rootScope.Scope scope}.
@@ -109,8 +111,12 @@ function $RootScopeProvider() {
         // all this scopes children
         //
         // See issue https://github.com/angular/angular.js/issues/10706
-        $scope.$$childHead && cleanUpScope($scope.$$childHead);
-        $scope.$$nextSibling && cleanUpScope($scope.$$nextSibling);
+        if ($scope.$$childHead) {
+          cleanUpScope($scope.$$childHead);
+        }
+        if ($scope.$$nextSibling) {
+          cleanUpScope($scope.$$nextSibling);
+        }
       }
 
       // The code below works around IE9 and V8's memory leaks
@@ -612,6 +618,7 @@ function $RootScopeProvider() {
               oldItem = oldValue[i];
               newItem = newValue[i];
 
+              // eslint-disable-next-line no-self-compare
               bothNaN = (oldItem !== oldItem) && (newItem !== newItem);
               if (!bothNaN && (oldItem !== newItem)) {
                 changeDetected++;
@@ -634,6 +641,7 @@ function $RootScopeProvider() {
                 oldItem = oldValue[key];
 
                 if (key in oldValue) {
+                  // eslint-disable-next-line no-self-compare
                   bothNaN = (oldItem !== oldItem) && (newItem !== newItem);
                   if (!bothNaN && (oldItem !== newItem)) {
                     changeDetected++;
@@ -1073,6 +1081,7 @@ function $RootScopeProvider() {
             $rootScope.$digest();
           } catch (e) {
             $exceptionHandler(e);
+            // eslint-disable-next-line no-unsafe-finally
             throw e;
           }
         }
@@ -1097,7 +1106,9 @@ function $RootScopeProvider() {
        */
       $applyAsync: function(expr) {
         var scope = this;
-        expr && applyAsyncQueue.push($applyAsyncExpression);
+        if (expr) {
+          applyAsyncQueue.push($applyAsyncExpression);
+        }
         expr = $parse(expr);
         scheduleApplyAsync();
 
diff --git a/src/ng/sanitizeUri.js b/src/ng/sanitizeUri.js
index adf8a7205fc2..aa09d0b4864d 100644
--- a/src/ng/sanitizeUri.js
+++ b/src/ng/sanitizeUri.js
@@ -1,6 +1,7 @@
 'use strict';
 
 /**
+ * @this
  * @description
  * Private service to sanitize uris for links and images. Used by $compile and $sanitize.
  */
diff --git a/src/ng/sce.js b/src/ng/sce.js
index bf881f8c9fd8..b2140e21bcbb 100644
--- a/src/ng/sce.js
+++ b/src/ng/sce.js
@@ -11,6 +11,8 @@
  *     Or gives undesired access to variables likes document or window?    *
  * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * */
 
+/* exported $SceProvider, $SceDelegateProvider */
+
 var $sceMinErr = minErr('$sce');
 
 var SCE_CONTEXTS = {
@@ -94,6 +96,8 @@ function adjustMatchers(matchers) {
 /**
  * @ngdoc provider
  * @name $sceDelegateProvider
+ * @this
+ *
  * @description
  *
  * The `$sceDelegateProvider` provider allows developers to configure the {@link ng.$sceDelegate
@@ -109,7 +113,7 @@ function adjustMatchers(matchers) {
  *
  * - your app is hosted at url `http://myapp.example.com/`
  * - but some of your templates are hosted on other domains you control such as
- *   `http://srv01.assets.example.com/`,  `http://srv02.assets.example.com/`, etc.
+ *   `http://srv01.assets.example.com/`, `http://srv02.assets.example.com/`, etc.
  * - and you have an open redirect at `http://myapp.example.com/clickThru?...`.
  *
  * Here is what a secure configuration for this scenario might look like:
@@ -390,6 +394,8 @@ function $SceDelegateProvider() {
 /**
  * @ngdoc provider
  * @name $sceProvider
+ * @this
+ *
  * @description
  *
  * The $sceProvider provider allows developers to configure the {@link ng.$sce $sce} service.
@@ -399,8 +405,6 @@ function $SceDelegateProvider() {
  * Read more about {@link ng.$sce Strict Contextual Escaping (SCE)}.
  */
 
-/* jshint maxlen: false*/
-
 /**
  * @ngdoc service
  * @name $sce
@@ -606,7 +610,7 @@ function $SceDelegateProvider() {
  * <file name="script.js">
  *   angular.module('mySceApp', ['ngSanitize'])
  *     .controller('AppController', ['$http', '$templateCache', '$sce',
- *       function($http, $templateCache, $sce) {
+ *       function AppController($http, $templateCache, $sce) {
  *         var self = this;
  *         $http.get("test_data.json", {cache: $templateCache}).success(function(userComments) {
  *           self.userComments = userComments;
@@ -666,7 +670,6 @@ function $SceDelegateProvider() {
  * ```
  *
  */
-/* jshint maxlen: 100 */
 
 function $SceProvider() {
   var enabled = true;
diff --git a/src/ng/sniffer.js b/src/ng/sniffer.js
index 5bc32fdf1db6..8023bd8722ab 100644
--- a/src/ng/sniffer.js
+++ b/src/ng/sniffer.js
@@ -1,11 +1,14 @@
 'use strict';
 
+/* exported $SnifferProvider */
+
 /**
  * !!! This is an undocumented "private" service !!!
  *
  * @name $sniffer
  * @requires $window
  * @requires $document
+ * @this
  *
  * @property {boolean} history Does the browser support html5 history api ?
  * @property {boolean} transitions Does the browser support CSS transition events ?
@@ -34,7 +37,7 @@ function $SnifferProvider() {
 
     if (bodyStyle) {
       for (var prop in bodyStyle) {
-        if (match = vendorRegex.exec(prop)) {
+        if ((match = vendorRegex.exec(prop))) {
           vendorPrefix = match[0];
           vendorPrefix = vendorPrefix[0].toUpperCase() + vendorPrefix.substr(1);
           break;
@@ -64,9 +67,7 @@ function $SnifferProvider() {
       // older webkit browser (533.9) on Boxee box has exactly the same problem as Android has
       // so let's not use the history API also
       // We are purposefully using `!(android < 4)` to cover the case when `android` is undefined
-      // jshint -W018
       history: !!(hasHistoryPushState && !(android < 4) && !boxee),
-      // jshint +W018
       hasEvent: function(event) {
         // IE9 implements 'input' event it's so fubared that we rather pretend that it doesn't have
         // it. In particular the event is not fired when backspace or delete key are pressed or
diff --git a/src/ng/templateRequest.js b/src/ng/templateRequest.js
index f5bce1b83349..e7c1007beddc 100644
--- a/src/ng/templateRequest.js
+++ b/src/ng/templateRequest.js
@@ -5,6 +5,8 @@ var $templateRequestMinErr = minErr('$compile');
 /**
  * @ngdoc provider
  * @name $templateRequestProvider
+ * @this
+ *
  * @description
  * Used to configure the options passed to the {@link $http} service when making a template request.
  *
@@ -86,7 +88,7 @@ function $TemplateRequestProvider() {
           cache: $templateCache,
           transformResponse: transformResponse
         }, httpOptions))
-        ['finally'](function() {
+        .finally(function() {
           handleRequestFn.totalPendingRequests--;
         })
         .then(function(response) {
diff --git a/src/ng/testability.js b/src/ng/testability.js
index c268f4405aac..0c4cfb29eeaf 100644
--- a/src/ng/testability.js
+++ b/src/ng/testability.js
@@ -1,6 +1,6 @@
 'use strict';
 
-
+/* @this */
 function $$TestabilityProvider() {
   this.$get = ['$rootScope', '$browser', '$location',
        function($rootScope,   $browser,   $location) {
diff --git a/src/ng/timeout.js b/src/ng/timeout.js
index b4f320e8142d..c4e0b5f0b964 100644
--- a/src/ng/timeout.js
+++ b/src/ng/timeout.js
@@ -1,6 +1,6 @@
 'use strict';
 
-
+/* @this */
 function $TimeoutProvider() {
   this.$get = ['$rootScope', '$browser', '$q', '$$q', '$exceptionHandler',
        function($rootScope,   $browser,   $q,   $$q,   $exceptionHandler) {
@@ -56,8 +56,7 @@ function $TimeoutProvider() {
         } catch (e) {
           deferred.reject(e);
           $exceptionHandler(e);
-        }
-        finally {
+        } finally {
           delete deferreds[promise.$$timeoutId];
         }
 
diff --git a/src/ng/window.js b/src/ng/window.js
index ae983eb3673c..563dd7dc6a62 100644
--- a/src/ng/window.js
+++ b/src/ng/window.js
@@ -3,6 +3,7 @@
 /**
  * @ngdoc service
  * @name $window
+ * @this
  *
  * @description
  * A reference to the browser's `window` object. While `window`
diff --git a/src/ngAnimate/.jshintrc b/src/ngAnimate/.eslintrc.json
similarity index 93%
rename from src/ngAnimate/.jshintrc
rename to src/ngAnimate/.eslintrc.json
index bf7ccdb0eec3..b0100218511b 100644
--- a/src/ngAnimate/.jshintrc
+++ b/src/ngAnimate/.eslintrc.json
@@ -1,12 +1,10 @@
 {
-  "extends": "../../.jshintrc-base",
-  "maxlen": false, /* ngAnimate docs contain wide tables */
-  "newcap": false,
-  "globals": {
-    "window": false,
-
-    "angular": false,
+  "rules": {
+    "maxlen": "off", /* ngAnimate docs contain wide tables */
+    "new-cap": "off"
+  },
 
+  "globals": {
     /* ng helpers */
     "copy": true,
     "extend": true,
diff --git a/src/ngAnimate/animateChildrenDirective.js b/src/ngAnimate/animateChildrenDirective.js
index 02fa86bfb4cb..7ff96b169d9e 100644
--- a/src/ngAnimate/animateChildrenDirective.js
+++ b/src/ngAnimate/animateChildrenDirective.js
@@ -21,7 +21,7 @@
  * @example
  * <example module="ngAnimateChildren" name="ngAnimateChildren" deps="angular-animate.js" animations="true">
      <file name="index.html">
-       <div ng-controller="mainController as main">
+       <div ng-controller="MainController as main">
          <label>Show container? <input type="checkbox" ng-model="main.enterElement" /></label>
          <label>Animate children? <input type="checkbox" ng-model="main.animateChildren" /></label>
          <hr>
@@ -71,7 +71,7 @@
     </file>
     <file name="script.js">
       angular.module('ngAnimateChildren', ['ngAnimate'])
-        .controller('mainController', function() {
+        .controller('MainController', function MainController() {
           this.animateChildren = false;
           this.enterElement = false;
         });
diff --git a/src/ngAnimate/animateCss.js b/src/ngAnimate/animateCss.js
index 3f5663d424bc..bedc34f1d1ce 100644
--- a/src/ngAnimate/animateCss.js
+++ b/src/ngAnimate/animateCss.js
@@ -1,5 +1,7 @@
 'use strict';
 
+/* exported $AnimateCssProvider */
+
 var ANIMATE_TIMER_KEY = '$$animateCss';
 
 /**
@@ -217,7 +219,6 @@ var ANIMATE_TIMER_KEY = '$$animateCss';
  * * `end` - This method will cancel the animation and remove all applied CSS classes and styles.
  */
 var ONE_SECOND = 1000;
-var BASE_TEN = 10;
 
 var ELAPSED_TIME_MAX_DECIMAL_PLACES = 3;
 var CLOSING_TIME_BUFFER = 1.5;
@@ -347,7 +348,7 @@ function registerRestorableStyles(backup, node, properties) {
   });
 }
 
-var $AnimateCssProvider = ['$animateProvider', function($animateProvider) {
+var $AnimateCssProvider = ['$animateProvider', /* @this */ function($animateProvider) {
   var gcsLookup = createLocalCacheLookup();
   var gcsStaggerLookup = createLocalCacheLookup();
 
@@ -411,7 +412,6 @@ var $AnimateCssProvider = ['$animateProvider', function($animateProvider) {
       return stagger || {};
     }
 
-    var cancelLastRAFRequest;
     var rafWaitQueue = [];
     function waitUntilQuiet(callback) {
       rafWaitQueue.push(callback);
@@ -710,7 +710,7 @@ var $AnimateCssProvider = ['$animateProvider', function($animateProvider) {
         close(true);
       }
 
-      function close(rejected) { // jshint ignore:line
+      function close(rejected) {
         // if the promise has been called already then we shouldn't close
         // the animation again
         if (animationClosed || (animationCompleted && animationPaused)) return;
@@ -737,8 +737,11 @@ var $AnimateCssProvider = ['$animateProvider', function($animateProvider) {
 
         if (Object.keys(restoreStyles).length) {
           forEach(restoreStyles, function(value, prop) {
-            value ? node.style.setProperty(prop, value)
-                  : node.style.removeProperty(prop);
+            if (value) {
+              node.style.setProperty(prop, value);
+            } else {
+              node.style.removeProperty(prop);
+            }
           });
         }
 
@@ -841,9 +844,11 @@ var $AnimateCssProvider = ['$animateProvider', function($animateProvider) {
             animationPaused = !playAnimation;
             if (timings.animationDuration) {
               var value = blockKeyframeAnimations(node, animationPaused);
-              animationPaused
-                  ? temporaryStyles.push(value)
-                  : removeFromArray(temporaryStyles, value);
+              if (animationPaused) {
+                temporaryStyles.push(value);
+              } else {
+                removeFromArray(temporaryStyles, value);
+              }
             }
           } else if (animationPaused && playAnimation) {
             animationPaused = false;
diff --git a/src/ngAnimate/animateCssDriver.js b/src/ngAnimate/animateCssDriver.js
index b018ca3a49dd..8420ef2191d5 100644
--- a/src/ngAnimate/animateCssDriver.js
+++ b/src/ngAnimate/animateCssDriver.js
@@ -1,6 +1,6 @@
 'use strict';
 
-var $$AnimateCssDriverProvider = ['$$animationProvider', function($$animationProvider) {
+var $$AnimateCssDriverProvider = ['$$animationProvider', /* @this */ function($$animationProvider) {
   $$animationProvider.drivers.push('$$animateCssDriver');
 
   var NG_ANIMATE_SHIM_CLASS_NAME = 'ng-animate-shim';
@@ -29,8 +29,6 @@ var $$AnimateCssDriverProvider = ['$$animationProvider', function($$animationPro
       isDocumentFragment(rootNode) || bodyNode.contains(rootNode) ? rootNode : bodyNode
     );
 
-    var applyAnimationClasses = applyAnimationClassesFactory($$jqLite);
-
     return function initDriverFn(animationDetails) {
       return animationDetails.from && animationDetails.to
           ? prepareFromToAnchorAnimation(animationDetails.from,
diff --git a/src/ngAnimate/animateJs.js b/src/ngAnimate/animateJs.js
index 9d138ed7c285..74b5fd39131b 100644
--- a/src/ngAnimate/animateJs.js
+++ b/src/ngAnimate/animateJs.js
@@ -4,7 +4,7 @@
 // TODO(matsko): add documentation
 //  by the time...
 
-var $$AnimateJsProvider = ['$animateProvider', function($animateProvider) {
+var $$AnimateJsProvider = ['$animateProvider', /* @this */ function($animateProvider) {
   this.$get = ['$injector', '$$AnimateRunner', '$$jqLite',
        function($injector,   $$AnimateRunner,   $$jqLite) {
 
@@ -228,7 +228,7 @@ var $$AnimateJsProvider = ['$animateProvider', function($animateProvider) {
       function packageAnimations(element, event, options, animations, fnName) {
         var operations = groupEventedAnimations(element, event, options, animations, fnName);
         if (operations.length === 0) {
-          var a,b;
+          var a, b;
           if (fnName === 'beforeSetClass') {
             a = groupEventedAnimations(element, 'removeClass', options, animations, 'beforeRemoveClass');
             b = groupEventedAnimations(element, 'addClass', options, animations, 'beforeAddClass');
@@ -256,11 +256,19 @@ var $$AnimateJsProvider = ['$animateProvider', function($animateProvider) {
             });
           }
 
-          runners.length ? $$AnimateRunner.all(runners, callback) : callback();
+          if (runners.length) {
+            $$AnimateRunner.all(runners, callback);
+          }  else {
+            callback();
+          }
 
           return function endFn(reject) {
             forEach(runners, function(runner) {
-              reject ? runner.cancel() : runner.end();
+              if (reject) {
+                runner.cancel();
+              } else {
+                runner.end();
+              }
             });
           };
         };
@@ -270,7 +278,7 @@ var $$AnimateJsProvider = ['$animateProvider', function($animateProvider) {
     function lookupAnimations(classes) {
       classes = isArray(classes) ? classes : classes.split(' ');
       var matches = [], flagMap = {};
-      for (var i=0; i < classes.length; i++) {
+      for (var i = 0; i < classes.length; i++) {
         var klass = classes[i],
             animationFactory = $animateProvider.$$registeredAnimations[klass];
         if (animationFactory && !flagMap[klass]) {
diff --git a/src/ngAnimate/animateJsDriver.js b/src/ngAnimate/animateJsDriver.js
index bba970456872..0da66d5c51f9 100644
--- a/src/ngAnimate/animateJsDriver.js
+++ b/src/ngAnimate/animateJsDriver.js
@@ -1,6 +1,6 @@
 'use strict';
 
-var $$AnimateJsDriverProvider = ['$$animationProvider', function($$animationProvider) {
+var $$AnimateJsDriverProvider = ['$$animationProvider', /* @this */ function($$animationProvider) {
   $$animationProvider.drivers.push('$$animateJsDriver');
   this.$get = ['$$animateJs', '$$AnimateRunner', function($$animateJs, $$AnimateRunner) {
     return function initDriverFn(animationDetails) {
diff --git a/src/ngAnimate/animateQueue.js b/src/ngAnimate/animateQueue.js
index 4e2b7541ad0e..4957e6cea004 100644
--- a/src/ngAnimate/animateQueue.js
+++ b/src/ngAnimate/animateQueue.js
@@ -2,7 +2,7 @@
 
 var NG_ANIMATE_ATTR_NAME = 'data-ng-animate';
 var NG_ANIMATE_PIN_DATA = '$ngAnimatePin';
-var $$AnimateQueueProvider = ['$animateProvider', function($animateProvider) {
+var $$AnimateQueueProvider = ['$animateProvider', /* @this */ function($animateProvider) {
   var PRE_DIGEST_STATE = 1;
   var RUNNING_STATE = 2;
   var ONE_SPACE = ' ';
@@ -176,10 +176,9 @@ var $$AnimateQueueProvider = ['$animateProvider', function($animateProvider) {
     }
 
     // IE9-11 has no method "contains" in SVG element and in Node.prototype. Bug #10259.
-    var contains = window.Node.prototype.contains || function(arg) {
-      // jshint bitwise: false
+    var contains = window.Node.prototype.contains || /* @this */ function(arg) {
+      // eslint-disable-next-line no-bitwise
       return this === arg || !!(this.compareDocumentPosition(arg) & 16);
-      // jshint bitwise: true
     };
 
     function findCallbacks(parent, element, event) {
@@ -577,7 +576,7 @@ var $$AnimateQueueProvider = ['$animateProvider', function($animateProvider) {
         runner.progress(event, phase, data);
       }
 
-      function close(reject) { // jshint ignore:line
+      function close(reject) {
         clearGeneratedClasses(element, options);
         applyAnimationClasses(element, options);
         applyAnimationStyles(element, options);
@@ -590,7 +589,7 @@ var $$AnimateQueueProvider = ['$animateProvider', function($animateProvider) {
       var node = getDomNode(element);
       var children = node.querySelectorAll('[' + NG_ANIMATE_ATTR_NAME + ']');
       forEach(children, function(child) {
-        var state = parseInt(child.getAttribute(NG_ANIMATE_ATTR_NAME));
+        var state = parseInt(child.getAttribute(NG_ANIMATE_ATTR_NAME), 10);
         var animationDetails = activeAnimationsLookup.get(child);
         if (animationDetails) {
           switch (state) {
diff --git a/src/ngAnimate/animation.js b/src/ngAnimate/animation.js
index 8ea59e390f2a..1194f1aa2656 100644
--- a/src/ngAnimate/animation.js
+++ b/src/ngAnimate/animation.js
@@ -1,6 +1,8 @@
 'use strict';
 
-var $$AnimationProvider = ['$animateProvider', function($animateProvider) {
+/* exported $$AnimationProvider */
+
+var $$AnimationProvider = ['$animateProvider', /* @this */ function($animateProvider) {
   var NG_ANIMATE_REF_ATTR = 'ng-animate-ref';
 
   var drivers = this.drivers = [];
@@ -388,7 +390,7 @@ var $$AnimationProvider = ['$animateProvider', function($animateProvider) {
         }
       }
 
-      function close(rejected) { // jshint ignore:line
+      function close(rejected) {
         element.off('$destroy', handleDestroyedElement);
         removeRunner(element);
 
diff --git a/src/ngAnimate/module.js b/src/ngAnimate/module.js
index eebab4664a1d..402e2c6752a8 100644
--- a/src/ngAnimate/module.js
+++ b/src/ngAnimate/module.js
@@ -567,7 +567,8 @@
         .controller('HomeController', [function() {
           //empty
         }])
-        .controller('ProfileController', ['$rootScope', '$routeParams', function($rootScope, $routeParams) {
+        .controller('ProfileController', ['$rootScope', '$routeParams',
+            function ProfileController($rootScope, $routeParams) {
           var index = parseInt($routeParams.id, 10);
           var record = $rootScope.records[index - 1];
 
diff --git a/src/ngAnimate/shared.js b/src/ngAnimate/shared.js
index a6c00708aff0..adfd35fc4668 100644
--- a/src/ngAnimate/shared.js
+++ b/src/ngAnimate/shared.js
@@ -24,7 +24,7 @@ var CSS_PREFIX = '', TRANSITION_PROP, TRANSITIONEND_EVENT, ANIMATION_PROP, ANIMA
 // Also, the only modern browser that uses vendor prefixes for transitions/keyframes is webkit
 // therefore there is no reason to test anymore for other vendor prefixes:
 // http://caniuse.com/#search=transition
-if ((window.ontransitionend === void 0) && (window.onwebkittransitionend !== void 0)) {
+if ((window.ontransitionend === undefined) && (window.onwebkittransitionend !== undefined)) {
   CSS_PREFIX = '-webkit-';
   TRANSITION_PROP = 'WebkitTransition';
   TRANSITIONEND_EVENT = 'webkitTransitionEnd transitionend';
@@ -33,7 +33,7 @@ if ((window.ontransitionend === void 0) && (window.onwebkittransitionend !== voi
   TRANSITIONEND_EVENT = 'transitionend';
 }
 
-if ((window.onanimationend === void 0) && (window.onwebkitanimationend !== void 0)) {
+if ((window.onanimationend === undefined) && (window.onwebkitanimationend !== undefined)) {
   CSS_PREFIX = '-webkit-';
   ANIMATION_PROP = 'WebkitAnimation';
   ANIMATIONEND_EVENT = 'webkitAnimationEnd animationend';
@@ -134,7 +134,7 @@ function extractElementNode(element) {
   if (!element[0]) return element;
   for (var i = 0; i < element.length; i++) {
     var elm = element[i];
-    if (elm.nodeType == ELEMENT_NODE) {
+    if (elm.nodeType === ELEMENT_NODE) {
       return elm;
     }
   }
diff --git a/src/ngAria/aria.js b/src/ngAria/aria.js
index ca493676c211..2f2a0f065dc1 100644
--- a/src/ngAria/aria.js
+++ b/src/ngAria/aria.js
@@ -53,7 +53,6 @@
  * {@link ngAria.$ariaProvider#config config} method. For more details, see the
  * {@link guide/accessibility Developer Guide}.
  */
- /* global -ngAriaModule */
 var ngAriaModule = angular.module('ngAria', ['ng']).
                         provider('$aria', $AriaProvider);
 
@@ -70,6 +69,7 @@ var isNodeOneOf = function(elem, nodeTypeArray) {
 /**
  * @ngdoc provider
  * @name $ariaProvider
+ * @this
  *
  * @description
  *
@@ -269,7 +269,7 @@ ngAriaModule.directive('ngShow', ['$aria', function($aria) {
 
           function getRadioReaction(newVal) {
             // Strict comparison would cause a BC
-            /* jshint eqeqeq:false */
+            // eslint-disable-next-line eqeqeq
             var boolVal = (attr.value == ngModel.$viewValue);
             elem.attr('aria-checked', boolVal);
           }
diff --git a/src/ngCookies/.jshintrc b/src/ngCookies/.jshintrc
deleted file mode 100644
index 1c700a8719e3..000000000000
--- a/src/ngCookies/.jshintrc
+++ /dev/null
@@ -1,8 +0,0 @@
-{
-  "extends": "../../.jshintrc-base",
-  "globals": {
-    "window": false,
-
-    "angular": false
-  }
-}
diff --git a/src/ngCookies/cookieWriter.js b/src/ngCookies/cookieWriter.js
index 1285a346bac7..ead63975bc4e 100644
--- a/src/ngCookies/cookieWriter.js
+++ b/src/ngCookies/cookieWriter.js
@@ -55,6 +55,6 @@ function $$CookieWriter($document, $log, $browser) {
 
 $$CookieWriter.$inject = ['$document', '$log', '$browser'];
 
-angular.module('ngCookies').provider('$$cookieWriter', function $$CookieWriterProvider() {
+angular.module('ngCookies').provider('$$cookieWriter', /* @this */ function $$CookieWriterProvider() {
   this.$get = $$CookieWriter;
 });
diff --git a/src/ngCookies/cookies.js b/src/ngCookies/cookies.js
index 28a761bf21de..1da28dc5b689 100644
--- a/src/ngCookies/cookies.js
+++ b/src/ngCookies/cookies.js
@@ -23,7 +23,7 @@ angular.module('ngCookies', ['ng']).
    * @description
    * Use `$cookiesProvider` to change the default behavior of the {@link ngCookies.$cookies $cookies} service.
    * */
-   provider('$cookies', [function $CookiesProvider() {
+   provider('$cookies', [/* @this */function $CookiesProvider() {
     /**
      * @ngdoc property
      * @name $cookiesProvider#defaults
diff --git a/src/ngLocale/.eslintrc.json b/src/ngLocale/.eslintrc.json
new file mode 100644
index 000000000000..1e8adae6eb69
--- /dev/null
+++ b/src/ngLocale/.eslintrc.json
@@ -0,0 +1,11 @@
+{
+  "rules": {
+    /* locale files are generated from a 3rd party library so they don't adhere to all the rules */
+    "block-spacing": "off",
+    "eqeqeq": "off",
+    "max-len": "off",
+    "no-bitwise": "off",
+    "no-multi-spaces": "off",
+    "quotes": "off"
+  }
+}
diff --git a/src/ngLocale/.jshintrc b/src/ngLocale/.jshintrc
deleted file mode 100644
index e80628ba7527..000000000000
--- a/src/ngLocale/.jshintrc
+++ /dev/null
@@ -1,12 +0,0 @@
-{
-  "extends": "../../.jshintrc-base",
-  "bitwise": false, /* locale files use bitwise operators */
-  "maxlen": false, /* locale files are generated from a 3rd party library that has long lines */
-  "eqeqeq": false,
-  "globals": {
-    "window": false,
-
-    "angular": false
-  },
-  "-W041": false
-}
diff --git a/src/ngMessageFormat/.eslintrc.json b/src/ngMessageFormat/.eslintrc.json
new file mode 100644
index 000000000000..01073b5ac51f
--- /dev/null
+++ b/src/ngMessageFormat/.eslintrc.json
@@ -0,0 +1,5 @@
+{
+  "globals": {
+    "goog": false // see src/module_closure.prefix
+  }
+}
diff --git a/src/ngMessageFormat/.jshintrc b/src/ngMessageFormat/.jshintrc
deleted file mode 100644
index 187060254eb1..000000000000
--- a/src/ngMessageFormat/.jshintrc
+++ /dev/null
@@ -1,9 +0,0 @@
-{
-  "extends": "../../.jshintrc-base",
-  "globals": {
-    "window": false,
-
-    "angular": false,
-    "goog": false // see src/module_closure.prefix
-  }
-}
diff --git a/src/ngMessageFormat/messageFormatCommon.js b/src/ngMessageFormat/messageFormatCommon.js
index 3991fac368e8..bde7d0d7730e 100644
--- a/src/ngMessageFormat/messageFormatCommon.js
+++ b/src/ngMessageFormat/messageFormatCommon.js
@@ -14,8 +14,8 @@
 // As such, this doesn't have to be efficient.
 function indexToLineAndColumn(text, index) {
   var lines = text.split(/\n/g);
-  for (var i=0; i < lines.length; i++) {
-    var line=lines[i];
+  for (var i = 0; i < lines.length; i++) {
+    var line = lines[i];
     if (index >= line.length) {
       index -= line.length;
     } else {
@@ -34,7 +34,7 @@ function parseTextLiteral(text) {
   parsedFn['$$watchDelegate'] = function watchDelegate(scope, listener, objectEquality) {
     var unwatch = scope['$watch'](noop,
         function textLiteralWatcher() {
-          if (isFunction(listener)) { listener.call(null, text, text, scope); }
+          if (isFunction(listener)) { listener(text, text, scope); }
           unwatch();
         },
         objectEquality);
@@ -51,14 +51,14 @@ function subtractOffset(expressionFn, offset) {
     return expressionFn;
   }
   function minusOffset(value) {
-    return (value == void 0) ? value : value - offset;
+    return (value == null) ? value : value - offset;
   }
   function parsedFn(context) { return minusOffset(expressionFn(context)); }
   var unwatch;
   parsedFn['$$watchDelegate'] = function watchDelegate(scope, listener, objectEquality) {
     unwatch = scope['$watch'](expressionFn,
         function pluralExpressionWatchListener(newValue, oldValue) {
-          if (isFunction(listener)) { listener.call(null, minusOffset(newValue), minusOffset(oldValue), scope); }
+          if (isFunction(listener)) { listener(minusOffset(newValue), minusOffset(oldValue), scope); }
         },
         objectEquality);
     return unwatch;
diff --git a/src/ngMessageFormat/messageFormatInterpolationParts.js b/src/ngMessageFormat/messageFormatInterpolationParts.js
index f664404da8cb..f2526f1c6ddc 100644
--- a/src/ngMessageFormat/messageFormatInterpolationParts.js
+++ b/src/ngMessageFormat/messageFormatInterpolationParts.js
@@ -65,7 +65,7 @@ InterpolationParts.prototype.getExpressionValues = function getExpressionValues(
 InterpolationParts.prototype.getResult = function getResult(expressionValues) {
   for (var i = 0; i < this.expressionIndices.length; i++) {
     var expressionValue = expressionValues[i];
-    if (this.allOrNothing && expressionValue === void 0) return;
+    if (this.allOrNothing && expressionValue === undefined) return;
     this.textParts[this.expressionIndices[i]] = expressionValue;
   }
   return this.textParts.join('');
@@ -76,7 +76,7 @@ InterpolationParts.prototype.toParsedFn = function toParsedFn(mustHaveExpression
   var self = this;
   this.flushPartialText();
   if (mustHaveExpression && this.expressionFns.length === 0) {
-    return void 0;
+    return undefined;
   }
   if (this.textParts.length === 0) {
     return parseTextLiteral('');
@@ -112,7 +112,7 @@ InterpolationParts.prototype.watchDelegate = function watchDelegate(scope, liste
 function InterpolationPartsWatcher(interpolationParts, scope, listener, objectEquality) {
   this.interpolationParts = interpolationParts;
   this.scope = scope;
-  this.previousResult = (void 0);
+  this.previousResult = (undefined);
   this.listener = listener;
   var self = this;
   this.expressionFnsWatcher = scope['$watchGroup'](interpolationParts.expressionFns, function(newExpressionValues, oldExpressionValues) {
diff --git a/src/ngMessageFormat/messageFormatParser.js b/src/ngMessageFormat/messageFormatParser.js
index 8ebb18ebb40c..8621a3ee8727 100644
--- a/src/ngMessageFormat/messageFormatParser.js
+++ b/src/ngMessageFormat/messageFormatParser.js
@@ -130,7 +130,7 @@ MessageFormatParser.prototype.errorInParseLogic = function errorInParseLogic() {
 };
 
 MessageFormatParser.prototype.assertRuleOrNull = function assertRuleOrNull(rule) {
-  if (rule === void 0) {
+  if (rule === undefined) {
     this.errorInParseLogic();
   }
 };
@@ -230,7 +230,7 @@ MessageFormatParser.prototype.rulePluralOffset = function rulePluralOffset() {
 };
 
 MessageFormatParser.prototype.assertChoiceKeyIsNew = function assertChoiceKeyIsNew(choiceKey, index) {
-  if (this.choices[choiceKey] !== void 0) {
+  if (this.choices[choiceKey] !== undefined) {
     var position = indexToLineAndColumn(this.text, index);
     throw $interpolateMinErr('dupvalue',
         'The choice “{0}” is specified more than once. Duplicate key is at line {1}, column {2} in text “{3}”',
@@ -268,7 +268,7 @@ MessageFormatParser.prototype.rulePluralValueOrKeyword = function rulePluralValu
   this.rule = this.ruleMessageText;
 };
 
-var BRACE_OPEN_RE = /\s*{/g;
+var BRACE_OPEN_RE = /\s*\{/g;
 var BRACE_CLOSE_RE = /}/g;
 MessageFormatParser.prototype.ruleMessageText = function ruleMessageText() {
   if (!this.consumeRe(BRACE_OPEN_RE)) {
@@ -288,7 +288,7 @@ var INTERP_OR_END_MESSAGE_RE = /\\.|{{|}/g;
 var INTERP_OR_PLURALVALUE_OR_END_MESSAGE_RE = /\\.|{{|#|}/g;
 var ESCAPE_OR_MUSTACHE_BEGIN_RE = /\\.|{{/g;
 MessageFormatParser.prototype.advanceInInterpolationOrMessageText = function advanceInInterpolationOrMessageText() {
-  var currentIndex = this.index, match, re;
+  var currentIndex = this.index, match;
   if (this.ruleChoiceKeyword == null) { // interpolation
     match = this.searchRe(ESCAPE_OR_MUSTACHE_BEGIN_RE);
     if (match == null) { // End of interpolation text.  Nothing more to process.
@@ -446,7 +446,6 @@ function getBeginOperator(opEnd) {
 // should support any other type of start/end interpolation symbol.
 var INTERESTING_OPERATORS_RE = /[[\]{}()'",]/g;
 MessageFormatParser.prototype.ruleInAngularExpression = function ruleInAngularExpression() {
-  var startIndex = this.index;
   var match = this.searchRe(INTERESTING_OPERATORS_RE);
   var position;
   if (match == null) {
diff --git a/src/ngMessageFormat/messageFormatSelector.js b/src/ngMessageFormat/messageFormatSelector.js
index b7cc52e37957..b672dca0d23a 100644
--- a/src/ngMessageFormat/messageFormatSelector.js
+++ b/src/ngMessageFormat/messageFormatSelector.js
@@ -17,7 +17,7 @@ function MessageSelectorBase(expressionFn, choices) {
   var self = this;
   this.expressionFn = expressionFn;
   this.choices = choices;
-  if (choices["other"] === void 0) {
+  if (choices["other"] === undefined) {
     throw $interpolateMinErr('reqother', '“other” is a required option.');
   }
   this.parsedFn = function(context) { return self.getResult(context); };
@@ -51,7 +51,7 @@ function MessageSelectorWatchers(msgSelector, scope, listener, objectEquality) {
   this.msgSelector = msgSelector;
   this.listener = listener;
   this.objectEquality = objectEquality;
-  this.lastMessage = void 0;
+  this.lastMessage = undefined;
   this.messageFnWatcher = noop;
   var expressionFnListener = function(newValue, oldValue) { return self.expressionFnListener(newValue, oldValue); };
   this.expressionFnWatcher = scope['$watch'](msgSelector.expressionFn, expressionFnListener, objectEquality);
@@ -91,7 +91,7 @@ SelectMessageProto.prototype = MessageSelectorBase.prototype;
 
 SelectMessage.prototype = new SelectMessageProto();
 SelectMessage.prototype.categorizeValue = function categorizeSelectValue(value) {
-  return (this.choices[value] !== void 0) ? value : "other";
+  return (this.choices[value] !== undefined) ? value : "other";
 };
 
 /**
@@ -112,10 +112,10 @@ PluralMessage.prototype = new PluralMessageProto();
 PluralMessage.prototype.categorizeValue = function categorizePluralValue(value) {
   if (isNaN(value)) {
     return "other";
-  } else if (this.choices[value] !== void 0) {
+  } else if (this.choices[value] !== undefined) {
     return value;
   } else {
     var category = this.pluralCat(value - this.offset);
-    return (this.choices[category] !== void 0) ? category : "other";
+    return (this.choices[category] !== undefined) ? category : "other";
   }
 };
diff --git a/src/ngMessageFormat/messageFormatService.js b/src/ngMessageFormat/messageFormatService.js
index e7df48401600..a8ad661c611a 100644
--- a/src/ngMessageFormat/messageFormatService.js
+++ b/src/ngMessageFormat/messageFormatService.js
@@ -173,13 +173,13 @@
  */
 
 var $$MessageFormatFactory = ['$parse', '$locale', '$sce', '$exceptionHandler', function $$messageFormat(
-                   $parse,   $locale,   $sce,   $exceptionHandler) {
+                               $parse,   $locale,   $sce,   $exceptionHandler) {
 
   function getStringifier(trustedContext, allOrNothing, text) {
     return function stringifier(value) {
       try {
         value = trustedContext ? $sce['getTrusted'](trustedContext, value) : $sce['valueOf'](value);
-        return allOrNothing && (value === void 0) ? value : $$stringify(value);
+        return allOrNothing && (value === undefined) ? value : $$stringify(value);
       } catch (err) {
         $exceptionHandler($interpolateMinErr['interr'](text, err));
       }
diff --git a/src/ngMessages/.jshintrc b/src/ngMessages/.jshintrc
deleted file mode 100644
index 1c700a8719e3..000000000000
--- a/src/ngMessages/.jshintrc
+++ /dev/null
@@ -1,8 +0,0 @@
-{
-  "extends": "../../.jshintrc-base",
-  "globals": {
-    "window": false,
-
-    "angular": false
-  }
-}
diff --git a/src/ngMessages/messages.js b/src/ngMessages/messages.js
index 45ef64b520f6..1c2a682c495f 100644
--- a/src/ngMessages/messages.js
+++ b/src/ngMessages/messages.js
@@ -347,7 +347,7 @@ angular.module('ngMessages', [], function initAngularHelpers() {
     return {
       require: 'ngMessages',
       restrict: 'AE',
-      controller: ['$element', '$scope', '$attrs', function($element, $scope, $attrs) {
+      controller: ['$element', '$scope', '$attrs', function NgMessagesCtrl($element, $scope, $attrs) {
         var ctrl = this;
         var latestKey = 0;
         var nextAttachId = 0;
@@ -407,9 +407,11 @@ angular.module('ngMessages', [], function initAngularHelpers() {
             messageCtrl.detach();
           });
 
-          unmatchedMessages.length !== totalMessages
-              ? $animate.setClass($element, ACTIVE_CLASS, INACTIVE_CLASS)
-              : $animate.setClass($element, INACTIVE_CLASS, ACTIVE_CLASS);
+          if (unmatchedMessages.length !== totalMessages) {
+            $animate.setClass($element, ACTIVE_CLASS, INACTIVE_CLASS);
+          } else {
+            $animate.setClass($element, INACTIVE_CLASS, ACTIVE_CLASS);
+          }
         };
 
         $scope.$watchCollection($attrs.ngMessages || $attrs['for'], ctrl.render);
@@ -425,8 +427,8 @@ angular.module('ngMessages', [], function initAngularHelpers() {
           if (!renderLater) {
             renderLater = true;
             $scope.$evalAsync(function() {
-              if (renderLater) {
-                cachedCollection && ctrl.render(cachedCollection);
+              if (renderLater && cachedCollection) {
+                ctrl.render(cachedCollection);
               }
             });
           }
diff --git a/src/ngMock/.eslintrc.json b/src/ngMock/.eslintrc.json
new file mode 100644
index 000000000000..65e328086562
--- /dev/null
+++ b/src/ngMock/.eslintrc.json
@@ -0,0 +1,6 @@
+{
+  "globals": {
+    "expect": false,
+    "jQuery": false
+  }
+}
diff --git a/src/ngMock/.jshintrc b/src/ngMock/.jshintrc
deleted file mode 100644
index ca9fcdd54d0a..000000000000
--- a/src/ngMock/.jshintrc
+++ /dev/null
@@ -1,15 +0,0 @@
-{
-  "extends": "../../.jshintrc-base",
-  "globals": {
-    "window": false,
-
-    "angular": false,
-    "expect": false,
-    "jQuery": false,
-
-    "AnimationEvent": false,
-    "TransitionEvent": false,
-    "WebKitAnimationEvent": false,
-    "WebKitTransitionEvent": false
-  }
-}
diff --git a/src/ngMock/angular-mocks.js b/src/ngMock/angular-mocks.js
index 8d3e5881f621..94fc9a68cf0e 100644
--- a/src/ngMock/angular-mocks.js
+++ b/src/ngMock/angular-mocks.js
@@ -245,7 +245,7 @@ angular.mock.$ExceptionHandlerProvider = function() {
       case 'rethrow':
         var errors = [];
         handler = function(e) {
-          if (arguments.length == 1) {
+          if (arguments.length === 1) {
             errors.push(e);
           } else {
             errors.push([].slice.call(arguments, 0));
@@ -552,16 +552,13 @@ angular.mock.$IntervalProvider = function() {
 };
 
 
-/* jshint -W101 */
-/* The R_ISO8061_STR regex is never going to fit into the 100 char limit!
- * This directive should go inside the anonymous function but a bug in JSHint means that it would
- * not be enacted early enough to prevent the warning.
- */
-var R_ISO8061_STR = /^(-?\d{4})-?(\d\d)-?(\d\d)(?:T(\d\d)(?:\:?(\d\d)(?:\:?(\d\d)(?:\.(\d{3}))?)?)?(Z|([+-])(\d\d):?(\d\d)))?$/;
-
 function jsonStringToDate(string) {
+  // The R_ISO8061_STR regex is never going to fit into the 100 char limit!
+  // eslit-disable-next-line max-len
+  var R_ISO8061_STR = /^(-?\d{4})-?(\d\d)-?(\d\d)(?:T(\d\d)(?::?(\d\d)(?::?(\d\d)(?:\.(\d{3}))?)?)?(Z|([+-])(\d\d):?(\d\d)))?$/;
+
   var match;
-  if (match = string.match(R_ISO8061_STR)) {
+  if ((match = string.match(R_ISO8061_STR))) {
     var date = new Date(0),
         tzHour = 0,
         tzMin  = 0;
@@ -644,6 +641,7 @@ angular.mock.TzDate = function(offset, timestamp) {
 
     timestamp = self.origDate.getTime();
     if (isNaN(timestamp)) {
+      // eslint-disable-next-line no-throw-literal
       throw {
         name: "Illegal Argument",
         message: "Arg '" + tsStr + "' passed into TzDate constructor is not a valid date string"
@@ -761,7 +759,6 @@ angular.mock.TzDate = function(offset, timestamp) {
 
 //make "tzDateInstance instanceof Date" return true
 angular.mock.TzDate.prototype = Date.prototype;
-/* jshint +W101 */
 
 
 /**
@@ -1209,7 +1206,7 @@ angular.mock.dump = function(object) {
          $httpBackend.expectPOST('/add-msg.py', undefined, function(headers) {
            // check if the header was sent, if it wasn't the expectation won't
            // match the request and the test will fail
-           return headers['Authorization'] == 'xxx';
+           return headers['Authorization'] === 'xxx';
          }).respond(201, '');
 
          $rootScope.saveMessage('whatever');
@@ -1351,7 +1348,11 @@ function createHttpBackendMock($rootScope, $timeout, $delegate, $browser) {
 
     function wrapResponse(wrapped) {
       if (!$browser && timeout) {
-        timeout.then ? timeout.then(handleTimeout) : $timeout(handleTimeout, timeout);
+        if (timeout.then) {
+          timeout.then(handleTimeout);
+        } else {
+          $timeout(handleTimeout, timeout);
+        }
       }
 
       return handleResponse;
@@ -1911,14 +1912,15 @@ function MockHttpExpectation(method, url, data, headers, keys) {
   }
 
   function compareUrl(u) {
-    return (url.slice(0, url.indexOf('?')) == u.slice(0, u.indexOf('?')) && getUrlParams(url).join() == getUrlParams(u).join());
+    return (url.slice(0, url.indexOf('?')) === u.slice(0, u.indexOf('?')) &&
+      getUrlParams(url).join() === getUrlParams(u).join());
   }
 
   this.data = data;
   this.headers = headers;
 
   this.match = function(m, u, d, h) {
-    if (method != m) return false;
+    if (method !== m) return false;
     if (!this.matchUrl(u)) return false;
     if (angular.isDefined(d) && !this.matchData(d)) return false;
     if (angular.isDefined(h) && !this.matchHeaders(h)) return false;
@@ -1929,7 +1931,7 @@ function MockHttpExpectation(method, url, data, headers, keys) {
     if (!url) return true;
     if (angular.isFunction(url.test)) return url.test(u);
     if (angular.isFunction(url)) return url(u);
-    return (url == u || compareUrl(u));
+    return (url === u || compareUrl(u));
   };
 
   this.matchHeaders = function(h) {
@@ -1945,6 +1947,7 @@ function MockHttpExpectation(method, url, data, headers, keys) {
     if (data && !angular.isString(data)) {
       return angular.equals(angular.fromJson(angular.toJson(data)), angular.fromJson(d));
     }
+    // eslint-disable-next-line eqeqeq
     return data == d;
   };
 
@@ -2043,7 +2046,7 @@ function MockXhr() {
 
     header = undefined;
     angular.forEach(this.$$respHeaders, function(headerVal, headerName) {
-      if (!header && angular.lowercase(headerName) == name) header = headerVal;
+      if (!header && angular.lowercase(headerName) === name) header = headerVal;
     });
     return header;
   };
@@ -2116,7 +2119,7 @@ angular.mock.$TimeoutDecorator = ['$delegate', '$browser', function($delegate, $
   function formatPendingTasksAsString(tasks) {
     var result = [];
     angular.forEach(tasks, function(task) {
-      result.push('{id: ' + task.id + ', ' + 'time: ' + task.time + '}');
+      result.push('{id: ' + task.id + ', time: ' + task.time + '}');
     });
 
     return result.join(', ');
@@ -2257,7 +2260,8 @@ angular.mock.$ControllerDecorator = ['$delegate', function($delegate) {
  * @param {string=} ident Override the property name to use when attaching the controller to the scope.
  * @return {Object} Instance of requested controller.
  */
-angular.mock.$ComponentControllerProvider = ['$compileProvider', function($compileProvider) {
+angular.mock.$ComponentControllerProvider = ['$compileProvider',
+    function ComponentControllerProvider($compileProvider) {
   this.$get = ['$controller','$injector', '$rootScope', function($controller, $injector, $rootScope) {
     return function $componentController(componentName, locals, bindings, ident) {
       // get all directives associated to the component name
@@ -2417,7 +2421,7 @@ angular.module('ngMockE2E', ['ng']).config(['$provide', function($provide) {
  * <file name="app.js">
  *   var myApp = angular.module('myApp', []);
  *
- *   myApp.controller('main', function($http) {
+ *   myApp.controller('MainCtrl', function MainCtrl($http) {
  *     var ctrl = this;
  *
  *     ctrl.phones = [];
@@ -2459,7 +2463,7 @@ angular.module('ngMockE2E', ['ng']).config(['$provide', function($provide) {
  *   });
  * </file>
  * <file name="index.html">
- *   <div ng-controller="main as $ctrl">
+ *   <div ng-controller="MainCtrl as $ctrl">
  *   <form name="newPhoneForm" ng-submit="$ctrl.addPhone($ctrl.newPhone)">
  *     <input type="text" ng-model="$ctrl.newPhone.name">
  *     <input type="submit" value="Add Phone">
@@ -2672,6 +2676,7 @@ angular.mock.$RootScopeDecorator = ['$delegate', function($delegate) {
    * @ngdoc method
    * @name $rootScope.Scope#$countChildScopes
    * @module ngMock
+   * @this $rootScope.Scope
    * @description
    * Counts all the direct and indirect child scopes of the current scope.
    *
@@ -2680,7 +2685,6 @@ angular.mock.$RootScopeDecorator = ['$delegate', function($delegate) {
    * @returns {number} Total number of child scopes.
    */
   function countChildScopes() {
-    // jshint validthis: true
     var count = 0; // exclude the current scope
     var pendingChildHeads = [this.$$childHead];
     var currentScope;
@@ -2702,6 +2706,7 @@ angular.mock.$RootScopeDecorator = ['$delegate', function($delegate) {
   /**
    * @ngdoc method
    * @name $rootScope.Scope#$countWatchers
+   * @this $rootScope.Scope
    * @module ngMock
    * @description
    * Counts all the watchers of direct and indirect child scopes of the current scope.
@@ -2712,7 +2717,6 @@ angular.mock.$RootScopeDecorator = ['$delegate', function($delegate) {
    * @returns {number} Total number of watchers.
    */
   function countWatchers() {
-    // jshint validthis: true
     var count = this.$$watchers ? this.$$watchers.length : 0; // include the current scope
     var pendingChildHeads = [this.$$childHead];
     var currentScope;
@@ -2732,7 +2736,7 @@ angular.mock.$RootScopeDecorator = ['$delegate', function($delegate) {
 }];
 
 
-!(function(jasmineOrMocha) {
+(function(jasmineOrMocha) {
 
   if (!jasmineOrMocha) {
     return;
@@ -2827,7 +2831,7 @@ angular.mock.$RootScopeDecorator = ['$delegate', function($delegate) {
    *
    * You cannot call `sharedInjector()` from within a context already using `sharedInjector()`.
    *
-   * ## Example
+   * ## Example
    *
    * Typically beforeAll is used to make many assertions about a single operation. This can
    * cut down test run-time as the test setup doesn't need to be re-run, and enabling focussed
@@ -2870,7 +2874,7 @@ angular.mock.$RootScopeDecorator = ['$delegate', function($delegate) {
 
     var initialized = false;
 
-    module.$$beforeAllHook(function() {
+    module.$$beforeAllHook(/* @this */ function() {
       if (injectorState.shared) {
         injectorState.sharedError = Error("sharedInjector() cannot be called inside a context that has already called sharedInjector()");
         throw injectorState.sharedError;
@@ -2891,7 +2895,7 @@ angular.mock.$RootScopeDecorator = ['$delegate', function($delegate) {
   };
 
   module.$$beforeEach = function() {
-    if (injectorState.shared && currentSpec && currentSpec != this) {
+    if (injectorState.shared && currentSpec && currentSpec !== this) {
       var state = currentSpec;
       currentSpec = this;
       angular.forEach(["$injector","$modules","$providerInjector", "$injectorStrict"], function(k) {
@@ -3049,7 +3053,7 @@ angular.mock.$RootScopeDecorator = ['$delegate', function($delegate) {
 
 
 
-  var ErrorAddingDeclarationLocationStack = function(e, errorForStack) {
+  var ErrorAddingDeclarationLocationStack = function ErrorAddingDeclarationLocationStack(e, errorForStack) {
     this.message = e.message;
     this.name = e.name;
     if (e.line) this.line = e.line;
@@ -3067,11 +3071,11 @@ angular.mock.$RootScopeDecorator = ['$delegate', function($delegate) {
     if (!errorForStack.stack) {
       try {
         throw errorForStack;
-      } catch (e) {}
+      } catch (e) { /* empty */ }
     }
-    return wasInjectorCreated() ? workFn.call(currentSpec) : workFn;
+    return wasInjectorCreated() ? WorkFn.call(currentSpec) : WorkFn;
     /////////////////////
-    function workFn() {
+    function WorkFn() {
       var modules = currentSpec.$modules || [];
       var strictDi = !!currentSpec.$injectorStrict;
       modules.unshift(['$injector', function($injector) {
@@ -3099,9 +3103,7 @@ angular.mock.$RootScopeDecorator = ['$delegate', function($delegate) {
           injector.annotate(blockFns[i]);
         }
         try {
-          /* jshint -W040 *//* Jasmine explicitly provides a `this` object when calling functions */
           injector.invoke(blockFns[i] || angular.noop, this);
-          /* jshint +W040 */
         } catch (e) {
           if (e.stack && errorForStack) {
             throw new ErrorAddingDeclarationLocationStack(e, errorForStack);
diff --git a/src/ngMock/browserTrigger.js b/src/ngMock/browserTrigger.js
index b31bad6ecbc7..036d8d636106 100644
--- a/src/ngMock/browserTrigger.js
+++ b/src/ngMock/browserTrigger.js
@@ -54,26 +54,24 @@
     var evnt;
     if (/transitionend/.test(eventType)) {
       if (window.WebKitTransitionEvent) {
-        evnt = new WebKitTransitionEvent(eventType, eventData);
+        evnt = new window.WebKitTransitionEvent(eventType, eventData);
         evnt.initEvent(eventType, false, true);
       } else {
         try {
-          evnt = new TransitionEvent(eventType, eventData);
-        }
-        catch (e) {
+          evnt = new window.TransitionEvent(eventType, eventData);
+        } catch (e) {
           evnt = window.document.createEvent('TransitionEvent');
           evnt.initTransitionEvent(eventType, null, null, null, eventData.elapsedTime || 0);
         }
       }
     } else if (/animationend/.test(eventType)) {
       if (window.WebKitAnimationEvent) {
-        evnt = new WebKitAnimationEvent(eventType, eventData);
+        evnt = new window.WebKitAnimationEvent(eventType, eventData);
         evnt.initEvent(eventType, false, true);
       } else {
         try {
-          evnt = new AnimationEvent(eventType, eventData);
-        }
-        catch (e) {
+          evnt = new window.AnimationEvent(eventType, eventData);
+        } catch (e) {
           evnt = window.document.createEvent('AnimationEvent');
           evnt.initAnimationEvent(eventType, null, null, null, eventData.elapsedTime || 0);
         }
@@ -194,6 +192,7 @@
     patchEventTargetForBubbling(evnt, element);
     do {
       element.dispatchEvent(evnt);
+      // eslint-disable-next-line no-unmodified-loop-condition
     } while (!stop && (element = element.parentNode));
   }
 
@@ -203,11 +202,11 @@
   }
 
   function isAttachedToDocument(element) {
-    while (element = element.parentNode) {
+    while ((element = element.parentNode)) {
         if (element === window) {
             return true;
         }
     }
     return false;
   }
-}());
+})();
diff --git a/src/ngParseExt/module.js b/src/ngParseExt/module.js
index 5166dd34033e..25dc52c37838 100644
--- a/src/ngParseExt/module.js
+++ b/src/ngParseExt/module.js
@@ -1,5 +1,7 @@
 'use strict';
 
+/* eslint-disable new-cap */
+
 /**
  * @ngdoc module
  * @name ngParseExt
diff --git a/src/ngResource/.jshintrc b/src/ngResource/.jshintrc
deleted file mode 100644
index 1c700a8719e3..000000000000
--- a/src/ngResource/.jshintrc
+++ /dev/null
@@ -1,8 +0,0 @@
-{
-  "extends": "../../.jshintrc-base",
-  "globals": {
-    "window": false,
-
-    "angular": false
-  }
-}
diff --git a/src/ngResource/resource.js b/src/ngResource/resource.js
index 16aec9bbfbba..032e66f65564 100644
--- a/src/ngResource/resource.js
+++ b/src/ngResource/resource.js
@@ -428,8 +428,9 @@ function shallowClearAndCopy(src, dst) {
  *
  */
 angular.module('ngResource', ['ng']).
-  provider('$resource', function() {
+  provider('$resource', function ResourceProvider() {
     var PROTOCOL_AND_DOMAIN_REGEX = /^https?:\/\/[^\/]*/;
+
     var provider = this;
 
     /**
@@ -569,7 +570,7 @@ angular.module('ngResource', ['ng']).
                 return encodedVal + p1;
               });
             } else {
-              url = url.replace(new RegExp("(\/?):" + urlParam + "(\\W|$)", "g"), function(match,
+              url = url.replace(new RegExp("(/?):" + urlParam + "(\\W|$)", "g"), function(match,
                   leadingSlashes, tail) {
                 if (tail.charAt(0) === '/') {
                   return tail;
@@ -654,12 +655,11 @@ angular.module('ngResource', ['ng']).
           Resource[name] = function(a1, a2, a3, a4) {
             var params = {}, data, success, error;
 
-            /* jshint -W086 */ /* (purposefully fall through case statements) */
             switch (arguments.length) {
               case 4:
                 error = a4;
                 success = a3;
-              //fallthrough
+                // falls through
               case 3:
               case 2:
                 if (isFunction(a2)) {
@@ -671,13 +671,14 @@ angular.module('ngResource', ['ng']).
 
                   success = a2;
                   error = a3;
-                  //fallthrough
+                  // falls through
                 } else {
                   params = a1;
                   data = a2;
                   success = a3;
                   break;
                 }
+                // falls through
               case 1:
                 if (isFunction(a1)) success = a1;
                 else if (hasBody) data = a1;
@@ -689,7 +690,6 @@ angular.module('ngResource', ['ng']).
                   "Expected up to 4 arguments [params, data, success, error], got {0} arguments",
                   arguments.length);
             }
-            /* jshint +W086 */ /* (purposefully fall through case statements) */
 
             var isInstanceCall = this instanceof Resource;
             var value = isInstanceCall ? data : (action.isArray ? [] : new Resource(data));
@@ -735,14 +735,12 @@ angular.module('ngResource', ['ng']).
 
               if (data) {
                 // Need to convert action.isArray to boolean in case it is undefined
-                // jshint -W018
                 if (angular.isArray(data) !== (!!action.isArray)) {
                   throw $resourceMinErr('badcfg',
                       'Error in resource configuration for action `{0}`. Expected response to ' +
                       'contain an {1} but got an {2} (Request: {3} {4})', name, action.isArray ? 'array' : 'object',
                     angular.isArray(data) ? 'array' : 'object', httpConfig.method, httpConfig.url);
                 }
-                // jshint +W018
                 if (action.isArray) {
                   value.length = 0;
                   forEach(data, function(item) {
diff --git a/src/ngRoute/.eslintrc.json b/src/ngRoute/.eslintrc.json
new file mode 100644
index 000000000000..99cb2c41cca4
--- /dev/null
+++ b/src/ngRoute/.eslintrc.json
@@ -0,0 +1,5 @@
+{
+  "globals": {
+    "ngRouteModule": false
+  }
+}
diff --git a/src/ngRoute/.jshintrc b/src/ngRoute/.jshintrc
deleted file mode 100644
index ce673f7f6738..000000000000
--- a/src/ngRoute/.jshintrc
+++ /dev/null
@@ -1,9 +0,0 @@
-{
-  "extends": "../../.jshintrc-base",
-  "globals": {
-    "window": false,
-
-    "angular": false,
-    "ngRouteModule": false
-  }
-}
diff --git a/src/ngRoute/directive/ngView.js b/src/ngRoute/directive/ngView.js
index 30c3397d5160..8cff45618261 100644
--- a/src/ngRoute/directive/ngView.js
+++ b/src/ngRoute/directive/ngView.js
@@ -143,16 +143,16 @@ ngRouteModule.directive('ngView', ngViewFillContentFactory);
               $locationProvider.html5Mode(true);
           }])
           .controller('MainCtrl', ['$route', '$routeParams', '$location',
-            function($route, $routeParams, $location) {
+            function MainCtrl($route, $routeParams, $location) {
               this.$route = $route;
               this.$location = $location;
               this.$routeParams = $routeParams;
           }])
-          .controller('BookCtrl', ['$routeParams', function($routeParams) {
+          .controller('BookCtrl', ['$routeParams', function BookCtrl($routeParams) {
             this.name = "BookCtrl";
             this.params = $routeParams;
           }])
-          .controller('ChapterCtrl', ['$routeParams', function($routeParams) {
+          .controller('ChapterCtrl', ['$routeParams', function ChapterCtrl($routeParams) {
             this.name = "ChapterCtrl";
             this.params = $routeParams;
           }]);
@@ -163,15 +163,15 @@ ngRouteModule.directive('ngView', ngViewFillContentFactory);
         it('should load and compile correct template', function() {
           element(by.linkText('Moby: Ch1')).click();
           var content = element(by.css('[ng-view]')).getText();
-          expect(content).toMatch(/controller\: ChapterCtrl/);
-          expect(content).toMatch(/Book Id\: Moby/);
-          expect(content).toMatch(/Chapter Id\: 1/);
+          expect(content).toMatch(/controller: ChapterCtrl/);
+          expect(content).toMatch(/Book Id: Moby/);
+          expect(content).toMatch(/Chapter Id: 1/);
 
           element(by.partialLinkText('Scarlet')).click();
 
           content = element(by.css('[ng-view]')).getText();
-          expect(content).toMatch(/controller\: BookCtrl/);
-          expect(content).toMatch(/Book Id\: Scarlet/);
+          expect(content).toMatch(/controller: BookCtrl/);
+          expect(content).toMatch(/Book Id: Scarlet/);
         });
       </file>
     </example>
diff --git a/src/ngRoute/route.js b/src/ngRoute/route.js
index 8dcb2bd718de..1c289e600117 100644
--- a/src/ngRoute/route.js
+++ b/src/ngRoute/route.js
@@ -38,6 +38,7 @@ var isEagerInstantiationEnabled;
 /**
  * @ngdoc provider
  * @name $routeProvider
+ * @this
  *
  * @description
  *
@@ -468,15 +469,15 @@ function $RouteProvider() {
      *     it('should load and compile correct template', function() {
      *       element(by.linkText('Moby: Ch1')).click();
      *       var content = element(by.css('[ng-view]')).getText();
-     *       expect(content).toMatch(/controller\: ChapterController/);
-     *       expect(content).toMatch(/Book Id\: Moby/);
-     *       expect(content).toMatch(/Chapter Id\: 1/);
+     *       expect(content).toMatch(/controller: ChapterController/);
+     *       expect(content).toMatch(/Book Id: Moby/);
+     *       expect(content).toMatch(/Chapter Id: 1/);
      *
      *       element(by.partialLinkText('Scarlet')).click();
      *
      *       content = element(by.css('[ng-view]')).getText();
-     *       expect(content).toMatch(/controller\: BookController/);
-     *       expect(content).toMatch(/Book Id\: Scarlet/);
+     *       expect(content).toMatch(/controller: BookController/);
+     *       expect(content).toMatch(/Book Id: Scarlet/);
      *     });
      *   </file>
      * </example>
diff --git a/src/ngRoute/routeParams.js b/src/ngRoute/routeParams.js
index 7e8e0d01ccbc..483d27a1e64a 100644
--- a/src/ngRoute/routeParams.js
+++ b/src/ngRoute/routeParams.js
@@ -7,6 +7,7 @@ ngRouteModule.provider('$routeParams', $RouteParamsProvider);
  * @ngdoc service
  * @name $routeParams
  * @requires $route
+ * @this
  *
  * @description
  * The `$routeParams` service allows you to retrieve the current set of route parameters.
diff --git a/src/ngSanitize/.eslintrc.json b/src/ngSanitize/.eslintrc.json
new file mode 100644
index 000000000000..d3d2b601ab4b
--- /dev/null
+++ b/src/ngSanitize/.eslintrc.json
@@ -0,0 +1,5 @@
+{
+  "globals": {
+    "sanitizeText": false
+  }
+}
diff --git a/src/ngSanitize/.jshintrc b/src/ngSanitize/.jshintrc
deleted file mode 100644
index 73c34918e2bf..000000000000
--- a/src/ngSanitize/.jshintrc
+++ /dev/null
@@ -1,9 +0,0 @@
-{
-  "extends": "../../.jshintrc-base",
-  "globals": {
-    "window": false,
-
-    "angular": false,
-    "sanitizeText": false
-  }
-}
diff --git a/src/ngSanitize/filter/linky.js b/src/ngSanitize/filter/linky.js
index 6ecdd889a10d..6247cb626b46 100644
--- a/src/ngSanitize/filter/linky.js
+++ b/src/ngSanitize/filter/linky.js
@@ -78,10 +78,10 @@
        angular.module('linkyExample', ['ngSanitize'])
          .controller('ExampleController', ['$scope', function($scope) {
            $scope.snippet =
-             'Pretty text with some links:\n'+
-             'http://angularjs.org/,\n'+
-             'mailto:us@somewhere.org,\n'+
-             'another@somewhere.org,\n'+
+             'Pretty text with some links:\n' +
+             'http://angularjs.org/,\n' +
+             'mailto:us@somewhere.org,\n' +
+             'another@somewhere.org,\n' +
              'and one more: ftp://127.0.0.1/.';
            $scope.snippetWithSingleURL = 'http://angularjs.org/';
          }]);
diff --git a/src/ngSanitize/sanitize.js b/src/ngSanitize/sanitize.js
index a7741a784ba6..64759e9c017a 100644
--- a/src/ngSanitize/sanitize.js
+++ b/src/ngSanitize/sanitize.js
@@ -143,6 +143,7 @@ var htmlSanitizeWriter;
 /**
  * @ngdoc provider
  * @name $sanitizeProvider
+ * @this
  *
  * @description
  * Creates and configures {@link $sanitize} instance.
@@ -220,7 +221,7 @@ function $SanitizeProvider() {
   // Regular Expressions for parsing tags and attributes
   var SURROGATE_PAIR_REGEXP = /[\uD800-\uDBFF][\uDC00-\uDFFF]/g,
     // Match everything outside of normal chars and " (quote character)
-    NON_ALPHANUMERIC_REGEXP = /([^\#-~ |!])/g;
+    NON_ALPHANUMERIC_REGEXP = /([^#-~ |!])/g;
 
 
   // Good source of info about elements and attributes
@@ -395,7 +396,7 @@ function $SanitizeProvider() {
       node = nextNode;
     }
 
-    while (node = inertBodyElement.firstChild) {
+    while ((node = inertBodyElement.firstChild)) {
       inertBodyElement.removeChild(node);
     }
   }
@@ -476,6 +477,7 @@ function $SanitizeProvider() {
           out(tag);
           out('>');
         }
+        // eslint-disable-next-line eqeqeq
         if (tag == ignoreCurrentElement) {
           ignoreCurrentElement = false;
         }
diff --git a/src/ngScenario/.jshintrc b/src/ngScenario/.eslintrc.json
similarity index 77%
rename from src/ngScenario/.jshintrc
rename to src/ngScenario/.eslintrc.json
index ab7250a69be3..454d02348435 100644
--- a/src/ngScenario/.jshintrc
+++ b/src/ngScenario/.eslintrc.json
@@ -1,9 +1,5 @@
 {
-  "extends": "../../.jshintrc-base",
   "globals": {
-    "window": false,
-
-    "angular": false,
     "includes": false,
     "asyncForEach": false,
     "msie": false,
diff --git a/src/ngScenario/Application.js b/src/ngScenario/Application.js
index 3b73a90cd6bb..07efe4fa2baa 100644
--- a/src/ngScenario/Application.js
+++ b/src/ngScenario/Application.js
@@ -35,7 +35,7 @@ angular.scenario.Application.prototype.getFrame_ = function() {
 angular.scenario.Application.prototype.getWindow_ = function() {
   var contentWindow = this.getFrame_().prop('contentWindow');
   if (!contentWindow) {
-    throw 'Frame window is not accessible.';
+    throw new Error('Frame window is not accessible.');
   }
   return contentWindow;
 };
@@ -113,13 +113,13 @@ angular.scenario.Application.prototype.executeAction = function(action) {
   var self = this;
   var $window = this.getWindow_();
   if (!$window.document) {
-    throw 'Sandbox Error: Application document not accessible.';
+    throw new Error('Sandbox Error: Application document not accessible.');
   }
   if (!$window.angular) {
     return action.call(this, $window, _jQuery($window.document));
   }
 
-  if (!!this.rootElement) {
+  if (this.rootElement) {
     executeWithElement(this.rootElement);
   } else {
     angularInit($window.document, angular.bind(this, executeWithElement));
diff --git a/src/ngScenario/Describe.js b/src/ngScenario/Describe.js
index 223f87593a00..8691c1f80cdf 100644
--- a/src/ngScenario/Describe.js
+++ b/src/ngScenario/Describe.js
@@ -23,7 +23,7 @@ angular.scenario.Describe = function(descName, parent) {
   var beforeEachFns = this.beforeEachFns;
   this.setupBefore = function() {
     if (parent) parent.setupBefore.call(this);
-    angular.forEach(beforeEachFns, function(fn) { fn.call(this); }, this);
+    angular.forEach(beforeEachFns, /* @this */ function(fn) { fn.call(this); }, this);
   };
 
   /**
@@ -31,7 +31,7 @@ angular.scenario.Describe = function(descName, parent) {
    */
   var afterEachFns = this.afterEachFns;
   this.setupAfter  = function() {
-    angular.forEach(afterEachFns, function(fn) { fn.call(this); }, this);
+    angular.forEach(afterEachFns, /* @this */ function(fn) { fn.call(this); }, this);
     if (parent) parent.setupAfter.call(this);
   };
 };
diff --git a/src/ngScenario/ObjectModel.js b/src/ngScenario/ObjectModel.js
index 84466f0952c8..b6a43917183c 100644
--- a/src/ngScenario/ObjectModel.js
+++ b/src/ngScenario/ObjectModel.js
@@ -77,7 +77,7 @@ angular.scenario.ObjectModel = function(runner) {
     var it = self.getSpec(spec.id);
     var step = it.getLastStep();
     if (step.name !== step.name) {
-      throw 'Events fired in the wrong order. Step names don\'t match.';
+      throw new Error('Events fired in the wrong order. Step names don\'t match.');
     }
     complete(step);
 
@@ -221,7 +221,7 @@ angular.scenario.ObjectModel.Spec.prototype.getLastStep = function() {
  * @param {angular.scenario.ObjectModel.Step} step
  */
 angular.scenario.ObjectModel.Spec.prototype.setStatusFromStep = function(step) {
-  if (!this.status || step.status == 'error') {
+  if (!this.status || step.status === 'error') {
     this.status = step.status;
     this.error = step.error;
     this.line = step.line;
diff --git a/src/ngScenario/Runner.js b/src/ngScenario/Runner.js
index 08493954e22b..848b425e640c 100644
--- a/src/ngScenario/Runner.js
+++ b/src/ngScenario/Runner.js
@@ -21,7 +21,7 @@ angular.scenario.Runner = function($window) {
     beforeEach: this.beforeEach,
     afterEach: this.afterEach
   };
-  angular.forEach(this.api, angular.bind(this, function(fn, key) {
+  angular.forEach(this.api, angular.bind(this, /* @this */ function(fn, key) {
     this.$window[key] = angular.bind(this, fn);
   }));
 };
@@ -66,7 +66,7 @@ angular.scenario.Runner.prototype.on = function(eventName, listener) {
  */
 angular.scenario.Runner.prototype.describe = function(name, body) {
   var self = this;
-  this.currentDescribe.describe(name, function() {
+  this.currentDescribe.describe(name, /* @this */ function() {
     var parentDescribe = self.currentDescribe;
     self.currentDescribe = this;
     try {
@@ -87,7 +87,7 @@ angular.scenario.Runner.prototype.describe = function(name, body) {
  */
 angular.scenario.Runner.prototype.ddescribe = function(name, body) {
   var self = this;
-  this.currentDescribe.ddescribe(name, function() {
+  this.currentDescribe.ddescribe(name, /* @this */ function() {
     var parentDescribe = self.currentDescribe;
     self.currentDescribe = this;
     try {
@@ -215,7 +215,7 @@ angular.scenario.Runner.prototype.run = function(application) {
         return scope.dsl[key].apply(scope, arguments);
       };
     });
-    runner.run(spec, function() {
+    runner.run(spec, /* @this */ function() {
       runner.$destroy();
       specDone.apply(this, arguments);
     });
diff --git a/src/ngScenario/Scenario.js b/src/ngScenario/Scenario.js
index daaf61d50c98..50ac6f2ab94e 100644
--- a/src/ngScenario/Scenario.js
+++ b/src/ngScenario/Scenario.js
@@ -39,7 +39,8 @@ angular.scenario.output = angular.scenario.output || function(name, fn) {
  */
 angular.scenario.dsl = angular.scenario.dsl || function(name, fn) {
   angular.scenario.dsl[name] = function() {
-    /* jshint -W040 *//* The dsl binds `this` for us when calling chained functions */
+    // The dsl binds `this` for us when calling chained functions
+    /* @this */
     function executeStatement(statement, args) {
       var result = statement.apply(this, args);
       if (angular.isFunction(result) || result instanceof angular.scenario.Future) {
@@ -59,7 +60,7 @@ angular.scenario.dsl = angular.scenario.dsl || function(name, fn) {
       return chain;
     }
     var statement = fn.apply(this, arguments);
-    return function() {
+    return /* @this */ function() {
       return executeStatement.call(this, statement, arguments);
     };
   };
@@ -142,6 +143,7 @@ angular.scenario.setUpAndRun = function(config) {
       console.log(formatException(error));
     } else {
       // Do something for IE
+      // eslint-disable-next-line no-alert
       alert(error);
     }
   });
@@ -301,11 +303,11 @@ _jQuery.fn.bindings = function(windowJquery, bindExp) {
     result.push('' + value);
   }
 
-  selection.each(function() {
+  selection.each(/* @this Node */ function() {
     var element = windowJquery(this),
         bindings;
-    if (bindings = element.data('$binding')) {
-      for (var expressions = [], binding, j=0, jj=bindings.length; j < jj; j++) {
+    if ((bindings = element.data('$binding'))) {
+      for (var expressions = [], binding, j = 0, jj = bindings.length; j < jj; j++) {
         binding = bindings[j];
 
         if (binding.expressions) {
diff --git a/src/ngScenario/SpecRunner.js b/src/ngScenario/SpecRunner.js
index 02aaa346b50c..5d627ae3f747 100644
--- a/src/ngScenario/SpecRunner.js
+++ b/src/ngScenario/SpecRunner.js
@@ -106,8 +106,8 @@ angular.scenario.SpecRunner.prototype.addFuture = function(name, behavior, line)
  */
 angular.scenario.SpecRunner.prototype.addFutureAction = function(name, behavior, line) {
   var self = this;
-  var NG = /\[ng\\\:/;
-  return this.addFuture(name, function(done) {
+  var NG = /\[ng\\:/;
+  return this.addFuture(name, /* @this */ function(done) {
     this.application.executeAction(function($window, $document) {
 
       //TODO(esprehn): Refactor this so it doesn't need to be in here.
@@ -125,6 +125,7 @@ angular.scenario.SpecRunner.prototype.addFutureAction = function(name, behavior,
           });
         }
         if (!result.length) {
+          // eslint-disable-next-line no-throw-literal
           throw {
             type: 'selector',
             message: 'Selector ' + selector + ' did not match any elements.'
diff --git a/src/ngScenario/angular-bootstrap.js b/src/ngScenario/angular-bootstrap.js
index 076303ceab87..3f1b0bf7bee5 100644
--- a/src/ngScenario/angular-bootstrap.js
+++ b/src/ngScenario/angular-bootstrap.js
@@ -1,7 +1,5 @@
 'use strict';
 
-/* jshint -W060 */ /* we really do want to write to the document here */
-
 (function(previousOnLoad) {
   var prefix = (function() {
     var filename = /(.*\/)angular-bootstrap.js(#(.*))?/;
@@ -26,7 +24,7 @@
   window.onload = function() {
     try {
       if (previousOnLoad) previousOnLoad();
-    } catch (e) {}
+    } catch (e) { /* empty */ }
     angular.scenario.setUpAndRun({});
   };
 
diff --git a/src/ngScenario/dsl.js b/src/ngScenario/dsl.js
index 438bee844ab2..625c2b80c368 100644
--- a/src/ngScenario/dsl.js
+++ b/src/ngScenario/dsl.js
@@ -1,5 +1,7 @@
 'use strict';
 
+/* eslint-disable no-invalid-this */
+
 /**
  * Shared DSL statements that are useful to all scenarios.
  */
@@ -444,7 +446,7 @@ angular.scenario.dsl('element', function() {
       var args = arguments,
           futureName = (args.length === 1)
               ? "element '" + this.label + "' get " + methodName + " '" + name + "'"
-              : "element '" + this.label + "' set " + methodName + " '" + name + "' to " + "'" +
+              : "element '" + this.label + "' set " + methodName + " '" + name + "' to '" +
                 value + "'";
 
       return this.addFutureAction(futureName, function($window, $document, done) {
diff --git a/src/ngScenario/matchers.js b/src/ngScenario/matchers.js
index 183dce465fcd..98e73cd70f64 100644
--- a/src/ngScenario/matchers.js
+++ b/src/ngScenario/matchers.js
@@ -4,42 +4,42 @@
  * Matchers for implementing specs. Follows the Jasmine spec conventions.
  */
 
-angular.scenario.matcher('toEqual', function(expected) {
+angular.scenario.matcher('toEqual', /* @this */ function(expected) {
   return angular.equals(this.actual, expected);
 });
 
-angular.scenario.matcher('toBe', function(expected) {
+angular.scenario.matcher('toBe', /* @this */ function(expected) {
   return this.actual === expected;
 });
 
-angular.scenario.matcher('toBeDefined', function() {
+angular.scenario.matcher('toBeDefined', /* @this */ function() {
   return angular.isDefined(this.actual);
 });
 
-angular.scenario.matcher('toBeTruthy', function() {
+angular.scenario.matcher('toBeTruthy', /* @this */ function() {
   return this.actual;
 });
 
-angular.scenario.matcher('toBeFalsy', function() {
+angular.scenario.matcher('toBeFalsy', /* @this */ function() {
   return !this.actual;
 });
 
-angular.scenario.matcher('toMatch', function(expected) {
+angular.scenario.matcher('toMatch', /* @this */ function(expected) {
   return new RegExp(expected).test(this.actual);
 });
 
-angular.scenario.matcher('toBeNull', function() {
+angular.scenario.matcher('toBeNull', /* @this */ function() {
   return this.actual === null;
 });
 
-angular.scenario.matcher('toContain', function(expected) {
+angular.scenario.matcher('toContain', /* @this */ function(expected) {
   return includes(this.actual, expected);
 });
 
-angular.scenario.matcher('toBeLessThan', function(expected) {
+angular.scenario.matcher('toBeLessThan', /* @this */ function(expected) {
   return this.actual < expected;
 });
 
-angular.scenario.matcher('toBeGreaterThan', function(expected) {
+angular.scenario.matcher('toBeGreaterThan', /* @this */ function(expected) {
   return this.actual > expected;
 });
diff --git a/src/ngScenario/output/Xml.js b/src/ngScenario/output/Xml.js
index cdd04f0c7fa1..cfd04f5e529d 100644
--- a/src/ngScenario/output/Xml.js
+++ b/src/ngScenario/output/Xml.js
@@ -4,7 +4,10 @@
  * Generates XML output into a context.
  */
 angular.scenario.output('xml', function(context, runner, model) {
-  var $ = function(args) {return new context.init(args);};
+  var $ = function(args) {
+    // eslint-disable-next-line new-cap
+    return new context.init(args);
+  };
   model.on('RunnerEnd', function() {
     var scenario = $('<scenario></scenario>');
     context.append(scenario);
diff --git a/src/ngTouch/.eslintrc.json b/src/ngTouch/.eslintrc.json
new file mode 100644
index 000000000000..f271b78a9205
--- /dev/null
+++ b/src/ngTouch/.eslintrc.json
@@ -0,0 +1,5 @@
+{
+  "globals": {
+    "ngTouch": false
+  }
+}
diff --git a/src/ngTouch/.jshintrc b/src/ngTouch/.jshintrc
deleted file mode 100644
index 28536244d722..000000000000
--- a/src/ngTouch/.jshintrc
+++ /dev/null
@@ -1,9 +0,0 @@
-{
-  "extends": "../../.jshintrc-base",
-  "globals": {
-    "window": false,
-
-    "angular": false,
-    "ngTouch": false
-  }
-}
diff --git a/src/ngTouch/directive/ngClick.js b/src/ngTouch/directive/ngClick.js
index 226541939d50..81f628486afb 100644
--- a/src/ngTouch/directive/ngClick.js
+++ b/src/ngTouch/directive/ngClick.js
@@ -161,7 +161,9 @@ var ngTouchClickDirectiveFactory = ['$parse', '$timeout', '$rootElement',
     event.preventDefault();
 
     // Blur focused form elements
-    event.target && event.target.blur && event.target.blur();
+    if (event.target && event.target.blur) {
+      event.target.blur();
+    }
   }
 
 
diff --git a/src/ngTouch/swipe.js b/src/ngTouch/swipe.js
index b89ba2c152a7..013eea3dc6bc 100644
--- a/src/ngTouch/swipe.js
+++ b/src/ngTouch/swipe.js
@@ -117,13 +117,17 @@ ngTouch.factory('$swipe', [function() {
         totalX = 0;
         totalY = 0;
         lastPos = startCoords;
-        eventHandlers['start'] && eventHandlers['start'](startCoords, event);
+        if (eventHandlers['start']) {
+          eventHandlers['start'](startCoords, event);
+        }
       });
       var events = getEvents(pointerTypes, 'cancel');
       if (events) {
         element.on(events, function(event) {
           active = false;
-          eventHandlers['cancel'] && eventHandlers['cancel'](event);
+          if (eventHandlers['cancel']) {
+            eventHandlers['cancel'](event);
+          }
         });
       }
 
@@ -152,22 +156,27 @@ ngTouch.factory('$swipe', [function() {
         if (totalY > totalX) {
           // Allow native scrolling to take over.
           active = false;
-          eventHandlers['cancel'] && eventHandlers['cancel'](event);
+          if (eventHandlers['cancel']) {
+            eventHandlers['cancel'](event);
+          }
           return;
         } else {
           // Prevent the browser from scrolling.
           event.preventDefault();
-          eventHandlers['move'] && eventHandlers['move'](coords, event);
+          if (eventHandlers['move']) {
+            eventHandlers['move'](coords, event);
+          }
         }
       });
 
       element.on(getEvents(pointerTypes, 'end'), function(event) {
         if (!active) return;
         active = false;
-        eventHandlers['end'] && eventHandlers['end'](getCoordinates(event), event);
+        if (eventHandlers['end']) {
+          eventHandlers['end'](getCoordinates(event), event);
+        }
       });
     }
   };
 }]);
 
-
diff --git a/src/ngTouch/touch.js b/src/ngTouch/touch.js
index 09966953884d..5ae19d6b4a87 100644
--- a/src/ngTouch/touch.js
+++ b/src/ngTouch/touch.js
@@ -1,7 +1,6 @@
 'use strict';
 
-/* global ngTouchClickDirectiveFactory: false,
- */
+/* global ngTouchClickDirectiveFactory: false */
 
 /**
  * @ngdoc module
@@ -61,6 +60,7 @@ function $TouchProvider($provide, $compileProvider) {
    */
   var ngClickOverrideEnabled = false;
   var ngClickDirectiveAdded = false;
+  // eslint-disable-next-line no-invalid-this
   this.ngClickOverrideEnabled = function(enabled) {
     if (angular.isDefined(enabled)) {
 
@@ -108,6 +108,7 @@ function $TouchProvider($provide, $compileProvider) {
   * Provides the {@link ngTouch.$touch#ngClickOverrideEnabled `ngClickOverrideEnabled`} method.
   *
   */
+  // eslint-disable-next-line no-invalid-this
   this.$get = function() {
     return {
       /**
diff --git a/test/.jshintrc b/test/.eslintrc.json
similarity index 88%
rename from test/.jshintrc
rename to test/.eslintrc.json
index f7749ef4e585..2bf89b2bb07e 100644
--- a/test/.jshintrc
+++ b/test/.eslintrc.json
@@ -1,7 +1,25 @@
 {
-  "extends": "../.jshintrc-base",
-  "browser": true,
+  "root": true,
+  "extends": "../.eslintrc-browser.json",
+
+  "env": {
+    "jasmine": true
+  },
+
+  "rules": {
+    // Some rules are not that important in tests and conflict with
+    // Jasmine or would make it easier to write some tests; we disable
+    // those ones here.
+    "no-invalid-this": "off",
+    "no-throw-literal": "off",
+    "no-unused-vars": "off"
+  },
+
   "globals": {
+    /* browser */
+    "ArrayBuffer": false,
+    "Uint8Array": false,
+
     /* auto/injector.js */
     "createInjector": false,
 
@@ -127,30 +145,13 @@
     "urlResolve": false,
     "urlIsSameOrigin": false,
 
-    /* jasmine / karma */
-    "it": false,
-    "fit": false,
-    "describe": false,
-    "fdescribe": false,
-    "beforeEach": false,
-    "afterEach": false,
-    "expect": false,
-    "jasmine": false,
-    "spyOn": false,
-    "waits": false,
-    "waitsFor": false,
-    "runs": false,
+    /* karma */
     "dump": false,
     "they": false,
     "fthey": false,
     "xthey": false,
     "assertCompareNodes": false,
 
-    /* e2e */
-    "browser": false,
-    "element": false,
-    "by": false,
-
     /* testabilityPatch / matchers */
     "inject": false,
     "module": false,
diff --git a/test/AngularSpec.js b/test/AngularSpec.js
index b7e4d821d743..d8b9bf5b9af2 100644
--- a/test/AngularSpec.js
+++ b/test/AngularSpec.js
@@ -1,7 +1,16 @@
 'use strict';
 
+// Lots of typed array globals are used in this file and ESLint is
+// not smart enough to understand the `typeof !== 'undefined'` guards.
+/* globals Blob, Uint8ClampedArray, Uint16Array, Uint32Array, Int8Array, Int16Array, Int32Array,
+Float32Array, Float64Array,  */
+
 describe('angular', function() {
-  var element;
+  var element, document;
+
+  beforeEach(function() {
+    document = window.document;
+  });
 
   afterEach(function() {
     dealoc(element);
@@ -559,9 +568,8 @@ describe('angular', function() {
     });
 
     it('should copy String() objects', function() {
-      /*jshint -W053 */
+      // eslint-disable-next-line no-new-wrappers
       var obj = new String('foo');
-      /*jshint +W053 */
       var dest = copy(obj);
       expect(dest).not.toBe(obj);
       expect(isObject(dest)).toBe(true);
@@ -569,9 +577,8 @@ describe('angular', function() {
     });
 
     it('should copy Boolean() objects', function() {
-      /*jshint -W053 */
+      // eslint-disable-next-line no-new-wrappers
       var obj = new Boolean(true);
-      /*jshint +W053 */
       var dest = copy(obj);
       expect(dest).not.toBe(obj);
       expect(isObject(dest)).toBe(true);
@@ -579,9 +586,8 @@ describe('angular', function() {
     });
 
     it('should copy Number() objects', function() {
-      /*jshint -W053 */
+      // eslint-disable-next-line no-new-wrappers
       var obj = new Number(42);
-      /*jshint +W053 */
       var dest = copy(obj);
       expect(dest).not.toBe(obj);
       expect(isObject(dest)).toBe(true);
@@ -589,12 +595,12 @@ describe('angular', function() {
     });
 
     it('should copy falsy String/Boolean/Number objects', function() {
-      /*jshint -W053 */
+      /* eslint-disable no-new-wrappers */
       expect(copy(new String('')).valueOf()).toBe('');
       expect(copy(new Boolean(false)).valueOf()).toBe(false);
       expect(copy(new Number(0)).valueOf()).toBe(0);
       expect(copy(new Number(NaN)).valueOf()).toBeNaN();
-      /*jshint +W053 */
+      /* eslint-enable */
     });
   });
 
@@ -929,7 +935,6 @@ describe('angular', function() {
     });
 
     it('should correctly test for keys that are present on Object.prototype', function() {
-      /* jshint -W001 */
       expect(equals({}, {hasOwnProperty: 1})).toBe(false);
       expect(equals({}, {toString: null})).toBe(false);
     });
@@ -974,7 +979,6 @@ describe('angular', function() {
 
 
     it('should safely compare objects which shadow Object.prototype.hasOwnProperty', function() {
-      /* jshint -W001 */
       var o1 = {
         hasOwnProperty: true,
         a: 1,
@@ -998,7 +1002,7 @@ describe('angular', function() {
 
     function mockCspElement(cspAttrName, cspAttrValue) {
       return spyOn(document, 'querySelector').and.callFake(function(selector) {
-        if (selector == '[' + cspAttrName + ']') {
+        if (selector === '[' + cspAttrName + ']') {
           var html = '<div ' + cspAttrName + (cspAttrValue ? ('="' + cspAttrValue + '" ') : '') + '></div>';
           return jqLite(html)[0];
         }
@@ -1298,7 +1302,6 @@ describe('angular', function() {
 
 
     it('should not break if obj is an array we override hasOwnProperty', function() {
-      /* jshint -W001 */
       var obj = [];
       obj[0] = 1;
       obj[1] = 2;
@@ -1354,7 +1357,7 @@ describe('angular', function() {
       var args,
           log = [];
 
-      (function() { args = arguments; }('a', 'b', 'c'));
+      (function() { args = arguments; })('a', 'b', 'c');
 
       forEach(args, function(value, key) { log.push(key + ':' + value); });
       expect(log).toEqual(['0:a', '1:b', '2:c']);
@@ -1423,7 +1426,6 @@ describe('angular', function() {
 
 
     it('should safely iterate through objects which shadow Object.prototype.hasOwnProperty', function() {
-      /* jshint -W001 */
       var obj = {
         hasOwnProperty: true,
         a: 1,
@@ -1466,7 +1468,7 @@ describe('angular', function() {
 
 
       it('should follow the ES spec when called with arguments', function() {
-        testForEachSpec(2, (function() { return arguments; }(1,2)));
+        testForEachSpec(2, (function() { return arguments; })(1,2));
       });
 
 
diff --git a/test/BinderSpec.js b/test/BinderSpec.js
index 04efd7085d7a..faeb9a9f25c7 100644
--- a/test/BinderSpec.js
+++ b/test/BinderSpec.js
@@ -224,7 +224,7 @@ describe('Binder', function() {
   }));
 
   it('HideBindingExpression', inject(function($rootScope, $compile) {
-    element = $compile('<div ng-hide="hidden == 3"/>')($rootScope);
+    element = $compile('<div ng-hide="hidden === 3"/>')($rootScope);
 
     $rootScope.hidden = 3;
     $rootScope.$apply();
@@ -426,15 +426,15 @@ describe('Binder', function() {
   it('ItShouldRepeatOnHashes', inject(function($rootScope, $compile) {
     element = $compile(
       '<ul>' +
-        '<li ng-repeat="(k,v) in {a:0,b:1}" ng-bind=\"k + v\"></li>' +
+        '<li ng-repeat="(k,v) in {a:0,b:1}" ng-bind="k + v"></li>' +
       '</ul>')($rootScope);
     $rootScope.$apply();
     expect(sortedHtml(element)).toBe(
         '<ul>' +
           '<!-- ngRepeat: (k,v) in {a:0,b:1} -->' +
-          '<li ng-bind=\"k + v\" ng-repeat="(k,v) in {a:0,b:1}">a0</li>' +
+          '<li ng-bind="k + v" ng-repeat="(k,v) in {a:0,b:1}">a0</li>' +
           '<!-- end ngRepeat: (k,v) in {a:0,b:1} -->' +
-          '<li ng-bind=\"k + v\" ng-repeat="(k,v) in {a:0,b:1}">b1</li>' +
+          '<li ng-bind="k + v" ng-repeat="(k,v) in {a:0,b:1}">b1</li>' +
           '<!-- end ngRepeat: (k,v) in {a:0,b:1} -->' +
         '</ul>');
   }));
diff --git a/test/auto/injectorSpec.js b/test/auto/injectorSpec.js
index b295c3510a9e..c0760aecb687 100644
--- a/test/auto/injectorSpec.js
+++ b/test/auto/injectorSpec.js
@@ -139,22 +139,21 @@ describe('injector', function() {
     });
 
 
-    function fn(a, b, c, d) {
-      /* jshint -W040 */
+    function Fn(a, b, c, d) {
       args = [this, a, b, c, d];
       return a + b + c + d;
     }
 
 
     it('should call function', function() {
-      fn.$inject = ['a', 'b', 'c', 'd'];
-      injector.invoke(fn, {name:"this"},  {c:3, d:4});
+      Fn.$inject = ['a', 'b', 'c', 'd'];
+      injector.invoke(Fn, {name:"this"},  {c:3, d:4});
       expect(args).toEqual([{name:'this'}, 1, 2, 3, 4]);
     });
 
 
     it('should treat array as annotations', function() {
-      injector.invoke(['a', 'b', 'c', 'd', fn], {name:"this"}, {c:3, d:4});
+      injector.invoke(['a', 'b', 'c', 'd', Fn], {name:"this"}, {c:3, d:4});
       expect(args).toEqual([{name:'this'}, 1, 2, 3, 4]);
     });
 
@@ -162,7 +161,7 @@ describe('injector', function() {
     it('should invoke the passed-in fn with all of the dependencies as arguments', function() {
       providers('c', function() {return 3;});
       providers('d', function() {return 4;});
-      expect(injector.invoke(['a', 'b', 'c', 'd', fn])).toEqual(10);
+      expect(injector.invoke(['a', 'b', 'c', 'd', Fn])).toEqual(10);
     });
 
 
@@ -185,16 +184,16 @@ describe('injector', function() {
       expect(annotate(fn)).toBe(fn.$inject);
       expect(annotate(function() {})).toEqual([]);
       expect(annotate(function() {})).toEqual([]);
-      // jscs:disable disallowSpacesInAnonymousFunctionExpression
+      /* eslint-disable space-before-function-paren, no-multi-spaces */
       expect(annotate(function  () {})).toEqual([]);
       expect(annotate(function /* */ () {})).toEqual([]);
-      // jscs:enable disallowSpacesInAnonymousFunctionExpression
+      /* eslint-enable */
     });
 
 
     it('should create $inject', function() {
       var extraParans = angular.noop;
-      // jscs:disable disallowSpacesInFunctionDeclaration
+      /* eslint-disable space-before-function-paren */
       // keep the multi-line to make sure we can handle it
       function $f_n0 /*
           */(
@@ -204,8 +203,8 @@ describe('injector', function() {
                  function(a, b) {}
                  */
           _c,
-          /* {some type} */ d) { extraParans();}
-      // jscs:enable disallowSpacesInFunctionDeclaration
+          /* {some type} */ d) { extraParans(); }
+      /* eslint-enable */
       expect(annotate($f_n0)).toEqual(['$a', 'b_', '_c',  'd']);
       expect($f_n0.$inject).toEqual(['$a', 'b_', '_c',  'd']);
     });
@@ -256,10 +255,10 @@ describe('injector', function() {
 
 
     describe('es6', function() {
-      /*jshint -W061 */
       if (support.ES6Function) {
         // The functions are generated using `eval` as just having the ES6 syntax can break some browsers.
         it('should be possible to annotate functions that are declared using ES6 syntax', function() {
+          // eslint-disable-next-line no-eval
           expect(annotate(eval('({ fn(x) { return; } })').fn)).toEqual(['x']);
         });
       }
@@ -267,6 +266,7 @@ describe('injector', function() {
 
       if (support.fatArrow) {
         it('should create $inject for arrow functions', function() {
+          // eslint-disable-next-line no-eval
           expect(annotate(eval('(a, b) => a'))).toEqual(['a', 'b']);
         });
       }
@@ -274,6 +274,7 @@ describe('injector', function() {
 
       if (support.fatArrow) {
         it('should create $inject for arrow functions with no parenthesis', function() {
+          // eslint-disable-next-line no-eval
           expect(annotate(eval('a => a'))).toEqual(['a']);
         });
       }
@@ -281,11 +282,12 @@ describe('injector', function() {
 
       if (support.fatArrow) {
         it('should take args before first arrow', function() {
+          // eslint-disable-next-line no-eval
           expect(annotate(eval('a => b => b'))).toEqual(['a']);
         });
 
         // Support: Chrome 50-51 only
-        // TODO (gkalpak): Remove when Chrome v52 is relased.
+        // TODO (gkalpak): Remove when Chrome v52 is released.
         // it('should be able to inject fat-arrow function', function() {
         //   inject(($injector) => {
         //     expect($injector).toBeDefined();
@@ -296,13 +298,14 @@ describe('injector', function() {
       if (support.classes) {
         it('should be possible to instantiate ES6 classes', function() {
           providers('a', function() { return 'a-value'; });
+          // eslint-disable-next-line no-eval
           var Clazz = eval('(class { constructor(a) { this.a = a; } aVal() { return this.a; } })');
           var instance = injector.instantiate(Clazz);
           expect(instance).toEqual(new Clazz('a-value'));
           expect(instance.aVal()).toEqual('a-value');
         });
 
-        if (/chrome/.test(navigator.userAgent)) {
+        if (/chrome/.test(window.navigator.userAgent)) {
           they('should detect ES6 classes regardless of whitespace/comments ($prop)', [
             'class Test {}',
             'class Test{}',
@@ -315,6 +318,7 @@ describe('injector', function() {
             'class/* Test */{}',
             'class /* Test */ {}'
           ], function(classDefinition) {
+            // eslint-disable-next-line no-eval
             var Clazz = eval('(' + classDefinition + ')');
             var instance = injector.invoke(Clazz);
 
@@ -323,7 +327,7 @@ describe('injector', function() {
         }
 
         // Support: Chrome 50-51 only
-        // TODO (gkalpak): Remove when Chrome v52 is relased.
+        // TODO (gkalpak): Remove when Chrome v52 is released.
         // it('should be able to invoke classes', function() {
         //   class Test {
         //     constructor($injector) {
@@ -335,7 +339,6 @@ describe('injector', function() {
         //   expect(instance.$injector).toBe(injector);
         // });
       }
-      /*jshint +W061 */
     });
 
 
@@ -360,7 +363,7 @@ describe('injector', function() {
     var injector = createInjector([function($provide) {
       $provide.value('value', 'value;');
       $provide.factory('fn', valueFn('function;'));
-      $provide.provider('service', function() {
+      $provide.provider('service', function Provider() {
         this.$get = valueFn('service;');
       });
     }, function(valueProvider, fnProvider, serviceProvider) {
@@ -469,7 +472,7 @@ describe('injector', function() {
       .config(function($aProvider) {
         log += 'aConfig;';
       })
-      .provider('$a', function() {
+      .provider('$a', function Provider$a() {
         log += '$aProvider;';
         this.$get = function() {};
       });
@@ -477,7 +480,7 @@ describe('injector', function() {
       .config(function($bProvider) {
         log += 'bConfig;';
       })
-      .provider('$b', function() {
+      .provider('$b', function Provider$b() {
         log += '$bProvider;';
         this.$get = function() {};
       });
@@ -562,9 +565,9 @@ describe('injector', function() {
 
       describe('service', function() {
         it('should register a class', function() {
-          var Type = function(value) {
+          function Type(value) {
             this.value = value;
-          };
+          }
 
           var instance = createInjector([function($provide) {
             $provide.value('value', 123);
@@ -786,7 +789,7 @@ describe('injector', function() {
       it('should handle exceptions', function() {
         expect(function() {
           createInjector([function() {
-            throw 'MyError';
+            throw new Error('MyError');
           }], {});
         }).toThrowMinErr('$injector', 'modulerr', /Failed to instantiate module .+ due to:\n.*MyError/);
       });
@@ -848,7 +851,7 @@ describe('injector', function() {
 
   describe('retrieval', function() {
     var instance = {name:'angular'};
-    var Instance = function() { this.name = 'angular'; };
+    function Instance() { this.name = 'angular'; }
 
     function createInjectorWithValue(instanceName, instance) {
       return createInjector([['$provide', function(provide) {
@@ -1142,12 +1145,11 @@ describe('strict-di injector', function() {
 
   it('should always use provider as `this` when invoking a factory', function() {
     var called = false;
+
     function factoryFn() {
       called = true;
-      // jshint -W040
       expect(typeof this.$get).toBe('function');
       return this;
-      // jshint +W040
     }
     module(function($provide) {
       $provide.factory('$test', factoryFn);
diff --git a/test/e2e/fixtures/.eslintrc.json b/test/e2e/fixtures/.eslintrc.json
new file mode 100644
index 000000000000..0dedeeca3a83
--- /dev/null
+++ b/test/e2e/fixtures/.eslintrc.json
@@ -0,0 +1,9 @@
+{
+  "root": true,
+  "extends": "../../../.eslintrc-browser.json",
+
+  "globals": {
+    "jQuery": false,
+    "$": false
+  }
+}
diff --git a/test/e2e/fixtures/.jshintrc b/test/e2e/fixtures/.jshintrc
deleted file mode 100644
index f3f63911e866..000000000000
--- a/test/e2e/fixtures/.jshintrc
+++ /dev/null
@@ -1,8 +0,0 @@
-{
-  "browser": true,
-  "globals": {
-    "angular": false,
-    "jQuery": false,
-    "$": false
-  }
-}
diff --git a/test/e2e/fixtures/anchor-scroll-y-offset/script.js b/test/e2e/fixtures/anchor-scroll-y-offset/script.js
index 260b6dc76cba..182633c7e68e 100644
--- a/test/e2e/fixtures/anchor-scroll-y-offset/script.js
+++ b/test/e2e/fixtures/anchor-scroll-y-offset/script.js
@@ -1,3 +1,5 @@
+'use strict';
+
 angular.
   module('test', []).
   controller('TestController', function($anchorScroll, $location, $scope) {
diff --git a/test/e2e/fixtures/anchor-scroll/script.js b/test/e2e/fixtures/anchor-scroll/script.js
index a83c034e9b0f..fb790ba2d4f3 100644
--- a/test/e2e/fixtures/anchor-scroll/script.js
+++ b/test/e2e/fixtures/anchor-scroll/script.js
@@ -1,3 +1,5 @@
+'use strict';
+
 angular.
   module('test', []).
   controller('TestController', function($anchorScroll, $location, $scope) {
diff --git a/test/e2e/fixtures/angular-already-loaded/script.js b/test/e2e/fixtures/angular-already-loaded/script.js
index f731efe3e2c9..d82793dcfc91 100644
--- a/test/e2e/fixtures/angular-already-loaded/script.js
+++ b/test/e2e/fixtures/angular-already-loaded/script.js
@@ -1,3 +1,5 @@
+'use strict';
+
 angular.
   module('test', []).
   controller('TestController', function($scope) {
diff --git a/test/e2e/fixtures/http/script.js b/test/e2e/fixtures/http/script.js
index ebd69e2d1558..745e738b7729 100644
--- a/test/e2e/fixtures/http/script.js
+++ b/test/e2e/fixtures/http/script.js
@@ -1,3 +1,5 @@
+'use strict';
+
 angular.
   module('test', []).
   config(function($httpProvider) {
@@ -5,12 +7,12 @@ angular.
       return {
         request: function(config) {
           return $q(function(resolve) {
-            setTimeout(resolve, 100, config);
+            window.setTimeout(resolve, 100, config);
           });
         },
         response: function(response) {
           return $q(function(resolve) {
-            setTimeout(resolve, 100, response);
+            window.setTimeout(resolve, 100, response);
           });
         }
       };
diff --git a/test/e2e/fixtures/loader/script.js b/test/e2e/fixtures/loader/script.js
index 3ea83bae30a5..051dbfb45569 100644
--- a/test/e2e/fixtures/loader/script.js
+++ b/test/e2e/fixtures/loader/script.js
@@ -1,3 +1,5 @@
+'use strict';
+
 angular.
   module('test', [
     'ngTouch',
diff --git a/test/e2e/fixtures/ng-jq-jquery/script.js b/test/e2e/fixtures/ng-jq-jquery/script.js
index 89fc6b873250..d614b2c4717c 100644
--- a/test/e2e/fixtures/ng-jq-jquery/script.js
+++ b/test/e2e/fixtures/ng-jq-jquery/script.js
@@ -1,3 +1,5 @@
+'use strict';
+
 angular.
   module('test', []).
   run(function($rootScope) {
diff --git a/test/e2e/fixtures/ng-jq/script.js b/test/e2e/fixtures/ng-jq/script.js
index 89fc6b873250..d614b2c4717c 100644
--- a/test/e2e/fixtures/ng-jq/script.js
+++ b/test/e2e/fixtures/ng-jq/script.js
@@ -1,3 +1,5 @@
+'use strict';
+
 angular.
   module('test', []).
   run(function($rootScope) {
diff --git a/test/e2e/fixtures/sample/script.js b/test/e2e/fixtures/sample/script.js
index f731efe3e2c9..d82793dcfc91 100644
--- a/test/e2e/fixtures/sample/script.js
+++ b/test/e2e/fixtures/sample/script.js
@@ -1,3 +1,5 @@
+'use strict';
+
 angular.
   module('test', []).
   controller('TestController', function($scope) {
diff --git a/test/e2e/tests/.eslintrc.json b/test/e2e/tests/.eslintrc.json
new file mode 100644
index 000000000000..a95ba011fe61
--- /dev/null
+++ b/test/e2e/tests/.eslintrc.json
@@ -0,0 +1,13 @@
+{
+  "root": true,
+  "extends": "../../../.eslintrc-node.json",
+
+  "env": {
+    "jasmine": true,
+    "protractor": true
+  },
+
+  "globals": {
+    "loadFixture": false
+  }
+}
diff --git a/test/e2e/tests/.jshintrc b/test/e2e/tests/.jshintrc
deleted file mode 100644
index 9ddc0db3923a..000000000000
--- a/test/e2e/tests/.jshintrc
+++ /dev/null
@@ -1,11 +0,0 @@
-{
-  "node": true,
-  "globals": {
-    "describe": false,
-    "ddescribe": false,
-    "xdescribe": false,
-    "it": false,
-    "xit": false,
-    "iit": false
-  }
-}
diff --git a/test/e2e/tests/anchor-scroll.spec.js b/test/e2e/tests/anchor-scroll.spec.js
index cc45b88d7607..0d8e478233ef 100644
--- a/test/e2e/tests/anchor-scroll.spec.js
+++ b/test/e2e/tests/anchor-scroll.spec.js
@@ -1,3 +1,5 @@
+'use strict';
+
 describe('$anchorScroll', function() {
   beforeEach(function() {
     jasmine.addMatchers({
@@ -138,6 +140,9 @@ describe('$anchorScroll', function() {
   });
 
   // Helpers
+  // Those are scripts executed in the browser, stop complaining about
+  // `document` not being defined.
+  /* eslint-disable no-undef */
   function _script_getTop(id) {
     var elem = document.getElementById(id);
     var rect = elem.getBoundingClientRect();
@@ -155,6 +160,7 @@ describe('$anchorScroll', function() {
            (rect.left < docElem.clientWidth) &&
            (rect.right > 0);
   }
+  /* eslint-enable */
 
   function execWithTempViewportHeight(tempHeight, fn) {
     setViewportHeight(tempHeight).then(function(oldHeight) {
diff --git a/test/e2e/tests/angular-already-loaded.spec.js b/test/e2e/tests/angular-already-loaded.spec.js
index 4b304d86cedc..9084d6ed5c7d 100644
--- a/test/e2e/tests/angular-already-loaded.spec.js
+++ b/test/e2e/tests/angular-already-loaded.spec.js
@@ -1,3 +1,5 @@
+'use strict';
+
 describe('App where angular is loaded more than once', function() {
   beforeEach(function() {
     loadFixture('angular-already-loaded');
diff --git a/test/e2e/tests/helpers/main.js b/test/e2e/tests/helpers/main.js
index 5459ffc2d836..279b806f8c8d 100644
--- a/test/e2e/tests/helpers/main.js
+++ b/test/e2e/tests/helpers/main.js
@@ -1,3 +1,5 @@
+'use strict';
+
 var helper = {
   loadFixture: function(fixture) {
     var i = 0;
diff --git a/test/e2e/tests/http.spec.js b/test/e2e/tests/http.spec.js
index fe8c7d67afd5..b5c5bfb10732 100644
--- a/test/e2e/tests/http.spec.js
+++ b/test/e2e/tests/http.spec.js
@@ -1,3 +1,5 @@
+'use strict';
+
 describe('$http', function() {
   beforeEach(function() {
     loadFixture('http');
diff --git a/test/e2e/tests/loader.spec.js b/test/e2e/tests/loader.spec.js
index f75d49b5bbf3..a4a3ab3a4516 100644
--- a/test/e2e/tests/loader.spec.js
+++ b/test/e2e/tests/loader.spec.js
@@ -1,3 +1,5 @@
+'use strict';
+
 describe('angular-loader', function() {
   beforeEach(function() {
     loadFixture('loader');
diff --git a/test/e2e/tests/ng-jq.spec.js b/test/e2e/tests/ng-jq.spec.js
index 9174e17c45c6..09a5d0b8af0f 100644
--- a/test/e2e/tests/ng-jq.spec.js
+++ b/test/e2e/tests/ng-jq.spec.js
@@ -1,3 +1,5 @@
+'use strict';
+
 describe('Customizing the jqLite / jQuery version', function() {
   it('should be able to force jqLite', function() {
     loadFixture('ng-jq');
diff --git a/test/e2e/tests/sample.spec.js b/test/e2e/tests/sample.spec.js
index e46a936d28b7..fa283fa33a6b 100644
--- a/test/e2e/tests/sample.spec.js
+++ b/test/e2e/tests/sample.spec.js
@@ -1,3 +1,5 @@
+'use strict';
+
 // Sample E2E test:
 describe('Sample', function() {
   beforeEach(function() {
diff --git a/test/e2e/tools/.eslintrc.json b/test/e2e/tools/.eslintrc.json
new file mode 100644
index 000000000000..b124e3b4846c
--- /dev/null
+++ b/test/e2e/tools/.eslintrc.json
@@ -0,0 +1,4 @@
+{
+  "root": true,
+  "extends": "../../../.eslintrc-node.json"
+}
diff --git a/test/e2e/tools/.jshintrc b/test/e2e/tools/.jshintrc
deleted file mode 100644
index c1f2978bcf78..000000000000
--- a/test/e2e/tools/.jshintrc
+++ /dev/null
@@ -1,3 +0,0 @@
-{
-  "node": true
-}
diff --git a/test/e2e/tools/util.js b/test/e2e/tools/util.js
index 0a615a7d7f84..62930fbff52f 100644
--- a/test/e2e/tools/util.js
+++ b/test/e2e/tools/util.js
@@ -2,7 +2,6 @@
 
 var fs = require('fs');
 var path = require('path');
-var url = require('url');
 
 var root = path.resolve(__dirname, '..');
 var tests = path.resolve(root, 'fixtures');
diff --git a/test/helpers/privateMocks.js b/test/helpers/privateMocks.js
index 706ab7bab538..1a1580b2c118 100644
--- a/test/helpers/privateMocks.js
+++ b/test/helpers/privateMocks.js
@@ -13,7 +13,6 @@ function baseThey(msg, vals, spec, itFn) {
   angular.forEach(vals, function(val, key) {
     var m = msg.split('$prop').join(angular.toJson(valsIsArray ? val : key));
     itFn(m, function() {
-      /* jshint -W040 : ignore possible strict violation due to use of this */
       spec.call(this, val);
     });
   });
@@ -32,16 +31,13 @@ function xthey(msg, vals, spec) {
 }
 
 function browserSupportsCssAnimations() {
-  var nav = window.navigator.appVersion;
-  if (nav.indexOf('MSIE') >= 0) {
-    var version = parseInt(navigator.appVersion.match(/MSIE ([\d.]+)/)[1]);
-    return version >= 10; //only IE10+ support keyframes / transitions
-  }
-  return true;
+  // Support: IE < 10
+  // Only IE10+ support keyframes / transitions
+  return !(window.document.documentMode < 10);
 }
 
 function createMockStyleSheet(doc, prefix) {
-  doc = doc ? doc[0] : document;
+  doc = doc ? doc[0] : window.document;
 
   var node = doc.createElement('style');
   var head = doc.getElementsByTagName('head')[0];
@@ -53,12 +49,10 @@ function createMockStyleSheet(doc, prefix) {
     addRule: function(selector, styles) {
       try {
         ss.insertRule(selector + '{ ' + styles + '}', 0);
-      }
-      catch (e) {
+      } catch (e) {
         try {
           ss.addRule(selector, styles);
-        }
-        catch (e2) {}
+        } catch (e2) { /* empty */ }
       }
     },
 
diff --git a/test/helpers/testabilityPatch.js b/test/helpers/testabilityPatch.js
index c432f8ee0920..669c304d861c 100644
--- a/test/helpers/testabilityPatch.js
+++ b/test/helpers/testabilityPatch.js
@@ -13,14 +13,13 @@ var support = {};
 
 for (var prop in supportTests) {
   if (supportTests.hasOwnProperty(prop)) {
-    /*jshint -W061 */
     try {
+      // eslint-disable-next-line no-eval
       eval(supportTests[prop]);
       support[prop] = true;
     } catch (e) {
       support[prop] = false;
     }
-    /*jshint +W061 */
   }
 }
 
@@ -49,7 +48,7 @@ beforeEach(function() {
     jqCache = jqLite.cache = {};
   }
 
-  angular.element(document.body).empty().removeData();
+  angular.element(window.document.body).empty().removeData();
 });
 
 afterEach(function() {
@@ -57,15 +56,15 @@ afterEach(function() {
 
   // both of these nodes are persisted across tests
   // and therefore the hashCode may be cached
-  var node = document.querySelector('html');
+  var node = window.document.querySelector('html');
   if (node) {
     node.$$hashKey = null;
   }
-  var bod = document.body;
+  var bod = window.document.body;
   if (bod) {
     bod.$$hashKey = null;
   }
-  document.$$hashKey = null;
+  window.document.$$hashKey = null;
 
   if (this.$injector) {
     var $rootScope = this.$injector.get('$rootScope');
@@ -76,7 +75,9 @@ afterEach(function() {
     dealoc($rootElement);
 
     // check $log mock
-    $log.assertEmpty && $log.assertEmpty();
+    if ($log.assertEmpty) {
+      $log.assertEmpty();
+    }
   }
 
   if (!window.jQuery) {
@@ -123,7 +124,7 @@ function dealoc(obj) {
       // jQuery 2.x doesn't expose the cache storage.
       for (var key in jqCache) {
         var value = jqCache[key];
-        if (value.data && value.data.$scope == obj) {
+        if (value.data && value.data.$scope === obj) {
           delete jqCache[key];
         }
       }
@@ -158,12 +159,12 @@ function sortedHtml(element, showNgClass) {
   var html = "";
   forEach(jqLite(element), function toString(node) {
 
-    if (node.nodeName == "#text") {
+    if (node.nodeName === "#text") {
       html += node.nodeValue.
         replace(/&(\w+[&;\W])?/g, function(match, entity) {return entity ? match : '&amp;';}).
         replace(/</g, '&lt;').
         replace(/>/g, '&gt;');
-    } else if (node.nodeName == "#comment") {
+    } else if (node.nodeName === "#comment") {
       html += '<!--' + node.nodeValue + '-->';
     } else {
       html += '<' + (node.nodeName || '?NOT_A_NODE?').toLowerCase();
@@ -178,37 +179,37 @@ function sortedHtml(element, showNgClass) {
         attrs.push(' class="' + className + '"');
       }
       for (var i = 0; i < attributes.length; i++) {
-        if (i > 0 && attributes[i] == attributes[i - 1]) {
-          continue; //IE9 creates dupes. Ignore them!
+        if (i > 0 && attributes[i] === attributes[i - 1]) {
+          continue; // IE9 creates dupes. Ignore them!
         }
 
         var attr = attributes[i];
-        if (attr.name.match(/^ng[\:\-]/) ||
+        if (attr.name.match(/^ng[:\-]/) ||
             (attr.value || attr.value === '') &&
-            attr.value != 'null' &&
-            attr.value != 'auto' &&
-            attr.value != 'false' &&
-            attr.value != 'inherit' &&
-            (attr.value != '0' || attr.name == 'value') &&
-            attr.name != 'loop' &&
-            attr.name != 'complete' &&
-            attr.name != 'maxLength' &&
-            attr.name != 'size' &&
-            attr.name != 'class' &&
-            attr.name != 'start' &&
-            attr.name != 'tabIndex' &&
-            attr.name != 'style' &&
-            attr.name.substr(0, 6) != 'jQuery') {
+            attr.value !== 'null' &&
+            attr.value !== 'auto' &&
+            attr.value !== 'false' &&
+            attr.value !== 'inherit' &&
+            (attr.value !== '0' || attr.name === 'value') &&
+            attr.name !== 'loop' &&
+            attr.name !== 'complete' &&
+            attr.name !== 'maxLength' &&
+            attr.name !== 'size' &&
+            attr.name !== 'class' &&
+            attr.name !== 'start' &&
+            attr.name !== 'tabIndex' &&
+            attr.name !== 'style' &&
+            attr.name.substr(0, 6) !== 'jQuery') {
           // in IE we need to check for all of these.
           if (/ng\d+/.exec(attr.name) ||
-              attr.name == 'getElementById' ||
+              attr.name === 'getElementById' ||
               // IE7 has `selected` in attributes
-              attr.name == 'selected' ||
+              attr.name === 'selected' ||
               // IE7 adds `value` attribute to all LI tags
-              (node.nodeName == 'LI' && attr.name == 'value') ||
+              (node.nodeName === 'LI' && attr.name === 'value') ||
               // IE8 adds bogus rowspan=1 and colspan=1 to TD elements
-              (node.nodeName == 'TD' && attr.name == 'rowSpan' && attr.value == '1') ||
-              (node.nodeName == 'TD' && attr.name == 'colSpan' && attr.value == '1')) {
+              (node.nodeName === 'TD' && attr.name === 'rowSpan' && attr.value === '1') ||
+              (node.nodeName === 'TD' && attr.name === 'colSpan' && attr.value === '1')) {
             continue;
           }
 
@@ -229,9 +230,9 @@ function sortedHtml(element, showNgClass) {
         }
         for (var css in node.style) {
           var value = node.style[css];
-          if (isString(value) && isString(css) && css != 'cssText' && value && (1 * css != css)) {
+          if (isString(value) && isString(css) && css !== 'cssText' && value && isNaN(Number(css))) {
             var text = lowercase(css + ': ' + value);
-            if (value != 'false' && style.indexOf(text) == -1) {
+            if (value !== 'false' && style.indexOf(text) === -1) {
               style.push(text);
             }
           }
@@ -278,7 +279,7 @@ function childrenTagsOf(element) {
  */
 function isCssVisible(node) {
   var display = node.css('display');
-  return !node.hasClass('ng-hide') && display != 'none';
+  return !node.hasClass('ng-hide') && display !== 'none';
 }
 
 function assertHidden(node) {
diff --git a/test/jqLiteSpec.js b/test/jqLiteSpec.js
index e0502073d96d..48835bb000c9 100644
--- a/test/jqLiteSpec.js
+++ b/test/jqLiteSpec.js
@@ -1,7 +1,7 @@
 'use strict';
 
 describe('jqLite', function() {
-  var scope, a, b, c;
+  var scope, a, b, c, document;
 
 
   beforeEach(module(provideLog));
@@ -14,6 +14,7 @@ describe('jqLite', function() {
 
 
   beforeEach(inject(function($rootScope) {
+    document = window.document;
     scope = $rootScope;
     jasmine.addMatchers({
       toJqEqual: function() {
@@ -22,7 +23,7 @@ describe('jqLite', function() {
             var msg = "Unequal length";
             var message = function() {return msg;};
 
-            var value = _actual_ && expected && _actual_.length == expected.length;
+            var value = _actual_ && expected && _actual_.length === expected.length;
             for (var i = 0; value && i < expected.length; i++) {
               var actual = jqLite(_actual_[i])[0];
               var expect = jqLite(expected[i])[0];
@@ -463,7 +464,7 @@ describe('jqLite', function() {
     it('should emit $destroy event if element removed via remove()', function() {
       var log = '';
       var element = jqLite(a);
-      element.on('$destroy', function() {log+= 'destroy;';});
+      element.on('$destroy', function() {log += 'destroy;';});
       element.remove();
       expect(log).toEqual('destroy;');
     });
@@ -984,7 +985,7 @@ describe('jqLite', function() {
       expect(element[0].innerHTML).toEqual('ab');
       expect(element[1].innerHTML).toEqual('c');
       expect(element.text()).toEqual('abc');
-      expect(element.text('xyz') == element).toBeTruthy();
+      expect(element.text('xyz') === element).toBeTruthy();
       expect(element.text()).toEqual('xyzxyz');
     });
 
@@ -1051,7 +1052,7 @@ describe('jqLite', function() {
       expect(element.length).toEqual(1);
       expect(element[0].innerHTML).toEqual('abc');
       expect(element.html()).toEqual('abc');
-      expect(element.html('xyz') == element).toBeTruthy();
+      expect(element.html('xyz') === element).toBeTruthy();
       expect(element.html()).toEqual('xyz');
     });
   });
@@ -1061,7 +1062,7 @@ describe('jqLite', function() {
     it('should write a value', function() {
       var element = jqLite('<div>abc</div>');
       expect(element.length).toEqual(1);
-      expect(element.empty() == element).toBeTruthy();
+      expect(element.empty() === element).toBeTruthy();
       expect(element.html()).toEqual('');
     });
   });
@@ -1815,7 +1816,7 @@ describe('jqLite', function() {
       iframe_.onload = iframe_.onreadystatechange = function() {
         if (iframe_.contentDocument) test();
       };
-      /* jshint scripturl:true */
+      // eslint-disable-next-line no-script-url
       iframe_.src = 'javascript:false';
       jqLite(document).find('body').append(iframe);
 
diff --git a/test/loaderSpec.js b/test/loaderSpec.js
index 87b1f333c262..26d676452b26 100644
--- a/test/loaderSpec.js
+++ b/test/loaderSpec.js
@@ -111,15 +111,20 @@ describe('module loader', function() {
     var log = '';
 
     angular.module('theModule', []).
-      factory('theProvider', function() { return {
-        api: 'firstProvider'
-      }; }).
+      factory('theProvider', function() {
+        return {
+          api: 'firstProvider'
+        };
+      }).
       decorator('theProvider', function($delegate) {
         $delegate.api = $delegate.api + '-decorator';
-        return $delegate; }).
-      factory('theProvider', function() { return {
-        api: 'secondProvider'
-      }; }).
+        return $delegate;
+      }).
+      factory('theProvider', function() {
+        return {
+          api: 'secondProvider'
+        };
+      }).
       run(function(theProvider) {
         log = theProvider.api;
       });
diff --git a/test/ng/anchorScrollSpec.js b/test/ng/anchorScrollSpec.js
index 1a5832c93fd7..8f7e4a2c8829 100644
--- a/test/ng/anchorScrollSpec.js
+++ b/test/ng/anchorScrollSpec.js
@@ -12,9 +12,9 @@ describe('$anchorScroll', function() {
         var mockedWin = {
           scrollTo: jasmine.createSpy('$window.scrollTo'),
           scrollBy: jasmine.createSpy('$window.scrollBy'),
-          document: document,
+          document: window.document,
           getComputedStyle: function(elem) {
-            return getComputedStyle(elem);
+            return window.getComputedStyle(elem);
           }
         };
 
@@ -184,7 +184,7 @@ describe('$anchorScroll', function() {
         expectScrollingTo('id=abc')));
 
 
-      it('should scroll to top if hash == "top" and no matching element', inject(
+      it('should scroll to top if hash === "top" and no matching element', inject(
         changeHashAndScroll('top'),
         expectScrollingToTop));
 
@@ -251,7 +251,7 @@ describe('$anchorScroll', function() {
         expectScrollingTo('id=abc')));
 
 
-      it('should scroll to top if hash == "top" and no matching element', inject(
+      it('should scroll to top if hash === "top" and no matching element', inject(
         callAnchorScroll('top'),
         expectScrollingToTop));
 
diff --git a/test/ng/animateRunnerSpec.js b/test/ng/animateRunnerSpec.js
index 0d25e92752b8..94f8b79fd1df 100644
--- a/test/ng/animateRunnerSpec.js
+++ b/test/ng/animateRunnerSpec.js
@@ -1,7 +1,5 @@
 'use strict';
 
-/* jshint newcap: false */
-
 describe('$$animateAsyncRun', function() {
   it('should fire the callback only when one or more RAFs have passed',
     inject(function($$animateAsyncRun, $$rAF) {
@@ -104,7 +102,7 @@ describe("$$AnimateRunner", function() {
 
       runner1[method]();
 
-      var expectedStatus = method === 'end' ? true : false;
+      var expectedStatus = method === 'end';
       expect(status1).toBe(expectedStatus);
       expect(status2).toBe(expectedStatus);
       expect(signature).toBe('21');
@@ -244,7 +242,7 @@ describe("$$AnimateRunner", function() {
         var runner2 = new $$AnimateRunner();
         var runner3 = new $$AnimateRunner();
 
-        var expectedStatus = method === 'end' ? true : false;
+        var expectedStatus = method === 'end';
 
         var status;
         $$AnimateRunner.all([runner1, runner2, runner3], function(response) {
diff --git a/test/ng/browserSpecs.js b/test/ng/browserSpecs.js
index 9140bcb71e03..2777d616763a 100755
--- a/test/ng/browserSpecs.js
+++ b/test/ng/browserSpecs.js
@@ -126,10 +126,10 @@ function MockDocument() {
   this.basePath = '/';
 
   this.find = function(name) {
-    if (name == 'base') {
+    if (name === 'base') {
       return {
         attr: function(name) {
-          if (name == 'href') {
+          if (name === 'href') {
             return self.basePath;
           } else {
             throw new Error(name);
@@ -755,7 +755,7 @@ describe('browser', function() {
     var jqDocHead;
 
     beforeEach(function() {
-      jqDocHead = jqLite(document).find('head');
+      jqDocHead = jqLite(window.document).find('head');
     });
 
     it('should return value from <base href>', function() {
diff --git a/test/ng/compileSpec.js b/test/ng/compileSpec.js
index 6acc2ec6f7a6..bfed32aed046 100755
--- a/test/ng/compileSpec.js
+++ b/test/ng/compileSpec.js
@@ -1,6 +1,10 @@
 'use strict';
 
+/* eslint-disable no-script-url */
+
 describe('$compile', function() {
+  var document = window.document;
+
   function isUnknownElement(el) {
     return !!el.toString().match(/Unknown/);
   }
@@ -522,10 +526,8 @@ describe('$compile', function() {
 
       try {
         element[0].childNodes[1] = {nodeType: 3, nodeName: 'OBJECT', textContent: 'fake node'};
-      } catch (e) {
-      } finally {
-        if (!element[0].childNodes[1]) return; //browser doesn't support this kind of mocking
-      }
+      } catch (e) { /* empty */ }
+      if (!element[0].childNodes[1]) return; // browser doesn't support this kind of mocking
 
       expect(element[0].childNodes[1].textContent).toBe('fake node');
 
@@ -662,7 +664,7 @@ describe('$compile', function() {
               if (value.substring(0,2) !== 'ng') {
                 value = value.replace('=""', '');
                 var match = value.match(/=(.*)/);
-                if (match && match[1].charAt(0) != '"') {
+                if (match && match[1].charAt(0) !== '"') {
                   value = value.replace(/=(.*)/, '="$1"');
                 }
                 list.push(value);
@@ -3663,7 +3665,6 @@ describe('$compile', function() {
       it('should call `$onInit`, if provided, after all the controllers on the element have been initialized', function() {
 
         function check() {
-          /*jshint validthis:true */
           expect(this.element.controller('d1').id).toEqual(1);
           expect(this.element.controller('d2').id).toEqual(2);
         }
@@ -5542,9 +5543,9 @@ describe('$compile', function() {
 
 
     it('should eventually expose isolate scope variables on ES6 class controller with controllerAs when bindToController is true', function() {
-      if (!/chrome/i.test(navigator.userAgent)) return;
-      /*jshint -W061 */
+      if (!/chrome/i.test(window.navigator.userAgent)) return;
       var controllerCalled = false;
+      // eslint-disable-next-line no-eval
       var Controller = eval(
         "class Foo {\n" +
         "  constructor($scope) {}\n" +
@@ -5592,7 +5593,6 @@ describe('$compile', function() {
         expect(Controller.prototype.$onInit).toHaveBeenCalled();
         expect(controllerCalled).toBe(true);
       });
-      /*jshint +W061 */
     });
 
 
@@ -6396,7 +6396,8 @@ describe('$compile', function() {
           return {
             controller: function($scope) {
               this.foo = 'baz'; // value should not be used.
-              return expectedController = {foo: 'bar'};
+              expectedController = {foo: 'bar'};
+              return expectedController;
             },
             link: function(scope, element, attrs, controller) {
               expect(expectedController).toBeDefined();
@@ -6474,7 +6475,8 @@ describe('$compile', function() {
           transclude: true,
           controller: function($transclude) {
             this.foo = 'baz';
-            return expectedController = {transclude:$transclude, foo: 'bar'};
+            expectedController = {transclude:$transclude, foo: 'bar'};
+            return expectedController;
           },
           link: function(scope, el, attr, ctrl) {
             ctrl.transclude(cloneAttach);
@@ -6533,9 +6535,10 @@ describe('$compile', function() {
           return {
             scope: true,
             controller: function($scope) {
-              return directiveController = {
+              directiveController = {
                 foo: 'bar'
               };
+              return directiveController;
             }
           };
         });
@@ -6543,9 +6546,10 @@ describe('$compile', function() {
         directive('myOtherDirective', function(log) {
           return {
             controller: function($scope) {
-              return otherDirectiveController = {
+              otherDirectiveController = {
                 baz: 'luh'
               };
+              return otherDirectiveController;
             }
           };
         });
@@ -6903,10 +6907,12 @@ describe('$compile', function() {
         };
       }
       function ParentController() {
-        return parentController = { name: 'Parent' };
+        parentController = { name: 'Parent' };
+        return parentController;
       }
       function SiblingController() {
-        return siblingController = { name: 'Sibling' };
+        siblingController = { name: 'Sibling' };
+        return siblingController;
       }
 
       angular.module('my', [])
@@ -7632,7 +7638,7 @@ describe('$compile', function() {
               replace: true,
               scope: {},
               link: function(scope) {
-                scope.x='iso';
+                scope.x = 'iso';
               },
               template: '<ul><li>W:{{x}}-{{$parent.$id}}-{{$id}};</li><li ng-transclude></li></ul>'
             };
@@ -9444,7 +9450,7 @@ describe('$compile', function() {
           directive('inner', valueFn({
             template: '<span>FooBar</span>',
             compile: function() {
-              innerCompilationCount +=1;
+              innerCompilationCount += 1;
             }
           }));
         });
@@ -9473,7 +9479,7 @@ describe('$compile', function() {
           directive('inner', valueFn({
             template: '<span>FooBar</span>',
             compile: function() {
-              innerCompilationCount +=1;
+              innerCompilationCount += 1;
             }
           }));
         });
@@ -9502,7 +9508,7 @@ describe('$compile', function() {
           directive('inner', valueFn({
             template: '<span>FooBar</span>',
             compile: function() {
-              innerCompilationCount +=1;
+              innerCompilationCount += 1;
             }
           }));
         });
@@ -9533,7 +9539,7 @@ describe('$compile', function() {
           directive('inner', valueFn({
             template: '<span>FooBar</span>',
             compile: function() {
-              innerCompilationCount +=1;
+              innerCompilationCount += 1;
             }
           }));
         });
@@ -9564,7 +9570,7 @@ describe('$compile', function() {
           directive('inner', valueFn({
             template: '<span>FooBar</span>',
             compile: function() {
-              innerCompilationCount +=1;
+              innerCompilationCount += 1;
             }
           }));
         });
@@ -9602,7 +9608,7 @@ describe('$compile', function() {
 
           directive('inner', valueFn({
             compile: function() {
-              innerCompilationCount +=1;
+              innerCompilationCount += 1;
             }
           }));
         });
@@ -10007,7 +10013,6 @@ describe('$compile', function() {
     }));
 
     it('should not sanitize attributes other than src', inject(function($compile, $rootScope) {
-      /* jshint scripturl:true */
       element = $compile('<img title="{{testUrl}}"></img>')($rootScope);
       $rootScope.testUrl = "javascript:doEvilStuff()";
       $rootScope.$apply();
@@ -10099,7 +10104,6 @@ describe('$compile', function() {
     });
 
     it('should sanitize all uris in srcset', inject(function($rootScope, $compile) {
-      /*jshint scripturl:true*/
       element = $compile('<img srcset="{{testUrl}}"></img>')($rootScope);
       var testSet = {
         'http://example.com/image.png':'http://example.com/image.png',
@@ -10141,7 +10145,6 @@ describe('$compile', function() {
   describe('a[href] sanitization', function() {
 
     it('should not sanitize href on elements other than anchor', inject(function($compile, $rootScope) {
-      /* jshint scripturl:true */
       element = $compile('<div href="{{testUrl}}"></div>')($rootScope);
       $rootScope.testUrl = "javascript:doEvilStuff()";
       $rootScope.$apply();
@@ -10150,7 +10153,6 @@ describe('$compile', function() {
     }));
 
     it('should not sanitize attributes other than href', inject(function($compile, $rootScope) {
-      /* jshint scripturl:true */
       element = $compile('<a title="{{testUrl}}"></a>')($rootScope);
       $rootScope.testUrl = "javascript:doEvilStuff()";
       $rootScope.$apply();
@@ -10262,7 +10264,6 @@ describe('$compile', function() {
     }));
 
     it('should pass through arbitrary values on onXYZ event attributes that contain a hyphen', inject(function($compile, $rootScope) {
-      /* jshint scripturl:true */
       element = $compile('<button on-click="{{onClickJs}}"></script>')($rootScope);
       $rootScope.onClickJs = 'javascript:doSomething()';
       $rootScope.$apply();
@@ -10300,7 +10301,6 @@ describe('$compile', function() {
     }));
 
     it('should clear out JS src attributes', inject(function($compile, $rootScope, $sce) {
-      /* jshint scripturl:true */
       element = $compile('<iframe src="{{testUrl}}"></iframe>')($rootScope);
       $rootScope.testUrl = "javascript:alert(1);";
       expect(function() { $rootScope.$apply(); }).toThrowMinErr(
@@ -10310,7 +10310,6 @@ describe('$compile', function() {
     }));
 
     it('should clear out non-resource_url src attributes', inject(function($compile, $rootScope, $sce) {
-      /* jshint scripturl:true */
       element = $compile('<iframe src="{{testUrl}}"></iframe>')($rootScope);
       $rootScope.testUrl = $sce.trustAsUrl("javascript:doTrustedStuff()");
       expect($rootScope.$apply).toThrowMinErr(
@@ -10319,7 +10318,6 @@ describe('$compile', function() {
     }));
 
     it('should pass through $sce.trustAs() values in src attributes', inject(function($compile, $rootScope, $sce) {
-      /* jshint scripturl:true */
       element = $compile('<iframe src="{{testUrl}}"></iframe>')($rootScope);
       $rootScope.testUrl = $sce.trustAsResourceUrl("javascript:doTrustedStuff()");
       $rootScope.$apply();
@@ -10346,7 +10344,6 @@ describe('$compile', function() {
     }));
 
     it('should clear out JS action attribute', inject(function($compile, $rootScope, $sce) {
-      /* jshint scripturl:true */
       element = $compile('<form action="{{testUrl}}"></form>')($rootScope);
       $rootScope.testUrl = "javascript:alert(1);";
       expect(function() { $rootScope.$apply(); }).toThrowMinErr(
@@ -10356,7 +10353,6 @@ describe('$compile', function() {
     }));
 
     it('should clear out non-resource_url action attribute', inject(function($compile, $rootScope, $sce) {
-      /* jshint scripturl:true */
       element = $compile('<form action="{{testUrl}}"></form>')($rootScope);
       $rootScope.testUrl = $sce.trustAsUrl("javascript:doTrustedStuff()");
       expect($rootScope.$apply).toThrowMinErr(
@@ -10366,7 +10362,6 @@ describe('$compile', function() {
 
 
     it('should pass through $sce.trustAs() values in action attribute', inject(function($compile, $rootScope, $sce) {
-      /* jshint scripturl:true */
       element = $compile('<form action="{{testUrl}}"></form>')($rootScope);
       $rootScope.testUrl = $sce.trustAsResourceUrl("javascript:doTrustedStuff()");
       $rootScope.$apply();
@@ -10419,7 +10414,7 @@ describe('$compile', function() {
         element = $compile('<iframe srcdoc="{{html}}"></iframe>')($rootScope);
         $rootScope.html = $sce.trustAsCss('<div onclick="">hello</div>');
         expect(function() { $rootScope.$digest(); }).toThrowMinErr('$interpolate', 'interr', new RegExp(
-            /Can't interpolate: {{html}}\n/.source +
+            /Can't interpolate: \{\{html}}\n/.source +
             /[^[]*\[\$sce:unsafe\] Attempting to use an unsafe value in a safe context./.source));
       }));
 
diff --git a/test/ng/cookieReaderSpec.js b/test/ng/cookieReaderSpec.js
index 29a672953d26..3b1388c563a0 100644
--- a/test/ng/cookieReaderSpec.js
+++ b/test/ng/cookieReaderSpec.js
@@ -1,11 +1,11 @@
 'use strict';
 
 describe('$$cookieReader', function() {
-  var $$cookieReader;
+  var $$cookieReader, document;
 
   function deleteAllCookies() {
     var cookies = document.cookie.split(";");
-    var path = location.pathname;
+    var path = window.location.pathname;
 
     for (var i = 0; i < cookies.length; i++) {
       var cookie = cookies[i];
@@ -20,6 +20,7 @@ describe('$$cookieReader', function() {
   }
 
   beforeEach(function() {
+    document = window.document;
     deleteAllCookies();
     expect(document.cookie).toEqual('');
 
diff --git a/test/ng/directive/aSpec.js b/test/ng/directive/aSpec.js
index 34ff310f8979..7a7964f650c5 100644
--- a/test/ng/directive/aSpec.js
+++ b/test/ng/directive/aSpec.js
@@ -35,13 +35,13 @@ describe('a', function() {
 
 
   it('should prevent default action to be executed when href is empty', function() {
-    var orgLocation = document.location.href,
+    var orgLocation = window.document.location.href,
         preventDefaultCalled = false,
         event;
 
     element = $compile('<a href="">empty link</a>')($rootScope);
 
-    event = document.createEvent('MouseEvent');
+    event = window.document.createEvent('MouseEvent');
     event.initMouseEvent(
       'click', true, true, window, 0, 0, 0, 0, 0, false, false, false, false, 0, null);
 
@@ -55,7 +55,7 @@ describe('a', function() {
 
     expect(preventDefaultCalled).toEqual(true);
 
-    expect(document.location.href).toEqual(orgLocation);
+    expect(window.document.location.href).toEqual(orgLocation);
   });
 
 
@@ -119,7 +119,7 @@ describe('a', function() {
   if (isDefined(window.SVGElement)) {
     describe('SVGAElement', function() {
       it('should prevent default action to be executed when href is empty', function() {
-        var orgLocation = document.location.href,
+        var orgLocation = window.document.location.href,
             preventDefaultCalled = false,
             event,
             child;
@@ -127,7 +127,7 @@ describe('a', function() {
         element = $compile('<svg><a xlink:href="">empty link</a></svg>')($rootScope);
         child = element.children('a');
 
-        event = document.createEvent('MouseEvent');
+        event = window.document.createEvent('MouseEvent');
         event.initMouseEvent(
           'click', true, true, window, 0, 0, 0, 0, 0, false, false, false, false, 0, null);
 
@@ -140,7 +140,7 @@ describe('a', function() {
         child[0].dispatchEvent(event);
 
         expect(preventDefaultCalled).toEqual(true);
-        expect(document.location.href).toEqual(orgLocation);
+        expect(window.document.location.href).toEqual(orgLocation);
       });
 
 
diff --git a/test/ng/directive/booleanAttrsSpec.js b/test/ng/directive/booleanAttrsSpec.js
index bab9ab9d97ca..38a91afa7336 100644
--- a/test/ng/directive/booleanAttrsSpec.js
+++ b/test/ng/directive/booleanAttrsSpec.js
@@ -36,7 +36,7 @@ describe('boolean attr directives', function() {
     $rootScope.isChecked = false;
     $rootScope.$digest();
     expect(element.attr('checked')).toBeFalsy();
-    $rootScope.isChecked=true;
+    $rootScope.isChecked = true;
     $rootScope.$digest();
     expect(element.attr('checked')).toBeTruthy();
   }));
@@ -60,11 +60,11 @@ describe('boolean attr directives', function() {
 
   it('should bind selected', inject(function($rootScope, $compile) {
     element = $compile('<select><option value=""></option><option ng-selected="isSelected">Greetings!</option></select>')($rootScope);
-    jqLite(document.body).append(element);
-    $rootScope.isSelected=false;
+    jqLite(window.document.body).append(element);
+    $rootScope.isSelected = false;
     $rootScope.$digest();
     expect(element.children()[1].selected).toBeFalsy();
-    $rootScope.isSelected=true;
+    $rootScope.isSelected = true;
     $rootScope.$digest();
     expect(element.children()[1].selected).toBeTruthy();
   }));
@@ -72,10 +72,10 @@ describe('boolean attr directives', function() {
 
   it('should bind readonly', inject(function($rootScope, $compile) {
     element = $compile('<input type="text" ng-readonly="isReadonly" />')($rootScope);
-    $rootScope.isReadonly=false;
+    $rootScope.isReadonly = false;
     $rootScope.$digest();
     expect(element.attr('readOnly')).toBeFalsy();
-    $rootScope.isReadonly=true;
+    $rootScope.isReadonly = true;
     $rootScope.$digest();
     expect(element.attr('readOnly')).toBeTruthy();
   }));
@@ -83,10 +83,10 @@ describe('boolean attr directives', function() {
 
   it('should bind open', inject(function($rootScope, $compile) {
     element = $compile('<details ng-open="isOpen"></details>')($rootScope);
-    $rootScope.isOpen=false;
+    $rootScope.isOpen = false;
     $rootScope.$digest();
     expect(element.attr('open')).toBeFalsy();
-    $rootScope.isOpen=true;
+    $rootScope.isOpen = true;
     $rootScope.$digest();
     expect(element.attr('open')).toBeTruthy();
   }));
@@ -95,10 +95,10 @@ describe('boolean attr directives', function() {
   describe('multiple', function() {
     it('should NOT bind to multiple via ngMultiple', inject(function($rootScope, $compile) {
       element = $compile('<select ng-multiple="isMultiple"></select>')($rootScope);
-      $rootScope.isMultiple=false;
+      $rootScope.isMultiple = false;
       $rootScope.$digest();
       expect(element.attr('multiple')).toBeFalsy();
-      $rootScope.isMultiple='multiple';
+      $rootScope.isMultiple = 'multiple';
       $rootScope.$digest();
       expect(element.attr('multiple')).toBeFalsy(); // ignore
     }));
diff --git a/test/ng/directive/formSpec.js b/test/ng/directive/formSpec.js
index eecce5a5e41a..7f9e30b56efc 100644
--- a/test/ng/directive/formSpec.js
+++ b/test/ng/directive/formSpec.js
@@ -402,7 +402,7 @@ describe('form', function() {
       browserTrigger(doc.find('input'));
 
       // let the browser process all events (and potentially reload the page)
-      setTimeout(function() { nextTurn = true;});
+      window.setTimeout(function() { nextTurn = true;});
       job.waitsFor(function() { return nextTurn; })
       .runs(function() {
         expect(reloadPrevented).toBe(true);
@@ -453,7 +453,7 @@ describe('form', function() {
         browserTrigger(doc.find('button'), 'click');
 
         // let the browser process all events (and potentially reload the page)
-        setTimeout(function() { nextTurn = true;}, 100);
+        window.setTimeout(function() { nextTurn = true;}, 100);
 
         var job = createAsync(done);
         job.waitsFor(function() { return nextTurn; })
@@ -1092,7 +1092,7 @@ describe('form', function() {
           '<div ng-form name="nested{{idB}}"' +
           '</div>' +
         '</div>' +
-      '</form'
+      '</form>'
     )(scope);
 
     scope.$digest();
diff --git a/test/ng/directive/inputSpec.js b/test/ng/directive/inputSpec.js
index 23df77d88b6b..7b177f33740d 100644
--- a/test/ng/directive/inputSpec.js
+++ b/test/ng/directive/inputSpec.js
@@ -38,7 +38,7 @@ describe('input', function() {
             };
 
             return {
-              pass: !actualValue || actualValue == 'false',
+              pass: !actualValue || actualValue === 'false',
               message: message
             };
           }
@@ -145,22 +145,30 @@ describe('input', function() {
 
     it('should not dirty the model on an input event in response to a placeholder change', function() {
       var inputElm = helper.compileInput('<input type="text" placeholder="Test" attr-capture ng-model="unsetValue" name="name" />');
-      msie && browserTrigger(inputElm, 'input');
+      if (msie) {
+        browserTrigger(inputElm, 'input');
+      }
       expect(inputElm.attr('placeholder')).toBe('Test');
       expect(inputElm).toBePristine();
 
       helper.attrs.$set('placeholder', '');
-      msie && browserTrigger(inputElm, 'input');
+      if (msie) {
+        browserTrigger(inputElm, 'input');
+      }
       expect(inputElm.attr('placeholder')).toBe('');
       expect(inputElm).toBePristine();
 
       helper.attrs.$set('placeholder', 'Test Again');
-      msie && browserTrigger(inputElm, 'input');
+      if (msie) {
+        browserTrigger(inputElm, 'input');
+      }
       expect(inputElm.attr('placeholder')).toBe('Test Again');
       expect(inputElm).toBePristine();
 
       helper.attrs.$set('placeholder', undefined);
-      msie && browserTrigger(inputElm, 'input');
+      if (msie) {
+        browserTrigger(inputElm, 'input');
+      }
       expect(inputElm.attr('placeholder')).toBeUndefined();
       expect(inputElm).toBePristine();
 
@@ -171,17 +179,23 @@ describe('input', function() {
 
     it('should not dirty the model on an input event in response to a interpolated placeholder change', function() {
       var inputElm = helper.compileInput('<input type="text" placeholder="{{ph}}" ng-model="unsetValue" name="name" />');
-      msie && browserTrigger(inputElm, 'input');
+      if (msie) {
+        browserTrigger(inputElm, 'input');
+      }
       expect(inputElm).toBePristine();
 
       $rootScope.ph = 1;
       $rootScope.$digest();
-      msie && browserTrigger(inputElm, 'input');
+      if (msie) {
+        browserTrigger(inputElm, 'input');
+      }
       expect(inputElm).toBePristine();
 
       $rootScope.ph = "";
       $rootScope.$digest();
-      msie && browserTrigger(inputElm, 'input');
+      if (msie) {
+        browserTrigger(inputElm, 'input');
+      }
       expect(inputElm).toBePristine();
 
       helper.changeInputValueTo('foo');
@@ -196,7 +210,9 @@ describe('input', function() {
 
       browserTrigger(inputElm, 'focusin');
       browserTrigger(inputElm, 'focus');
-      msie && browserTrigger(inputElm, 'input');
+      if (msie) {
+        browserTrigger(inputElm, 'input');
+      }
       expect(inputElm.attr('placeholder')).toBe('Test');
       expect(inputElm).toBePristine();
 
@@ -215,12 +231,16 @@ describe('input', function() {
 
       $rootScope.ph = 1;
       $rootScope.$digest();
-      msie && browserTrigger(inputElm, 'input');
+      if (msie) {
+        browserTrigger(inputElm, 'input');
+      }
       expect(inputElm).toBePristine();
 
       $rootScope.ph = "";
       $rootScope.$digest();
-      msie && browserTrigger(inputElm, 'input');
+      if (msie) {
+        browserTrigger(inputElm, 'input');
+      }
       expect(inputElm).toBePristine();
 
       helper.changeInputValueTo('foo');
@@ -230,13 +250,17 @@ describe('input', function() {
 
     it('should not dirty the model on an input event in response to a focus', function() {
       var inputElm = helper.compileInput('<input type="text" placeholder="Test" ng-model="unsetValue" name="name" />');
-      msie && browserTrigger(inputElm, 'input');
+      if (msie) {
+        browserTrigger(inputElm, 'input');
+      }
       expect(inputElm.attr('placeholder')).toBe('Test');
       expect(inputElm).toBePristine();
 
       browserTrigger(inputElm, 'focusin');
       browserTrigger(inputElm, 'focus');
-      msie && browserTrigger(inputElm, 'input');
+      if (msie) {
+        browserTrigger(inputElm, 'input');
+      }
       expect(inputElm.attr('placeholder')).toBe('Test');
       expect(inputElm).toBePristine();
 
@@ -247,17 +271,23 @@ describe('input', function() {
 
     it('should not dirty the model on an input event in response to a blur', function() {
       var inputElm = helper.compileInput('<input type="text" placeholder="Test" ng-model="unsetValue" name="name" />');
-      msie && browserTrigger(inputElm, 'input');
+      if (msie) {
+        browserTrigger(inputElm, 'input');
+      }
       expect(inputElm.attr('placeholder')).toBe('Test');
       expect(inputElm).toBePristine();
 
       browserTrigger(inputElm, 'focusin');
       browserTrigger(inputElm, 'focus');
-      msie && browserTrigger(inputElm, 'input');
+      if (msie) {
+        browserTrigger(inputElm, 'input');
+      }
       expect(inputElm).toBePristine();
 
       browserTrigger(inputElm, 'focusout');
-      msie && browserTrigger(inputElm, 'input');
+      if (msie) {
+        browserTrigger(inputElm, 'input');
+      }
       browserTrigger(inputElm, 'blur');
       expect(inputElm).toBePristine();
 
@@ -3324,13 +3354,13 @@ describe('input', function() {
         /* domain length, label and total */
         expect(EMAIL_REGEXP.test('a@xxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxx')).toBe(true);
         expect(EMAIL_REGEXP.test('a@xxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxx')).toBe(false);
-        /* jshint maxlen:320 */
+        /* eslint-disable max-len */
         expect(EMAIL_REGEXP.test('a@xxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxx.xxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxx.xxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxx.xxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxx')).toBe(true);
         expect(EMAIL_REGEXP.test('a@xxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxx.xxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxx.xxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxx.xxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxx.x')).toBe(true);
         expect(EMAIL_REGEXP.test('a@xxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxx.xxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxx.xxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxx.xxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxx.xx')).toBe(false);
         expect(EMAIL_REGEXP.test('aaaaaaaaaaaaaaaaaaaaaaaaaaaaaaaaaaaaaaaaaaaaaaaaaaaaaaaaaaaaaaaa@xxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxx.xxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxx.xxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxx.xx')).toBe(true);
         expect(EMAIL_REGEXP.test('aaaaaaaaaaaaaaaaaaaaaaaaaaaaaaaaaaaaaaaaaaaaaaaaaaaaaaaaaaaaaaaa@xxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxx.xxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxx.xxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxx.xxx')).toBe(false);
-        /* jshint maxlen:200 */
+        /* eslint-enable */
         /* local-part valid characters and dot-atom syntax */
         expect(EMAIL_REGEXP.test("'@x")).toBe(true);
         expect(EMAIL_REGEXP.test('-!#$%&*+/0123456789=?ABCDEFGHIJKLMNOPQRSTUVWXYZ@x')).toBe(true);
diff --git a/test/ng/directive/ngClassSpec.js b/test/ng/directive/ngClassSpec.js
index 1d7cd1b56f16..f592a39bd313 100644
--- a/test/ng/directive/ngClassSpec.js
+++ b/test/ng/directive/ngClassSpec.js
@@ -34,7 +34,6 @@ describe('ngClass', function() {
 
 
   it('should add new and remove old classes with same names as Object.prototype properties dynamically', inject(function($rootScope, $compile) {
-    /* jshint -W001 */
     element = $compile('<div class="existing" ng-class="dynClass"></div>')($rootScope);
     $rootScope.dynClass = { watch: true, hasOwnProperty: true, isPrototypeOf: true };
     $rootScope.$digest();
@@ -438,7 +437,7 @@ describe('ngClass animations', function() {
     module('ngAnimateMock');
     inject(function($compile, $rootScope, $animate, $timeout) {
       element = angular.element('<div ng-class="val"></div>');
-      var body = jqLite(document.body);
+      var body = jqLite(window.document.body);
       body.append(element);
       $compile(element)($rootScope);
 
diff --git a/test/ng/directive/ngIfSpec.js b/test/ng/directive/ngIfSpec.js
index 9ee94c95b55b..6941befa254f 100755
--- a/test/ng/directive/ngIfSpec.js
+++ b/test/ng/directive/ngIfSpec.js
@@ -250,7 +250,7 @@ describe('ngIf animations', function() {
     // we need to run animation on attached elements;
     return function(_$rootElement_) {
       $rootElement = _$rootElement_;
-      body = jqLite(document.body);
+      body = jqLite(window.document.body);
       body.append($rootElement);
     };
   }));
diff --git a/test/ng/directive/ngIncludeSpec.js b/test/ng/directive/ngIncludeSpec.js
index 2f05e971cc47..5cd272c63bd7 100644
--- a/test/ng/directive/ngIncludeSpec.js
+++ b/test/ng/directive/ngIncludeSpec.js
@@ -40,7 +40,7 @@ describe('ngInclude', function() {
   it('should include an external file', inject(putIntoCache('myUrl', '{{name}}'),
       function($rootScope, $compile) {
     element = jqLite('<div><ng:include src="url"></ng:include></div>');
-    var body = jqLite(document.body);
+    var body = jqLite(window.document.body);
     body.append(element);
     element = $compile(element)($rootScope);
     $rootScope.name = 'misko';
@@ -54,41 +54,41 @@ describe('ngInclude', function() {
   it('should support ng-include="src" syntax', inject(putIntoCache('myUrl', '{{name}}'),
       function($rootScope, $compile) {
     element = jqLite('<div><div ng-include="url"></div></div>');
-    jqLite(document.body).append(element);
+    jqLite(window.document.body).append(element);
     element = $compile(element)($rootScope);
     $rootScope.name = 'Alibaba';
     $rootScope.url = 'myUrl';
     $rootScope.$digest();
     expect(element.text()).toEqual('Alibaba');
-    jqLite(document.body).empty();
+    jqLite(window.document.body).empty();
   }));
 
 
   it('should NOT use untrusted URL expressions ', inject(putIntoCache('myUrl', '{{name}} text'),
       function($rootScope, $compile, $sce) {
     element = jqLite('<ng:include src="url"></ng:include>');
-    jqLite(document.body).append(element);
+    jqLite(window.document.body).append(element);
     element = $compile(element)($rootScope);
     $rootScope.name = 'chirayu';
     $rootScope.url = 'http://example.com/myUrl';
     expect(function() { $rootScope.$digest(); }).toThrowMinErr(
         '$sce', 'insecurl',
-        /Blocked loading resource from url not allowed by \$sceDelegate policy.  URL: http:\/\/example.com\/myUrl.*/);
-    jqLite(document.body).empty();
+        /Blocked loading resource from url not allowed by \$sceDelegate policy. {2}URL: http:\/\/example.com\/myUrl.*/);
+    jqLite(window.document.body).empty();
   }));
 
 
   it('should NOT use mistyped expressions ', inject(putIntoCache('myUrl', '{{name}} text'),
       function($rootScope, $compile, $sce) {
     element = jqLite('<ng:include src="url"></ng:include>');
-    jqLite(document.body).append(element);
+    jqLite(window.document.body).append(element);
     element = $compile(element)($rootScope);
     $rootScope.name = 'chirayu';
     $rootScope.url = $sce.trustAsUrl('http://example.com/myUrl');
     expect(function() { $rootScope.$digest(); }).toThrowMinErr(
         '$sce', 'insecurl',
-        /Blocked loading resource from url not allowed by \$sceDelegate policy.  URL: http:\/\/example.com\/myUrl.*/);
-    jqLite(document.body).empty();
+        /Blocked loading resource from url not allowed by \$sceDelegate policy. {2}URL: http:\/\/example.com\/myUrl.*/);
+    jqLite(window.document.body).empty();
   }));
 
 
@@ -345,7 +345,7 @@ describe('ngInclude', function() {
     element = $compile('<div><span ng-include="includeUrl"></span></div>')($rootScope);
 
     // the element needs to be appended for the script to run
-    element.appendTo(document.body);
+    element.appendTo(window.document.body);
     window._ngIncludeCausesScriptToRun = false;
     $httpBackend.expect('GET', 'url1').respond('<script>window._ngIncludeCausesScriptToRun = true;</script>');
     $rootScope.includeUrl = 'url1';
@@ -374,6 +374,7 @@ describe('ngInclude', function() {
       $httpBackend.flush();
       var child = element.find('rect');
       expect(child.length).toBe(2);
+      // eslint-disable-next-line no-undef
       expect(child[0] instanceof SVGRectElement).toBe(true);
     });
   });
@@ -665,7 +666,7 @@ describe('ngInclude animations', function() {
     // we need to run animation on attached elements;
     return function(_$rootElement_) {
       $rootElement = _$rootElement_;
-      body = jqLite(document.body);
+      body = jqLite(window.document.body);
       body.append($rootElement);
     };
   }));
diff --git a/test/ng/directive/ngModelSpec.js b/test/ng/directive/ngModelSpec.js
index bc06daba03f6..c2609de43722 100644
--- a/test/ng/directive/ngModelSpec.js
+++ b/test/ng/directive/ngModelSpec.js
@@ -1095,6 +1095,7 @@ describe('ngModel', function() {
 
       it('should be possible to extend Object prototype and still be able to do form validation',
         inject(function($compile, $rootScope) {
+        // eslint-disable-next-line no-extend-native
         Object.prototype.someThing = function() {};
         var element = $compile('<form name="myForm">' +
                                  '<input type="text" name="username" ng-model="username" minlength="10" required />' +
@@ -1630,7 +1631,7 @@ describe('ngModel', function() {
       expect(isFormValid).toBe(false);
       expect($rootScope.myForm.$valid).toBe(false);
 
-      $rootScope.value='value';
+      $rootScope.value = 'value';
       $rootScope.$apply();
       expect(isFormValid).toBe(true);
       expect($rootScope.myForm.$valid).toBe(true);
@@ -1647,7 +1648,7 @@ describe('ngModel', function() {
       var animations = [];
       for (var i = 0; i < queue.length; i++) {
         var animation = queue[i];
-        if (animation.element[0] == node) {
+        if (animation.element[0] === node) {
           animations.push(animation);
         }
       }
diff --git a/test/ng/directive/ngRepeatSpec.js b/test/ng/directive/ngRepeatSpec.js
index e91939ca3194..bb7ed2b950e5 100644
--- a/test/ng/directive/ngRepeatSpec.js
+++ b/test/ng/directive/ngRepeatSpec.js
@@ -36,6 +36,7 @@ describe('ngRepeat', function() {
         '<li ng-repeat="item in items">{{item.name}};</li>' +
       '</ul>')(scope);
 
+    // eslint-disable-next-line no-extend-native
     Array.prototype.extraProperty = "should be ignored";
     // INIT
     scope.items = [{name: 'misko'}, {name:'shyam'}];
@@ -101,13 +102,13 @@ describe('ngRepeat', function() {
         '<li ng-repeat="item in items">{{item.name}};</li>' +
       '</ul>')(scope);
 
-    document.body.innerHTML = "<p>" +
-                                      "<a name='x'>a</a>" +
-                                      "<a name='y'>b</a>" +
-                                      "<a name='x'>c</a>" +
-                                    "</p>";
+    window.document.body.innerHTML = "<p>" +
+                                       "<a name='x'>a</a>" +
+                                       "<a name='y'>b</a>" +
+                                       "<a name='x'>c</a>" +
+                                     "</p>";
 
-    var htmlCollection = document.getElementsByTagName('a');
+    var htmlCollection = window.document.getElementsByTagName('a');
     scope.items = htmlCollection;
     scope.$digest();
     expect(element.find('li').length).toEqual(3);
@@ -115,8 +116,8 @@ describe('ngRepeat', function() {
   });
 
   it('should iterate over an array-like class', function() {
-    /* jshint -W009 */
     function Collection() {}
+    // eslint-disable-next-line no-array-constructor
     Collection.prototype = new Array();
     Collection.prototype.length = 0;
 
@@ -275,6 +276,7 @@ describe('ngRepeat', function() {
               '<li ng-repeat="item in items track by $index">{{item}};</li>' +
           '</ul>')(scope);
 
+      // eslint-disable-next-line no-extend-native
       Array.prototype.extraProperty = "should be ignored";
       // INIT
       scope.items = [true, true, true];
@@ -432,7 +434,7 @@ describe('ngRepeat', function() {
       element = $compile(
         '<div>' +
         '  <div ng-repeat="item in items | filter:x as results">{{item}}</div>' +
-        '  <div ng-if="results.length == 0">' +
+        '  <div ng-if="results.length === 0">' +
         '    No results found...' +
         '  </div>' +
         '</div>')(scope);
@@ -1141,7 +1143,7 @@ describe('ngRepeat', function() {
       scope.$digest();
       expect($exceptionHandler.errors.shift().message).
           toMatch(
-            /^\[ngRepeat:dupes\] Duplicates in a repeater are not allowed\. Use 'track by' expression to specify unique keys\. Repeater: item in items, Duplicate key: object:3, Duplicate value: {}/);
+            /^\[ngRepeat:dupes] Duplicates in a repeater are not allowed\. Use 'track by' expression to specify unique keys\. Repeater: item in items, Duplicate key: object:3, Duplicate value: {}/);
 
       // recover
       scope.items = [a];
@@ -1162,7 +1164,7 @@ describe('ngRepeat', function() {
       scope.$digest();
       expect($exceptionHandler.errors.shift().message).
           toMatch(
-            /^\[ngRepeat:dupes\] Duplicates in a repeater are not allowed\. Use 'track by' expression to specify unique keys\. Repeater: item in items, Duplicate key: object:9, Duplicate value: {}/);
+            /^\[ngRepeat:dupes] Duplicates in a repeater are not allowed\. Use 'track by' expression to specify unique keys\. Repeater: item in items, Duplicate key: object:9, Duplicate value: {}/);
 
       // recover
       scope.items = [a];
@@ -1263,7 +1265,7 @@ describe('ngRepeat', function() {
 
 
     it('should allow mixing ngRepeat with ngIf', inject(function($compile, $rootScope) {
-      element = $compile('<div><div ng-repeat="i in [1,2,3,4]" ng-if="i % 2 == 0">{{i}};</div></div>')($rootScope);
+      element = $compile('<div><div ng-repeat="i in [1,2,3,4]" ng-if="i % 2 === 0">{{i}};</div></div>')($rootScope);
       $rootScope.$digest();
       expect(element.text()).toBe('2;4;');
     }));
@@ -1416,7 +1418,7 @@ describe('ngRepeat animations', function() {
     // we need to run animation on attached elements;
     return function(_$rootElement_) {
       $rootElement = _$rootElement_;
-      body = jqLite(document.body);
+      body = jqLite(window.document.body);
       body.append($rootElement);
     };
   }));
diff --git a/test/ng/directive/ngShowHideSpec.js b/test/ng/directive/ngShowHideSpec.js
index 3170537d09c5..d764a6fb4f55 100644
--- a/test/ng/directive/ngShowHideSpec.js
+++ b/test/ng/directive/ngShowHideSpec.js
@@ -116,7 +116,7 @@ describe('ngShow / ngHide animations', function() {
 
   beforeEach(function() {
     // we need to run animation on attached elements;
-    body = jqLite(document.body);
+    body = jqLite(window.document.body);
   });
 
   afterEach(function() {
diff --git a/test/ng/directive/ngSrcSpec.js b/test/ng/directive/ngSrcSpec.js
index 5a66587ae21e..762e9339faf0 100644
--- a/test/ng/directive/ngSrcSpec.js
+++ b/test/ng/directive/ngSrcSpec.js
@@ -1,6 +1,7 @@
-/*jshint scripturl:true*/
 'use strict';
 
+/* eslint-disable no-script-url */
+
 describe('ngSrc', function() {
   var element;
 
diff --git a/test/ng/directive/ngSrcsetSpec.js b/test/ng/directive/ngSrcsetSpec.js
index e6842b69292b..15aba45b5749 100644
--- a/test/ng/directive/ngSrcsetSpec.js
+++ b/test/ng/directive/ngSrcsetSpec.js
@@ -1,6 +1,7 @@
-/*jshint scripturl:true*/
 'use strict';
 
+/* eslint-disable no-script-url */
+
 describe('ngSrcset', function() {
   var element;
 
diff --git a/test/ng/directive/ngStyleSpec.js b/test/ng/directive/ngStyleSpec.js
index 4d1ef2069bea..b708eb7a4d82 100644
--- a/test/ng/directive/ngStyleSpec.js
+++ b/test/ng/directive/ngStyleSpec.js
@@ -26,7 +26,7 @@ describe('ngStyle', function() {
   it('should support lazy one-time binding for object literals', inject(function($rootScope, $compile) {
     element = $compile('<div ng-style="::{height: heightStr}"></div>')($rootScope);
     $rootScope.$digest();
-    expect(parseInt(element.css('height') + 0)).toEqual(0); // height could be '' or '0px'
+    expect(parseInt(element.css('height') + 0, 10)).toEqual(0); // height could be '' or '0px'
     $rootScope.$apply('heightStr = "40px"');
     expect(element.css('height')).toBe('40px');
   }));
@@ -42,7 +42,7 @@ describe('ngStyle', function() {
       postCompVal = '100px';
       element = jqLite('<div ng-style="styleObj"></div>');
       element.css(preCompStyle, preCompVal);
-      jqLite(document.body).append(element);
+      jqLite(window.document.body).append(element);
       $compile(element)($rootScope);
       scope = $rootScope;
       scope.styleObj = {'margin-top': '44px'};
diff --git a/test/ng/directive/ngSwitchSpec.js b/test/ng/directive/ngSwitchSpec.js
index 9efad341b4c7..ac94ab29e6e3 100644
--- a/test/ng/directive/ngSwitchSpec.js
+++ b/test/ng/directive/ngSwitchSpec.js
@@ -21,7 +21,7 @@ describe('ngSwitch', function() {
     $rootScope.select = 1;
     $rootScope.$apply();
     expect(element.text()).toEqual('first:');
-    $rootScope.name="shyam";
+    $rootScope.name = "shyam";
     $rootScope.$apply();
     expect(element.text()).toEqual('first:shyam');
     $rootScope.select = 2;
@@ -51,7 +51,7 @@ describe('ngSwitch', function() {
     $rootScope.select = 1;
     $rootScope.$apply();
     expect(element.text()).toEqual('first:, first too:');
-    $rootScope.name="shyam";
+    $rootScope.name = "shyam";
     $rootScope.$apply();
     expect(element.text()).toEqual('first:shyam, first too:shyam');
     $rootScope.select = 2;
@@ -314,7 +314,7 @@ describe('ngSwitch animation', function() {
     // we need to run animation on attached elements;
     return function(_$rootElement_) {
       $rootElement = _$rootElement_;
-      body = jqLite(document.body);
+      body = jqLite(window.document.body);
       body.append($rootElement);
     };
   }));
diff --git a/test/ng/directive/selectSpec.js b/test/ng/directive/selectSpec.js
index 2cd5b092a464..3be1afd2dc18 100644
--- a/test/ng/directive/selectSpec.js
+++ b/test/ng/directive/selectSpec.js
@@ -302,7 +302,7 @@ describe('select', function() {
           '<optgroup label="first">' +
             '<option value="A">A</option>' +
         '</optgroup>' +
-        '<optgroup label="second">' + '\n' +
+        '<optgroup label="second">\n' +
             '<option value="B">B</option>' +
         '</optgroup>      ' +
       '</select>');
@@ -324,7 +324,7 @@ describe('select', function() {
           '<optgroup label="first">' +
             '<option value="A">A</option>' +
         '</optgroup>' +
-        '<optgroup label="second">' + '\n' +
+        '<optgroup label="second">\n' +
             '<option value="B">B</option>' +
         '</optgroup>      ' +
       '</select>');
diff --git a/test/ng/documentSpec.js b/test/ng/documentSpec.js
index 349d12453913..3fe65150e876 100644
--- a/test/ng/documentSpec.js
+++ b/test/ng/documentSpec.js
@@ -4,7 +4,7 @@ describe('$document', function() {
 
 
   it("should inject $document", inject(function($document) {
-    expect($document).toEqual(jqLite(document));
+    expect($document).toEqual(jqLite(window.document));
   }));
 
 
@@ -33,7 +33,7 @@ describe('$$isDocumentHidden', function() {
   it('should listen on the visibilitychange event', function() {
     var doc;
 
-    var spy = spyOn(document, 'addEventListener').and.callThrough();
+    var spy = spyOn(window.document, 'addEventListener').and.callThrough();
 
     inject(function($$isDocumentHidden, $document) {
       expect(spy.calls.mostRecent().args[0]).toBe('visibilitychange');
@@ -44,7 +44,7 @@ describe('$$isDocumentHidden', function() {
   });
 
   it('should remove the listener when the $rootScope is destroyed', function() {
-    var spy = spyOn(document, 'removeEventListener').and.callThrough();
+    var spy = spyOn(window.document, 'removeEventListener').and.callThrough();
 
     inject(function($$isDocumentHidden, $rootScope) {
       $rootScope.$destroy();
diff --git a/test/ng/filter/filterSpec.js b/test/ng/filter/filterSpec.js
index 357d69c00700..0136cd76e47c 100644
--- a/test/ng/filter/filterSpec.js
+++ b/test/ng/filter/filterSpec.js
@@ -400,6 +400,7 @@ describe('Filter: filter', function() {
 
 
   it('should not be affected by `Object.prototype` when using a string expression', function() {
+    // eslint-disable-next-line no-extend-native
     Object.prototype.someProp = 'oo';
 
     var items = [
diff --git a/test/ng/filter/filtersSpec.js b/test/ng/filter/filtersSpec.js
index 8059a51c9df5..42e39d40830d 100644
--- a/test/ng/filter/filtersSpec.js
+++ b/test/ng/filter/filtersSpec.js
@@ -197,7 +197,7 @@ describe('filters', function() {
 
 
     it('should do basic filter', function() {
-      /* jshint -W008 */
+      /* eslint-disable no-floating-decimal */
       expect(number(0, 0)).toEqual('0');
       expect(number(-999)).toEqual('-999');
       expect(number(123)).toEqual('123');
@@ -233,6 +233,7 @@ describe('filters', function() {
       expect(number(1.255,    2)).toEqual("1.26");
       expect(number(1.255,    3)).toEqual("1.255");
       expect(number(0,        8)).toEqual("0.00000000");
+      /* eslint-enable */
     });
 
     it('should pass through null and undefined to be compatible with one-time binding', function() {
diff --git a/test/ng/filter/orderBySpec.js b/test/ng/filter/orderBySpec.js
index 411410e143e7..45feac983efb 100644
--- a/test/ng/filter/orderBySpec.js
+++ b/test/ng/filter/orderBySpec.js
@@ -111,19 +111,21 @@ describe('Filter: orderBy', function() {
 
 
     it('should support string predicates with names containing non-identifier characters', function() {
-      /*jshint -W008 */
+      /* eslint-disable no-floating-decimal */
       expect(orderBy([{"Tip %": .25}, {"Tip %": .15}, {"Tip %": .40}], '"Tip %"'))
         .toEqualData([{"Tip %": .15}, {"Tip %": .25}, {"Tip %": .40}]);
       expect(orderBy([{"원": 76000}, {"원": 31000}, {"원": 156000}], '"원"'))
         .toEqualData([{"원": 31000}, {"원": 76000}, {"원": 156000}]);
+      /* eslint-enable */
     });
 
 
     it('should throw if quoted string predicate is quoted incorrectly', function() {
-      /*jshint -W008 */
+      /* eslint-disable no-floating-decimal */
       expect(function() {
         return orderBy([{"Tip %": .15}, {"Tip %": .25}, {"Tip %": .40}], '"Tip %\'');
       }).toThrow();
+      /* eslint-enable */
     });
 
 
@@ -650,19 +652,21 @@ describe('Filter: orderBy', function() {
 
 
     it('should support string predicates with names containing non-identifier characters', function() {
-      /*jshint -W008 */
+      /* eslint-disable no-floating-decimal */
       expect(orderBy([{"Tip %": .25}, {"Tip %": .15}, {"Tip %": .40}], '"Tip %"'))
         .toEqualData([{"Tip %": .15}, {"Tip %": .25}, {"Tip %": .40}]);
       expect(orderBy([{"원": 76000}, {"원": 31000}, {"원": 156000}], '"원"'))
         .toEqualData([{"원": 31000}, {"원": 76000}, {"원": 156000}]);
+      /* eslint-enable */
     });
 
 
     it('should throw if quoted string predicate is quoted incorrectly', function() {
-      /*jshint -W008 */
+      /* eslint-disable no-floating-decimal */
       expect(function() {
         return orderBy([{"Tip %": .15}, {"Tip %": .25}, {"Tip %": .40}], '"Tip %\'');
       }).toThrow();
+      /* eslint-enable */
     });
 
 
diff --git a/test/ng/httpBackendSpec.js b/test/ng/httpBackendSpec.js
index bf27cf290a02..3040337580a4 100644
--- a/test/ng/httpBackendSpec.js
+++ b/test/ng/httpBackendSpec.js
@@ -14,7 +14,7 @@ describe('$httpBackend', function() {
       $$scripts: [],
       createElement: jasmine.createSpy('createElement').and.callFake(function() {
         // Return a proper script element...
-        return document.createElement(arguments[0]);
+        return window.document.createElement(arguments[0]);
       }),
       body: {
         appendChild: jasmine.createSpy('body.appendChild').and.callFake(function(script) {
@@ -22,7 +22,7 @@ describe('$httpBackend', function() {
         }),
         removeChild: jasmine.createSpy('body.removeChild').and.callFake(function(script) {
           var index = fakeDocument.$$scripts.indexOf(script);
-          if (index != -1) {
+          if (index !== -1) {
             fakeDocument.$$scripts.splice(index, 1);
           }
         })
diff --git a/test/ng/httpSpec.js b/test/ng/httpSpec.js
index 479ce359bc92..709766122c14 100644
--- a/test/ng/httpSpec.js
+++ b/test/ng/httpSpec.js
@@ -682,7 +682,7 @@ describe('$http', function() {
 
       it('should send custom headers', function() {
         $httpBackend.expect('GET', '/url', undefined, function(headers) {
-          return headers['Custom'] == 'header';
+          return headers['Custom'] === 'header';
         }).respond('');
 
         $http({url: '/url', method: 'GET', headers: {
@@ -695,7 +695,7 @@ describe('$http', function() {
 
       it('should set default headers for GET request', function() {
         $httpBackend.expect('GET', '/url', undefined, function(headers) {
-          return headers['Accept'] == 'application/json, text/plain, */*';
+          return headers['Accept'] === 'application/json, text/plain, */*';
         }).respond('');
 
         $http({url: '/url', method: 'GET', headers: {}});
@@ -705,8 +705,8 @@ describe('$http', function() {
 
       it('should set default headers for POST request', function() {
         $httpBackend.expect('POST', '/url', 'messageBody', function(headers) {
-          return headers['Accept'] == 'application/json, text/plain, */*' &&
-                 headers['Content-Type'] == 'application/json;charset=utf-8';
+          return headers['Accept'] === 'application/json, text/plain, */*' &&
+                 headers['Content-Type'] === 'application/json;charset=utf-8';
         }).respond('');
 
         $http({url: '/url', method: 'POST', headers: {}, data: 'messageBody'});
@@ -716,8 +716,8 @@ describe('$http', function() {
 
       it('should set default headers for PUT request', function() {
         $httpBackend.expect('PUT', '/url', 'messageBody', function(headers) {
-          return headers['Accept'] == 'application/json, text/plain, */*' &&
-                 headers['Content-Type'] == 'application/json;charset=utf-8';
+          return headers['Accept'] === 'application/json, text/plain, */*' &&
+                 headers['Content-Type'] === 'application/json;charset=utf-8';
         }).respond('');
 
         $http({url: '/url', method: 'PUT', headers: {}, data: 'messageBody'});
@@ -726,8 +726,8 @@ describe('$http', function() {
 
       it('should set default headers for PATCH request', function() {
         $httpBackend.expect('PATCH', '/url', 'messageBody', function(headers) {
-          return headers['Accept'] == 'application/json, text/plain, */*' &&
-                 headers['Content-Type'] == 'application/json;charset=utf-8';
+          return headers['Accept'] === 'application/json, text/plain, */*' &&
+                 headers['Content-Type'] === 'application/json;charset=utf-8';
         }).respond('');
 
         $http({url: '/url', method: 'PATCH', headers: {}, data: 'messageBody'});
@@ -736,7 +736,7 @@ describe('$http', function() {
 
       it('should set default headers for custom HTTP method', function() {
         $httpBackend.expect('FOO', '/url', undefined, function(headers) {
-          return headers['Accept'] == 'application/json, text/plain, */*';
+          return headers['Accept'] === 'application/json, text/plain, */*';
         }).respond('');
 
         $http({url: '/url', method: 'FOO', headers: {}});
@@ -746,8 +746,8 @@ describe('$http', function() {
 
       it('should override default headers with custom', function() {
         $httpBackend.expect('POST', '/url', 'messageBody', function(headers) {
-          return headers['Accept'] == 'Rewritten' &&
-                 headers['Content-Type'] == 'Rewritten';
+          return headers['Accept'] === 'Rewritten' &&
+                 headers['Content-Type'] === 'Rewritten';
         }).respond('');
 
         $http({url: '/url', method: 'POST', data: 'messageBody', headers: {
@@ -771,8 +771,8 @@ describe('$http', function() {
 
       it('should override default headers with custom in a case insensitive manner', function() {
         $httpBackend.expect('POST', '/url', 'messageBody', function(headers) {
-          return headers['accept'] == 'Rewritten' &&
-                 headers['content-type'] == 'Content-Type Rewritten' &&
+          return headers['accept'] === 'Rewritten' &&
+                 headers['content-type'] === 'Content-Type Rewritten' &&
                  isUndefined(headers['Accept']) &&
                  isUndefined(headers['Content-Type']);
         }).respond('');
@@ -812,7 +812,7 @@ describe('$http', function() {
 
       it('should NOT delete Content-Type header if request data/body is set by request transform', function() {
         $httpBackend.expect('POST', '/url', {'one': 'two'}, function(headers) {
-          return headers['Content-Type'] == 'application/json;charset=utf-8';
+          return headers['Content-Type'] === 'application/json;charset=utf-8';
         }).respond('');
 
         $http({
@@ -830,7 +830,7 @@ describe('$http', function() {
       it('should set the XSRF cookie into a XSRF header', inject(function() {
         function checkXSRF(secret, header) {
           return function(headers) {
-            return headers[header || 'X-XSRF-TOKEN'] == secret;
+            return headers[header || 'X-XSRF-TOKEN'] === secret;
           };
         }
 
@@ -857,7 +857,7 @@ describe('$http', function() {
         var headerConfig = {'Accept': function() { return 'Rewritten'; }};
 
         function checkHeaders(headers) {
-          return headers['Accept'] == 'Rewritten';
+          return headers['Accept'] === 'Rewritten';
         }
 
         $httpBackend.expect('GET', '/url', undefined, checkHeaders).respond('');
@@ -923,7 +923,7 @@ describe('$http', function() {
 
       function checkHeader(name, value) {
         return function(headers) {
-          return headers[name] == value;
+          return headers[name] === value;
         };
       }
 
@@ -1127,6 +1127,7 @@ describe('$http', function() {
         it('should ignore Blob objects', function() {
           if (!window.Blob) return;
 
+          // eslint-disable-next-line no-undef
           var blob = new Blob(['blob!'], { type: 'text/plain' });
 
           $httpBackend.expect('POST', '/url', '[object Blob]').respond('');
@@ -1136,6 +1137,7 @@ describe('$http', function() {
         it('should ignore FormData objects', function() {
           if (!window.FormData) return;
 
+          // eslint-disable-next-line no-undef
           var formData = new FormData();
           formData.append('angular', 'is great');
 
@@ -1187,7 +1189,7 @@ describe('$http', function() {
         });
 
         it('should pipeline more functions', function() {
-          function first(d, h) {return d + '-first' + ':' + h('h1');}
+          function first(d, h) {return d + '-first:' + h('h1');}
           function second(d) {return uppercase(d);}
 
           $httpBackend.expect('POST', '/url', 'REQ-FIRST:V1').respond(200);
@@ -1418,7 +1420,7 @@ describe('$http', function() {
 
 
         it('should pipeline more functions', function() {
-          function first(d, h) {return d + '-first' + ':' + h('h1');}
+          function first(d, h) {return d + '-first:' + h('h1');}
           function second(d) {return uppercase(d);}
 
           $httpBackend.expect('POST', '/url').respond(200, 'resp', {h1: 'v1'});
@@ -1878,7 +1880,7 @@ describe('$http', function() {
 
         $http.defaults.headers.common.foo = 'bar';
         $httpBackend.expect('GET', '/url', undefined, function(headers) {
-          return headers['foo'] == 'bar';
+          return headers['foo'] === 'bar';
         }).respond('');
 
         $http.get('/url');
diff --git a/test/ng/locationSpec.js b/test/ng/locationSpec.js
index c75ca0fd298e..20567017c5c7 100644
--- a/test/ng/locationSpec.js
+++ b/test/ng/locationSpec.js
@@ -9,7 +9,7 @@ describe('$location', function() {
   afterEach(function() {
     // link rewriting used in html5 mode on legacy browsers binds to document.onClick, so we need
     // to clean this up after each test.
-    jqLite(document).off('click');
+    jqLite(window.document).off('click');
   });
 
 
@@ -332,7 +332,7 @@ describe('$location', function() {
 
 
     it('should prefix path with forward-slash', function() {
-      var locationUrl = new LocationHtml5Url('http://server/', 'http://server/') ;
+      var locationUrl = new LocationHtml5Url('http://server/', 'http://server/');
       locationUrl.path('b');
 
       expect(locationUrl.path()).toBe('/b');
@@ -341,7 +341,7 @@ describe('$location', function() {
 
 
     it('should set path to forward-slash when empty', function() {
-      var locationUrl = new LocationHtml5Url('http://server/', 'http://server/') ;
+      var locationUrl = new LocationHtml5Url('http://server/', 'http://server/');
       locationUrl.$$parse('http://server/');
       expect(locationUrl.path()).toBe('/');
       expect(locationUrl.absUrl()).toBe('http://server/');
@@ -378,7 +378,7 @@ describe('$location', function() {
     });
 
     it('should prepend path with basePath', function() {
-      var locationUrl = new LocationHtml5Url('http://server/base/', 'http://server/base/') ;
+      var locationUrl = new LocationHtml5Url('http://server/base/', 'http://server/base/');
       locationUrl.$$parse('http://server/base/abc?a');
       expect(locationUrl.path()).toBe('/abc');
       expect(locationUrl.search()).toEqual({a: true});
@@ -637,21 +637,21 @@ describe('$location', function() {
       });
 
       it('should return an array for duplicate params', function() {
-        var locationUrl = new LocationHtml5Url('http://host.com', 'http://host.com') ;
+        var locationUrl = new LocationHtml5Url('http://host.com', 'http://host.com');
         locationUrl.$$parse('http://host.com');
         locationUrl.search('q', ['1/2 3','4/5 6']);
         expect(locationUrl.search()).toEqual({'q': ['1/2 3','4/5 6']});
       });
 
       it('should encode an array correctly from search and add to url', function() {
-        var locationUrl = new LocationHtml5Url('http://host.com', 'http://host.com') ;
+        var locationUrl = new LocationHtml5Url('http://host.com', 'http://host.com');
         locationUrl.$$parse('http://host.com');
         locationUrl.search({'q': ['1/2 3','4/5 6']});
         expect(locationUrl.absUrl()).toEqual('http://host.com?q=1%2F2%203&q=4%2F5%206');
       });
 
       it('should rewrite params when specifing a single param in search', function() {
-        var locationUrl = new LocationHtml5Url('http://host.com', 'http://host.com') ;
+        var locationUrl = new LocationHtml5Url('http://host.com', 'http://host.com');
         locationUrl.$$parse('http://host.com');
         locationUrl.search({'q': '1/2 3'});
         expect(locationUrl.absUrl()).toEqual('http://host.com?q=1%2F2%203');
@@ -891,7 +891,7 @@ describe('$location', function() {
             NEW_URL = 'http://new.com/a/b#!/new';
 
         $rootScope.$apply(function() {
-          $window.location.href= NEW_URL;
+          $window.location.href = NEW_URL;
           $browser.$$checkUrlChange(); // simulate firing event from browser
           expect($location.absUrl()).toBe(OLD_URL); // should be async
         });
@@ -1349,7 +1349,7 @@ describe('$location', function() {
       attrs = attrs ? ' ' + attrs + ' ' : '';
 
       if (typeof linkHref === 'string' && !relLink) {
-        if (linkHref[0] == '/') {
+        if (linkHref[0] === '/') {
           linkHref = 'http://host.com' + linkHref;
         } else if (!linkHref.match(/:\/\//)) {
           // fake the behavior of <base> tag
@@ -1397,7 +1397,7 @@ describe('$location', function() {
 
     afterEach(function() {
       dealoc(root);
-      dealoc(document.body);
+      dealoc(window.document.body);
     });
 
 
@@ -1788,14 +1788,14 @@ describe('$location', function() {
         setupRewriteChecks(),
         function($browser) {
           var rightClick;
-          if (document.createEvent) {
-            rightClick = document.createEvent('MouseEvents');
+          if (window.document.createEvent) {
+            rightClick = window.document.createEvent('MouseEvents');
             rightClick.initMouseEvent('click', true, true, window, 1, 10, 10, 10,  10, false,
                                       false, false, false, 2, null);
 
             link.dispatchEvent(rightClick);
-          } else if (document.createEventObject) { // for IE
-            rightClick = document.createEventObject();
+          } else if (window.document.createEventObject) { // for IE
+            rightClick = window.document.createEventObject();
             rightClick.type = 'click';
             rightClick.cancelBubble = true;
             rightClick.detail = 1;
@@ -2254,7 +2254,7 @@ describe('$location', function() {
         return function($rootElement, $compile, $rootScope) {
           $rootElement.html('<a href="http://server/#!/somePath">link</a>');
           $compile($rootElement)($rootScope);
-          jqLite(document.body).append($rootElement);
+          jqLite(window.document.body).append($rootElement);
         };
       });
 
@@ -2287,7 +2287,7 @@ describe('$location', function() {
         return function($rootElement, $compile, $rootScope) {
           $rootElement.html('<a href="http://server/somePath">link</a>');
           $compile($rootElement)($rootScope);
-          jqLite(document.body).append($rootElement);
+          jqLite(window.document.body).append($rootElement);
         };
       });
 
@@ -2474,12 +2474,12 @@ describe('$location', function() {
     var locationUrl;
 
     it('should rewrite URL', function() {
-      /* jshint scripturl: true */
       locationUrl = new LocationHashbangUrl('http://server/pre/', 'http://server/pre/', '#');
 
       expect(parseLinkAndReturn(locationUrl, 'http://other')).toEqual(undefined);
       expect(parseLinkAndReturn(locationUrl, 'http://server/pre/')).toEqual('http://server/pre/');
       expect(parseLinkAndReturn(locationUrl, 'http://server/pre/#otherPath')).toEqual('http://server/pre/#/otherPath');
+      // eslint-disable-next-line no-script-url
       expect(parseLinkAndReturn(locationUrl, 'javascript:void(0)')).toEqual(undefined);
     });
 
diff --git a/test/ng/logSpec.js b/test/ng/logSpec.js
index f214b19e729c..c4ce3b8339dd 100644
--- a/test/ng/logSpec.js
+++ b/test/ng/logSpec.js
@@ -9,11 +9,11 @@ describe('$log', function() {
   beforeEach(module(function($provide) {
     $window = {navigator: {}, document: {}};
     logger = '';
-    log = function() { logger+= 'log;'; };
-    warn = function() { logger+= 'warn;'; };
-    info = function() { logger+= 'info;'; };
-    error = function() { logger+= 'error;'; };
-    debug = function() { logger+= 'debug;'; };
+    log = function() { logger += 'log;'; };
+    warn = function() { logger += 'warn;'; };
+    info = function() { logger += 'info;'; };
+    error = function() { logger += 'error;'; };
+    debug = function() { logger += 'debug;'; };
 
     $provide.provider('$log', $LogProvider);
     $provide.value('$exceptionHandler', angular.mock.rethrow);
@@ -93,11 +93,11 @@ describe('$log', function() {
 
     it("should not attempt to log the second argument in IE if it is not specified", inject(
       function() {
-        log = function(arg1, arg2) { logger+= 'log;' + arg2; };
-        warn = function(arg1, arg2) { logger+= 'warn;' + arg2; };
-        info = function(arg1, arg2) { logger+= 'info;' + arg2; };
-        error = function(arg1, arg2) { logger+= 'error;' + arg2; };
-        debug = function(arg1, arg2) { logger+= 'debug;' + arg2; };
+        log = function(arg1, arg2) { logger += 'log;' + arg2; };
+        warn = function(arg1, arg2) { logger += 'warn;' + arg2; };
+        info = function(arg1, arg2) { logger += 'info;' + arg2; };
+        error = function(arg1, arg2) { logger += 'error;' + arg2; };
+        debug = function(arg1, arg2) { logger += 'debug;' + arg2; };
       },
       removeApplyFunctionForIE,
       function($log) {
diff --git a/test/ng/parseSpec.js b/test/ng/parseSpec.js
index e1f21f6b80de..ce4797d7d6b6 100644
--- a/test/ng/parseSpec.js
+++ b/test/ng/parseSpec.js
@@ -1,5 +1,9 @@
 'use strict';
 
+// This file has many tests which read nicely if constant conditions
+// are used.
+/* eslint-disable no-constant-condition */
+
 describe('parser', function() {
 
   describe('lexer', function() {
@@ -25,7 +29,7 @@ describe('parser', function() {
     });
 
     it('should tokenize a string', function() {
-      var tokens = lex("a.bc[22]+1.3|f:'a\\\'c':\"d\\\"e\"");
+      var tokens = lex("a.bc[22]+1.3|f:'a\\'c':\"d\\\"e\"");
       var i = 0;
       expect(tokens[i].index).toEqual(0);
       expect(tokens[i].text).toEqual('a');
@@ -1848,7 +1852,6 @@ describe('parser', function() {
       }));
 
       it('should parse expressions', function() {
-        /*jshint -W006, -W007 */
         expect(scope.$eval("-1")).toEqual(-1);
         expect(scope.$eval("1 + 2.5")).toEqual(3.5);
         expect(scope.$eval("1 + -2.5")).toEqual(-1.5);
@@ -1874,7 +1877,7 @@ describe('parser', function() {
       });
 
       it('should parse comparison', function() {
-        /* jshint -W041 */
+        /* eslint-disable eqeqeq, no-self-compare */
         expect(scope.$eval("false")).toBeFalsy();
         expect(scope.$eval("!true")).toBeFalsy();
         expect(scope.$eval("1==1")).toBeTruthy();
@@ -1897,6 +1900,7 @@ describe('parser', function() {
         expect(scope.$eval("true===3===3")).toEqual(true === 3 === 3);
         expect(scope.$eval("3===3===true")).toEqual(3 === 3 === true);
         expect(scope.$eval("3 >= 3 > 2")).toEqual(3 >= 3 > 2);
+        /* eslint-enable */
       });
 
       it('should parse logical', function() {
@@ -2244,9 +2248,9 @@ describe('parser', function() {
       });
 
       it('should evaluate object methods in correct context (this)', function() {
-        var C = function() {
+        function C() {
           this.a = 123;
-        };
+        }
         C.prototype.getA = function() {
           return this.a;
         };
@@ -2257,9 +2261,9 @@ describe('parser', function() {
       });
 
       it('should evaluate methods in correct context (this) in argument', function() {
-        var C = function() {
+        function C() {
           this.a = 123;
-        };
+        }
         C.prototype.sum = function(value) {
           return this.a + value;
         };
@@ -2327,8 +2331,8 @@ describe('parser', function() {
       });
 
       it('should evaluate negation', function() {
-        /* jshint -W018 */
         expect(scope.$eval("!false || true")).toEqual(!false || true);
+        // eslint-disable-next-line eqeqeq
         expect(scope.$eval("!11 == 10")).toEqual(!11 == 10);
         expect(scope.$eval("12/6/2")).toEqual(12 / 6 / 2);
       });
@@ -2356,7 +2360,7 @@ describe('parser', function() {
 
       it('should short-circuit AND operator', function() {
         scope.run = function() {
-          throw "IT SHOULD NOT HAVE RUN";
+          throw new Error("IT SHOULD NOT HAVE RUN");
         };
         expect(scope.$eval('false && run()')).toBe(false);
         expect(scope.$eval('false && true && run()')).toBe(false);
@@ -2364,7 +2368,7 @@ describe('parser', function() {
 
       it('should short-circuit OR operator', function() {
         scope.run = function() {
-          throw "IT SHOULD NOT HAVE RUN";
+          throw new Error("IT SHOULD NOT HAVE RUN");
         };
         expect(scope.$eval('true || run()')).toBe(true);
         expect(scope.$eval('true || false || run()')).toBe(true);
@@ -2943,12 +2947,13 @@ describe('parser', function() {
         });
 
         it('should prevent the exploit', function() {
-           expect(function() {
-             scope.$eval('(1)[{0: "__proto__", 1: "__proto__", 2: "__proto__", 3: "safe", length: 4, toString: [].pop}].foo = 1');
-           }).toThrow();
-           if (!msie || msie > 10) {
-             expect((1)['__proto__'].foo).toBeUndefined();
-           }
+          expect(function() {
+            scope.$eval('(1)[{0: "__proto__", 1: "__proto__", 2: "__proto__", 3: "safe", length: 4, toString: [].pop}].foo = 1');
+          }).toThrow();
+          if (!msie || msie > 10) {
+            // eslint-disable-next-line no-proto
+            expect((1)['__proto__'].foo).toBeUndefined();
+          }
         });
 
         it('should prevent the exploit', function() {
@@ -3185,7 +3190,7 @@ describe('parser', function() {
         var n = 0;
         scope.fn = function() {
           var c = n++;
-          return { c: c, anotherFn: function() { return this.c == c; } };
+          return { c: c, anotherFn: function() { return this.c === c; } };
         };
         expect(scope.$eval('fn().anotherFn()')).toBe(true);
       });
diff --git a/test/ng/qSpec.js b/test/ng/qSpec.js
index 2d0325464c39..d6fdc776ebdd 100644
--- a/test/ng/qSpec.js
+++ b/test/ng/qSpec.js
@@ -192,8 +192,8 @@ describe('q', function() {
 
 
   beforeEach(function() {
-    q = qFactory(mockNextTick.nextTick, exceptionHandler, true),
-    q_no_error = qFactory(mockNextTick.nextTick, exceptionHandler, false),
+    q = qFactory(mockNextTick.nextTick, exceptionHandler, true);
+    q_no_error = qFactory(mockNextTick.nextTick, exceptionHandler, false);
     defer = q.defer;
     deferred =  defer();
     promise = deferred.promise;
@@ -234,12 +234,11 @@ describe('q', function() {
     });
 
     it('should support the instanceof operator', function() {
-      /*jshint newcap: false */
+      // eslint-disable-next-line new-cap
       var promise = new q(noop);
       expect(promise instanceof q).toBe(true);
       promise = q(noop);
       expect(promise instanceof q).toBe(true);
-      /*jshint newcap: true */
     });
 
 
@@ -846,7 +845,7 @@ describe('q', function() {
         expect(resolveSpy).not.toHaveBeenCalled();
         expect(rejectSpy).toHaveBeenCalled();
         expect(rejectSpy.calls.argsFor(0)[0].message).
-            toMatch(/\[\$q\:qcycle\] Expected promise to be resolved with value other than itself/);
+            toMatch(/\[\$q:qcycle\] Expected promise to be resolved with value other than itself/);
       });
 
 
@@ -2068,7 +2067,7 @@ describe('q', function() {
 
 
     beforeEach(function() {
-      q = qFactory(mockNextTick.nextTick, mockExceptionLogger.logger),
+      q = qFactory(mockNextTick.nextTick, mockExceptionLogger.logger);
       defer = q.defer;
       deferred =  defer();
       promise = deferred.promise;
@@ -2238,7 +2237,7 @@ describe('q', function() {
 
 
     it('should still reject the promise, when exception is thrown in success handler, even if exceptionHandler rethrows', function() {
-      deferred.promise.then(function() { throw 'reject'; }).then(null, errorSpy);
+      deferred.promise.then(function() { throw new Error('reject'); }).then(null, errorSpy);
       deferred.resolve('resolve');
       mockNextTick.flush();
       expect(exceptionExceptionSpy).toHaveBeenCalled();
@@ -2247,7 +2246,7 @@ describe('q', function() {
 
 
     it('should still reject the promise, when exception is thrown in error handler, even if exceptionHandler rethrows', function() {
-      deferred.promise.then(null, function() { throw 'reject again'; }).then(null, errorSpy);
+      deferred.promise.then(null, function() { throw new Error('reject again'); }).then(null, errorSpy);
       deferred.reject('reject');
       mockNextTick.flush();
       expect(exceptionExceptionSpy).toHaveBeenCalled();
diff --git a/test/ng/rafSpec.js b/test/ng/rafSpec.js
index 361c8a0aa90b..89b2cb30a787 100644
--- a/test/ng/rafSpec.js
+++ b/test/ng/rafSpec.js
@@ -27,7 +27,7 @@ describe('$$rAF', function() {
 
     try {
       $$rAF.flush();
-    } catch (e) {}
+    } catch (e) { /* empty */ }
     expect(present).toBe(true);
   }));
 
@@ -94,7 +94,7 @@ describe('$$rAF', function() {
 
       try {
         cancel();
-      } catch (e) {}
+      } catch (e) { /* empty */ }
 
       expect($window.webkitCancelRequestAnimationFrame).toHaveBeenCalled();
     });
diff --git a/test/ng/rootScopeSpec.js b/test/ng/rootScopeSpec.js
index 70e565b7b434..2184bd4fc9d6 100644
--- a/test/ng/rootScopeSpec.js
+++ b/test/ng/rootScopeSpec.js
@@ -13,8 +13,8 @@ describe('Scope', function() {
 
 
     it('should expose the constructor', inject(function($rootScope) {
-      /* jshint -W103 */
       if (msie < 11) return;
+      // eslint-disable-next-line no-proto
       expect($rootScope.__proto__).toBe($rootScope.constructor.prototype);
     }));
 
@@ -333,9 +333,9 @@ describe('Scope', function() {
 
     it('should repeat watch cycle while model changes are identified', inject(function($rootScope) {
       var log = '';
-      $rootScope.$watch('c', function(v) {$rootScope.d = v; log+='c'; });
-      $rootScope.$watch('b', function(v) {$rootScope.c = v; log+='b'; });
-      $rootScope.$watch('a', function(v) {$rootScope.b = v; log+='a'; });
+      $rootScope.$watch('c', function(v) {$rootScope.d = v; log += 'c'; });
+      $rootScope.$watch('b', function(v) {$rootScope.c = v; log += 'b'; });
+      $rootScope.$watch('a', function(v) {$rootScope.b = v; log += 'a'; });
       $rootScope.$digest();
       log = '';
       $rootScope.a = 1;
@@ -438,11 +438,11 @@ describe('Scope', function() {
       $rootScope.a = [];
       $rootScope.b = {};
       $rootScope.$watch('a', function(value) {
-        log +='.';
+        log += '.';
         expect(value).toBe($rootScope.a);
       }, true);
       $rootScope.$watch('b', function(value) {
-        log +='!';
+        log += '!';
         expect(value).toBe($rootScope.b);
       }, true);
       $rootScope.$digest();
@@ -755,12 +755,12 @@ describe('Scope', function() {
               arrayLikelog.push(element.name);
             });
           });
-          document.body.innerHTML = "<p>" +
-                                      "<a name='x'>a</a>" +
-                                      "<a name='y'>b</a>" +
-                                    "</p>";
+          window.document.body.innerHTML = "<p>" +
+                                             "<a name='x'>a</a>" +
+                                             "<a name='y'>b</a>" +
+                                           "</p>";
 
-          $rootScope.arrayLikeObject =  document.getElementsByTagName('a');
+          $rootScope.arrayLikeObject = window.document.getElementsByTagName('a');
           $rootScope.$digest();
           expect(arrayLikelog).toEqual(['x', 'y']);
         });
@@ -811,7 +811,7 @@ describe('Scope', function() {
           $rootScope.$digest();
           expect(log.empty()).toEqual([{newVal: {}, oldVal: {}, identical: true}]);
 
-          $rootScope.obj.a= 'A';
+          $rootScope.obj.a = 'A';
           $rootScope.$digest();
           expect(log.empty()).toEqual([{newVal: {a: 'A'}, oldVal: {}}]);
 
@@ -1263,7 +1263,7 @@ describe('Scope', function() {
       expect($rootScope.$eval('a=1')).toEqual(1);
       expect($rootScope.a).toEqual(1);
 
-      $rootScope.$eval(function(self) {self.b=2;});
+      $rootScope.$eval(function(self) {self.b = 2;});
       expect($rootScope.b).toEqual(2);
     }));
 
diff --git a/test/ng/sanitizeUriSpec.js b/test/ng/sanitizeUriSpec.js
index c36ec48a2535..a64b7dd4487f 100644
--- a/test/ng/sanitizeUriSpec.js
+++ b/test/ng/sanitizeUriSpec.js
@@ -1,6 +1,7 @@
-/* jshint scripturl: true */
 'use strict';
 
+/* eslint-disable no-script-url */
+
 describe('sanitizeUri', function() {
   var sanitizeHref, sanitizeImg, sanitizeUriProvider, testUrl;
   beforeEach(function() {
@@ -18,7 +19,7 @@ describe('sanitizeUri', function() {
   });
 
   function isEvilInCurrentBrowser(uri) {
-    var a = document.createElement('a');
+    var a = window.document.createElement('a');
     a.setAttribute('href', uri);
     return a.href.substring(0, 4) !== 'http';
   }
diff --git a/test/ng/sceSpecs.js b/test/ng/sceSpecs.js
index b15ee5fa6812..3da311a05353 100644
--- a/test/ng/sceSpecs.js
+++ b/test/ng/sceSpecs.js
@@ -437,7 +437,7 @@ describe('SCE', function() {
           runTest({whiteList: ['http://***']}, null)();
         }).toThrowMinErr('$injector', 'modulerr', new RegExp(
              /Failed to instantiate module function ?\(\$sceDelegateProvider\) due to:\n/.source +
-             /[^[]*\[\$sce:iwcard\] Illegal sequence \*\*\* in string matcher\.  String: http:\/\/\*\*\*/.source));
+             /[^[]*\[\$sce:iwcard\] Illegal sequence \*\*\* in string matcher\. {2}String: http:\/\/\*\*\*/.source));
       });
     });
 
diff --git a/test/ng/templateRequestSpec.js b/test/ng/templateRequestSpec.js
index dc78e21f3bc8..b064b51875f7 100644
--- a/test/ng/templateRequestSpec.js
+++ b/test/ng/templateRequestSpec.js
@@ -21,7 +21,7 @@ describe('$templateRequest', function() {
 
           expect($http.get).toHaveBeenCalledOnceWith('tpl.html', {
             cache: $templateCache,
-            transformResponse: [  ]
+            transformResponse: []
           });
         });
 
@@ -214,7 +214,7 @@ describe('$templateRequest', function() {
 
     try {
       $httpBackend.flush();
-    } catch (e) {}
+    } catch (e) { /* empty */ }
 
     expect($templateRequest.totalPendingRequests).toBe(0);
   }));
diff --git a/test/ngAnimate/.jshintrc b/test/ngAnimate/.eslintrc.json
similarity index 85%
rename from test/ngAnimate/.jshintrc
rename to test/ngAnimate/.eslintrc.json
index d202a2b3bf1c..060d812cd85b 100644
--- a/test/ngAnimate/.jshintrc
+++ b/test/ngAnimate/.eslintrc.json
@@ -1,7 +1,7 @@
 {
-  "extends": "../.jshintrc",
-  "browser": true,
-  "newcap": false,
+  "rules": {
+    "new-cap": "off"
+  },
   "globals": {
     "mergeAnimationDetails": false,
     "prepareAnimationOptions": false,
diff --git a/test/ngAnimate/animateCssDriverSpec.js b/test/ngAnimate/animateCssDriverSpec.js
index abc4eefa7a89..0f44cb440203 100644
--- a/test/ngAnimate/animateCssDriverSpec.js
+++ b/test/ngAnimate/animateCssDriverSpec.js
@@ -463,7 +463,8 @@ describe("ngAnimate $$animateCssDriver", function() {
                 $$willAnimate: addClass === expectedClass,
                 start: function() {
                   animationStarted = addClass;
-                  return runner = new $$AnimateRunner();
+                  runner = new $$AnimateRunner();
+                  return runner;
                 }
               };
             };
diff --git a/test/ngAnimate/animateCssSpec.js b/test/ngAnimate/animateCssSpec.js
index 6cc78e1e2f7e..be5eb6ced46e 100644
--- a/test/ngAnimate/animateCssSpec.js
+++ b/test/ngAnimate/animateCssSpec.js
@@ -8,8 +8,11 @@ describe("ngAnimate $animateCss", function() {
   function assertAnimationRunning(element, not) {
     var className = element.attr('class');
     var regex = /\b\w+-active\b/;
-    not ? expect(className).toMatch(regex)
-        : expect(className).not.toMatch(regex);
+    if (not) {
+      expect(className).toMatch(regex);
+    } else {
+      expect(className).not.toMatch(regex);
+    }
   }
 
   function getPossiblyPrefixedStyleValue(element, styleProp) {
@@ -1970,7 +1973,7 @@ describe("ngAnimate $animateCss", function() {
 
           var element = angular.element('<div></div>');
 
-          if (event == 'add') {
+          if (event === 'add') {
             ss.addRule('.natural-class', 'transition:1s linear all;');
           } else {
             ss.addRule('.natural-class', 'transition:0s linear none;');
diff --git a/test/ngAnimate/animateJsDriverSpec.js b/test/ngAnimate/animateJsDriverSpec.js
index d3f8722cb45d..13438344f7d2 100644
--- a/test/ngAnimate/animateJsDriverSpec.js
+++ b/test/ngAnimate/animateJsDriverSpec.js
@@ -35,7 +35,7 @@ describe("ngAnimate $$animateJsDriver", function() {
       });
 
       captureLog.length = 0;
-      element = jqLite('<div></div');
+      element = jqLite('<div></div>');
 
       return function($rootElement, $$animateJsDriver) {
         $rootElement.append(element);
@@ -131,7 +131,7 @@ describe("ngAnimate $$animateJsDriver", function() {
         $animate.flush();
 
         expect(animationsClosed).toBe(true);
-        expect(status).toBe(method === 'end' ? true : false);
+        expect(status).toBe(method === 'end');
       });
     });
 
@@ -172,7 +172,7 @@ describe("ngAnimate $$animateJsDriver", function() {
 
         expect(animationsClosed).toBe(true);
 
-        expect(status).toBe(method === 'end' ? true : false);
+        expect(status).toBe(method === 'end');
       });
     });
   });
diff --git a/test/ngAnimate/animateJsSpec.js b/test/ngAnimate/animateJsSpec.js
index 99d7dcd076f6..6445c17b9c4a 100644
--- a/test/ngAnimate/animateJsSpec.js
+++ b/test/ngAnimate/animateJsSpec.js
@@ -554,7 +554,8 @@ describe("ngAnimate $$animateJs", function() {
           return {
             start: function() {
               log.push('start ' + event);
-              return runner = new $$AnimateRunner();
+              runner = new $$AnimateRunner();
+              return runner;
             }
           };
         };
@@ -584,7 +585,8 @@ describe("ngAnimate $$animateJs", function() {
         var runner;
         animations[event] = function(element, a, b, c) {
           log.push('start ' + event);
-          return runner = new $$AnimateRunner();
+          runner = new $$AnimateRunner();
+          return runner;
         };
 
         runAnimation(event, function() {
diff --git a/test/ngAnimate/animateSpec.js b/test/ngAnimate/animateSpec.js
index 844bfdb02a0c..86e61c5adf85 100644
--- a/test/ngAnimate/animateSpec.js
+++ b/test/ngAnimate/animateSpec.js
@@ -270,8 +270,11 @@ describe("animations", function() {
 
           var message = '$animateProvider.classNameFilter(regex) prohibits accepting a regex value which matches/contains the "ng-animate" CSS class.';
 
-          bool ? expectation.toThrowMinErr('$animate', 'nongcls', message)
-               : expectation.not.toThrowMinErr('$animate', 'nongcls', message);
+          if (bool) {
+            expectation.toThrowMinErr('$animate', 'nongcls', message);
+          } else {
+            expectation.not.toThrowMinErr('$animate', 'nongcls', message);
+          }
         }
       });
     });
@@ -1741,7 +1744,8 @@ describe("animations", function() {
       $provide.factory('$$animation', function($$AnimateRunner) {
         return function() {
           captureLog.push(capturedAnimation = arguments);
-          return runner = new $$AnimateRunner();
+          runner = new $$AnimateRunner();
+          return runner;
         };
       });
 
@@ -1991,6 +1995,7 @@ describe("animations", function() {
 
     it('should not get affected by custom, enumerable properties on `Object.prototype`',
       inject(function($animate) {
+        // eslint-disable-next-line no-extend-native
         Object.prototype.foo = 'ENUMARABLE_AND_NOT_AN_ARRAY';
 
         element = jqLite('<div></div>');
diff --git a/test/ngAnimate/animationSpec.js b/test/ngAnimate/animationSpec.js
index 5de3ffc9e1e2..f036908b0998 100644
--- a/test/ngAnimate/animationSpec.js
+++ b/test/ngAnimate/animationSpec.js
@@ -208,7 +208,11 @@ describe('$$animation', function() {
         // the animation is started
         $rootScope.$digest();
 
-        event === 'resolve' ? runner.end() : runner.cancel();
+        if (event === 'resolve') {
+          runner.end();
+        } else {
+          runner.cancel();
+        }
 
         // the resolve/rejection digest
         $animate.flush();
@@ -748,7 +752,7 @@ describe('$$animation', function() {
 
           expect(runnerLog).toEqual([]);
 
-          ('from' ? fromElement : toElement).remove();
+          (event === 'from' ? fromElement : toElement).remove();
           expect(runnerLog).toEqual(['end']);
         });
       });
@@ -862,7 +866,8 @@ describe('$$animation', function() {
         mockedDriverFn = function(element, method, options, domOperation) {
           return {
             start: function() {
-              return runner = new $$AnimateRunner();
+              runner = new $$AnimateRunner();
+              return runner;
             }
           };
         };
diff --git a/test/ngCookies/cookieWriterSpec.js b/test/ngCookies/cookieWriterSpec.js
index e5986aea785e..4a1419c4f8cf 100644
--- a/test/ngCookies/cookieWriterSpec.js
+++ b/test/ngCookies/cookieWriterSpec.js
@@ -1,11 +1,11 @@
 'use strict';
 
 describe('$$cookieWriter', function() {
-  var $$cookieWriter;
+  var $$cookieWriter, document;
 
   function deleteAllCookies() {
     var cookies = document.cookie.split(";");
-    var path = location.pathname;
+    var path = window.location.pathname;
 
     for (var i = 0; i < cookies.length; i++) {
       var cookie = cookies[i];
@@ -20,6 +20,7 @@ describe('$$cookieWriter', function() {
   }
 
   beforeEach(function() {
+    document = window.document;
     deleteAllCookies();
     expect(document.cookie).toEqual('');
 
@@ -141,7 +142,7 @@ describe('cookie options', function() {
                   if (isUndefined(prev)) {
                     return isUndefined(pair[1]) ? true : pair[1];
                   } else {
-                    throw 'duplicate key in cookie string';
+                    throw new Error('duplicate key in cookie string');
                   }
                 } else {
                   return prev;
diff --git a/test/ngMessageFormat/messageFormatSpec.js b/test/ngMessageFormat/messageFormatSpec.js
index 41958180d19f..43a6ae477293 100644
--- a/test/ngMessageFormat/messageFormatSpec.js
+++ b/test/ngMessageFormat/messageFormatSpec.js
@@ -129,13 +129,13 @@ describe('$$ngMessageFormat', function() {
           expect(parsedFn.expressions.length).toBe(1);
           expect(parsedFn.expressions[0]).toEqual("recipients.length");
 
-          $rootScope.recipients.length=2;
+          $rootScope.recipients.length = 2;
           expect(parsedFn($rootScope)).toEqual("You gave some people gifts");
 
-          $rootScope.recipients.length=1;
+          $rootScope.recipients.length = 1;
           expect(parsedFn($rootScope)).toEqual("You gave one person a gift");
 
-          $rootScope.recipients.length=0;
+          $rootScope.recipients.length = 0;
           expect(parsedFn($rootScope)).toEqual("You gave no gifts");
         });
 
@@ -152,13 +152,13 @@ describe('$$ngMessageFormat', function() {
           expect(parsedFn.expressions.length).toBe(1);
           expect(parsedFn.expressions[0]).toEqual("recipients.length");
 
-          $rootScope.recipients.length=2;
+          $rootScope.recipients.length = 2;
           expect(parsedFn($rootScope)).toEqual("Harry Potter gave them a gift");
 
-          $rootScope.recipients.length=1;
+          $rootScope.recipients.length = 1;
           expect(parsedFn($rootScope)).toEqual("Harry Potter gave one gift to Alice");
 
-          $rootScope.recipients.length=0;
+          $rootScope.recipients.length = 0;
           expect(parsedFn($rootScope)).toEqual("Harry Potter gave no gifts");
         });
 
@@ -175,17 +175,17 @@ describe('$$ngMessageFormat', function() {
           expect(parsedFn.expressions.length).toBe(1);
           expect(parsedFn.expressions[0]).toEqual("recipients.length");
 
-          $rootScope.recipients.length=3;
+          $rootScope.recipients.length = 3;
           // "#" should get replaced with the value of "recipients.length - offset"
           expect(parsedFn($rootScope)).toEqual("Harry Potter gave Alice and 2 other people a gift (#=2)");
 
-          $rootScope.recipients.length=2;
+          $rootScope.recipients.length = 2;
           expect(parsedFn($rootScope)).toEqual("Harry Potter gave Alice and one other person a gift (#=1)");
 
-          $rootScope.recipients.length=1;
+          $rootScope.recipients.length = 1;
           expect(parsedFn($rootScope)).toEqual("Harry Potter gave one gift to Alice (#=0)");
 
-          $rootScope.recipients.length=0;
+          $rootScope.recipients.length = 0;
           expect(parsedFn($rootScope)).toEqual("Harry Potter gave no gifts (#=-1)");
         });
       });
diff --git a/test/ngMock/angular-mocksSpec.js b/test/ngMock/angular-mocksSpec.js
index a86c2f555003..fbec570b0a7f 100644
--- a/test/ngMock/angular-mocksSpec.js
+++ b/test/ngMock/angular-mocksSpec.js
@@ -428,7 +428,7 @@ describe('ngMock', function() {
 
       it('should delegate exception to the $exceptionHandler service', inject(
           function($interval, $exceptionHandler) {
-        $interval(function() { throw "Test Error"; }, 1000);
+        $interval(function() { throw 'Test Error'; }, 1000);
         expect($exceptionHandler.errors).toEqual([]);
 
         $interval.flush(1000);
@@ -443,7 +443,7 @@ describe('ngMock', function() {
           function($interval, $rootScope) {
         var applySpy = spyOn($rootScope, '$apply').and.callThrough();
 
-        $interval(function() { throw "Test Error"; }, 1000);
+        $interval(function() { throw new Error('Test Error'); }, 1000);
         expect(applySpy).not.toHaveBeenCalled();
 
         $interval.flush(1000);
@@ -454,7 +454,7 @@ describe('ngMock', function() {
       it('should still update the interval promise when an exception is thrown',
           inject(function($interval) {
         var log = [],
-            promise = $interval(function() { throw "Some Error"; }, 1000);
+            promise = $interval(function() { throw new Error('Some Error'); }, 1000);
 
         promise.then(function(value) { log.push('promise success: ' + value); },
                    function(err) { log.push('promise error: ' + err); },
@@ -745,7 +745,6 @@ describe('ngMock', function() {
     }));
 
     it('should serialize scope that has overridden "hasOwnProperty"', inject(function($rootScope, $sniffer) {
-      /* jshint -W001 */
       $rootScope.hasOwnProperty = 'X';
       expect(d($rootScope)).toMatch(/Scope\(.*\): \{/);
       expect(d($rootScope)).toMatch(/hasOwnProperty: "X"/);
@@ -949,7 +948,7 @@ describe('ngMock', function() {
           if (!error.stack) {
             try {
               throw error;
-            } catch (e) {}
+            } catch (e) { /* empty */}
           }
 
           return !!error.stack;
@@ -1083,6 +1082,7 @@ describe('ngMock', function() {
 
     it('should be able to handle Blobs as mock data', function() {
       if (typeof Blob !== 'undefined') {
+        // eslint-disable-next-line no-undef
         var mockBlob = new Blob(['{"foo":"bar"}'], {type: 'application/json'});
 
         hb.when('GET', '/url1').respond(200, mockBlob, {});
@@ -1834,7 +1834,7 @@ describe('ngMock', function() {
 
       it('should accept headers as function', function() {
         var exp = new MockHttpExpectation('GET', '/url', undefined, function(h) {
-          return h['Content-Type'] == 'application/json';
+          return h['Content-Type'] === 'application/json';
         });
 
         expect(exp.matchHeaders({})).toBe(false);
@@ -2067,7 +2067,7 @@ describe('ngMock', function() {
       }
     );
 
-    if (/chrome/.test(navigator.userAgent)) {
+    if (/chrome/.test(window.navigator.userAgent)) {
       it('should support assigning bindings to class-based controller', function() {
         var called = false;
         var data = [
@@ -2076,9 +2076,8 @@ describe('ngMock', function() {
           { name: 'flurp', id: 2 }
         ];
         module(function($controllerProvider) {
-          //jshint evil: true
+          // eslint-disable-next-line no-eval
           var TestCtrl = eval('(class { constructor() { called = true; } })');
-          //jshint evil: false
           $controllerProvider.register('testCtrl', TestCtrl);
         });
         inject(function($controller, $rootScope) {
diff --git a/test/ngResource/resourceSpec.js b/test/ngResource/resourceSpec.js
index f872fa42528c..40e9df6b5695 100644
--- a/test/ngResource/resourceSpec.js
+++ b/test/ngResource/resourceSpec.js
@@ -484,7 +484,7 @@ describe("basic usage", function() {
 
   it('should send correct headers', function() {
     $httpBackend.expectPUT('/CreditCard/123', undefined, function(headers) {
-      return headers['If-None-Match'] == "*";
+      return headers['If-None-Match'] === "*";
     }).respond({id:123});
 
     CreditCard.conditionalPut({id: {key:123}});
diff --git a/test/ngRoute/directive/ngViewSpec.js b/test/ngRoute/directive/ngViewSpec.js
index 9655c7d6a4e4..37ce71d33071 100644
--- a/test/ngRoute/directive/ngViewSpec.js
+++ b/test/ngRoute/directive/ngViewSpec.js
@@ -83,11 +83,12 @@ describe('ngView', function() {
 
 
     it('should instantiate controller with an alias', function() {
-      var log = [], controllerScope,
-          Ctrl = function($scope) {
-            this.name = 'alias';
-            controllerScope = $scope;
-          };
+      var log = [], controllerScope;
+
+      function Ctrl($scope) {
+        this.name = 'alias';
+        controllerScope = $scope;
+      }
 
       module(function($compileProvider, $routeProvider) {
         $routeProvider.when('/some', {templateUrl: '/tpl.html', controller: Ctrl, controllerAs: 'ctrl'});
@@ -570,10 +571,10 @@ describe('ngView', function() {
         $rootScope.$digest();
 
         angular.forEach(element.contents(), function(node) {
-          if (node.nodeType == 3 /* text node */) {
+          if (node.nodeType === 3 /* text node */) {
             expect(angular.element(node).scope()).not.toBe($route.current.scope);
             expect(angular.element(node).controller()).not.toBeDefined();
-          } else if (node.nodeType == 8 /* comment node */) {
+          } else if (node.nodeType === 8 /* comment node */) {
             expect(angular.element(node).scope()).toBe(element.scope());
             expect(angular.element(node).controller()).toBe(element.controller());
           } else {
@@ -711,7 +712,7 @@ describe('ngView', function() {
       // we need to run animation on attached elements;
       return function(_$rootElement_) {
         $rootElement = _$rootElement_;
-        body = angular.element(document.body);
+        body = angular.element(window.document.body);
       };
     }));
 
diff --git a/test/ngSanitize/sanitizeSpec.js b/test/ngSanitize/sanitizeSpec.js
index cb3bbce07aac..5794d06e17a8 100644
--- a/test/ngSanitize/sanitizeSpec.js
+++ b/test/ngSanitize/sanitizeSpec.js
@@ -313,7 +313,7 @@ describe('HTML', function() {
     beforeEach(function() {
       html = '';
       uriValidator = jasmine.createSpy('uriValidator');
-      writer = htmlSanitizeWriter({push:function(text) {html+=text;}}, uriValidator);
+      writer = htmlSanitizeWriter({push:function(text) {html += text;}}, uriValidator);
     });
 
     it('should write basic HTML', function() {
@@ -479,13 +479,13 @@ describe('HTML', function() {
     });
 
     it('should not be URI', function() {
-      /* jshint scripturl: true */
+      // eslint-disable-next-line no-script-url
       expect('javascript:alert').not.toBeValidUrl();
     });
 
     describe('javascript URLs', function() {
       it('should ignore javascript:', function() {
-        /* jshint scripturl: true */
+        // eslint-disable-next-line no-script-url
         expect('JavaScript:abc').not.toBeValidUrl();
         expect(' \n Java\n Script:abc').not.toBeValidUrl();
         expect('http://JavaScript/my.js').toBeValidUrl();
diff --git a/test/ngScenario/ApplicationSpec.js b/test/ngScenario/ApplicationSpec.js
index 46c12ca13817..a6343cea424a 100644
--- a/test/ngScenario/ApplicationSpec.js
+++ b/test/ngScenario/ApplicationSpec.js
@@ -9,16 +9,16 @@ describe('angular.scenario.Application', function() {
   }
 
   beforeEach(function() {
-    document.body.innerHTML = '';
+    window.document.body.innerHTML = '';
     frames = _jQuery("<div></div>");
-    _jQuery(document.body).append(frames);
+    _jQuery(window.document.body).append(frames);
     app = new angular.scenario.Application(frames);
   });
 
 
   afterEach(function() {
     _jQuery('iframe').off(); // cleanup any leftover onload handlers
-    document.body.innerHTML = '';
+    window.document.body.innerHTML = '';
   });
 
 
@@ -176,7 +176,7 @@ describe('angular.scenario.Application', function() {
     expect(testWindow.angular.resumeDeferredBootstrap).toBeUndefined();
     callLoadHandlers(app);
     expect(testWindow.angular.resumeDeferredBootstrap).toBeDefined();
-    expect(app.rootElement).toBeUndefined;
+    expect(app.rootElement).toBeUndefined();
     expect(injectorSpy).not.toHaveBeenCalled();
 
     var resumeBootstrapSpy = spyOn(testWindow.angular, 'resumeBootstrap').and.returnValue($injector);
diff --git a/test/ngScenario/DescribeSpec.js b/test/ngScenario/DescribeSpec.js
index 8dcc4683b24a..b911ab75031a 100644
--- a/test/ngScenario/DescribeSpec.js
+++ b/test/ngScenario/DescribeSpec.js
@@ -82,6 +82,7 @@ describe('angular.scenario.Describe', function() {
     expect(specs.length).toEqual(0);
   });
 
+
   it('should only return iit and ddescribe if present', function() {
     root.describe('A', function() {
       this.it('1', angular.noop);
diff --git a/test/ngScenario/SpecRunnerSpec.js b/test/ngScenario/SpecRunnerSpec.js
index 6a207450b5f7..2e102ae2ea98 100644
--- a/test/ngScenario/SpecRunnerSpec.js
+++ b/test/ngScenario/SpecRunnerSpec.js
@@ -94,7 +94,7 @@ describe('angular.scenario.SpecRunner', function() {
   it('should execute notify UI on spec setup error', function() {
     var finished;
     var spec = createSpec('test spec', function() {
-      throw 'message';
+      throw new Error('message');
     });
     runner.run(spec, function() {
       finished = true;
@@ -130,7 +130,7 @@ describe('angular.scenario.SpecRunner', function() {
     var finished;
     var spec = createSpec('test spec', function() {
       this.addFuture('test future', function(done) {
-        throw 'error message';
+        throw new Error('error message');
       });
     });
     runner.run(spec, function() {
@@ -150,7 +150,7 @@ describe('angular.scenario.SpecRunner', function() {
     var finished, after;
     var spec = createSpec('test spec', function() {
       this.addFuture('body', function(done) {
-        throw 'error message';
+        throw new Error('error message');
       });
     });
     spec.after = function() {
diff --git a/test/ngScenario/e2e/.eslintrc.json b/test/ngScenario/e2e/.eslintrc.json
new file mode 100644
index 000000000000..8df3459845a9
--- /dev/null
+++ b/test/ngScenario/e2e/.eslintrc.json
@@ -0,0 +1,9 @@
+{
+  "root": true,
+  "extends": "../../../.eslintrc-node.json",
+
+  "env": {
+    "jasmine": true,
+    "protractor": true
+  }
+}
diff --git a/test/ngScenario/e2e/widgets-scenario.js b/test/ngScenario/e2e/widgets-scenario.js
index 764347284f61..3d7a3e383645 100644
--- a/test/ngScenario/e2e/widgets-scenario.js
+++ b/test/ngScenario/e2e/widgets-scenario.js
@@ -53,6 +53,7 @@ describe('widgets', function() {
      * Custom value parser for futures.
      */
     function checkboxParser(value) {
+      // eslint-disable-next-line no-undef
       return angular.fromJson(value.substring(value.indexOf('=') + 1));
     }
 
diff --git a/test/ngScenario/output/HtmlSpec.js b/test/ngScenario/output/HtmlSpec.js
index e5d6e9e78d42..295fa45eaa54 100644
--- a/test/ngScenario/output/HtmlSpec.js
+++ b/test/ngScenario/output/HtmlSpec.js
@@ -53,7 +53,7 @@ describe('angular.scenario.output.html', function() {
 
   it('should update totals when steps complete', function() {
     // Failure
-    for (var i=0; i < 3; ++i) {
+    for (var i = 0; i < 3; ++i) {
       runner.emit('SpecBegin', spec);
       runner.emit('StepBegin', spec, step);
       runner.emit('StepFailure', spec, step, 'error');
diff --git a/test/ngTouch/directive/ngClickSpec.js b/test/ngTouch/directive/ngClickSpec.js
index dc453cd83345..9e11f8e0c9c8 100644
--- a/test/ngTouch/directive/ngClickSpec.js
+++ b/test/ngTouch/directive/ngClickSpec.js
@@ -6,7 +6,7 @@ describe('ngClick (touch)', function() {
   // TODO(braden): Once we have other touch-friendly browsers on CI, allow them here.
   // Currently Firefox and IE refuse to fire touch events.
   // Enable iPhone for manual testing.
-  if (!/chrome|iphone/i.test(navigator.userAgent)) {
+  if (!/chrome|iphone/i.test(window.navigator.userAgent)) {
     return;
   }
 
diff --git a/test/ngTouch/directive/ngSwipeSpec.js b/test/ngTouch/directive/ngSwipeSpec.js
index 24ad0d76dc20..1f2b7440dd83 100644
--- a/test/ngTouch/directive/ngSwipeSpec.js
+++ b/test/ngTouch/directive/ngSwipeSpec.js
@@ -8,7 +8,7 @@ var swipeTests = function(description, restrictBrowsers, startEvent, moveEvent,
     if (restrictBrowsers) {
       // TODO(braden): Once we have other touch-friendly browsers on CI, allow them here.
       // Currently Firefox and IE refuse to fire touch events.
-      var chrome = /chrome/.test(navigator.userAgent.toLowerCase());
+      var chrome = /chrome/.test(window.navigator.userAgent.toLowerCase());
       if (!chrome) {
         return;
       }
diff --git a/test/ngTouch/swipeSpec.js b/test/ngTouch/swipeSpec.js
index 5d3bf5b67ecd..790594e20197 100644
--- a/test/ngTouch/swipeSpec.js
+++ b/test/ngTouch/swipeSpec.js
@@ -90,7 +90,7 @@ describe('$swipe', function() {
         // TODO(braden): Once we have other touch-friendly browsers on CI, allow them here.
         // Currently Firefox and IE refuse to fire touch events.
         // Enable iPhone for manual testing.
-        if (!/chrome|iphone/i.test(navigator.userAgent)) {
+        if (!/chrome|iphone/i.test(window.navigator.userAgent)) {
           return;
         }
       }
diff --git a/validate-commit-msg.js b/validate-commit-msg.js
index f0c23fda950a..d65345b35642 100755
--- a/validate-commit-msg.js
+++ b/validate-commit-msg.js
@@ -16,8 +16,8 @@ var util = require('util');
 
 
 var MAX_LENGTH = 100;
-var PATTERN = /^(?:fixup!\s*)?(\w*)(\(([\w\$\.\*/-]*)\))?\: (.*)$/;
-var IGNORED = /^WIP\:/;
+var PATTERN = /^(?:fixup!\s*)?(\w*)(\(([\w\$\.\*/-]*)\))?: (.*)$/;
+var IGNORED = /^WIP:/;
 var TYPES = {
   feat: true,
   fix: true,
@@ -60,8 +60,6 @@ var validateMessage = function(message) {
   }
 
   var type = match[1];
-  var scope = match[3];
-  var subject = match[4];
 
   if (!TYPES.hasOwnProperty(type)) {
     error('"%s" is not allowed type !', type);
@@ -96,6 +94,10 @@ if (process.argv.join('').indexOf('jasmine-node') === -1) {
   var incorrectLogFile = commitMsgFile.replace('COMMIT_EDITMSG', 'logs/incorrect-commit-msgs');
 
   fs.readFile(commitMsgFile, function(err, buffer) {
+    if (err) {
+      console.error(err);
+      process.exit(1);
+    }
     var msg = firstLineFromBuffer(buffer);
 
     if (!validateMessage(msg)) {
diff --git a/validate-commit-msg.spec.js b/validate-commit-msg.spec.js
index 968ee048fd72..a00102174b5b 100644
--- a/validate-commit-msg.spec.js
+++ b/validate-commit-msg.spec.js
@@ -14,10 +14,12 @@ describe('validate-commit-msg.js', function() {
     logs.length = 0;
 
     spyOn(console, 'error').andCallFake(function(msg) {
+      // eslint-disable-next-line no-control-regex
       errors.push(msg.replace(/\x1B\[\d+m/g, '')); // uncolor
     });
 
     spyOn(console, 'log').andCallFake(function(msg) {
+      // eslint-disable-next-line no-control-regex
       logs.push(msg.replace(/\x1B\[\d+m/g, '')); // uncolor
     });
   });
